/*
 * UpdateDatabase.java
 *
 * Created on November 25, 2002, 11:33 AM
 */

/**
 *
 * @author  sof
 */

import apostal.toma.database.*;
import apostal.toma.data.*;
import apostal.toma.view.*;

import java.util.Vector;
import java.util.Iterator;

import toolbox.sql.SQLTools;

import javax.swing.*;

public class UpdateDatabase {

    private final static int NOSERVER = 0;
    private final static int SERVER = 1;

    public static void printUsageAndExit() {
        System.out.println("UpdateDatabase [server] (default: no server)");
        System.exit(1);
    }

    /**
     * when run with no argument, we consider we are in a local TOMA installation (client or singlestation).
     * when we give the "server" argument, we consider we are run from the server installation
     *
     **/
    public static void main(String argv[]) {
        /*if(argv.length<1 || argv[0]==null || argv[0].equals(""))
        {
            UpdateDatabase.printUsageAndExit();
        }
        else
        {*/
        int type = UpdateDatabase.NOSERVER;
        if (argv.length > 0 && argv[0].equals("server"))
            type = UpdateDatabase.SERVER;

        //load database
        TOMADatabase db = null;
        if (type == 0) {
            TOMAParameters params = new TOMAParameters();
            params.loadOnlyClientServerData();
            db = TOMADatabase.getInstance();
        } else if (type == 1)
            db = TOMADatabase.getInstance(true);
        else
            UpdateDatabase.printUsageAndExit();

        //modifiy
        if (db != null) {
            UpdateDatabase update = new UpdateDatabase(db);
            update.update();
        } else
            System.out.println("database not found!");
        //}
    }

    private TOMADatabase db;

    public UpdateDatabase(TOMADatabase db) {
        this.db = db;
    }

    public void update() {
        Vector trainings = null;
        boolean roll = false;
        try {
            String initialName = "Organization - Gestion d'entreprise";
            String newName = "Organisation - Gestion d'entreprise";
            this.updateDomainName(initialName, newName, "fra");

            initialName = "Mode, Hygine";
            newName = "Mode";
            this.updateDomainName(initialName, newName, "fra");
            initialName = "Berufe im Bereich Mode, Gesundheit und Hygiene";
            newName = "Mode";
            this.updateDomainName(initialName, newName, "deu");
            initialName = "Careers in fashion, health and hygiene";
            newName = "Fashion";
            this.updateDomainName(initialName, newName, "eng");

            int id = this.removeSuperDomain("Droit", "fra");
            this.updateDomainName("Droit", "Droit - Fiscalit", "fra");
            this.updateDomainName("Recht", "Recht - Besteuerung", "deu");
            this.updateDomainName("Law", "Law - Taxation", "eng");
            if (id > -1) {
                this.createNewDomain(id, "Droit des affaires", "Business law", "Wirtschaftsrecht");
                this.createNewDomain(id, "Droit priv", "Private law", "Privatrecht");
                this.createNewDomain(id, "Droit public", "Public law", "ffentliches Recht");
                this.createNewDomain(id, "Fiscalit des entreprises", "Corporate taxation", "Unternehmensbesteuerung");
                this.createNewDomain(id, "Fiscalit internationale", "International taxation", "Internationale Besteuerung");
                this.createNewDomain(id, "Fiscalit des personnes", "Individual taxation", "Personen Besteuerung");
            } else
                System.out.println("super domain from 'Droit' was not removed");

            id = this.getDomainByName("Comptabilit - Gestion financire", "fra");
            if (id > -1)
                this.createNewDomain(id, "Audit", "Audit", "Rechnungsprfung");
            else
                System.out.println("domain 'Comptabilit - Gestion financire' not found");

            id = this.getDomainByName("Banque - Assurance", "fra");
            if (id > -1)
                this.createNewDomain(id, "Fonds d'investissements", "Investment funds", "Wertpapieranlage");
            else
                System.out.println("domain 'Banque - Assurance' not found");

            id = this.getDomainByName("Langues", "fra");
            if (id > -1) {
                this.createNewDomain(id, "Danois", "Danish", "Dnish");
                this.createNewDomain(id, "Grec moderne", "Greek, Modern", "Griechisch");
                this.createNewDomain(id, "Finnois", "Finnish", "Finnisch");
                this.createNewDomain(id, "Sudois", "Swedish", "Schwedisch");
                this.createNewDomain(id, "Norvgien", "Norwegian", "Norwegisch");
                this.createNewDomain(id, "Polonais", "Polish", "Polnisch");
                this.createNewDomain(id, "Hongrois", "Hungarian", "Ungarisch");
                this.createNewDomain(id, "Tchque", "Czech", "Tschechisch");
                this.createNewDomain(id, "Japonais", "Japanese", "Japanisch");
                this.createNewDomain(id, "Russe", "Russian", "Russisch");
                this.createNewDomain(id, "Latin", "Latin", "Lateinisch");
                this.createNewDomain(id, "Arabe", "Arabic", "Arabisch");
                // ajout du chinois (24/09/2003)
                this.createNewDomain(id, "Chinois", "Chinese", "Chinesisch");

            } else
                System.out.println("domain 'Langues' not found");

            this.removeDomain("Boulangerie - Ptisserie", "fra", "Ptisserie - Confiserie", "fra");
            id = this.updateDomainName("Ptisserie - Confiserie", "Boulangerie - Ptisserie - Confiserie", "fra");
            this.updateDomainName("Konditorei", "Bckerei - Konditorei", "deu");
            //this.updateDomainName("", "Bakery - Confectioner's", "eng");
            //didn't exist?
            if (this.getDomainByName("Bakery - Confectioner's", "eng") < 0)
                this.createNewDomainName(id, "Bakery - Confectioner's", "eng");

            /* Update du 24-09-2003 */

            id = this.getDomainByName("Alimentation - HORECA", "fra");
            if (id > -1)
                this.createNewDomain(id, "Hygine - HACCP", "Hygiene - HACCP", "Hygiene - HACCP");
            else
                System.out.println("domain 'Alimentation-HORECA' not found");

            id = this.getDomainByName("Droit - Fiscalit", "fra");
            if (id > -1) {
                this.createNewDomain(id, "Droit europen", "European law", "Europisches Recht");
                this.createNewDomain(id, "Economie", "Economics", "Wirtschaft");

            } else
                System.out.println("domain 'Droit - Fiscalit' not found");

            id = this.createNewSuperDomain("Techniques industrielles", "Industrial Techniques", "Industrielle Techniken");
            if (id > -1) {
                this.createNewDomain(id, "Hydraulique - pneumatique", "Hydraulics - Pneumatics", "Hydraulik - Pneumatik");
                this.createNewDomain(id, "Soudage", "Welding", "Schweissen");
            }

            id = this.createNewSuperDomain("Arts et loisirs", "Arts and leisure", "Kunst und Freizeit");
            if (id > -1) {
                this.createNewDomain(id, "Littrature", "Literature", "Literatur");
                this.createNewDomain(id, "Musique", "Music", "Musik");
                this.createNewDomain(id, "Dessin - Peinture", "Drawing  Painting", "Zeichnen und Malen");
                this.createNewDomain(id, "Histoire de l'art", "History of art", "Kunstgeschichte");
                this.createNewDomain(id, "Arts plastiques", "Plastic arts", "Bildende Kunst");
                this.createNewDomain(id, "Photographie", "Photography", "Fotografie");
                this.createNewDomain(id, "Dcoration", "Decoration", "Dekoration");
                this.createNewDomain(id, "Dcouverte de cultures", "Discovery of cultures", "Fremde Kulturen");
                this.createNewDomain(id, "Activits sportives", "Sports", "Sportliche Aktivitten");
            }

            id = this.createNewSuperDomain("Education diffrencie", "Education for disabled", "Lernbehinderte");
            id = this.createNewSuperDomain("Alphabtisation", "Elimination of illiteracy", "Alphabetisierung");

            trainings = this.removeDomain("Formations gnrales", "fra");

        } catch (Exception ex) {
            roll = true;
            db.setRollbackTrue();
            ex.printStackTrace();
        }
        db.closeConnection();
        String titleFrame = "Resultat de l'update";
        String message = "La mise  jour a bien fonctionn<br/>";
        if (trainings != null && !trainings.isEmpty()) {
            message += "<br/>Les formations suivantes se trouvaient dans un domaine qui a t effac : <br/><br/>";
            Iterator it = trainings.iterator();
            while (it.hasNext()) {
                String t = (String) it.next();
                message += t + "<br/>";
            }
        }
        if (!roll){
            UpdateResultView question = new UpdateResultView(titleFrame, message);
            question.show();
        }
    }

    public int createNewDomain(int idSuperDomain, String frenchName, String englishName, String germanName) {
        int id = -1;
        //get the nbOrder: last nbOrder with same idSuperDomain + 1
        RequeteSelect rs1 = new RequeteSelect(true, db, "max(nbOrder)", "domain", "idSuperDomain='" + new Integer(idSuperDomain) + "'");
        int max = -1;
        if (rs1.next())
            max = rs1.getInt(1);
        rs1.close();
        int nbOrder = max + 1;

        id = this.getSubDomainByName(frenchName, "fra", idSuperDomain);
        if (id < 0) {
            Object values[][] = new Object[2][2];
            values[0][0] = "idSuperDomain";
            values[0][1] = new Integer(idSuperDomain);
            values[1][0] = "nbOrder";
            values[1][1] = new Integer(nbOrder);
            RequeteInsert insert = new RequeteInsert(db, "domain", values);
            insert.close();

            //get the domain created
            String[][] where = new String[2][3];
            where[0][0] = (new Integer(idSuperDomain)).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSuperDomain";
            where[1][0] = (new Integer(nbOrder)).toString();
            where[1][1] = "Integer";
            where[1][2] = "nbOrder";
            RequeteSelectWhere rs = new RequeteSelectWhere(db, "domain", where);
            if (rs.next()) {
                id = rs.getInt("idDomain");
                System.out.println("The domain " + englishName + " was created");
            } else
                System.out.println("There was a problem to create the domain " + englishName);
            rs.close();

            if (id > -1) {
                //put the domain names
                Object values_fra[][] = new Object[3][2];
                values_fra[0][0] = "idDomain";
                values_fra[0][1] = new Integer(id);
                values_fra[1][0] = "languageCode";
                values_fra[1][1] = "fra";
                values_fra[2][0] = "name";
                values_fra[2][1] = frenchName;
                insert = new RequeteInsert(db, "domainName", values_fra);
                insert.close();
                Object values_eng[][] = new Object[3][2];
                values_eng[0][0] = "idDomain";
                values_eng[0][1] = new Integer(id);
                values_eng[1][0] = "languageCode";
                values_eng[1][1] = "eng";
                values_eng[2][0] = "name";
                values_eng[2][1] = englishName;
                insert = new RequeteInsert(db, "domainName", values_eng);
                insert.close();
                Object values_deu[][] = new Object[3][2];
                values_deu[0][0] = "idDomain";
                values_deu[0][1] = new Integer(id);
                values_deu[1][0] = "languageCode";
                values_deu[1][1] = "deu";
                values_deu[2][0] = "name";
                values_deu[2][1] = germanName;
                insert = new RequeteInsert(db, "domainName", values_deu);
                insert.close();
            }
        } else {
            System.out.println("The domain " + englishName + " already exists");
        }

        return id;
    }

    public int createNewSuperDomain(String frenchName, String englishName, String germanName) {
        int id = -1;

        //get the nbOrder: last nbOrder of superDomains
        RequeteSelect rs1 = new RequeteSelect(true, db, "max(nbOrder)", "domain", "idSuperDomain<0");
        int max = -1;
        if (rs1.next())
            max = rs1.getInt(1);
        rs1.close();
        int nbOrder = max + 1;

        id = this.getDomainByName(frenchName, "fra");
        if (id < 0) {
            Object values[][] = new Object[2][2];
            values[0][0] = "idSuperDomain";
            values[0][1] = null;
            values[1][0] = "nbOrder";
            values[1][1] = new Integer(nbOrder);
            RequeteInsert insert = new RequeteInsert(db, "domain", values);
            insert.close();
            //get the domain created
            RequeteSelect rs = new RequeteSelect(db, "domain", "idSuperDomain<0 AND nbOrder=" + nbOrder);
            if (rs.next()) {
                id = rs.getInt("idDomain");
                System.out.println("The domain " + englishName + " was created");
            } else
                System.out.println("There was a problem to create the domain " + englishName);
            rs.close();
            if (id > -1) {
                //put the domain names
                Object values_fra[][] = new Object[3][2];
                values_fra[0][0] = "idDomain";
                values_fra[0][1] = new Integer(id);
                values_fra[1][0] = "languageCode";
                values_fra[1][1] = "fra";
                values_fra[2][0] = "name";
                values_fra[2][1] = frenchName;
                insert = new RequeteInsert(db, "domainName", values_fra);
                insert.close();
                Object values_eng[][] = new Object[3][2];
                values_eng[0][0] = "idDomain";
                values_eng[0][1] = new Integer(id);
                values_eng[1][0] = "languageCode";
                values_eng[1][1] = "eng";
                values_eng[2][0] = "name";
                values_eng[2][1] = englishName;
                insert = new RequeteInsert(db, "domainName", values_eng);
                insert.close();
                Object values_deu[][] = new Object[3][2];
                values_deu[0][0] = "idDomain";
                values_deu[0][1] = new Integer(id);
                values_deu[1][0] = "languageCode";
                values_deu[1][1] = "deu";
                values_deu[2][0] = "name";
                values_deu[2][1] = germanName;
                insert = new RequeteInsert(db, "domainName", values_deu);
                insert.close();
            }
        } else {
            System.out.println("The domain " + englishName + " already exists");
        }

        return id;
    }

    public void createNewDomainName(int idDomain, String name, String languageCode) {

        Object values[][] = new Object[3][2];
        values[0][0] = "idDomain";
        values[0][1] = new Integer(idDomain);
        values[1][0] = "languageCode";
        values[1][1] = languageCode;
        values[2][0] = "name";
        values[2][1] = name;

        RequeteInsert ri = new RequeteInsert(db, "domainName", values);
        ri.close();
    }

    public int updateDomainName(String initialName, String newName, String languageCode) {
        Domain d = new Domain();
        d.setName(initialName);
        DomainDB ddb = new DomainDB(d);
        Language lng = new Language(languageCode);
        boolean loaded = ddb.loadByName(lng);
        if (!loaded)
            System.out.println("Update Domain: no such domain: " + initialName);
        else {
            System.out.println("Update Domain: domain found: " + newName);

            String where[][] = new String[2][3];
            where[0][0] = (new Integer(d.getIdDomain())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idDomain";
            where[1][0] = languageCode;
            where[1][1] = "String";
            where[1][2] = "languageCode";

            Object values[][] = new Object[1][2];
            values[0][0] = "name";
            values[0][1] = newName;

            RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "domainName", values, where);
            ru.close();
        }

        return d.getIdDomain();
    }

    public int removeSuperDomain(String domainName, String languageCode) {
        int id = -1;
        Domain d = new Domain();
        d.setName(domainName);
        DomainDB ddb = new DomainDB(d);
        Language lng = new Language(languageCode);
        boolean loaded = ddb.loadByName(lng);
        if (!loaded)
            System.out.println("Update Domain: no such domain: " + domainName);
        else {
            System.out.println("Update Domain: domain found: " + domainName);

            id = d.getIdDomain();
            String where[][] = new String[1][3];
            where[0][0] = (new Integer(id)).toString();
            where[0][1] = "Integer";
            where[0][2] = "idDomain";

            Object values[][] = new Object[1][2];
            values[0][0] = "idSuperDomain";
            values[0][1] = null;

            RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "domain", values, where);
            ru.close();
        }
        return id;
    }

    public int getDomainByName(String domainName, String languageCode) {
        int id = -1;
        Domain d = new Domain();
        d.setName(domainName);
        DomainDB ddb = new DomainDB(d);
        Language lng = new Language(languageCode);
        boolean loaded = ddb.loadByName(lng);
        if (!loaded)
            System.out.println("Update Domain: no such domain: " + domainName);
        else {
            System.out.println("Update Domain: domain found: " + domainName);

            id = d.getIdDomain();
        }
        return id;
    }

    public int getSubDomainByName(String domainName, String languageCode, int idSuperDomain) {
        int id = -1;
        String dom = SQLTools.escape(domainName);
        String sql = "name='" + dom + "' AND languageCode='" + languageCode + "'";
        sql += " AND EXISTS (SELECT 1 FROM domain WHERE domain.idDomain=domainName.idDomain AND idSuperDomain=" + idSuperDomain + ")";
        RequeteSelect rs = new RequeteSelect(db, "domainName", sql);
        if (rs.next()) {
            id = rs.getInt("idDomain");
        }
        rs.close();
        return id;
    }

    /**
     * deletes a domain, and put all the trainings that were in it in the other domain given
     **/
    public void removeDomain(String domainName, String languageCode, String newDomainName, String newDomainLanguageCode) {
        int oldId = this.getDomainByName(domainName, languageCode);
        int newId = this.getDomainByName(newDomainName, newDomainLanguageCode);

        if (oldId > -1) {
            if (newId > -1) {
                //change all the trainings that were in this domain in the new domain
                Object[][] values = new Object[1][2];
                values[0][0] = "idDomain";
                values[0][1] = new Integer(newId);
                RequeteUpdate ru = new RequeteUpdate(db, "trainingDomain", values, "idDomain", new Integer(oldId));
                ru.close();
            } else {
                System.out.println("new domain doesn't exist: " + newDomainName + ": deleting trainingDomain for domain " + domainName);
                RequeteDelete rd = new RequeteDelete(db, "trainingDomain", "idDomain", new Integer(oldId));
                rd.close();
            }

            //remove the domain
            RequeteDelete rd = new RequeteDelete(db, "domainName", "idDomain", new Integer(oldId));
            rd.close();
            rd = new RequeteDelete(db, "domain", "idDomain", new Integer(oldId));
            rd.close();
        } else if (oldId == -1)
            System.out.println("old domain " + domainName + " not found");
    }

    public Vector removeDomain(String domainName, String languageCode) {
        Vector trainings = new Vector();
        int id = this.getDomainByName(domainName, languageCode);
        if (id > -1) {
            RequeteSelect rs = new RequeteSelect(db, "domain", "idSuperDomain='" + id + "'");
            while (rs.next()) {
                int idSubDomain = rs.getInt("idDomain");
                Vector temp = this.changeTrainingDomain(id, idSubDomain, languageCode);
                if (!temp.isEmpty()) {
                    trainings.addAll(temp);
                }
                RequeteDelete rdSub = new RequeteDelete(db, "domainName", "idDomain", new Integer(idSubDomain));
                rdSub.close();
                rdSub = new RequeteDelete(db, "domain", "idDomain", new Integer(idSubDomain));
                rdSub.close();
            }
            rs.close();

            // get Trainings in the removed domain
            rs = new RequeteSelect(db, "trainingDomain", "idDomain='" + id + "'");
            while (rs.next()) {
                int idTraining = rs.getInt("idTraining");
                Training t = TrainingDB.getInstance(new Language(languageCode), false, idTraining);
                String msg = t.getTitle() + " (" + t.getCode()+") dans le domaine \"" + domainName +"\"";
                trainings.add(msg);
            }
            rs.close();
            //remove the domain
            RequeteDelete rd = new RequeteDelete(db, "trainingDomain", "idDomain", new Integer(id));
            rd.close();
            rd = new RequeteDelete(db, "domainName", "idDomain", new Integer(id));
            rd.close();
            rd = new RequeteDelete(db, "domain", "idDomain", new Integer(id));
            rd.close();
        }
        return trainings;
    }

    public String getDomainName(int idDomain, String languageCode) {
        String name = "";
        String[][] where2 = new String[2][3];
        where2[0][0] = (new Integer(idDomain)).toString();
        where2[0][1] = "Integer";
        where2[0][2] = "idDomain";
        where2[1][0] = languageCode;
        where2[1][1] = "String";
        where2[1][2] = "languageCode";
        RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "domainName", where2);
        if (rs2.next()) {
            name = rs2.getString("name");
        }
        rs2.close();
        return name;
    }

    public Vector changeTrainingDomain(int idSuperDomain, int idOldDomain, String languadeCode) {
        Vector messages = new Vector();
        String oldDomain = this.getDomainName(idOldDomain, languadeCode);
        RequeteSelect rs = new RequeteSelect(db, "domainName", "Name='" + oldDomain + "' AND LanguageCode='" + languadeCode + "' AND idDomain<>" + idOldDomain);
        if (rs.next()) {
            int idNewDomain = rs.getInt("idDomain");
            int idSupDom = -1;
            RequeteSelect rs1 = new RequeteSelect(db, "domain", "idDomain", new Integer(idNewDomain));
            if (rs1.next()) {
                idSupDom = rs1.getNullableInt("idSuperDomain");
            }
            rs1.close();
            rs1 = new RequeteSelect(db, "trainingDomain", "idDomain", new Integer(idOldDomain));
            Object[][] values = new Object[1][2];
            while (rs1.next()) {
                if (idSupDom > -1) {
                    String[][] where2 = new String[2][3];
                    where2[0][0] = (new Integer(idSuperDomain)).toString();
                    where2[0][1] = "Integer";
                    where2[0][2] = "idDomain";
                    where2[1][0] = (new Integer(rs1.getInt("idTraining"))).toString();
                    where2[1][1] = "Integer";
                    where2[1][2] = "idTraining";

                    values[0][0] = "idDomain";
                    values[0][1] = new Integer(idSupDom);
                    RequeteUpdateWhere ruW = new RequeteUpdateWhere(db, "trainingDomain", values, where2);
                    ruW.close();
                }
            }
            rs1.close();

            values[0][0] = "idDomain";
            values[0][1] = new Integer(idNewDomain);

            RequeteUpdate ru = new RequeteUpdate(db, "trainingDomain", values, "idDomain", new Integer(idOldDomain));
            ru.close();

        } else {
            String oldSuperDomain = this.getDomainName(idSuperDomain, languadeCode);
            RequeteSelect rs2 = new RequeteSelect(db, "trainingDomain", "idDomain", new Integer(idOldDomain));
            while (rs2.next()) {
                int idTraining = rs2.getInt("idTraining");
                Training t = TrainingDB.getInstance(new Language(languadeCode), false, idTraining);
                String msg = t.getTitle() + " (" + t.getCode()+") dans le domaine \"" + oldSuperDomain + "\\" + oldDomain +"\"";
                messages.add(msg);
            }
            rs2.close();
            RequeteDelete rd = new RequeteDelete(db, "trainingDomain", "idDomain", new Integer(idOldDomain));
            rd.close();

        }
        rs.close();
        return messages;
    }

}
