// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma;


import apostal.toma.data.Language;
import apostal.toma.data.TOMAConstants;
import apostal.toma.data.TOMAParameters;
import apostal.toma.data.TOMATemplate;
import apostal.toma.database.*;
import apostal.toma.view.TOMAFirstRun;
import apostal.toma.view.TOMAUI;
import apostal.toma.view.TOMAView;
import apostal.toma.viewcontrol.TOMAEventHandler;
import toolbox.util.QuickSort;
import toolbox.util.ToStringComparator;

import java.io.BufferedWriter;
import java.io.PrintWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.text.SimpleDateFormat;
import java.util.Properties;
import java.util.Vector;
import java.util.Iterator;

/**
 * this class is the main class of the TOMA program.
 * It is a singleton, because we want only one TOMA application in a same JVM.
 * It is also a singleton factory for the "TOMAView" class, which is the main graphical class.
 */
public class TOMA {

    /************* static ******************/

    /** tuning **/
    /*private static java.util.Date initialDate;

    public static void printTime(String message)
    {
      java.util.Date d=new java.util.Date();
      long time=d.getTime()-TOMA.initialDate.getTime();
      TOMA.log(TOMA.WARNING, "when "+message+": "+new java.lang.Long(time));
    }*/


    /* log user */
    /*public static final int NONE = 0;
    public static final int SEVERE = 1;
    public static final int INFO = 2;
    public static final int WARNING = 3;*/

    private static TOMA instance;

    public static int ALL = 1;
    public static int CONFIG = 2;
    public static int FINE = 3;
    public static int FINER = 4;
    public static int FINEST = 5;
    public static int INFO = 6;
    public static int OFF = 7;
    public static int SEVERE = 8;
    public static int WARNING = 9;

    private static File log;
    private static BufferedWriter fout;
    private static PrintWriter pout;

    static {
        try {
            //file
            log = File.createTempFile("tomalog", ".log", new File(System.getProperty("user.home"))); // DN
            FileWriter writer = new FileWriter(log);
            fout = new BufferedWriter(writer);
	    pout=new PrintWriter(writer);

        } catch (java.io.IOException ex) {

            ex.printStackTrace();
        }
    }


    public static void log(int i, String message) {
        try {
            java.util.Date now = new java.util.Date();
            SimpleDateFormat formater =  new SimpleDateFormat("dd MMM yyyy 'at' HH:mm:ss");
            String mes = new String(formater.format(now));
            if (i==TOMA.WARNING) {
                mes += " WARNING : ";
            } else if (i==TOMA.INFO) {
                mes += " INFO : ";
            } else {
               mes += " SEVERE : ";
            }
            mes += message;
            fout.write(mes);
            fout.newLine();
            fout.flush();
        } catch (java.io.IOException ex) {
            ex.printStackTrace();
        }
    }
    public static void log(Exception ex){

	    log(TOMA.SEVERE, "exception: "+ex.getClass().getName()+", message="+ex.getMessage());
	    ex.printStackTrace(pout);
	    pout.flush();
    }
    public static void log(int i, Vector v){
        if(v!=null){
            Iterator it=v.iterator();
            while(it.hasNext()){
                String msg=(String) it.next();
                TOMA.log(i, msg);
            }
        }
    }


    public static void main(String[] argv) {
//UI
        TOMAUI ui = new TOMAUI();
        ui.setUI();

//vrifier que ce n'est pas le "firstRun"
        try {
            Properties firstRunProps = new Properties();
            FileInputStream fin = new FileInputStream(TOMAConstants.parametersFile);
            firstRunProps.load(fin);

            fin.close();

            String myType = (String) firstRunProps.get("firstRunType");

            if (myType == null || myType.equals("")) {
//lancement normal de TOMA
                TOMA toma = TOMA.getInstance();
                TOMAView view = toma.openTomaView();
            } else {
//first run
                TOMAFirstRun f = new TOMAFirstRun();
            }

        } catch (Exception ex) {
        }
    }

    public static TOMA getInstance() {
        if (instance == null) {
            instance = new apostal.toma.TOMA();
        }
        return instance;
    }

    /************ non static *****************/

    private TOMAView tomaView;
    private TOMAEventHandler handler;
    private TOMAParameters tomaParameters;
    private TOMATemplate tomaTemplate;

/* on charge toutes les listes fixes dans la BD,
pour pas avoir  le refaire sur chaque cran ou elles servent*/
    private Vector countries;
    private Vector languages;
    private Vector domains;
    private Vector levels;
    private Vector slots;
    private Vector moos;

    protected TOMA() {
        tomaParameters = new TOMAParameters();
        tomaParameters.load();

//charger les listes constantes
        Language lng = tomaParameters.getLanguage();
        if (tomaParameters.isUsingProxy()) {
            System.setProperty("proxySet", "true");
            System.setProperty("proxyHost",tomaParameters.getProxyHost());
            System.setProperty("proxyPort",tomaParameters.getProxyPort());
        }
        ToStringComparator comp = new ToStringComparator();
        QuickSort sort = new QuickSort(comp);

        countries = CountryDB.load(lng);
        countries = sort.qsort(countries);

        languages = LanguageDB.load(lng);
        languages = sort.qsort(languages);

        domains = DomainDB.loadFirstLevel(lng);
        domains = sort.qsort(domains);

        levels = LevelDB.load(lng);
        levels = sort.qsort(levels);

        slots = SlotDB.load(lng);

        moos = ModeOfOrganizationDB.load(lng);
        moos = sort.qsort(moos);
    }

    public Vector getCountries() {
        return countries;
    }

    public Vector getLanguages() {
        return languages;
    }

    public Vector getDomains() {
        return domains;
    }

    public Vector getLevels() {
        return levels;
    }

    public Vector getSlots() {
        return slots;
    }

    public Vector getMoos() {
        return moos;
    }


    public TOMAEventHandler getHandler() {
        return handler;
    }

    public TOMAView openTomaView() {
        handler = new TOMAEventHandler();

        handler.unlock();

        tomaView = handler.openTOMAView();
        return tomaView;
    }

    public TOMAView getTomaView() {
        return tomaView;
    }

    public TOMATemplate getTomaTemplate() {
        if (tomaTemplate == null) {
            TOMAEventHandler myhandler = new TOMAEventHandler();
            this.tomaTemplate = myhandler.openTemplate();
        }

        return tomaTemplate;
    }

    public TOMAParameters getTomaParameters() {
        return tomaParameters;
    }
}
