// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
//      - XML (in the "TED" format, "Training Exchange Definition",
//                      http://binux.tudor.lu:8080/XML/ted.xsd)
//      - PDF
//      - RTF
//      - HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
//      Address:    CRP Henri Tudor
//                      6 rue Coudenhove-Kalergi
//                      L - 1359 Luxembourg
//      Email:          toma@tudor.lu

package apostal.toma;

import apostal.toma.external.*;
import java.util.Vector;


import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

public class TOMADeleteServerTrainings
{
    public static void main(String argv[]){
		if(argv.length>2){
			TOMADeleteServerTrainings delete=new TOMADeleteServerTrainings(argv[0], argv[1], argv[2]);
			delete.deleteAll();
		}
		else
			System.out.println("Usage: TOMADeleteServerTrainings login password propertiesFile");
	}
	
	private String _propertiesFile;
	private String _login;
	private String _password;
	
	private Vector callParameters;
	private SOAPClient client;
	
	private TOMADeleteServerTrainings(String login, String password, String propertiesFile){
		this._propertiesFile=propertiesFile;
		this._login=login;
		this._password=password;
		
		this.preparePublication();
	}
	
	public void preparePublication()
	{
		//read the properties file
		String url=null;
		String target=null;
		String method=null;
		String soapAction=null;
	      DocumentBuilder docBuilder = null;
        	try {
			
            DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
            docBuilder = docBuilderFactory.newDocumentBuilder();
            Document doc = docBuilder.parse(_propertiesFile);
            doc.getDocumentElement().normalize();
            
            Element webServices=doc.getDocumentElement();
            if(webServices!=null)
            {
            	NodeList list=webServices.getElementsByTagName("DeleteAllWebService");
            	if(list!=null && list.getLength()>0)
            	{
		            Element encodingWebService=(Element) list.item(0);
    		                               
		            if(encodingWebService!=null)
        		    {
            			url=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "URL");
		            	target=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Target");
        		    	method=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Method");                        
						soapAction=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "SOAPAction");
						
                        //get parameters
                        Element paramsEl=XMLHelper.getSingleElementByTagName(encodingWebService, "CallParameters");
                        if(paramsEl!=null){                            
                            //get the parameters
                            callParameters=new Vector();
                            NodeList params=paramsEl.getChildNodes();
                            int nb=params.getLength();
                            for(int i=0;i<nb;i++){
                                Node n=params.item(i);
                                if(n.getNodeType()==Node.ELEMENT_NODE){
                                    SOAPCallParameter param=new SOAPCallParameter((Element) n);
                                    callParameters.add(param);
                                }
                            }
                        }
		            }            
            	}
            }
        }
        catch (Exception ex){
            System.out.println("Exception while reading the result from TOMADeleteServerTrainings");
            ex.printStackTrace();
            return;
        }		
      
      	client=new SOAPClient(url, target, method, soapAction);		
      	TOMA.log(TOMA.WARNING, "SOAPClient created with: url="+url+", target="+target+", method="+method+", soapAction="+soapAction);
	}
	
	
	private void deleteAll(){
		boolean result=client.deleteAllTrainings(_login, _password, callParameters);
		if(result)
			System.out.println("All trainings deleted");
		else
			System.out.println("Problem while deleting all trainings !");
	}	
}
