/*
    Copyright 2004,2005 CRP Henri Tudor
    
    This file is part of Efficient's animator tool, "efficient.animator".
    Efficient project: http://efficient.citi.tudor.lu

    Efficient.animator is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Efficient.animator is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Efficient.animator; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * XMLHelper.java
 * 
 * Created on Nov 4, 2005 by sof
 *
 */
package apostal.toma;

import java.io.File;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.FileOutputStream;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.*;


import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.transform.stream.*;

public class XMLHelper {

    /*********** read and save ************/
    
    public static Document readDocument(String filename){
        DocumentBuilder docBuilder = null;
        Document doc=null;
        try {
            DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
            docBuilderFactory.setNamespaceAware(true);
            docBuilder = docBuilderFactory.newDocumentBuilder();
            doc = docBuilder.parse(new File(filename));
            doc.getDocumentElement().normalize();
        }
        catch (Exception ex)
        {
            TOMA.log(ex);            
        }        
        return doc;
    } 
    
    public static boolean saveDocument(Document doc, String filename)
    {
        boolean ok=false;               
        try {                                       
            TransformerFactory tFactory = TransformerFactory.newInstance();
            Transformer transformer = tFactory.newTransformer();
            Source input = new DOMSource(doc);                      
            OutputStreamWriter writer=new OutputStreamWriter(new FileOutputStream(filename));
            Result output = new StreamResult(writer);
            transformer.transform(input, output);   
            ok=true;            
        }
        catch (Exception ex){
            TOMA.log(ex);    
        }   
        return ok;      
    }       
    
    public static String getDocumentAsString(Document doc){
        String s=null;
        try{
            TransformerFactory fact=TransformerFactory.newInstance();
            Transformer tr = fact.newTransformer();
            tr.setOutputProperty(OutputKeys.INDENT, "yes");
            tr.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
            DOMSource source=new DOMSource(doc);
            StringWriter writer=new StringWriter();
            StreamResult result=new StreamResult(writer);
            tr.transform(source, result);
            s=writer.toString();
        }
        catch (Exception ex){
            TOMA.log(ex);    
        }   
        return s;          
    }
    
    /*********** textual node values ************/
    
    public static String getTextualNodeValue(Node el)
    {
        String result=null;
        NodeList list=el.getChildNodes();
        if(list.getLength()>0)
        {           
            int length=list.getLength();
            for(int i=0;i<length;i++)
            {
                Node node=list.item(i);             
                if(node.getNodeType()==Node.TEXT_NODE)
                {
                    if(result==null)
                        result=node.getNodeValue();
                    else
                        result=result+node.getNodeValue();
                }                   
            }
        }
                
        if(result!=null)
            result=result.trim();
                
        return result;
    }       
    
    public static Element getFirstDescendantByName(Element el, String name){
        Element child=null;
        NodeList list=el.getElementsByTagName(name);
        if(list.getLength()>0){
            child=(Element) list.item(0);
        }
        return child;
    }

    public static Element getSingleElementByTagName(Element el, String name)
    {
    	Element element=null;
    	NodeList list=el.getElementsByTagName(name);
    	if(list.getLength()>0)
    		element=(Element) list.item(0);
    		
    	return element;
    }

    public static String getSingleTextualElementValueByTagName(Element el, String name)
    {
    	String s=null;
    	NodeList list=el.getElementsByTagName(name);
    	if(list.getLength()>0)
    	{
    		Element element=(Element) list.item(0);
    		s=XMLHelper.getTextualNodeValue(element);
    	}
    		
    	return s;
    }

    /**
    * @return this Element's textual node value
    **/
    public static String getTextualNodeValue(Element el)
    {
    	String result=null;
    	NodeList list=el.getChildNodes();
    	if(list.getLength()>0)
    	{
    		int i=list.getLength();
    		int c=0;
    		boolean found=false;
    		while(c<i && !found)
    		{
    			Node node=list.item(c);
    			if(node.getNodeType()==Node.TEXT_NODE)
    			{
    				found=true;
    				result=node.getNodeValue();
    			}
    			c++;
    		}
    	}
    	return result;
    }    
}
