// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.data;

import apostal.toma.TOMA;

import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import toolbox.util.HashtableSort;
import toolbox.util.ObjectTree;
/**
 * @(#) Domain.java
 */

public class Domain extends TOMAData
{
    private int idDomain;
    private String name;
    private int nborder;
    private int idSuperDomain;
    private Vector domains;

    public Domain(int idDomain)
    {
	this.idDomain=idDomain;
	idSuperDomain=-1;
    }

    public Domain()
    {
	idSuperDomain=-1;
    }

    public int getIdDomain( )
    {
	return idDomain;
    }

    public String getName( )
    {
	return name;
    }

    public int getNborder()
    { return nborder; }

    public Vector getDomains()
    {
	return domains;
    }

    public int getIdSuperDomain( )
    {
	return idSuperDomain;
    }

    public void setIdDomain(int idDomain)
    {
	this.idDomain=idDomain;
    }
    public void setIdSuperDomain(int idSuperDomain)
    {
	this.idSuperDomain=idSuperDomain;
    }
    public void setName(String name)
    {
	this.name=name;
    }

    public void setNborder(int nborder)
    { this.nborder = nborder; }

    public void setDomains(Vector domains)
    {
	this.domains=domains;
    }


	public String toString()
	{
	  return name;
	}

    /**
     * Remove the domains that are repeated with less sub-domains
     * @param all the domains that contain a training, for example
     * if we have the hierarchy:
     *  a - b - c
     *  d
     * And if the training is in c & d, we will have a, b, c and d in the vector
     * @return a vector of vectors containing the path to a domain:
     * In the example, the vector (a,  b, c) and the vector (d)
     */
    public static Vector getLastLevelDomainsPaths(Vector domains)
    {
      Vector trees=new Vector();

      
      //first levels
      Vector firsts=Domain.getFirstLevelDomainsInList(domains);

      //other levels
      Vector others=(Vector) domains.clone();
      others.removeAll(firsts);

      Iterator iter = firsts.iterator();
      while (iter.hasNext())
      {
	Domain d = (Domain) iter.next();
	ObjectTree nodes=Domain.getTreeForDomain(d, others);

	trees.add(nodes);
      }

      //get tree path
      Vector result=new Vector();
      Iterator iter_trees = trees.iterator();
      while (iter_trees.hasNext())
      {
	ObjectTree tree = (ObjectTree) iter_trees.next();
	Vector paths=tree.getPaths();
	result.addAll(paths);
      }

      return result;
    }

    private static ObjectTree getTreeForDomain(Domain domain, Vector flatDomains)
    {
      Vector trees=new Vector();

      //first levels
      Vector firsts=Domain.getChildrenInList(flatDomains, domain);

      //other levels
      Vector others=(Vector) flatDomains.clone();
      others.removeAll(firsts);

      Iterator iter = firsts.iterator();
      while (iter.hasNext())
      {
	Domain d = (Domain) iter.next();
	ObjectTree nodes=Domain.getTreeForDomain(d, others);

	trees.add(nodes);
      }

      ObjectTree tree=new ObjectTree(domain, trees);

      return tree;
    }

    /**
     * @returns the first level domains in the list
     */
    private static Vector getFirstLevelDomainsInList(Vector domains)
    {
      Vector children=new Vector();
      if(domains!=null)
      {
        Iterator it=domains.iterator();
	while(it.hasNext())
	{
	  Domain d=(Domain) it.next();
	  if(d.getIdSuperDomain()==-1)
	  {
	    children.add(d);
	  }
	}
      }

      return children;
    }

    /**
     * @returns the children of the Domain "father" in the list
     */
    private static Vector getChildrenInList(Vector domains, Domain father)
    {
      int id=father.getIdDomain();
      Vector children=new Vector();
      if(domains!=null)
      {
        Iterator it=domains.iterator();
	while(it.hasNext())
	{
	  Domain d=(Domain) it.next();
	  if(d.getIdSuperDomain()==id)
	    children.add(d);
	}
      }
      return children;
    }

}
