// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.data;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import apostal.toma.TOMA;
import apostal.toma.data.TOMAParameters;

import java.util.Properties;
import java.io.File;
import java.io.FileInputStream;

public class TOMALabels
{
  private Properties props;

  /* load the labels for the actual interface language */
  public TOMALabels()
  {
    TOMAParameters params=TOMA.getInstance().getTomaParameters();
    Language lng=params.getLanguage();
    this.load(lng);
  }

  public TOMALabels(Language lng)
  {
    this.load(lng);
  }

  private void load(Language lng)
  {
    TOMAParameters params=TOMA.getInstance().getTomaParameters();
    String path=params.getTomaPath();
    if(path==null)
    {
        if(lng!=null)
            path="labels"+File.separator+"labels_"+lng.getCode();
        else
            path="labels"+File.separator+"labels_eng";            
    }
    else{
      if(!path.endsWith(File.separator))
          path=path+File.separator;
      path=path+"labels"+File.separator+"labels_"+lng.getCode();
    }
     FileInputStream fin=null;
    try{
      fin=new FileInputStream(path);
    } catch(java.io.FileNotFoundException ex)
    {
	TOMA.log(TOMA.SEVERE, "label file "+path+" not found");
    }
      catch(java.lang.SecurityException ex)
    {
	TOMA.log(TOMA.SEVERE, "you do not have the rights to open the file "+path);
    }

    if(fin!=null)
    {
      props=new Properties();
      try{
      props.load(fin);
      } catch(java.io.IOException ex)
      {
      	TOMA.log(TOMA.SEVERE, "IOException opening the file "+path);
      }
    }
  }

  public String get(String key)
  {
/*<<<<<<< TOMALabels.java
  	
      return props.getProperty(key);
      }
======= */
      if(props!=null)
        return props.getProperty(key);
      else
        return null;
  }
/* >>>>>>> 1.3 */
}