// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.data;

import apostal.toma.TOMA;
import apostal.toma.database.LanguageDB;

import java.util.Properties;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

public class TOMAParameters {

    private Language exportationLanguage;
    private String templateFile;
    private Language language;
    private String tomaPath;
    private boolean isClientServer = false;
    private String server;
    private String browser;
    private boolean openWarningWindow;
    private boolean usingProxy;
    private String proxyHost;
    private String proxyPort;


    public TOMAParameters() {
    }

    public void save() {

        //make properties
        Properties props = new Properties();
        if (language != null)
            props.setProperty("languageCode", language.getCode());
        if (exportationLanguage != null)
            props.setProperty("exportationLanguageCode", exportationLanguage.getCode());

        props.setProperty("templateFile", templateFile);
        props.setProperty("tomaPath", tomaPath);
        props.setProperty("usingProxy", new Boolean(usingProxy).toString());
        if (proxyHost != null) {
            props.setProperty("proxyHost", proxyHost);
        }
        if (proxyPort != null) {
            props.setProperty("proxyPort", proxyPort);
        }

        if (server != null)
            props.setProperty("server", server);

        if (browser != null)
            props.setProperty("browser", browser);

        props.setProperty("openWarningWindow", new Boolean(openWarningWindow).toString());

        //save
        FileOutputStream fout = null;
        try {
            fout = new FileOutputStream(TOMAConstants.parametersFile);
        } catch (java.io.FileNotFoundException ex) {
            TOMA.log(TOMA.SEVERE, "the template file " + templateFile + " was not found");
        } catch (java.lang.SecurityException ex) {
            TOMA.log(TOMA.SEVERE, "You do not have the rights to write to the template file " + templateFile);
        }
        if (fout != null) {
            try {
                props.store(fout, "Parameters used for the TOMA application");

                fout.flush();
                fout.close();
            } catch (IOException e) {
                TOMA.log(TOMA.WARNING, "the template file could not be saved");
            }
        }

    }

    public void loadOnlyClientServerData() {
        Properties props = null;
        try {
            FileInputStream fin = new FileInputStream(TOMAConstants.parametersFile);
            props = new Properties();
            props.load(fin);

            fin.close();
        } catch (java.io.FileNotFoundException ex) {
            TOMA.log(TOMA.SEVERE, "template file " + templateFile + " not found");
        } catch (java.io.IOException ex) {
            TOMA.log(TOMA.SEVERE, "template file " + templateFile + " caused an IO Exception");
        }

        if (props != null) {
            server = props.getProperty("server");
            if (server != null)
                isClientServer = true;
        }
    }

    public void load() {
        Properties props = null;
        try {
            FileInputStream fin = new FileInputStream(TOMAConstants.parametersFile);
            props = new Properties();
            props.load(fin);

            fin.close();
        } catch (java.io.FileNotFoundException ex) {
            TOMA.log(TOMA.SEVERE, "template file " + templateFile + " not found");
        } catch (java.io.IOException ex) {
            TOMA.log(TOMA.SEVERE, "template file " + templateFile + " caused an IO Exception");
        }

        if (props != null) {

            String languageCode = props.getProperty("languageCode");
            language = new Language(languageCode);
            LanguageDB ldb = new LanguageDB(language);
            ldb.loadByCode(languageCode);
            if (!language.isForInterface()) {
                TOMA.log(TOMA.INFO, "the language " + languageCode + " can not be used for the interface");
                language = new Language(Language.defaultLanguageCode);
                LanguageDB ldb2 = new LanguageDB(language);
                ldb2.loadByCode(Language.defaultLanguageCode);
                languageCode = Language.defaultLanguageCode;
            }

            String exportationLanguageCode = props.getProperty("exportationLanguageCode");
            exportationLanguage = new Language(exportationLanguageCode);
            LanguageDB ldb3 = new LanguageDB(exportationLanguage);
            ldb3.loadByCode(languageCode);
            if (!exportationLanguage.isForPublication()) {
                TOMA.log(TOMA.INFO, "the language " + exportationLanguageCode + " can not be used for the publication");
                exportationLanguage = new Language(Language.defaultLanguageCode);
                LanguageDB ldb4 = new LanguageDB(exportationLanguage);
                ldb4.loadByCode(Language.defaultLanguageCode);
                exportationLanguageCode = Language.defaultLanguageCode;
            }
            String valueOfOpenWarningWindow = props.getProperty("openWarningWindow");
            if (valueOfOpenWarningWindow != null && !valueOfOpenWarningWindow.equals("")) {
                openWarningWindow = new Boolean(valueOfOpenWarningWindow).booleanValue();
            } else {
                openWarningWindow = false;
            }
            String valueOFUsingProxy = props.getProperty("usingProxy");
            if (valueOFUsingProxy != null && !valueOFUsingProxy.equals("")) {
                usingProxy = new Boolean(valueOFUsingProxy).booleanValue();
            } else {
                usingProxy = false;
            }

            proxyHost = props.getProperty("proxyHost");
            proxyPort = props.getProperty("proxyPort");
            templateFile = props.getProperty("templateFile");
            tomaPath = props.getProperty("tomaPath");
            server = props.getProperty("server");
            if (server != null)
                isClientServer = true;
            browser = props.getProperty("browser");
        }
    }


    public boolean getOpenWarningWindow() {
        return openWarningWindow;
    }

    public void setOpenWarningWindow(boolean openWarningWindow) {
        this.openWarningWindow = openWarningWindow;
    }


    public Language getExportationLanguage() {
        return exportationLanguage;
    }

    public void setExportationLanguage(final Language exportationLanguage) {
        this.exportationLanguage = exportationLanguage;
    }

    public Language getLanguage() {
        return language;
    }

    public void setLanguage(final Language language) {
        this.language = language;
    }

    public String getTemplateFile() {
        return templateFile;
    }

    public void setTemplateFile(final String templateFile) {
        this.templateFile = templateFile;
    }


    public String getProxyHost() {
        return proxyHost;
    }

    public void setProxyHost(final String proxyHost) {
        this.proxyHost = proxyHost;
    }

    public String getProxyPort() {
        return proxyPort;
    }

    public void setProxyPort(final String proxyPort) {
        this.proxyPort = proxyPort;
    }

    public boolean isUsingProxy() {
        return usingProxy;
    }

    public void setUsingProxy(boolean usingProxy) {
        this.usingProxy = usingProxy;
    }


    public String getTomaPath() {
        return tomaPath;
    }

    public void setTomaPath(final String tomaPath) {
        this.tomaPath = tomaPath;
    }

    public boolean isClientServer() {
        return isClientServer;
    }

    public String getServer() {
        return server;
    }

    public void setServer(String _server) {
        this.server = _server;
    }

    public void setBrowser(String _browser) {
        this.browser = _browser;
    }

    public String getBrowser() {
        return browser;
    }
}
