// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.data;

import java.util.Vector;
import toolbox.text.ExtendedList;
import java.sql.Date;

import java.util.Calendar;
import java.util.GregorianCalendar;
/**
 * @(#) Training.java
 */

public abstract class Training extends TOMAData implements java.lang.Cloneable{
	private java.sql.Date beginValidityDate;
	private String certificatesOrDiplomas;
	private String code;
	private String comment;
	private String commentNotPublished;
	private Vector contentDescription;
	private String contentDescriptionConclusion;
	private String contentDescriptionIntroduction;
	private String courseMedia;
	private java.sql.Date dateCreation;
	private java.sql.Date dateMaj;
	private String duration;
	private java.sql.Date endValidityDate;
	private String evaluation;
	private int idTraining=-1;
	private String inscriptionConditions;
        private Vector keywords;
	private Vector languages;
	private Level level;
	private ModeOfOrganization modeOfOrganization;
	private Vector objectives;
	private String objectivesConclusion;
	private String objectivesIntroduction;
	private String partnership;
	private String paymentFacilities;
	private String pedagogicalMethods;
	private toolbox.text.ExtendedList pointsDealtWith;
	private Vector prerequisites;
	private String price;
	private String priceComment;
	private Vector slots;
	private String title;
	private Vector locations;
	private Vector teachers;
	private Vector competences;
	private Vector trainingContacts;

    public Training(int idTraining)
    {
	this();
	this.idTraining=idTraining;
    }

    public Training()
    {
	java.util.Date d=new java.util.Date();
	long millis=d.getTime();
	beginValidityDate=new Date(millis);

	GregorianCalendar cal=new GregorianCalendar();
	cal.roll(Calendar.YEAR, true);
	endValidityDate=new Date(cal.getTime().getTime());
    }

	public java.sql.Date getBeginValidityDate( )
	{
		return beginValidityDate;
	}

	public String getCertificatesOrDiplomas( )
	{
		return certificatesOrDiplomas;
	}

	public String getCode( )
	{
		return code;
	}

	public String getComment( )
	{
		return comment;
	}

	public String getCommentNotPublished( )
	{
		return commentNotPublished;
	}

	public Vector getContentDescription( )
	{
		return contentDescription;
	}

	public String getContentDescriptionConclusion( )
	{
		return contentDescriptionConclusion;
	}

	public String getContentDescriptionIntroduction( )
	{
		return contentDescriptionIntroduction;
	}

	public String getCourseMedia( )
	{
		return courseMedia;
	}

	public java.sql.Date getDateCreation( )
	{
		return dateCreation;
	}

	public java.sql.Date getDateMaj( )
	{
		return dateMaj;
	}

	public String getDuration( )
	{
		return duration;
	}

	public java.sql.Date getEndValidityDate( )
	{
		return endValidityDate;
	}

	public String getEvaluation( )
	{
		return evaluation;
	}

	public int getIdTraining( )
	{
		return idTraining;
	}

	public String getInscriptionConditions( )
	{
		return inscriptionConditions;
	}

	public Vector getKeywords( )
	{
		return keywords;
	}

	public Vector getLanguages( )
	{
		return languages;
	}

	public Level getLevel( )
	{
		return level;
	}

	public Vector getLocations( )
	{
		return locations;
	}

	public ModeOfOrganization getModeOfOrganization( )
	{
		return modeOfOrganization;
	}

	public Vector getObjectives( )
	{
		return objectives;
	}

	public String getObjectivesConclusion( )
	{
		return objectivesConclusion;
	}

	public String getObjectivesIntroduction( )
	{
		return objectivesIntroduction;
	}

	public String getPartnership( )
	{
		return partnership;
	}

	public String getPaymentFacilities( )
	{
		return paymentFacilities;
	}

	public String getPedagogicalMethods( )
	{
		return pedagogicalMethods;
	}

	public toolbox.text.ExtendedList getPointsDealtWith( )
	{
		return pointsDealtWith;
	}

    public Vector getPrerequisites(){ return prerequisites; }

    public void setPrerequisites(Vector prerequisites){ this.prerequisites = prerequisites; }

	public String getPrice( )
	{
		return price;
	}

	public String getPriceComment( )
	{
		return priceComment;
	}

	public Vector getSlots( )
	{
		return slots;
	}

	public Vector getTeachers( )
	{
		return teachers;
	}

    public Vector getCompetences()
    {
	return competences;
    }

	public String getTitle( )
	{
		return title;
	}

	public Vector getTrainingContacts( )
	{
	    return trainingContacts;
	}

	public void setBeginValidityDate( final java.sql.Date beginvaliditydate )
	{
		beginValidityDate = beginvaliditydate;
	}

	public void setCertificatesOrDiplomas( final String certificatesordiplomas )
	{
		certificatesOrDiplomas = certificatesordiplomas;
	}

	public void setCode( final String code )
	{
		this.code = code;
	}

	public void setComment( final String comment )
	{
		this.comment = comment;
	}

	public void setCommentNotPublished( final String commentNotPublished )
	{
		this.commentNotPublished = commentNotPublished;
	}

	public void setContentDescription( final Vector contentdescription )
	{
		contentDescription = contentdescription;
	}

	public void setContentDescriptionConclusion( final String contentdescriptionconclusion )
	{
		contentDescriptionConclusion = contentdescriptionconclusion;
	}

	public void setContentDescriptionIntroduction( final String contentdescriptionintroduction )
	{
		contentDescriptionIntroduction = contentdescriptionintroduction;
	}

	public void setCourseMedia( final String coursemedia )
	{
		courseMedia = coursemedia;
	}

	public void setDateCreation( final java.sql.Date datecreation )
	{
		dateCreation = datecreation;
	}

	public void setDateMaj( final java.sql.Date datemaj )
	{
		dateMaj = datemaj;
	}

	public void setDuration( final String duration )
	{
		this.duration = duration;
	}

	public void setEndValidityDate( final java.sql.Date endvaliditydate )
	{
		endValidityDate = endvaliditydate;
	}

	public void setEvaluation( final String evaluation )
	{
		this.evaluation = evaluation;
	}

	public void setIdTraining( final int idtraining )
	{
		idTraining = idtraining;
	}

	public void setInscriptionConditions( final String inscriptionconditions )
	{
		inscriptionConditions = inscriptionconditions;
	}

    public void setKeywords(final Vector keywords)
    {
	this.keywords=keywords;
    }

	public void setLanguages( final Vector languages )
	{
		this.languages = languages;
	}

	public void setLevel( final Level level )
	{
		this.level = level;
	}

	public void setLocations( final Vector locations )
	{
		this.locations = locations;
	}

	public void setModeOfOrganization( final ModeOfOrganization modeoforganization )
	{
		modeOfOrganization = modeoforganization;
	}

	public void setObjectives( final Vector objectives )
	{
		this.objectives = objectives;
	}

	public void setObjectivesConclusion( final String objectivesconclusion )
	{
		objectivesConclusion = objectivesconclusion;
	}

	public void setObjectivesIntroduction( final String objectivesintroduction )
	{
		objectivesIntroduction = objectivesintroduction;
	}

	public void setPartnership( final String partnership )
	{
		this.partnership = partnership;
	}

	public void setPaymentFacilities( final String paymentfacilities )
	{
		paymentFacilities = paymentfacilities;
	}

	public void setPedagogicalMethods( final String pedagogicalmethods )
	{
		pedagogicalMethods = pedagogicalmethods;
	}

	public void setPointsDealtWith( final toolbox.text.ExtendedList pointsdealtwith )
	{
		pointsDealtWith = pointsdealtwith;
	}

	public void setPrice( final String price )
	{
		this.price = price;
	}

	public void setPriceComment( final String pricecomment )
	{
		priceComment = pricecomment;
	}

	public void setSlots( final Vector slots )
	{
		this.slots = slots;
	}

	public void setTeachers( final Vector teachers)
	{
	    this.teachers = teachers;
	}

	public void setCompetences( final Vector competences)
	{
	    this.competences = competences;
	}

	public void setTitle( final String title )
	{
		this.title = title;
	}

	public void setTrainingContacts( final Vector trainingcontacts )
	{
		trainingContacts = trainingcontacts;
	}

	public String toString()
	{
	  return title+" ("+code+")";
	}


    public Training duplicate()
    {
      Training t=null;
      try{
        t=(Training) this.clone();
	t.setIdTraining(-1);
      }catch(java.lang.CloneNotSupportedException ex)
      {
        //never
	apostal.toma.TOMA.log(apostal.toma.TOMA.SEVERE, "training not cloneable");
      }

      return t;
    }
}
