// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.data;

import apostal.toma.database.ProgrammeSessionDB;
import apostal.toma.database.UnitDB;

import apostal.toma.data.Language;

import java.util.Vector;
import java.util.Iterator;

import java.sql.Date;

/**
 * @(#) TrainingProgramme.java
 */

public class TrainingProgramme extends StandaloneTraining
{
	private Vector programmeSessions;
    private Vector units;
	
    public TrainingProgramme(){}

    public TrainingProgramme(int idTraining)
    {
	super(idTraining);
    }	

    public void setProgrammeSessions(Vector programmeSessions)
    {
	this.programmeSessions=programmeSessions;
    }

    public Vector getProgrammeSessions()
    {
	return programmeSessions;
    }

    public Vector getUnits()
    {
	return units;
    }

    public void setUnits(Vector units)
    {
	this.units=units;
    }
    
    public Date getFirstSeanceDate(){
    	Date beginDate = null;
    	Iterator it = programmeSessions.iterator();
    	Vector dateSeances = new Vector();
    	while(it.hasNext()){
    		ProgrammeSession ps = (ProgrammeSession)it.next();
    		ProgrammeSessionDB psDB = new ProgrammeSessionDB(ps);
    		psDB.loadById(new Language("fra"),true);
    		beginDate = ps.getBeginDate();
    		if (beginDate!=null){
    			dateSeances.add(beginDate);
    		}
    	}
    	if (dateSeances.size()==0){
    		Iterator itUnit = units.iterator();
    		while (it.hasNext()){
    			Unit unit = (Unit)it.next();
    			UnitDB uDB = new UnitDB(unit);
    			uDB.load(new Language("fra"),true);
    			beginDate = unit.getFirstSeanceDate();
    			if (beginDate!=null){
    				dateSeances.add(beginDate);	
    			}
    		} 
    	}
    	boolean sorted;
    	do	{
      		sorted = true;
      		for (int i = 0; i < dateSeances.size () - 1; i++)
      		{
        		java.sql.Date date1 = (java.sql.Date)dateSeances.elementAt (i);
        		java.sql.Date date2 = (java.sql.Date)dateSeances.elementAt (i + 1);
        		if (date1.after(date2))
        		{
          			dateSeances.setElementAt(date2,i);
          			dateSeances.setElementAt(date1,i+1);          								
          			sorted = false;
        		}
      		}
    	}
    	while (!sorted);
    	if (dateSeances.size()!=0){
    		return (Date)dateSeances.elementAt(0);    	
    	} else {
    		return null;
    	}    	
    }
    public Date getEndSeanceDate(){
    	Date endDate = null;
    	Iterator it = programmeSessions.iterator();
    	Vector dateSeances = new Vector();
    	while(it.hasNext()){
    		ProgrammeSession ps = (ProgrammeSession)it.next();
    		ProgrammeSessionDB psDB = new ProgrammeSessionDB(ps);
    		psDB.loadById(new Language("fra"),true);
    		endDate = ps.getEndDate();
    		if (endDate!=null){
    			dateSeances.add(endDate);
    		}
    	}
    	if (dateSeances.size()==0){
    		Iterator itUnit = units.iterator();
    		while (it.hasNext()){
    			Unit unit = (Unit)it.next();
    			UnitDB uDB = new UnitDB(unit);
    			uDB.load(new Language("fra"),true);
    			endDate = unit.getEndSeanceDate();
    			if (endDate!=null){
    				dateSeances.add(endDate);	
    			}
    		} 
    	}
    	boolean sorted;
    	do	{
      		sorted = true;
      		for (int i = 0; i < dateSeances.size () - 1; i++)
      		{
        		java.sql.Date date1 = (java.sql.Date)dateSeances.elementAt (i);
        		java.sql.Date date2 = (java.sql.Date)dateSeances.elementAt (i + 1);
        		if (date1.after(date2))
        		{
          			dateSeances.setElementAt(date2,i);
          			dateSeances.setElementAt(date1,i+1);          								
          			sorted = false;
        		}
      		}
    	}
    	while (!sorted);
    	int size = dateSeances.size(); 
    	if (size!=0){
    		return (Date)dateSeances.elementAt(size-1);    	
    	} else {
    		return null;
    	}
    }
}
