// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;


import java.util.Vector;

import java.util.Iterator;

import apostal.toma.data.Country;

import apostal.toma.data.Language;

/**

 * @(#) Area.java

 */


public class AreaDB {

    private Area area;


    public AreaDB(Area area) {

        this.area = area;

    }


    public void loadById(Language language) {

        if (language != null) {

            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];


            where[0][0] = (new Integer(area.getIdArea())).toString();

            where[0][1] = "Integer";

            where[0][2] = "idArea";


            RequeteSelectWhere rs = new RequeteSelectWhere(db, "area", where);

            if (rs.next()) {

                area.setName(rs.getString("areaName"));

                Country country = new Country(rs.getString("countryCode"));

                CountryDB cdb = new CountryDB(country);

                cdb.loadByCode(language);

                area.setCountry(country);

                area.setIdSuperArea(rs.getNullableInt("idSuperArea"));



                //sub area

                Vector areas = new Vector();

                RequeteSelect rs2 = new RequeteSelect(db, "area", "idSuperArea", new Integer(area.getIdArea()));

                while (rs2.next()) {

                    int id = rs2.getInt("idArea");

                    Area a = new Area(id);

                    a.setIdSuperArea(area.getIdArea());


                    areas.add(a);

                }

                rs2.close();

                area.setAreas(areas);

            }

            rs.close();


        }

    }


    public static boolean exists(int idArea) {

        boolean exists = false;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "area", "idArea", new Integer(idArea));

        if (rs.next()) {

            exists = true;

        }

        rs.close();


        return exists;

    }


    public void loadSubLevel(final Language language) {

        Vector areas = area.getAreas();

        AreaDB adb = null;

        if (areas != null) {

            Iterator iter = areas.iterator();

            while (iter.hasNext()) {

                Area a = (Area) iter.next();

                adb = new AreaDB(a);

                adb.loadById(language);

            }

        }

    }


    public static Vector loadFirstLevel(final Language language) {

        TOMADatabase db = TOMADatabase.getInstance();

        Vector v = new Vector();


        String where = "idSuperArea<0";

        RequeteSelect rs = new RequeteSelect(db, "area", where);

        while (rs.next()) {

            int idArea = rs.getInt("idArea");

            String name = rs.getString("areaName");

            String code = rs.getString("countryCode");

            Country c = new Country(code);

            CountryDB cdb = new CountryDB(c);

            cdb.loadByCode(language);


            Area a = new Area(idArea);

            a.setName(name);

            a.setCountry(c);

            a.setIdSuperArea(-1);



            //sub area

            Vector areas = new Vector();

            RequeteSelect rs2 = new RequeteSelect(db, "area", "idSuperArea", new Integer(idArea));

            while (rs2.next()) {

                int id = rs2.getInt("idArea");

                Area sub = new Area(id);

                sub.setIdSuperArea(idArea);

                areas.add(sub);

            }

            rs2.close();

            a.setAreas(areas);


            AreaDB adb = new AreaDB(a);

            v.add(a);

        }

        rs.close();


        return v;

    }


    public static Vector loadFirstLevelByCountry(final Language language, Country c) {

        Vector v = new Vector();

        if (c != null) {

            TOMADatabase db = TOMADatabase.getInstance();


            String where = "idSuperArea<0 and countryCode like '" + c.getCode() + "'";

            RequeteSelect rs = new RequeteSelect(db, "area", where);

            while (rs.next()) {

                int idArea = rs.getInt("idArea");

                String name = rs.getString("areaName");

                String code = rs.getString("countryCode");


                Area a = new Area(idArea);

                a.setName(name);

                a.setCountry(c);

                a.setIdSuperArea(-1);



                //sub area

                Vector areas = new Vector();

                RequeteSelect rs2 = new RequeteSelect(db, "area", "idSuperArea", new Integer(idArea));

                while (rs2.next()) {

                    int id = rs2.getInt("idArea");

                    Area sub = new Area(id);

                    sub.setIdSuperArea(idArea);

                    areas.add(sub);

                }

                rs2.close();

                a.setAreas(areas);


                AreaDB adb = new AreaDB(a);

                v.add(a);

            }

            rs.close();

        }


        return v;

    }


}

