// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import java.util.Vector;
import java.sql.Date;

import apostal.toma.data.Language;

/**
 * @(#) Catalogue.java
 */

public class CatalogueDB implements Modifiable {

    private Catalogue catalogue;

    public CatalogueDB(Catalogue catalogue) {
        this.catalogue = catalogue;
    }

    public static boolean exists(int idCatalogue) {
        boolean exists = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "catalogue", "idCatalogue", new Integer(idCatalogue));
        if (rs.next()) {
            exists = true;
        }
        rs.close();


        return exists;
    }

    public static void createRootCatalogue() {
        //empty BD
        Catalogue c0 = new Catalogue();
        c0.setTitle("Desktop");
        c0.setNborder(0);
        //no idsupercatalogue
        CatalogueDB c0db = new CatalogueDB(c0);
        c0db.create();

        TOMA.log(TOMA.INFO, "Catalogue root created, id=" + new Integer(c0.getIdCatalogue()));
    }

    /*  public static Catalogue getRootCatalogue(Language language, boolean all) {
          Catalogue cat = null;
          TOMADatabase db = TOMADatabase.getInstance();
          RequeteSelect rs = new RequeteSelect(db, "catalogue", "idSuperCatalogue is NULL");
          if (rs.next()) {
              int id = rs.getInt("idCatalogue");
              cat = new Catalogue(id);
              CatalogueDB cdb = new CatalogueDB(cat);
              cdb.loadById(language, all);
          }
          rs.close();

          return cat;
      }   */


    public static Catalogue getRootCatalogue(Language language, boolean all) {
        Catalogue cat = null;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "catalogue", "idSuperCatalogue is NULL");
        if (rs.next()) {
            int id = rs.getInt("idCatalogue");
            cat = new Catalogue(id);
            CatalogueDB cdb = new CatalogueDB(cat);
            cdb.loadByIdAndRS(language, all, rs);
        }
        rs.close();

        return cat;
    }

    public static Catalogue getCatalogueByTitle(Language language, String title, boolean all){
        Catalogue cat = null;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "catalogue", "title", title);
        if (rs.next()) {
            int id = rs.getInt("idCatalogue");
            cat = new Catalogue(id);
            CatalogueDB cdb = new CatalogueDB(cat);
            cdb.loadByIdAndRS(language, all, rs);
        }
        rs.close();

        return cat;    
    }

    public int getMaxTrainingOrder() {
        int max = 0;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rsmax = new RequeteSelect(true, db, "max(nborder)", "trainingCatalogue", "idCatalogue=" + (new Integer(catalogue.getIdCatalogue())).toString());
        if (rsmax.next()) {
            max = rsmax.getInt(1);
        }
        rsmax.close();


        return max;
    }

    /**
     * checks if it is the "root" catalogue
     * (only for catalogues that already have and id in TOMA)
     */
    public boolean isRootCatalogue() {
        Language lng = TOMA.getInstance().getTomaParameters().getLanguage();
        Catalogue root = CatalogueDB.getRootCatalogue(lng, false);
        if (root.getIdCatalogue() == catalogue.getIdCatalogue())
            return true;
        else
            return false;
    }

    public boolean loadByTitleAndTest(Language language, boolean all, boolean withLists) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[2][3];

        where[0][0] = catalogue.getTitle();
        where[0][1] = "String";
        where[0][2] = "title";

        where[1][0] = (new Integer(catalogue.getIdSuperCatalogue())).toString();
        where[1][1] = "Integer";
        where[1][2] = "idSuperCatalogue";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "catalogue", where);
        if (rs.next()) {
            int id = rs.getInt("idCatalogue");
            catalogue.setIdCatalogue(id);
            this.loadById(language, all, withLists);
            loaded = true;
        } else {
            apostal.toma.TOMA.log(apostal.toma.TOMA.INFO, "no catalogue found for cat with title=" + catalogue.getTitle() + " and idSuperCatalogue=" + new Integer(catalogue.getIdSuperCatalogue()));
        }
        rs.close();

        return loaded;
    }

    public void loadByTitle(Language language, boolean all, boolean withLists) {
        this.loadByTitleAndTest(language, all, withLists);
    }

    public boolean loadById(Language language, boolean all) {
        return this.loadById(language, all, true);
    }

    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        return this.loadByIdAndRS(language, all, true, rs);
    }

    public boolean loadById(Language language, boolean all, boolean withLists) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "catalogue", where);
        if (rs.next()) {
            loaded = true;
            catalogue.setTitle(rs.getString("title"));

            if (all) {
                catalogue.setDescription(rs.getString("description"));
                catalogue.setIdSuperCatalogue(rs.getNullableInt("idSuperCatalogue"));
                catalogue.setNborder(rs.getInt("nborder"));

                catalogue.setDateCreation(rs.getDate("dateCreation"));
                catalogue.setDateMaj(rs.getDate("dateMaj"));
            }

            if (withLists) {
                //trainings
                Vector trainings = new Vector();
                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "trainingCatalogue", where, "nborder");
                while (rs2.next()) {
                    int idTr = rs2.getInt("idTraining");
                    char type = 'C';
                    Training training = null;
                    //type of training
                    RequeteSelect rs_tr = new RequeteSelect(db, "training", "idTraining", new Integer(idTr));
                    if (rs_tr.next()) {
                        type = rs_tr.getChar("type");
                    }
                    if (type == 'U') {
                        training = new Unit(idTr);
                        UnitDB trdb = new UnitDB((Unit) training);
                        trdb.loadById(language, false);
                    } else if (type == 'P') {
                        training = new TrainingProgramme(idTr);
                        TrainingProgrammeDB trdb = new TrainingProgrammeDB((TrainingProgramme) training);
                        trdb.loadById(language, false);
                    } else {
                        training = new TrainingCourse(idTr);
                        TrainingCourseDB trdb = new TrainingCourseDB((TrainingCourse) training);
                        trdb.loadById(language, false);
                    }

                    trainings.add(training);
                }
                rs2.close();
                catalogue.setTrainings(trainings);

                //child catalogues
                Vector catalogues = new Vector();
                String[][] where2 = new String[1][3];
                where2[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
                where2[0][1] = "Integer";
                where2[0][2] = "idSuperCatalogue";
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "catalogue", where2, "nborder");
                while (rs3.next()) {
                    int idCat = rs3.getInt("idCatalogue");
                    Catalogue cat = new Catalogue(idCat);
                    CatalogueDB catdb = new CatalogueDB(cat);
                    catdb.loadById(language, true);
                    catalogues.add(cat);
                }
                rs3.close();
                catalogue.setCatalogues(catalogues);
            }
        }
        rs.close();

        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, boolean withLists, InterfaceRequeteSelect rs) {
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";
        boolean loaded = true;
        catalogue.setTitle(rs.getString("title"));
        if (all) {
            catalogue.setDescription(rs.getString("description"));
            catalogue.setIdSuperCatalogue(rs.getNullableInt("idSuperCatalogue"));
            catalogue.setNborder(rs.getInt("nborder"));

            catalogue.setDateCreation(rs.getDate("dateCreation"));
            catalogue.setDateMaj(rs.getDate("dateMaj"));
        }
        if (withLists) {
            //trainings
            Vector trainings = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "trainingCatalogue", where, "nborder");
            while (rs2.next()) {
                int idTr = rs2.getInt("idTraining");
                char type = 'C';
                Training training = null;
                //type of training
                RequeteSelect rs_tr = new RequeteSelect(db, "training", "idTraining", new Integer(idTr));
                if (rs_tr.next()) {
                    type = rs_tr.getChar("type");
                }
                if (type == 'U') {
                    training = new Unit(idTr);
                    UnitDB trdb = new UnitDB((Unit) training);
                    trdb.loadByIdAndRS(language, false, rs_tr);
                } else if (type == 'P') {
                    training = new TrainingProgramme(idTr);
                    TrainingProgrammeDB trdb = new TrainingProgrammeDB((TrainingProgramme) training);
                    trdb.loadByIdAndRS(language, false, rs_tr);
                } else {
                    training = new TrainingCourse(idTr);
                    TrainingCourseDB trdb = new TrainingCourseDB((TrainingCourse) training);
                    trdb.loadByIdAndRS(language, false, rs_tr);
                }

                trainings.add(training);
            }
            rs2.close();
            catalogue.setTrainings(trainings);
            //child catalogues
            Vector catalogues = new Vector();
            String[][] where2 = new String[1][3];
            where2[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idSuperCatalogue";
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "catalogue", where2, "nborder");
            while (rs3.next()) {
                int idCat = rs3.getInt("idCatalogue");
                Catalogue cat = new Catalogue(idCat);
                CatalogueDB catdb = new CatalogueDB(cat);
                catdb.loadByIdAndRS(language, true, rs3);
                catalogues.add(cat);
            }
            rs3.close();
            catalogue.setCatalogues(catalogues);
        }
        return loaded;
    }


    public boolean loadElementsNotInTedById(Language language, boolean loadNborder) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "catalogue", where);
        if (rs.next()) {
            loaded = true;

            if (loadNborder) {
                int nb = rs.getInt("nborder");
                catalogue.setNborder(nb);
            }


            Vector trainings = catalogue.getTrainings();
            if (trainings == null)
                trainings = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "trainingCatalogue", where);
            while (rs3.next()) {
                int idt = rs3.getInt("idTraining");
                Training tr = TrainingDB.getInstance(language, false, idt);
                if (tr != null)
                    trainings.add(tr);
            }
            rs3.close();
            catalogue.setTrainings(trainings);
        }
        rs.close();


        return loaded;
    }

    public boolean unlock() {
        boolean unlock = DatabaseFacilities.unlock("idCatalogue", catalogue.getIdCatalogue(), "catalogue");
        return unlock;
    }

    public boolean lock() {
        boolean lock = DatabaseFacilities.lock("idCatalogue", catalogue.getIdCatalogue(), "catalogue");
        return lock;
    }

    public boolean isLocked() {
        boolean locked = DatabaseFacilities.isLocked("idCatalogue", catalogue.getIdCatalogue(), "catalogue");
        return locked;
    }

    /**
     * change the nborder so that it uses the next nborder available for the super catalogue
     **/
    public void setNextNborder() {
        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rsnb = new RequeteSelect(true, db, "max(nborder)", "catalogue", "idSuperCatalogue='" + new Integer(catalogue.getIdSuperCatalogue()) + "'");
        if (rsnb.next()) {
            int max = rsnb.getInt(1);
            max++;
            catalogue.setNborder(max);
        } else {
            catalogue.setNborder(0);
        }
        rsnb.close();

    }

    public void create() {
        //set the next available nborder for this super catalogue
        //if the actual nborder is not set (-1)
        if (catalogue.getNborder() == -1) {
            TOMA.log(TOMA.INFO,"calcul du nborder");
            this.setNextNborder();
        }

        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);

        RequeteInsert ri = new RequeteInsert(db, "catalogue", insert);
        ri.close();

        String[][] where = new String[2][3];
        where[0][0] = catalogue.getTitle();
        where[0][1] = "String";
        where[0][2] = "title";
        where[1][0] = (new Integer(catalogue.getIdSuperCatalogue())).toString();
        where[1][1] = "Integer";
        where[1][2] = "idSuperCatalogue";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "catalogue", where);
        if (rs.next()) {
            catalogue.setIdCatalogue(rs.getInt("idCatalogue"));
            catalogue.setDateCreation(rs.getDate("dateCreation"));
            catalogue.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        //set the next available nborder for this super catalogue
        //if the actual nborder is not set (-1)
        if (catalogue.getNborder() == -1) {
            this.setNextNborder();
        }

        TOMADatabase db = TOMADatabase.getInstance();
        Object[][] update = this.getSaveData(false);

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(catalogue.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";
        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "catalogue", update, where);
        ru.close();
        db.commit();

        //date maj
        catalogue.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        TOMADatabase db = TOMADatabase.getInstance();

        //trainings
        //remove existing
        RequeteDelete rd = new RequeteDelete(db, "trainingCatalogue", "idCatalogue", new Integer(catalogue.getIdCatalogue()));
        rd.close();

        //add
        Vector trainings = catalogue.getTrainings();
        Vector newtrainings = new Vector();
        if (trainings != null) {
            int nbtr = trainings.size();
            for (int i = 0; i < nbtr; i++) {
                Training t = (Training) trainings.elementAt(i);

                if (TrainingDB.exists(t.getIdTraining())) {
                    newtrainings.add(t);

                    Object[][] tr = new Object[3][2];
                    tr[0][0] = "idCatalogue";
                    tr[0][1] = new Integer(catalogue.getIdCatalogue());

                    tr[1][0] = "idTraining";
                    tr[1][1] = new Integer(t.getIdTraining());

                    tr[2][0] = "nborder";
                    tr[2][1] = new Integer(i);

                    RequeteInsert ri2 = new RequeteInsert(db, "trainingCatalogue", tr);
                    ri2.close();

                }

            }
        }
        catalogue.setTrainings(newtrainings);

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Vector values = new Vector();
        Vector names = new Vector();

        names.add("title");
        values.add(catalogue.getTitle());

        names.add("description");
        values.add(catalogue.getDescription());

        int idSuperCatalogue = catalogue.getIdSuperCatalogue();
        names.add("idSuperCatalogue");
        boolean exists = CatalogueDB.exists(idSuperCatalogue);
        if (idSuperCatalogue > -1 && exists)
            values.add(new Integer(idSuperCatalogue));
        else
            values.add(null);

        names.add("nborder");
        values.add(new Integer(catalogue.getNborder()));

        if (creation)
            DatabaseFacilities.addCreationDates(values, names);
        else
            DatabaseFacilities.addUpdateDates(values, names);

        names.add("lock");
        values.add(Boolean.TRUE);

        Object[][] data = new Object[values.size()][2];
        for (int i = 0; i < values.size(); i++) {
            data[i][0] = names.elementAt(i);
            data[i][1] = values.elementAt(i);
        }

        return data;
    }

    public boolean testConstraints() {
        if (catalogue.getTitle() == null || catalogue.getTitle().equals(""))
            return false;
        else
            return true;
    }

    public boolean testUpdate() {
        if (this.testConstraints()) {
            String[][] where = new String[2][3];
            where[0][0] = catalogue.getTitle();
            where[0][1] = "String";
            where[0][2] = "title";
            where[1][0] = (new Integer(catalogue.getIdSuperCatalogue())).toString();
            where[1][1] = "Integer";
            where[1][2] = "idSuperCatalogue";
            boolean test = DatabaseFacilities.testUpdate("catalogue", where, "idCatalogue", catalogue.getIdCatalogue());
            return test;
        } else
            return false;
    }

    public boolean testCreate() {
        if (this.testConstraints()) {
            String[][] where = new String[2][3];
            where[0][0] = catalogue.getTitle();
            where[0][1] = "String";
            where[0][2] = "title";
            where[1][0] = (new Integer(catalogue.getIdSuperCatalogue())).toString();
            where[1][1] = "Integer";
            where[1][2] = "idSuperCatalogue";
            boolean test = DatabaseFacilities.testCreate("catalogue", where);
            return test;
        } else
            return false;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        int idCatalogue = catalogue.getIdCatalogue();

        RequeteDelete rd1 = new RequeteDelete(db, "trainingCatalogue", "idCatalogue", new Integer(idCatalogue));
        rd1.close();

        RequeteDelete rd2 = new RequeteDelete(db, "cataloguePublished", "idCatalogue", new Integer(idCatalogue));
        rd2.close();

        RequeteSelect rs = new RequeteSelect(db, "catalogue", "idSuperCatalogue", new Integer(idCatalogue));
        while (rs.next()) {
            int idc = rs.getInt("idCatalogue");

            Catalogue c = new Catalogue(idc);
            CatalogueDB catdb = new CatalogueDB(c);
            catdb.delete();
        }
        rs.close();

        RequeteDelete rd = new RequeteDelete(db, "catalogue", "idCatalogue", new Integer(idCatalogue));
        rd.close();

        db.commit();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "catalogue", "0", "0");
        while (rs.next()) {
            Catalogue catalogue = new Catalogue(rs.getInt("idCatalogue"));
            CatalogueDB cataloguedb = new CatalogueDB(catalogue);
            cataloguedb.delete();
        }
        rs.close();
        db.commit();
    }
}
