// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import toolbox.util.HashtableSort;

import java.sql.Date;

import apostal.toma.data.Language;

/**
 * @(#) CataloguePublishedDB.java
 */

public class CataloguePublishedDB {

    private CataloguePublished cataloguePublished;

    public CataloguePublishedDB(CataloguePublished cataloguePublished) {
        this.cataloguePublished = cataloguePublished;
    }

    public void loadById() {
        TOMADatabase db = TOMADatabase.getInstance();

        //title
        RequeteSelect rs = new RequeteSelect(db, "catalogue", "idCatalogue", new Integer(cataloguePublished.getIdCatalogue()));
        if (rs.next()) {
            cataloguePublished.setTitle(rs.getString("title"));
        }
        rs.close();
        //catalogues that are in the catalogue and in the unit
        Vector catalogues = new Vector();
        String[][] where3 = new String[1][3];
        where3[0][0] = (new Integer(cataloguePublished.getIdCatalogue())).toString();
        where3[0][1] = "Integer";
        where3[0][2] = "idSuperCatalogue";
        RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "catalogue", where3, "nborder");
        while (rs2.next()) {
            int idCat = rs2.getInt("idCatalogue");
            RequeteSelect rs3 = new RequeteSelect(db, "cataloguePublished", "idCatalogue", new Integer(idCat));
            if (rs3.next()) //publi dans cette unit
            {
                CataloguePublished cat = new CataloguePublished(idCat, cataloguePublished.getIdPublicationUnit());
                CataloguePublishedDB cdb = new CataloguePublishedDB(cat);
                cdb.loadById();

                catalogues.add(cat);
            }
            rs3.close();
        }
        rs2.close();
        cataloguePublished.setCatalogues(catalogues);

        //trainings that are in the catalogue and in the unit
        String[][] where = new String[2][3];
        where[0][0] = (new Integer(cataloguePublished.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";

        where[1][0] = (new Integer(cataloguePublished.getIdPublicationUnit())).toString();
        where[1][1] = "Integer";
        where[1][2] = "idPublicationUnit";

        Hashtable trs = new Hashtable();
        RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "trainingPublished", where);
        while (rs4.next()) {
            int idTraining = rs4.getInt("idTraining");

            //nborder
            int nborder = 0;
            String[][] where2 = new String[2][3];
            where2[0][0] = (new Integer(cataloguePublished.getIdCatalogue())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idCatalogue";

            where2[1][0] = (new Integer(idTraining)).toString();
            where2[1][1] = "Integer";
            where2[1][2] = "idTraining";

            RequeteSelectWhere rs6 = new RequeteSelectWhere(db, "trainingCatalogue", where2);
            if (rs6.next()) {
                nborder = rs6.getInt("nborder");
            }
            rs6.close();

            TrainingPublished tr = new TrainingPublished(cataloguePublished.getIdPublicationUnit(), cataloguePublished.getIdCatalogue(), idTraining, nborder);
            TrainingPublishedDB trdb = new TrainingPublishedDB(tr);
            trdb.loadById();

            trs.put(tr, new Integer(nborder));
        }
        rs4.close();
        HashtableSort sort = new HashtableSort(trs);
        cataloguePublished.setTrainings(sort.sort());


    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = new Object[2][2];
        insert[0][0] = "idCatalogue";
        insert[0][1] = new Integer(cataloguePublished.getIdCatalogue());
        insert[1][0] = "idPublicationUnit";
        insert[1][1] = new Integer(cataloguePublished.getIdPublicationUnit());

        RequeteInsert ri = new RequeteInsert(db, "cataloguePublished", insert);
        ri.close();

        db.commit();
    }

    public boolean testCreate() {
        String[][] where = new String[2][3];
        where[0][0] = (new Integer(cataloguePublished.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";
        where[1][0] = (new Integer(cataloguePublished.getIdPublicationUnit())).toString();
        where[1][1] = "Integer";
        where[1][2] = "idPublicationUnit";
        boolean test = DatabaseFacilities.testCreate("cataloguePublished", where);
        return test;
    }
}
