// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.HashSet;


import apostal.toma.data.Address;
import apostal.toma.data.Language;

/**
 * @(#) Contact.java
 */

public class ContactDB implements Modifiable {

    private Contact contact;

    public static boolean exists(int idContact) {
        boolean exists = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "contact", "idContact", new Integer(idContact));
        if (rs.next()) {
            exists = true;
        }
        rs.close();


        return exists;
    }

    public ContactDB(Contact contact) {
        this.contact = contact;
    }

    public static Vector load(Language language, boolean all) {
        TOMADatabase db = TOMADatabase.getInstance();

        Vector contacts = new Vector();
        String[][] values = new String[0][3];
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "contact", values);
        while (rs.next()) {
            int id = rs.getInt("idContact");
            Contact t = new Contact(id);
            ContactDB tdb = new ContactDB(t);
            tdb.loadByIdAndRS(language, all,rs);

            contacts.add(t);
        }
        rs.close();


        return contacts;
    }

    /**
     * returns all the trainings that use this teacher
     */
    public Vector getTrainingsByContact(Language lng, boolean all) {
        HashSet found = new HashSet();
        Vector trainings = new Vector();
        TOMADatabase db = TOMADatabase.getInstance();
        //inscription contacts
        RequeteSelect rs = new RequeteSelect(db, "trainingInscriptionContact", "idContact", new Integer(contact.getIdContact()));
        while (rs.next()) {
            int id = rs.getInt("idTraining");
            Training t = TrainingDB.getInstance(lng, all, id);
            trainings.add(t);
            found.add(new Integer(id));
        }
        rs.close();
        //training contacts
        rs = new RequeteSelect(db, "trainingTrainingContact", "idContact", new Integer(contact.getIdContact()));
        while (rs.next()) {
            int id = rs.getInt("idTraining");
            if (!found.contains(new Integer(id))) {
                Training t = TrainingDB.getInstance(lng, all, id);
                trainings.add(t);
                found.add(new Integer(id));
            }
        }
        rs.close();

        return trainings;
    }

    public boolean loadByFirstnameLastnameTelEmailAndTest(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[4][3];
        where[0][0] = contact.getFirstname();
        where[0][1] = "String";
        where[0][2] = "firstname";
        where[1][0] = contact.getLastname();
        where[1][1] = "String";
        where[1][2] = "lastname";
        where[2][0] = contact.getTel();
        where[2][1] = "String";
        where[2][2] = "tel";
        where[3][0] = contact.getEmail();
        where[3][1] = "String";
        where[3][2] = "email";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "contact", where);
        if (rs.next()) {
            int id = rs.getInt("idContact");
            contact.setIdContact(id);
            this.loadByIdAndRS(language, all,rs);
            loaded = true;
        }
        rs.close();

        return loaded;
    }

    public void loadByFirstnameLastnameTelEmail(Language language, boolean all) {
        this.loadByFirstnameLastnameTelEmailAndTest(language, all);
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(contact.getIdContact())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idContact";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "contact", where);
        if (rs.next()) {
            loaded = true;

            String _firstname = rs.getString("firstname");
            if (_firstname != null) contact.setFirstname(_firstname);
            contact.setLastname(rs.getString("lastname"));
            String _tel = rs.getString("tel");
            if (_tel != null) contact.setTel(_tel);
            String _email = rs.getString("email");
            if (_email != null) contact.setEmail(_email);

            if (all) {
                String _title = rs.getString("title");
                if (_title != null) contact.setTitle(_title);
                String _function = rs.getString("function");
                if (_function != null) contact.setFunction(_function);
                String _fax = rs.getString("fax");
                if (_fax != null) contact.setFax(_fax);

                String postCode = rs.getString("postCode");
                String city = rs.getString("city");
                String countryCode = rs.getString("countryCode");
                Country c = new Country(countryCode);
                CountryDB cdb = new CountryDB(c);
                cdb.loadByCode(language);

                if (city != null) //il y a une adresse
                {
                    Vector lines = new Vector();
                    RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "contactAddressLine", where, "nborder");
                    while (rs2.next()) {
                        String line = rs2.getString("contactAddressLine");
                        lines.add(line);
                    }
                    rs2.close();

                    Address address = new Address(lines, city, postCode, c);
                    contact.setAddress(address);
                }

                contact.setDateCreation(rs.getDate("dateCreation"));
                contact.setDateMaj(rs.getDate("dateMaj"));

            }
        }
        rs.close();

        return loaded;
    }

    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(contact.getIdContact())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idContact";

        /*RequeteSelectWhere rs = new RequeteSelectWhere(db, "contact", where);
        if (rs.next()) {  */
        loaded = true;

        String _firstname = rs.getString("firstname");
        if (_firstname != null) contact.setFirstname(_firstname);
        contact.setLastname(rs.getString("lastname"));
        String _tel = rs.getString("tel");
        if (_tel != null) contact.setTel(_tel);
        String _email = rs.getString("email");
        if (_email != null) contact.setEmail(_email);

        if (all) {
            String _title = rs.getString("title");
            if (_title != null) contact.setTitle(_title);
            String _function = rs.getString("function");
            if (_function != null) contact.setFunction(_function);
            String _fax = rs.getString("fax");
            if (_fax != null) contact.setFax(_fax);

            String postCode = rs.getString("postCode");
            String city = rs.getString("city");
            String countryCode = rs.getString("countryCode");
            Country c = new Country(countryCode);
            CountryDB cdb = new CountryDB(c);
            cdb.loadByCode(language);

            if (city != null) //il y a une adresse
            {
                Vector lines = new Vector();
                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "contactAddressLine", where, "nborder");
                while (rs2.next()) {
                    String line = rs2.getString("contactAddressLine");
                    lines.add(line);
                }
                rs2.close();

                Address address = new Address(lines, city, postCode, c);
                contact.setAddress(address);
            }

            contact.setDateCreation(rs.getDate("dateCreation"));
            contact.setDateMaj(rs.getDate("dateMaj"));

        }
        /* }
         rs.close();*/

        return loaded;
    }


    public boolean unlock() {
        boolean unlock = DatabaseFacilities.unlock("idContact", contact.getIdContact(), "contact");
        return unlock;
    }

    public boolean lock() {
        boolean lock = DatabaseFacilities.lock("idContact", contact.getIdContact(), "contact");
        return lock;
    }

    public boolean isLocked() {
        boolean locked = DatabaseFacilities.isLocked("idContact", contact.getIdContact(), "contact");
        return locked;
    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);

        RequeteInsert ri = new RequeteInsert(db, "contact", insert);
        ri.close();


        String[][] where = new String[4][3];
        where[0][0] = contact.getFirstname();
        where[0][1] = "String";
        where[0][2] = "firstname";
        where[1][0] = contact.getLastname();
        where[1][1] = "String";
        where[1][2] = "lastname";
        where[2][0] = contact.getTel();
        where[2][1] = "String";
        where[2][2] = "tel";
        where[3][0] = contact.getEmail();
        where[3][1] = "String";
        where[3][2] = "email";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "contact", where);
        if (rs.next()) {
            contact.setIdContact(rs.getInt("idContact"));
            contact.setDateCreation(rs.getDate("dateCreation"));
            contact.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] update = this.getSaveData(false);

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(contact.getIdContact())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idContact";

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "contact", update, where);
        ru.close();

        db.commit();

        //date maj
        contact.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        TOMADatabase db = TOMADatabase.getInstance();

        //address lines

        RequeteDelete rd = new RequeteDelete(db, "contactAddressLine", "idContact", (new Integer(contact.getIdContact())).toString());
        rd.close();

        Address address = contact.getAddress();
        if (address != null) {
            Object[] lines = address.getAddressLines().toArray();
            int length = lines.length;
            for (int i = 0; i < length; i++) {
                String line = (String) lines[i];
                Object[][] value = new Object[3][2];

                value[0][0] = "idContact";
                value[0][1] = new Integer(contact.getIdContact());

                value[1][0] = "contactAddressLine";
                value[1][1] = line;

                value[2][0] = "nborder";
                value[2][1] = new Integer(i);

                RequeteInsert ri = new RequeteInsert(db, "contactAddressLine", value);
                ri.close();
            }
        }

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Vector values = new Vector();
        Vector names = new Vector();

        values.add(contact.getTitle());
        names.add("title");

        values.add(contact.getFirstname());
        names.add("firstname");

        values.add(contact.getLastname());
        names.add("lastname");

        values.add(contact.getFunction());
        names.add("function");

        values.add(contact.getTel());
        names.add("tel");

        values.add(contact.getFax());
        names.add("fax");

        values.add(contact.getEmail());
        names.add("email");

        Address address = contact.getAddress();
        if (address != null) {
            String postCode = address.getPostCode();
            String city = address.getCity();
            Country country = address.getCountry();

            values.add(postCode);
            names.add("postCode");

            values.add(city);
            names.add("city");

            names.add("countryCode");
            if (country != null)
                values.add(country.getCode());
            else
                values.add(null);
        } else {
            names.add("postCode");
            values.add(null);

            values.add(null);
            names.add("city");

            values.add(null);
            names.add("countryCode");
        }

        //dates
        if (creation)
            DatabaseFacilities.addCreationDates(values, names);
        else
            DatabaseFacilities.addUpdateDates(values, names);

        //lock: true
        values.add(Boolean.TRUE);
        names.add("lock");

        Object[][] data = new Object[values.size()][2];
        for (int i = 0; i < values.size(); i++) {
            data[i][0] = names.elementAt(i);
            data[i][1] = values.elementAt(i);
        }

        return data;
    }

    public boolean testConstraints() {
        if (contact.getLastname() == null || contact.getLastname().equals(""))
            return false;
        else
            return true;
    }

    public boolean testUpdate() {
        if (this.testConstraints()) {
            String[][] where = new String[4][3];
            where[0][0] = contact.getFirstname();
            where[0][1] = "String";
            where[0][2] = "firstname";
            where[1][0] = contact.getLastname();
            where[1][1] = "String";
            where[1][2] = "lastname";
            where[2][0] = contact.getTel();
            where[2][1] = "String";
            where[2][2] = "tel";
            where[3][0] = contact.getFax();
            where[3][1] = "String";
            where[3][2] = "fax";
            boolean test = DatabaseFacilities.testUpdate("contact", where, "idContact", contact.getIdContact());
            return test;
        } else
            return false;
    }

    public boolean testCreate() {
        if (this.testConstraints()) {
            String[][] where = new String[4][3];
            where[0][0] = contact.getFirstname();
            where[0][1] = "String";
            where[0][2] = "firstname";
            where[1][0] = contact.getLastname();
            where[1][1] = "String";
            where[1][2] = "lastname";
            where[2][0] = contact.getTel();
            where[2][1] = "String";
            where[2][2] = "tel";
            where[3][0] = contact.getEmail();
            where[3][1] = "String";
            where[3][2] = "email";
            boolean test = DatabaseFacilities.testCreate("contact", where);
            return test;
        } else
            return false;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        int idContact = contact.getIdContact();

        RequeteDelete rd1 = new RequeteDelete(db, "contactAddressLine", "idContact", new Integer(idContact));
        rd1.close();

        RequeteDelete rd2 = new RequeteDelete(db, "trainingInscriptionContact", "idContact", new Integer(idContact));
        rd2.close();

        RequeteDelete rd3 = new RequeteDelete(db, "trainingTrainingContact", "idContact", new Integer(idContact));
        rd3.close();

        RequeteDelete rd = new RequeteDelete(db, "contact", "idContact", new Integer(idContact));
        rd.close();

        db.commit();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "contact", "0", "0");
        while (rs.next()) {
            Contact contact = new Contact(rs.getInt("idContact"));
            ContactDB contactdb = new ContactDB(contact);
            contactdb.delete();
        }
        rs.close();

        db.commit();
    }

    public boolean isUsedInTraining() {
        boolean used = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "trainingInscriptionContact", "idContact", new Integer(contact.getIdContact()));
        if (rs.next()) {
            used = true;
        }
        rs.close();
        if (!used) {
            rs = new RequeteSelect(db, "trainingTrainingContact", "idContact", new Integer(contact.getIdContact()));
            if (rs.next()) {
                used = true;
            }
            rs.close();
        }

        return used;
    }
}
