// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;
import java.sql.Date;
import java.sql.Time;

import apostal.toma.data.Session;
import apostal.toma.data.Language;

/**
 * @(#) CourseSession.java
 */

public class CourseSessionDB extends SessionDB {
    CourseSession courseSession;

    public CourseSessionDB(CourseSession session) {
        super(session);

        this.courseSession = session;
    }

    public boolean loadBySessionNameAndTest(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = courseSession.getSessionName();
        where[0][1] = "String";
        where[0][2] = "sessionName";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
        if (rs.next()) {
            int id = rs.getInt("idSession");
            courseSession.setIdSession(id);
            this.loadById(language, all);
            loaded = true;
        }
        rs.close();

        return loaded;
    }

    public void loadBySessionName(Language language, boolean all) {
        this.loadBySessionNameAndTest(language, all);
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = super.loadById(language, all);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";

            RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
            if (rs.next()) {
                loaded = true;

                //text cal
                String _textual = rs.getString("textualCalendar");
                if (_textual != null) courseSession.setTextualCalendar(_textual);
                //seances
                Vector seances = new Vector();
                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "seance", where);
                while (rs2.next()) {
                    Date seanceDate = rs2.getDate("seanceDate");
                    int beginhour = rs2.getInt("beginhour");
                    int beginminute = rs2.getInt("beginminute");
                    int endhour = rs2.getInt("endhour");
                    int endminute = rs2.getInt("endminute");

                    Seance s = new Seance();
                    s.setBeginHour(beginhour);
                    s.setBeginMinute(beginminute);
                    s.setEndHour(endhour);
                    s.setEndMinute(endminute);
                    s.setSeanceDate(seanceDate);

                    seances.add(s);
                }
                rs2.close();
                courseSession.setSeances(seances);

                //location
                int idloc = rs.getNullableInt("idLocation");
                if (idloc > -1) {
                    Location location = new Location(idloc);
                    LocationDB ldb = new LocationDB(location);
                    ldb.loadById(language, false);

                    courseSession.setLocation(location);
                }
                //slot
                String slotValue = rs.getString("slotValue");
                if (slotValue != null) {
                    Slot slot = new Slot(slotValue);
                    SlotDB sdb = new SlotDB(slot);
                    sdb.loadByValue(language);

                    courseSession.setSlot(slot);
                }

                //teachers
                Vector teachers = new Vector();
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "sessionTeacher", where);
                while (rs3.next()) {
                    int idTeacher = rs3.getInt("idTeacher");
                    Teacher t = new Teacher(idTeacher);
                    TeacherDB tdb = new TeacherDB(t);
                    tdb.loadById(language, false);
                    teachers.add(t);
                }
                rs3.close();
                courseSession.setTeachers(teachers);
            }
            rs.close();


        }
        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";


            String _textual = rs.getString("textualCalendar");
            if (_textual != null) courseSession.setTextualCalendar(_textual);
            //seances
            Vector seances = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "seance", where);
            while (rs2.next()) {
                Date seanceDate = rs2.getDate("seanceDate");
                int beginhour = rs2.getInt("beginhour");
                int beginminute = rs2.getInt("beginminute");
                int endhour = rs2.getInt("endhour");
                int endminute = rs2.getInt("endminute");

                Seance s = new Seance();
                s.setBeginHour(beginhour);
                s.setBeginMinute(beginminute);
                s.setEndHour(endhour);
                s.setEndMinute(endminute);
                s.setSeanceDate(seanceDate);

                seances.add(s);
            }
            rs2.close();
            courseSession.setSeances(seances);

            //location
            int idloc = rs.getNullableInt("idLocation");
            if (idloc > -1) {
                Location location = new Location(idloc);
                LocationDB ldb = new LocationDB(location);
                ldb.loadById(language, false);

                courseSession.setLocation(location);
            }
            //slot
            String slotValue = rs.getString("slotValue");
            if (slotValue != null) {
                Slot slot = new Slot(slotValue);
                SlotDB sdb = new SlotDB(slot);
                sdb.loadByValue(language);

                courseSession.setSlot(slot);
            }

            //teachers
            Vector teachers = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "sessionTeacher", where);
            while (rs3.next()) {
                int idTeacher = rs3.getInt("idTeacher");
                Teacher t = new Teacher(idTeacher);
                TeacherDB tdb = new TeacherDB(t);
                tdb.loadById(language, false);
                teachers.add(t);
            }
            rs3.close();
            courseSession.setTeachers(teachers);
        }

        return loaded;
    }



    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";


            String _textual = rs.getString("textualCalendar");
            if (_textual != null) courseSession.setTextualCalendar(_textual);
            //seances
            Vector seances = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "seance", where);
            while (rs2.next()) {
                Date seanceDate = rs2.getDate("seanceDate");
                int beginhour = rs2.getInt("beginhour");
                int beginminute = rs2.getInt("beginminute");
                int endhour = rs2.getInt("endhour");
                int endminute = rs2.getInt("endminute");

                Seance s = new Seance();
                s.setBeginHour(beginhour);
                s.setBeginMinute(beginminute);
                s.setEndHour(endhour);
                s.setEndMinute(endminute);
                s.setSeanceDate(seanceDate);

                seances.add(s);
            }
            rs2.close();
            courseSession.setSeances(seances);

            //location
            int idloc = rs.getNullableInt("idLocation");
            if (idloc > -1) {
                Location location = new Location(idloc);
                LocationDB ldb = new LocationDB(location);
                ldb.loadById(language, true);

                courseSession.setLocation(location);
            }
            //slot
            String slotValue = rs.getString("slotValue");
            if (slotValue != null) {
                Slot slot = new Slot(slotValue);
                SlotDB sdb = new SlotDB(slot);
                sdb.loadByValue(language);

                courseSession.setSlot(slot);
            }

            //teachers
            Vector teachers = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "sessionTeacher", where);
            while (rs3.next()) {
                int idTeacher = rs3.getInt("idTeacher");
                Teacher t = new Teacher(idTeacher);
                TeacherDB tdb = new TeacherDB(t);
                tdb.loadById(language, true);
                teachers.add(t);
            }
            rs3.close();
            courseSession.setTeachers(teachers);
        }

        return loaded;
    }


    public void create() {

        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);
        RequeteInsert ri = new RequeteInsert(db, "session", insert);
        ri.close();

        String[][] where = new String[2][3];
        where[0][0] = (new Integer(session.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        where[1][0] = session.getSessionName();
        where[1][1] = "String";
        where[1][2] = "sessionName";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
        if (rs.next()) {
            session.setIdSession(rs.getInt("idSession"));
            session.setDateCreation(rs.getDate("dateCreation"));
            session.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {

        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(session.getIdSession())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idSession";

        Object[][] update = this.getSaveData(false);
        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "session", update, where);
        ru.close();

        db.commit();

        //date maj
        session.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public Object[][] getSaveData(boolean creation) {
        Object[][] data1 = super.getSaveData(creation);
        int size = data1.length;
        Object[][] data = new Object[size + 4][2];
        for (int i = 0; i < size; i++) {
            data[i][0] = data1[i][0];
            data[i][1] = data1[i][1];
        }

        //textual Calendar
        data[size][0] = "textualCalendar";
        data[size][1] = courseSession.getTextualCalendar();

        //type
        data[size + 1][0] = "type";
        data[size + 1][1] = "C";

        //location
        data[size + 2][0] = "idLocation";
        Location location = courseSession.getLocation();
        if (location != null && LocationDB.exists(location.getIdLocation()))
            data[size + 2][1] = new Integer(location.getIdLocation());
        else {
            data[size + 2][1] = null;
            courseSession.setLocation(null);
        }

        //slot
        data[size + 3][0] = "slotValue";
        Slot slot = courseSession.getSlot();
        if (slot != null)
            data[size + 3][1] = slot.getValue();
        else
            data[size + 3][1] = null;

        return data;
    }

    public void setLinks() {
        super.setLinks();

        TOMADatabase db = TOMADatabase.getInstance();

        //seances
        RequeteDelete rd = new RequeteDelete(db, "seance", "idSession", (new Integer(session.getIdSession())));
        rd.close();
        Vector seances = courseSession.getSeances();
        if (seances != null) {
            Iterator it = seances.iterator();
            while (it.hasNext()) {
                Seance s = (Seance) it.next();

                Object[][] insert = new Object[6][2];
                insert[0][0] = "seanceDate";
                insert[0][1] = s.getSeanceDate();
                insert[1][0] = "beginHour";
                insert[1][1] = new Integer(s.getBeginHour());
                insert[2][0] = "beginMinute";
                insert[2][1] = new Integer(s.getBeginMinute());
                insert[3][0] = "endHour";
                insert[3][1] = new Integer(s.getEndHour());
                insert[4][0] = "endMinute";
                insert[4][1] = new Integer(s.getEndMinute());
                insert[5][0] = "idSession";
                insert[5][1] = new Integer(session.getIdSession());

                RequeteInsert ri = new RequeteInsert(db, "seance", insert);
                ri.close();
            }
        }

        //teachers
        rd = new RequeteDelete(db, "sessionTeacher", "idSession", (new Integer(session.getIdSession())));
        rd.close();
        Vector teachers = courseSession.getTeachers();
        Vector newteachers = new Vector();
        if (teachers != null) {
            Iterator it = teachers.iterator();
            while (it.hasNext()) {
                Teacher t = (Teacher) it.next();
                if (TeacherDB.exists(t.getIdTeacher())) {
                    newteachers.add(t);

                    Object[][] insert = new Object[2][2];
                    insert[0][0] = "idSession";
                    insert[0][1] = new Integer(session.getIdSession());
                    insert[1][0] = "idTeacher";
                    insert[1][1] = new Integer(t.getIdTeacher());

                    RequeteInsert ri = new RequeteInsert(db, "sessionTeacher", insert);
                    ri.close();
                }
            }
        }
        courseSession.setTeachers(newteachers);

        db.commit();
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        //seances
        RequeteDelete rd = new RequeteDelete(db, "seance", "idSession", new Integer(session.getIdSession()));
        rd.close();

        //teachers
        RequeteDelete rd1 = new RequeteDelete(db, "sessionTeacher", "idSession", new Integer(session.getIdSession()));
        rd1.close();

        db.commit();

        super.delete();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "session", "type", "C");
        while (rs.next()) {
            CourseSession session = new CourseSession(rs.getInt("idSession"));
            CourseSessionDB courseSessiondb = new CourseSessionDB(session);
            courseSessiondb.delete();
        }
        rs.close();
        db.commit();
    }
}
