// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;

import apostal.toma.database.*;


import java.util.Vector;

import java.sql.Date;

/**

 * @(#) Modifiable.java

 */


public class DatabaseFacilities {

    public static boolean isLocked(String idname, int id, String tablename) {

        TOMADatabase db = TOMADatabase.getInstance();

        boolean locked = false;


        String[][] where = new String[1][3];


        where[0][0] = (new Integer(id)).toString();

        where[0][1] = "Integer";

        where[0][2] = idname;


        RequeteSelectWhere rs = new RequeteSelectWhere(db, tablename, where);

        if (rs.next()) {

            locked = rs.getBoolean("lock");

        }

        rs.close();


        return locked;

    }

    public static boolean unlock(String idname, int id, String tablename) {

        return DatabaseFacilities.setLock(idname, id, tablename, false);

    }


    public static boolean lock(String idname, int id, String tablename) {

        return DatabaseFacilities.setLock(idname, id, tablename, true);

    }


    public static boolean setLock(String idname, int id, String tablename, boolean lock) {

        TOMADatabase db = TOMADatabase.getInstance();

        boolean unlock = false;


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(id)).toString();

        where[0][1] = "Integer";

        where[0][2] = idname;


        Object[][] update = new Object[1][2];

        update[0][0] = "lock";

        update[0][1] = new Boolean(lock);


        RequeteUpdateWhere ru = new RequeteUpdateWhere(true, db, tablename, update, where);

        if (ru.getResult() > 0)

            unlock = true;

        ru.close();


        db.commit();

        return unlock;

    }


    public static void unlockAll() {
        DatabaseFacilities.unlockAll(false);
    }

    public static void unlockAll(boolean fromServer) {

        TOMADatabase db = TOMADatabase.getInstance(fromServer);


        Object[][] values = new Object[1][2];

        values[0][0] = "lock";

        values[0][1] = new Boolean(false);


        RequeteUpdate ru;



        //publication Unit

        ru = new RequeteUpdate(db, "publicationUnit", values, "1", "1");

        ru.close();



        //catalogue

        ru = new RequeteUpdate(db, "catalogue", values, "1", "1");

        ru.close();



        //training

        ru = new RequeteUpdate(db, "training", values, "1", "1");

        ru.close();



        //contact

        ru = new RequeteUpdate(db, "contact", values, "1", "1");

        ru.close();



        //organism

        ru = new RequeteUpdate(db, "organism", values, "1", "1");

        ru.close();



        //teacher

        ru = new RequeteUpdate(db, "teacher", values, "1", "1");

        ru.close();



        //location

        ru = new RequeteUpdate(db, "location", values, "1", "1");

        ru.close();


        db.commit();

    }


    public static boolean testUpdate(String tablename, String[][] idsec, String idname, int id) {

        boolean exist = false;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelectWhere rs = new RequeteSelectWhere(db, tablename, idsec);

        if (rs.next()) {

            // seulement les lignes diffrentes

            if (id != rs.getInt(idname)) {

                exist = true;

            }

        }

        rs.close();


        return !exist;

    }


    public static boolean testCreate(String tablename, String[][] idsec) {

        boolean exist = false;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelectWhere rs = new RequeteSelectWhere(db, tablename, idsec);

        if (rs.next()) {

            exist = true;

        }

        rs.close();


        return !exist;

    }


    public static void addCreationDates(Vector values, Vector names) {

        //date actuelle

        java.util.Date d = new java.util.Date();

        long millis = d.getTime();

        Date date = new Date(millis);


        values.add(date);

        names.add("dateMaj");


        names.add("dateCreation");

        values.add(date);

    }


    public static void addUpdateDates(Vector values, Vector names) {

        //date actuelle

        java.util.Date d = new java.util.Date();

        long millis = d.getTime();

        Date date = new Date(millis);


        values.add(date);

        names.add("dateMaj");

    }


    public static Date getDate() {

        //date actuelle

        java.util.Date d = new java.util.Date();

        long millis = d.getTime();

        Date date = new Date(millis);


        return date;

    }


    public static void removeAllData() {

        //organism

        OrganismDB.deleteAll();



        //catalogue

        CatalogueDB.deleteAll();



        //contact

        ContactDB.deleteAll();



        //CourseSession

        CourseSessionDB.deleteAll();



        //location

        LocationDB.deleteAll();



        //publicationUnit

        PublicationUnitDB.deleteAll();



        //teacher

        TeacherDB.deleteAll();



        //ProgrammeSession

        ProgrammeSessionDB.deleteAll();



        //UnitSession

        UnitSessionDB.deleteAll();



        //trainingCourse

        TrainingCourseDB.deleteAll();



        //trainingProgramme

        TrainingProgrammeDB.deleteAll();



        //unit

        UnitDB.deleteAll();

        //crer le catalogue root!!!
        CatalogueDB.createRootCatalogue();

        //crer l'organisme
        /*Organism o=new Organism();
        o.setDenomination("organism");
        OrganismDB odb=new OrganismDB(o);
        if(odb.testCreate())
            odb.create();*/
    }

}

