// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;


import java.util.Vector;

import java.util.Iterator;

import java.util.Hashtable;

import java.util.HashSet;

import toolbox.util.HashtableSort;

import apostal.toma.data.Language;

/**

 * @(#) Domain.java

 */


public class DomainDB {

    private Domain domain;


    public DomainDB(Domain domain) {

        this.domain = domain;

    }


    public static boolean exists(int idDomain) {

        boolean exists = false;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "domain", "idDomain", new Integer(idDomain));

        if (rs.next()) {

            exists = true;

        }

        rs.close();


        return exists;

    }


    public Domain getSuperDomain(Language language) {

        this.loadById(language);


        Domain d = null;

        if (DomainDB.exists(domain.getIdSuperDomain())) {

            d = new Domain(domain.getIdSuperDomain());

            DomainDB ddb = new DomainDB(d);

            ddb.loadById(language);

        }


        return d;

    }


    /**

     * enlve les domains "en double" dans cette liste en ne laissant que

     * ceux de dernier niveau

     */

    public static Vector reduceToLastLevelsDomains(Language ln, Vector domains) {

        Vector childs = new Vector();

        if (domains != null) {

            Iterator iter = domains.iterator();

            while (iter.hasNext()) {

                Domain d = (Domain) iter.next();

                DomainDB ddb = new DomainDB(d);

                //parcourir ceux dj mis

                Iterator childs_iter = childs.iterator();

                boolean replaced = false;

                while (childs_iter.hasNext() && !replaced) {

                    Domain d2 = (Domain) childs_iter.next();

                    DomainDB ddb2 = new DomainDB(d2);

                    //si d fils de d2 -> changer

                    if (ddb.isChild(ln, d2)) {

                        childs.remove(d2);

                        childs.add(d);

                        replaced = true;

                    }

                    //si d2 fils de d -> ne rien faire mais ne pas le rajouter  la fin

                    else if (ddb2.isChild(ln, d)) {

                        replaced = true;

                    }

                }

                if (!replaced) {

                    childs.add(d);

                }

            }

        }


        return childs;

    }


    /**

     * get all the domains with the given name

     * in all languages of TOMA

     * Rem: gives only one domain of each, in the first "corresponding" language:

     *this methods is only here in case 2 distinct domains (with different id) would have the same name in some language

     */

    public static Vector getDomainsByName(String name) {

        Vector domains = new Vector();

        //stocker les identifiants qu'on a dj mis, pour ne pas sauver plusieurs fois le meme domaine

        //rem: on stocke les id sous forme de String, pour etre surs de la mthode "equals"

        HashSet ids = new HashSet();


        TOMADatabase db = TOMADatabase.getInstance();



        //trouver les langues

        RequeteSelect rslang = new RequeteSelect(true, db, "distinct languageCode", "domainName", null);

        while (rslang.next()) {

            String code = rslang.getString("languageCode");

            Language l = new Language(code);


            Domain d = new Domain();

            d.setName(name);

            DomainDB ddb = new DomainDB(d);


            if (ddb.loadByName(l)) {

                String id = String.valueOf(d.getIdDomain());

                if (!ids.contains(id)) {

                    domains.add(d);

                    ids.add(id);

                }

            }

        }

        rslang.close();


        return domains;

    }


    public boolean isChild(Language ln, Domain father) {

        boolean child = false;

        int idfather = father.getIdDomain();


        DomainDB ddb = null;

        Domain current = domain;

        int id = current.getIdSuperDomain();


        while (!child && id != -1) {

            if (idfather == id)

                child = true;

            else {

                //remonter au pre d'au dessus

                current = new Domain(id);

                ddb = new DomainDB(current);

                ddb.loadById(ln);

                id = current.getIdSuperDomain();

            }

        }

        return child;

    }


    /**

     * loads the domain by its name, in the specified language

     * (the name must be given in the domainLanguage, and the domain will be loaded using this language)

     */

    public boolean loadByName(Language domainLanguage) {

        boolean found = false;

        if (domainLanguage != null) {

            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[2][3];


            where[0][0] = domain.getName();

            where[0][1] = "String";

            where[0][2] = "name";

            where[1][0] = domainLanguage.getCode();

            where[1][1] = "String";

            where[1][2] = "languageCode";


            RequeteSelectWhere rs = new RequeteSelectWhere(db, "domainName", where);

            if (rs.next()) {

                found = true;

                int id = rs.getInt("idDomain");

                domain.setIdDomain(id);

                this.loadById(domainLanguage);

            }

            rs.close();


        }

        return found;

    }


    /**

     * loads a domain by its name when not knowing in which language the name is given.

     * The language found will be used to load the domain.

     * It will be he first language found with such a domain name.

     */

    public boolean loadByName() {

        boolean found = false;


        TOMADatabase db = TOMADatabase.getInstance();



        //trouver les langues

        RequeteSelect rslang = new RequeteSelect(true, db, "distinct languageCode", "domainName", null);

        while (rslang.next() && !found) {

            String code = rslang.getString("languageCode");

            Language l = new Language(code);

            found = this.loadByName(l);

        }

        rslang.close();


        return found;

    }


    public void loadById(Language language) {

        if (language != null) {

            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];


            where[0][0] = (new Integer(domain.getIdDomain())).toString();

            where[0][1] = "Integer";

            where[0][2] = "idDomain";


            RequeteSelectWhere rs = new RequeteSelectWhere(db, "domain", where);

            if (rs.next()) {


                //name

                String[][] where2 = new String[2][3];

                where2[0][0] = (new Integer(domain.getIdDomain())).toString();

                where2[0][1] = "Integer";

                where2[0][2] = "idDomain";

                where2[1][0] = language.getCode();

                where2[1][1] = "String";

                where2[1][2] = "languageCode";

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "domainName", where2);

                if (rs2.next()) {

                    domain.setName(rs2.getString("name"));

                }

                rs2.close();


                domain.setNborder(rs.getInt("nborder"));

                domain.setIdSuperDomain(rs.getNullableInt("idSuperDomain"));



                //sub domains

                Hashtable table = new Hashtable();

                RequeteSelect rs3 = new RequeteSelect(db, "domain", "idSuperDomain", new Integer(domain.getIdDomain()));

                while (rs3.next()) {

                    int id = rs3.getInt("idDomain");

                    Domain d = new Domain(id);

                    d.setIdSuperDomain(domain.getIdDomain());


                    table.put(d, new Integer(rs3.getInt("nborder")));

                }

                rs3.close();

                HashtableSort sort = new HashtableSort(table);

                domain.setDomains(sort.sort());

            }

            rs.close();


        }

    }


    public void loadSubLevel(final Language language) {

        Vector domains = domain.getDomains();

        DomainDB ddb = null;

        if (domains != null) {

            Iterator iter = domains.iterator();

            while (iter.hasNext()) {

                Domain d = (Domain) iter.next();

                ddb = new DomainDB(d);

                ddb.loadById(language);

            }

        }

    }


    public static Vector loadFirstLevel(final Language language) {

        TOMADatabase db = TOMADatabase.getInstance();

        Vector v = new Vector();


        String where = "idSuperDomain<0 order by nborder";

        RequeteSelect rs = new RequeteSelect(db, "domain", where);

        while (rs.next()) {

            int idDomain = rs.getInt("idDomain");

            String name = null;


            if (language != null) {

                String[][] where2 = new String[2][3];

                where2[0][0] = (new Integer(idDomain)).toString();

                where2[0][1] = "Integer";

                where2[0][2] = "idDomain";


                where2[1][0] = language.getCode();

                where2[1][1] = "String";

                where2[1][2] = "languageCode";


                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "domainName", where2);

                if (rs2.next()) {

                    name = rs2.getString("name");

                }

                rs2.close();

            }


            Domain d = new Domain(idDomain);

            d.setName(name);

            d.setNborder(rs.getInt("nborder"));

            d.setIdSuperDomain(-1);

            DomainDB ddb = new DomainDB(d);

            v.add(d);

        }

        rs.close();


        return v;

    }

}

