// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;

import apostal.toma.TOMA;

import java.util.Vector;

/**

 * @(#) Language.java

 */


public class LanguageDB {

    private Language language;


    public LanguageDB(Language language) {

        this.language = language;

    }


    /*********************** database ************************/

    public void loadByCode(final Language language) {

        if (language != null)

            this.loadByCode(language.getCode());

    }


    public void loadByCode(final String languageCode) {

        TOMADatabase db = TOMADatabase.getInstance();


        if (languageCode != null && language.getCode() != null) {

            String[][] where = new String[1][3];

            where[0][0] = language.getCode();

            where[0][1] = "String";

            where[0][2] = "languageCode";


            RequeteSelectWhere rs = new RequeteSelectWhere(db, "language", where);

            if (rs.next()) {

                char forInterface = rs.getChar("interface");

                if (forInterface == '1')

                    language.setForInterface(true);

                else

                    language.setForInterface(false);


                char forPublication = rs.getChar("publication");

                if (forPublication == '1')

                    language.setForPublication(true);

                else

                    language.setForPublication(false);


                char forTraining = rs.getChar("training");

                if (forTraining == '1')

                    language.setForTraining(true);

                else

                    language.setForTraining(false);

            }

            rs.close();


            String[][] where2 = new String[2][3];

            where2[0][0] = language.getCode();

            where2[0][1] = "String";

            where2[0][2] = "languageCode";


            where2[1][0] = languageCode;

            where2[1][1] = "String";

            where2[1][2] = "interfaceLanguageCode";


            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "languageName", where2);


            if (rs2.next()) {

                language.setName(rs2.getString("name"));

            }

            rs2.close();

        }


    }


    public static Vector loadSomeLanguages(final Language language, boolean training, boolean inter, boolean publication) {

        TOMADatabase db = TOMADatabase.getInstance();

        Vector v = new Vector();

        if (language != null) {

            int size = 0;

            if (training) size++;

            if (inter) size++;

            if (publication) size++;

            String[][] where_lng = new String[size][3];

            int cpt = 0;

            if (training) {

                where_lng[cpt][0] = "1";

                where_lng[cpt][1] = "String";

                where_lng[cpt][2] = "training";

                cpt++;

            }

            if (inter) {

                where_lng[cpt][0] = "1";

                where_lng[cpt][1] = "String";

                where_lng[cpt][2] = "interface";

                cpt++;

            }

            if (publication) {

                where_lng[cpt][0] = "1";

                where_lng[cpt][1] = "String";

                where_lng[cpt][2] = "publication";

            }

            RequeteSelectWhere rs_lng = new RequeteSelectWhere(db, "language", where_lng);

            while (rs_lng.next()) {


                String code = rs_lng.getString("languageCode");

                boolean forInterface = rs_lng.getBoolean("interface");

                boolean forPublication = rs_lng.getBoolean("publication");

                boolean forTraining = rs_lng.getBoolean("training");

                String name = null;


                String[][] where2 = new String[2][3];

                where2[0][0] = code;

                where2[0][1] = "String";

                where2[0][2] = "languageCode";

                where2[1][0] = language.getCode();

                where2[1][1] = "String";

                where2[1][2] = "interfaceLanguageCode";


                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "languageName", where2);

                if (rs2.next()) {

                    name = rs2.getString("name");

                }

                rs2.close();


                Language l = new Language(code, name, forInterface, forPublication, forTraining);


                v.add(l);

            }

            rs_lng.close();


        }


        return v;

    }


    public static Vector load(final Language language) {

        TOMADatabase db = TOMADatabase.getInstance();

        Vector v = new Vector();

        String[][] where = new String[0][3];


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "language", where);

        while (rs.next()) {

            String code = rs.getString("languageCode");

            boolean forInterface = rs.getBoolean("interface");

            boolean forPublication = rs.getBoolean("publication");

            boolean forTraining = rs.getBoolean("training");

            String name = null;


            if (language != null) {


                String[][] where2 = new String[2][3];

                where2[0][0] = code;

                where2[0][1] = "String";

                where2[0][2] = "languageCode";

                where2[1][0] = language.getCode();

                where2[1][1] = "String";

                where2[1][2] = "interfaceLanguageCode";


                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "languageName", where2);

                if (rs2.next()) {

                    name = rs2.getString("name");

                }

                rs2.close();

            }

            Language l = new Language(code, name, forInterface, forPublication, forTraining);


            v.add(l);

        }

        rs.close();


        return v;

    }

}

