// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;
import java.util.HashSet;
import java.sql.Date;

import apostal.toma.data.Area;
import apostal.toma.data.Address;
import apostal.toma.data.Language;

/**
 * @(#) Location.java
 */

public class LocationDB implements Modifiable {

    private Location location;

    public static boolean exists(int idLocation) {
        boolean exists = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "location", "idLocation", new Integer(idLocation));
        if (rs.next()) {
            exists = true;
        }
        rs.close();


        return exists;
    }

    public LocationDB(Location location) {
        this.location = location;
    }

    /**
     * returns all the trainings that use this location
     */
    public Vector getTrainingsByLocation(Language lng, boolean all) {
        HashSet found = new HashSet();
        Vector trainings = new Vector();
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "trainingLocation", "idLocation", new Integer(location.getIdLocation()));
        while (rs.next()) {
            int id = rs.getInt("idTraining");
            Training t = TrainingDB.getInstance(lng, all, id);
            trainings.add(t);
            found.add(new Integer(id));
        }
        rs.close();
        //locations dans des sessions
        rs = new RequeteSelect(db, "session", "idLocation", new Integer(location.getIdLocation()));
        while (rs.next()) {
            int id = rs.getInt("idTraining");
            if (!found.contains(new Integer(id))) {
                Training t = TrainingDB.getInstance(lng, all, id);
                trainings.add(t);
                found.add(new Integer(id));
            }
        }
        rs.close();
        //locations dans des programme sessions
        rs = new RequeteSelect(db, "programmeSessionLocation", "idLocation", new Integer(location.getIdLocation()));
        while (rs.next()) {
            int ids = rs.getInt("idSession");
            RequeteSelect rs2 = new RequeteSelect(db, "session", "idSession", new Integer(ids));
            if (rs2.next()) {
                int id = rs2.getInt("idTraining");
                if (!found.contains(new Integer(id))) {
                    Training t = TrainingDB.getInstance(lng, all, id);
                    trainings.add(t);
                    found.add(new Integer(id));
                }
            }
            rs2.close();
        }
        rs.close();


        return trainings;
    }

    public static Vector load(Language language, boolean all) {
        TOMADatabase db = TOMADatabase.getInstance();

        Vector locations = new Vector();
        String[][] values = new String[0][3];
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "location", values);
        while (rs.next()) {
            int id = rs.getInt("idLocation");
            Location t = new Location(id);
            LocationDB tdb = new LocationDB(t);
            tdb.loadByIdAndRS(language, all, rs);

            locations.add(t);
        }
        rs.close();


        return locations;
    }

    public boolean loadByDenominationAndTest(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = location.getDenomination();
        where[0][1] = "String";
        where[0][2] = "denomination";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "location", where);
        if (rs.next()) {
            int id = rs.getInt("idLocation");
            location.setIdLocation(id);
            this.loadByIdAndRS(language, all, rs);
            loaded = true;
        }
        rs.close();

        return loaded;
    }

    public void loadByDenomination(Language language, boolean all) {
        this.loadByDenominationAndTest(language, all);
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(location.getIdLocation())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idLocation";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "location", where);
        if (rs.next()) {
            loaded = true;
            location.setDenomination(rs.getString("denomination"));

            if (all) {
                String compl = rs.getString("completeName");
                if (compl != null)
                    location.setCompleteName(compl);
                String _tel = rs.getString("tel");
                if (_tel != null)
                    location.setTel(_tel);
                String _fax = rs.getString("fax");
                if (_fax != null)
                    location.setFax(_fax);
                String _email = rs.getString("email");
                if (_email != null)
                    location.setEmail(_email);

                String postCode = rs.getString("postCode");
                String city = rs.getString("city");
                String countryCode = rs.getString("countryCode");
                if (countryCode != null) {
                    Country c = new Country(countryCode);
                    CountryDB cdb = new CountryDB(c);
                    cdb.loadByCode(language);

                    Vector lines = new Vector();

                    RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "locationAddressLine", where, "nborder");
                    while (rs2.next()) {
                        int nborder = rs2.getInt("nborder");
                        String line = rs2.getString("locationAddressLine");
                        lines.add(line);
                    }
                    rs2.close();

                    Address address = new Address(lines, city, postCode, c);
                    location.setAddress(address);
                }

                int idArea = rs.getNullableInt("idArea");
                if (idArea > -1) {
                    Area a = new Area(idArea);
                    AreaDB adb = new AreaDB(a);
                    adb.loadById(language);
                    location.setArea(a);
                }

                String accessDesc = rs.getString("accessDescription");
                if (accessDesc != null)
                    location.setAccessDescription(accessDesc);
                String accessComm = rs.getString("accessComment");
                if (accessComm != null)
                    location.setAccessComment(accessComm);
                String accessFac = rs.getString("accessFacilities");
                if (accessFac != null)
                    location.setAccessFacilities(accessFac);

                location.setDateCreation(rs.getDate("dateCreation"));
                location.setDateMaj(rs.getDate("dateMaj"));

                //images
                Vector images = new Vector();
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "image", where);
                while (rs3.next()) {
                    images.add(rs3.getString("image"));
                }
                rs3.close();
                location.setImages(images);
            }
        }
        rs.close();


        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = true;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(location.getIdLocation())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idLocation";

        /*RequeteSelectWhere rs=new RequeteSelectWhere(db, "location", where);
        if(rs.next())
            {
            loaded=true;*/
        location.setDenomination(rs.getString("denomination"));

        if (all) {
            String compl = rs.getString("completeName");
            if (compl != null)
                location.setCompleteName(compl);
            String _tel = rs.getString("tel");
            if (_tel != null)
                location.setTel(_tel);
            String _fax = rs.getString("fax");
            if (_fax != null)
                location.setFax(_fax);
            String _email = rs.getString("email");
            if (_email != null)
                location.setEmail(_email);

            String postCode = rs.getString("postCode");
            String city = rs.getString("city");
            String countryCode = rs.getString("countryCode");
            if (countryCode != null) {
                Country c = new Country(countryCode);
                CountryDB cdb = new CountryDB(c);
                cdb.loadByCode(language);

                Vector lines = new Vector();

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "locationAddressLine", where, "nborder");
                while (rs2.next()) {
                    int nborder = rs2.getInt("nborder");
                    String line = rs2.getString("locationAddressLine");
                    lines.add(line);
                }
                rs2.close();

                Address address = new Address(lines, city, postCode, c);
                location.setAddress(address);
            }

            int idArea = rs.getNullableInt("idArea");
            if (idArea > -1) {
                Area a = new Area(idArea);
                AreaDB adb = new AreaDB(a);
                adb.loadById(language);
                location.setArea(a);
            }

            String accessDesc = rs.getString("accessDescription");
            if (accessDesc != null)
                location.setAccessDescription(accessDesc);
            String accessComm = rs.getString("accessComment");
            if (accessComm != null)
                location.setAccessComment(accessComm);
            String accessFac = rs.getString("accessFacilities");
            if (accessFac != null)
                location.setAccessFacilities(accessFac);

            location.setDateCreation(rs.getDate("dateCreation"));
            location.setDateMaj(rs.getDate("dateMaj"));

            //images
            Vector images = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "image", where);
            while (rs3.next()) {
                images.add(rs3.getString("image"));
            }
            rs3.close();
            location.setImages(images);
        }
        /*   }
       rs.close();*/


        return loaded;
    }

    public boolean unlock() {
        boolean unlock = DatabaseFacilities.unlock("idLocation", location.getIdLocation(), "location");
        return unlock;
    }

    public boolean lock() {
        boolean lock = DatabaseFacilities.lock("idLocation", location.getIdLocation(), "location");
        return lock;
    }

    public boolean isLocked() {
        boolean locked = DatabaseFacilities.isLocked("idLocation", location.getIdLocation(), "location");
        return locked;
    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();
        Object[][] insert = this.getSaveData(true);
        RequeteInsert ri = new RequeteInsert(db, "location", insert);
        ri.close();
        //rcuprer l'idLocation
        String[][] where = new String[1][3];
        where[0][0] = location.getDenomination();
        where[0][1] = "String";
        where[0][2] = "denomination";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "location", where);
        if (rs.next()) {
            location.setIdLocation(rs.getInt("idLocation"));
            location.setDateCreation(rs.getDate("dateCreation"));
            location.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();
        db.commit();
        //date maj
        location.setDateMaj(DatabaseFacilities.getDate());
        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] update = this.getSaveData(false);

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(location.getIdLocation())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idLocation";

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "location", update, where);
        ru.close();

        db.commit();

        this.setLinks();
    }

    public void setLinks() {
        TOMADatabase db = TOMADatabase.getInstance();

        //address lines
        //enlever toutes celles existant
        RequeteDelete rd = new RequeteDelete(db, "locationAddressLine", "idLocation", (new Integer(location.getIdLocation())).toString());
        rd.close();
        //rajouter les nouvelles
        Address address = location.getAddress();
        if (address != null) {
            Object[] lines = address.getAddressLines().toArray();
            int length = lines.length;
            for (int i = 0; i < length; i++) {
                String line = (String) lines[i];
                Object[][] value = new Object[3][2];

                value[0][0] = "idLocation";
                value[0][1] = new Integer(location.getIdLocation());

                value[1][0] = "locationAddressLine";
                value[1][1] = line;

                value[2][0] = "nborder";
                value[2][1] = new Integer(i);

                RequeteInsert ri2 = new RequeteInsert(db, "locationAddressLine", value);
                ri2.close();
            }
        }
        //images
        rd = new RequeteDelete(db, "image", "idLocation", (new Integer(location.getIdLocation())).toString());
        rd.close();
        Vector images = location.getImages();
        if (images != null) {
            Iterator it = images.iterator();
            while (it.hasNext()) {
                String image = (String) it.next();

                String[][] whereim = new String[2][3];
                whereim[0][0] = (new Integer(location.getIdLocation())).toString();
                whereim[0][1] = "Integer";
                whereim[0][2] = "idLocation";
                whereim[1][0] = image;
                whereim[1][1] = "String";
                whereim[1][2] = "image";
                RequeteSelectWhere rsim = new RequeteSelectWhere(db, "image", whereim);
                if (!rsim.next()) {
                    Object[][] value = new Object[2][2];
                    value[0][0] = "idLocation";
                    value[0][1] = new Integer(location.getIdLocation());
                    value[1][0] = "image";
                    value[1][1] = image;

                    RequeteInsert ri2 = new RequeteInsert(db, "image", value);
                    ri2.close();
                }
                rsim.close();
            }
        }

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Vector values = new Vector();
        Vector names = new Vector();

        names.add("denomination");
        values.add(location.getDenomination());

        names.add("completeName");
        values.add(location.getCompleteName());

        names.add("tel");
        values.add(location.getTel());

        names.add("fax");
        values.add(location.getFax());

        names.add("email");
        values.add(location.getEmail());

        Address address = location.getAddress();
        if (address != null) {
            String postCode = address.getPostCode();
            String city = address.getCity();
            Country country = address.getCountry();

            values.add(postCode);
            names.add("postCode");

            values.add(city);
            names.add("city");

            names.add("countryCode");
            if (country != null)
                values.add(country.getCode());
            else
                values.add(null);
        } else {
            values.add(null);
            names.add("postCode");

            values.add(null);
            names.add("city");

            values.add(null);
            names.add("countryCode");

        }

        Area area = location.getArea();
        names.add("idArea");
        if (area != null)
            values.add(new Integer(area.getIdArea()));
        else
            values.add(null);

        names.add("accessDescription");
        values.add(location.getAccessDescription());

        names.add("accessComment");
        values.add(location.getAccessComment());

        names.add("accessFacilities");
        values.add(location.getAccessFacilities());

        if (creation)
            DatabaseFacilities.addCreationDates(values, names);
        else
            DatabaseFacilities.addUpdateDates(values, names);

        names.add("lock");
        values.add(Boolean.TRUE);

        Object[][] data = new Object[values.size()][2];
        for (int i = 0; i < values.size(); i++) {
            data[i][0] = names.elementAt(i);
            data[i][1] = values.elementAt(i);
        }

        return data;
    }

    public boolean testConstraints() {
        if (location.getDenomination() == null || location.getDenomination().equals(""))
            return false;
        else
            return true;
    }

    public boolean testUpdate() {
        if (this.testConstraints()) {
            String[][] where = new String[1][3];
            where[0][0] = location.getDenomination();
            where[0][1] = "String";
            where[0][2] = "denomination";
            boolean test = DatabaseFacilities.testUpdate("location", where, "idLocation", location.getIdLocation());
            return test;
        } else
            return false;
    }

    public boolean testCreate() {
        if (this.testConstraints()) {
            String[][] where = new String[1][3];
            where[0][0] = location.getDenomination();
            where[0][1] = "String";
            where[0][2] = "denomination";
            boolean test = DatabaseFacilities.testCreate("location", where);
            return test;
        } else
            return false;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        //lng=default lng
        Language lng = new Language(Language.defaultLanguageCode);

        int idLocation = location.getIdLocation();

        //session ayant ce location
        RequeteSelect rs = new RequeteSelect(db, "session", "idLocation", new Integer(idLocation));
        while (rs.next()) {
            char type = rs.getChar("type");
            if (type == 'U') {
                UnitSession us = new UnitSession(rs.getInt("idSession"));
                UnitSessionDB usdb = new UnitSessionDB(us);
                usdb.loadById(lng, true);
                us.setLocation(null);
                usdb.update();
            } else //trainingCourse (il n'y en n'a jamais pour les tp)
            {
                CourseSession cs = new CourseSession(rs.getInt("idSession"));
                CourseSessionDB csdb = new CourseSessionDB(cs);
                csdb.loadById(lng, true);
                cs.setLocation(null);
                csdb.update();
            }
        }
        rs.close();

        //programmeSession ayant ce location
        RequeteSelect rs_ps = new RequeteSelect(db, "programmeSessionLocation", "idLocation", new Integer(idLocation));
        while (rs_ps.next()) {
            ProgrammeSession ps = new ProgrammeSession(rs_ps.getInt("idSession"));
            ProgrammeSessionDB psdb = new ProgrammeSessionDB(ps);
            psdb.loadById(lng, true);
            ps.setLocations(new Vector());
            psdb.update();
        }
        rs.close();

        RequeteDelete rd1 = new RequeteDelete(db, "locationAddressLine", "idLocation", new Integer(idLocation));
        rd1.close();
        RequeteDelete rd2 = new RequeteDelete(db, "trainingLocation", "idLocation", new Integer(idLocation));
        rd2.close();
        RequeteDelete rd3 = new RequeteDelete(db, "image", "idLocation", new Integer(idLocation));
        rd3.close();

        RequeteDelete rd = new RequeteDelete(db, "location", "idLocation", new Integer(idLocation));
        rd.close();

        db.commit();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "location", "0", "0");
        while (rs.next()) {
            Location location = new Location(rs.getInt("idLocation"));
            LocationDB locationdb = new LocationDB(location);
            locationdb.delete();
        }
        rs.close();
        db.commit();
    }

    public boolean isUsedInTraining() {
        boolean used = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "trainingLocation", "idLocation", new Integer(location.getIdLocation()));
        if (rs.next()) {
            used = true;
        }
        rs.close();

        return used;
    }
}
