// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;

import apostal.toma.*;


import java.util.Vector;

import apostal.toma.data.Language;


/**

 * @(#) Organism.java

 */


public class OrganismDB implements Modifiable {


    private Organism organism;


    public OrganismDB(Organism organism) {

        this.organism = organism;

    }


    public static Organism getOrganism(Language language, boolean all) {

        Organism o = null;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "organism", "0", "0");

        if (rs.next()) {

            o = new Organism(rs.getInt("idOrganism"));

            OrganismDB odb = new OrganismDB(o);

            odb.loadById(language, all);

        }

        rs.close();


        return o;

    }


    /*************** database access ***********************/

    public boolean loadById(Language language, boolean all) {

        boolean loaded = false;

        if (all) {

            TOMADatabase db = TOMADatabase.getInstance();


            String[][] where = new String[1][3];

            where[0][0] = (new Integer(organism.getIdOrganism())).toString();

            where[0][1] = "Integer";

            where[0][2] = "idOrganism";


            RequeteSelectWhere rs = new RequeteSelectWhere(db, "organism", where);

            if (rs.next()) {

                loaded = true;


                organism.setDenomination(rs.getString("denomination"));

                String compl = rs.getString("completeName");

                if (compl != null)

                    organism.setCompleteName(compl);

                String pres = rs.getString("presentation");

                if (pres != null)

                    organism.setPresentation(pres);

                String _url = rs.getString("url");

                if (_url != null)

                    organism.setUrl(_url);



                //addresses

                Vector addresses = new Vector();

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "organismAddress", where, "nborder");

                while (rs2.next()) {

                    String postCode = rs2.getString("postCode");

                    String city = rs2.getString("city");

                    String countryCode = rs2.getString("countryCode");

                    Country c = null;

                    if (countryCode != null) {

                        c = new Country(countryCode);

                        CountryDB cdb = new CountryDB(c);

                        cdb.loadByCode(language);

                    }



                    //address lines

                    Vector lines = new Vector();

                    String[][] where2 = new String[1][3];

                    where2[0][0] = (new Integer(rs2.getInt("idOrganismAddress"))).toString();

                    where2[0][1] = "Integer";

                    where2[0][2] = "idOrganismAddress";


                    RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "organismAddressLine", where2, "nborder");

                    while (rs3.next()) {

                        String line = rs3.getString("organismAddressLine");


                        lines.add(line);

                    }

                    rs3.close();


                    Address add = new Address(lines, city, postCode, c);

                    addresses.add(add);

                }

                rs2.close();

                organism.setAddresses(addresses);

            }

            rs.close();


        }

        return loaded;

    }


    public boolean unlock() {

        boolean unlock = DatabaseFacilities.unlock("idOrganism", organism.getIdOrganism(), "organism");

        return unlock;

    }

    public boolean lock() {

        boolean lock = DatabaseFacilities.lock("idOrganism", organism.getIdOrganism(), "organism");

        return lock;

    }


    public boolean isLocked() {

        boolean locked = DatabaseFacilities.isLocked("idOrganism", organism.getIdOrganism(), "organism");

        return locked;

    }


    public void create() {

        TOMADatabase db = TOMADatabase.getInstance();


        Object[][] insert = this.getSaveData(true);


        RequeteInsert ri = new RequeteInsert(db, "organism", insert);

        ri.close();



        //rcuprer l'idContact

        String[][] where = new String[1][3];

        where[0][0] = organism.getDenomination();

        where[0][1] = "String";

        where[0][2] = "denomination";


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "organism", where);

        if (rs.next()) {

            organism.setIdOrganism(rs.getInt("idOrganism"));

        }

        rs.close();


        db.commit();


        this.setLinks();

        this.unlock();
    }

    public void update() {

        TOMADatabase db = TOMADatabase.getInstance();


        Object[][] update = this.getSaveData(false);


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(organism.getIdOrganism())).toString();

        where[0][1] = "Integer";

        where[0][2] = "idOrganism";


        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "organism", update, where);

        ru.close();


        db.commit();


        this.setLinks();

    }


    public void setLinks() {

        TOMADatabase db = TOMADatabase.getInstance();



        //addresses



        //enlever les addresslines

        RequeteSelect rsadd = new RequeteSelect(db, "organismAddress", "idOrganism", new Integer(organism.getIdOrganism()));

        while (rsadd.next()) {

            int idadd = rsadd.getInt("idOrganismAddress");


            RequeteDelete rdline = new RequeteDelete(db, "organismAddressLine", "idOrganismAddress", (new Integer(idadd)).toString());

            rdline.close();

        }

        rsadd.close();



        //enlever toutes les adresses existantes

        RequeteDelete rd = new RequeteDelete(db, "organismAddress", "idOrganism", (new Integer(organism.getIdOrganism())).toString());

        rd.close();

        //rajouter les nouvelles

        Vector addresses = organism.getAddresses();

        if (addresses != null) {

            Object[] addresss = addresses.toArray();

            int length = addresss.length;

            for (int i = 0; i < length; i++) {

                Address address = (Address) addresss[i];

                Object[][] value = new Object[5][2];

                value[0][0] = "idOrganism";

                value[0][1] = new Integer(organism.getIdOrganism());


                value[1][0] = "postCode";

                value[1][1] = address.getPostCode();


                value[2][0] = "city";

                value[2][1] = address.getCity();


                Country country = address.getCountry();

                String code = null;

                if (country != null)

                    code = country.getCode();


                value[3][0] = "countryCode";

                value[3][1] = code;


                value[4][0] = "nborder";

                value[4][1] = new Integer(i);


                RequeteInsert ri2 = new RequeteInsert(db, "organismAddress", value);

                ri2.close();



                //rcuprer l'idAddress

                int idAddress = 0;

                String[][] where2 = new String[2][3];

                where2[0][0] = (new Integer(organism.getIdOrganism())).toString();

                where2[0][1] = "Integer";

                where2[0][2] = "idOrganism";

                where2[1][0] = (new Integer(i)).toString();

                where2[1][1] = "Integer";

                where2[1][2] = "nborder";

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "organismAddress", where2);

                if (rs2.next()) {

                    idAddress = rs2.getInt("idOrganismAddress");



                    //address lines

                    Vector addressLines = address.getAddressLines();

                    if (addressLines != null) {

                        Object[] lines = addressLines.toArray();

                        int length2 = lines.length;

                        for (int j = 0; j < length2; j++) {

                            String line = (String) lines[j];

                            Object[][] value2 = new Object[3][2];

                            value2[0][0] = "idOrganismAddress";

                            value2[0][1] = new Integer(idAddress);


                            value2[1][0] = "organismAddressLine";

                            value2[1][1] = line;


                            value2[2][0] = "nborder";

                            value2[2][1] = new Integer(j);


                            RequeteInsert ri3 = new RequeteInsert(db, "organismAddressLine", value2);

                            ri3.close();


                        }

                    }

                } else

                    TOMA.log(TOMA.SEVERE, "no organismAddress with idOrganism=" + new Integer(organism.getIdOrganism()) + " and order=" + new Integer(i));

                rs2.close();

            }

        }


        db.commit();

    }


    public Object[][] getSaveData(boolean create) {

        Vector values = new Vector();

        Vector names = new Vector();


        names.add("denomination");

        values.add(organism.getDenomination());


        names.add("completeName");

        values.add(organism.getCompleteName());


        names.add("presentation");

        values.add(organism.getPresentation());


        names.add("url");

        values.add(organism.getUrl());


        names.add("lock");

        values.add(Boolean.TRUE);


        Object[][] data = new Object[values.size()][2];

        for (int i = 0; i < values.size(); i++) {

            data[i][0] = names.elementAt(i);

            data[i][1] = values.elementAt(i);

        }


        return data;

    }


    public boolean testUpdate() {
        return this.testConstraints();
    }

    public boolean testCreate() {
        //return this.testConstraints();
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "organism", "0", "0");
        if (!rs.next()) //s'il n'existe pas dj un organisme
            return this.testConstraints();
        else //s'il existe dj un organisme: TOMA mono-organisme
            return false;
    }


    public boolean testConstraints() {

        if (organism.getDenomination() == null || organism.getDenomination().equals(""))

            return false;

        else

            return true;

    }


    public void delete() {

        TOMADatabase db = TOMADatabase.getInstance();


        int idOrganism = organism.getIdOrganism();


        RequeteSelect rs = new RequeteSelect(db, "organismAddress", "idOrganism", new Integer(idOrganism));

        while (rs.next()) {

            int idAddress = rs.getInt("idOrganismAddress");


            RequeteDelete rd = new RequeteDelete(db, "organismAddressLine", "idOrganismAddress", (new Integer(idAddress)).toString());

            rd.close();

        }

        rs.close();


        RequeteDelete rd1 = new RequeteDelete(db, "organismAddress", "idOrganism", new Integer(idOrganism));

        rd1.close();


        RequeteDelete rd = new RequeteDelete(db, "organism", "idOrganism", new Integer(idOrganism));

        rd.close();


        db.commit();

    }


    public static void deleteAll() {

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "organism", "0", "0");

        while (rs.next()) {

            Organism organism = new Organism(rs.getInt("idOrganism"));

            OrganismDB organismdb = new OrganismDB(organism);

            organismdb.delete();

        }

        rs.close();

        db.commit();

    }

}

