// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;

/**
 * @(#) ProgrammeSession.java
 */

public class ProgrammeSessionDB extends SessionDB {
    private ProgrammeSession programmeSession;

    public ProgrammeSessionDB(ProgrammeSession session) {
        super(session);
        this.programmeSession = session;
    }

    public boolean loadBySessionNameAndTest(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = programmeSession.getSessionName();
        where[0][1] = "String";
        where[0][2] = "sessionName";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
        if (rs.next()) {
            int id = rs.getInt("idSession");
            programmeSession.setIdSession(id);
            this.loadById(language, all);
            loaded = true;
        }
        rs.close();

        return loaded;
    }

    public void loadBySessionName(Language language, boolean all) {
        this.loadBySessionNameAndTest(language, all);
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = super.loadById(language, all);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";

            RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
            if (rs.next()) {
                loaded = true;

                //locations
                Vector locations = new Vector();
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "programmeSessionLocation", where);
                while (rs3.next()) {
                    int idLocation = rs3.getInt("idLocation");
                    Location loc = new Location(idLocation);
                    LocationDB ldb = new LocationDB(loc);
                    ldb.loadById(language, false);
                    locations.add(loc);
                }
                rs3.close();
                programmeSession.setLocations(locations);

                //slots
                Vector slots = new Vector();
                RequeteSelectWhere rs_slots = new RequeteSelectWhere(db, "programmeSessionSlot", where);
                while (rs_slots.next()) {
                    String value = rs_slots.getString("slotValue");
                    Slot s = new Slot(value);
                    SlotDB sdb = new SlotDB(s);
                    sdb.loadByValue(language);
                    slots.add(s);
                }
                rs_slots.close();
                programmeSession.setSlots(slots);
            }
            rs.close();


        }
        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";

            //locations
            Vector locations = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "programmeSessionLocation", where);
            while (rs3.next()) {
                int idLocation = rs3.getInt("idLocation");
                Location loc = new Location(idLocation);
                LocationDB ldb = new LocationDB(loc);
                ldb.loadById(language, false);
                locations.add(loc);
            }
            rs3.close();
            programmeSession.setLocations(locations);

            //slots
            Vector slots = new Vector();
            RequeteSelectWhere rs_slots = new RequeteSelectWhere(db, "programmeSessionSlot", where);
            while (rs_slots.next()) {
                String value = rs_slots.getString("slotValue");
                Slot s = new Slot(value);
                SlotDB sdb = new SlotDB(s);
                sdb.loadByValue(language);
                slots.add(s);
            }
            rs_slots.close();
            programmeSession.setSlots(slots);
        }

        return loaded;
    }


    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            String[][] where = new String[1][3];
            where[0][0] = (new Integer(session.getIdSession())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idSession";

            //locations
            Vector locations = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "programmeSessionLocation", where);
            while (rs3.next()) {
                int idLocation = rs3.getInt("idLocation");
                Location loc = new Location(idLocation);
                LocationDB ldb = new LocationDB(loc);
                ldb.loadById(language, true);
                locations.add(loc);
            }
            rs3.close();
            programmeSession.setLocations(locations);

            //slots
            Vector slots = new Vector();
            RequeteSelectWhere rs_slots = new RequeteSelectWhere(db, "programmeSessionSlot", where);
            while (rs_slots.next()) {
                String value = rs_slots.getString("slotValue");
                Slot s = new Slot(value);
                SlotDB sdb = new SlotDB(s);
                sdb.loadByValue(language);
                slots.add(s);
            }
            rs_slots.close();
            programmeSession.setSlots(slots);
        }

        return loaded;
    }


    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);
        RequeteInsert ri = new RequeteInsert(db, "session", insert);
        ri.close();

        String[][] where = new String[2][3];
        where[0][0] = (new Integer(session.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        where[1][0] = session.getSessionName();
        where[1][1] = "String";
        where[1][2] = "sessionName";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
        if (rs.next()) {
            session.setIdSession(rs.getInt("idSession"));
            session.setDateCreation(rs.getDate("dateCreation"));
            session.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(session.getIdSession())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idSession";

        Object[][] update = this.getSaveData(false);
        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "session", update, where);
        ru.close();

        db.commit();

        //date maj
        session.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public Object[][] getSaveData(boolean creation) {
        Object[][] data1 = super.getSaveData(creation);
        int size = data1.length;
        Object[][] data = new Object[size + 1][2];
        for (int i = 0; i < size; i++) {
            data[i][0] = data1[i][0];
            data[i][1] = data1[i][1];
        }

        data[size][0] = "type";
        data[size][1] = "P";

        return data;
    }

    public void setLinks() {
        super.setLinks();

        TOMADatabase db = TOMADatabase.getInstance();

        //locations
        RequeteDelete rd = new RequeteDelete(db, "programmeSessionLocation", "idSession", (new Integer(session.getIdSession())));
        rd.close();
        Vector locations = programmeSession.getLocations();
        Vector newlocs = new Vector();
        if (locations != null) {
            Iterator it = locations.iterator();
            while (it.hasNext()) {
                Location loc = (Location) it.next();

                if (LocationDB.exists(loc.getIdLocation())) {
                    newlocs.add(loc);

                    Object[][] insert = new Object[2][2];
                    insert[0][0] = "idSession";
                    insert[0][1] = new Integer(session.getIdSession());
                    insert[1][0] = "idLocation";
                    insert[1][1] = new Integer(loc.getIdLocation());

                    RequeteInsert ri = new RequeteInsert(db, "programmeSessionLocation", insert);
                    ri.close();
                }
            }
        }
        programmeSession.setLocations(newlocs);

        //slots
        rd = new RequeteDelete(db, "programmeSessionSlot", "idSession", (new Integer(session.getIdSession())));
        rd.close();
        Vector slots = programmeSession.getSlots();
        if (slots != null) {
            Iterator it = slots.iterator();
            while (it.hasNext()) {
                Slot slot = (Slot) it.next();

                Object[][] insert = new Object[2][2];
                insert[0][0] = "idSession";
                insert[0][1] = new Integer(session.getIdSession());
                insert[1][0] = "slotValue";
                insert[1][1] = slot.getValue();

                RequeteInsert ri = new RequeteInsert(db, "programmeSessionSlot", insert);
                ri.close();
            }
        }

        db.commit();
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        //locations
        RequeteDelete rd1 = new RequeteDelete(db, "programmeSessionLocation", "idSession", new Integer(session.getIdSession()));
        rd1.close();

        //slots
        RequeteDelete rd2 = new RequeteDelete(db, "programmeSessionSlot", "idSession", new Integer(session.getIdSession()));
        rd2.close();

        db.commit();

        super.delete();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "session", "type", "P");
        while (rs.next()) {
            ProgrammeSession session = new ProgrammeSession(rs.getInt("idSession"));
            ProgrammeSessionDB pSessiondb = new ProgrammeSessionDB(session);
            pSessiondb.delete();
        }
        rs.close();
        db.commit();
    }
}
