// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import toolbox.util.HashtableSort;

import java.sql.Date;

import apostal.toma.data.Language;

/**
 * @(#) PublicationUnit.java
 */

public class PublicationUnitDB implements Modifiable {

    private final static char PUBLICATION_XML_CHAR='X';
    private final static char PUBLICATION_HTML_CHAR='H';
    private final static char PUBLICATION_PDF_CHAR='P';
    private final static char PUBLICATION_SOAP_CHAR='S';
    private final static char PUBLICATION_RTF_CHAR='R';
    private final static char PUBLICATION_XSL_CHAR='T';
	private final static char PUBLICATION_SOAP_DELETE_CHAR='D';    
    
    private PublicationUnit publicationUnit;

    public PublicationUnitDB(PublicationUnit publicationUnit) {
        this.publicationUnit = publicationUnit;
    }

    public static Vector load(Language language, boolean all) {
        TOMADatabase db = TOMADatabase.getInstance();

        Vector pubs = new Vector();
        String[][] values = new String[0][3];
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "publicationUnit", values);
        while (rs.next()) {
            int id = rs.getInt("idPublicationUnit");
            PublicationUnit pub = new PublicationUnit(id);
            PublicationUnitDB pdb = new PublicationUnitDB(pub);
            pdb.loadByIdAndRS(language, all,rs);

            pubs.add(pub);
        }
        rs.close();

        return pubs;
    }

    /*************** database access ***********************/
    public boolean loadByName(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = publicationUnit.getName();
        where[0][1] = "String";
        where[0][2] = "name";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "publicationUnit", where);
        if (rs.next()) {
            loaded = true;
            int id = rs.getInt("idPublicationUnit");
            publicationUnit.setIdPublicationUnit(id);
            this.loadByIdAndRS(language, all,rs);
        }
        rs.close();

        return loaded;
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(publicationUnit.getIdPublicationUnit())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idPublicationUnit";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "publicationUnit", where);
        if (rs.next()) {
            loaded = true;
            publicationUnit.setName(rs.getString("name"));

            char _type = rs.getChar("type");
            if (_type == PUBLICATION_XML_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_XML);
            else if (_type == PUBLICATION_HTML_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_HTML);
            else if (_type == PUBLICATION_PDF_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_PDF);
            else if (_type == PUBLICATION_SOAP_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_SOAP);
            else if (_type == PUBLICATION_RTF_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_RTF);
            else if (_type == PUBLICATION_XSL_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_XSL);
			else if (_type == PUBLICATION_SOAP_DELETE_CHAR)
                publicationUnit.setType(PublicationUnit.PUBLICATION_SOAP_DELETE);

            publicationUnit.setDateLastPublished(rs.getDate("dateLastPublished"));

            if (all) {
                String dest = rs.getString("destinationPath");
                if (dest != null)
                    publicationUnit.setDestinationPath(dest);

                publicationUnit.setPublishOrganismData(rs.getBoolean("publishOrganismData"));
                publicationUnit.setConsiderValidityDates(rs.getBoolean("considerValidityDates"));

                String props = rs.getString("propertiesFile");
                if (props != null)
                    publicationUnit.setPropertiesFile(props);

                String languageCode = rs.getString("languageCode");
                Language ln = new Language(languageCode);
                LanguageDB ldb = new LanguageDB(ln);
                ldb.loadByCode(language);
                publicationUnit.setLanguage(ln);

                String template = rs.getString("templateFile");
                if (template != null)
                    publicationUnit.setTemplateFile(template);

                publicationUnit.setFirstCatalogueTitle(rs.getString("firstCatalogueTitle"));

                publicationUnit.setDateCreation(rs.getDate("dateCreation"));
                publicationUnit.setDateMaj(rs.getDate("dateMaj"));

                //trainingsPublished
                Vector trainings = new Vector();
                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "trainingPublished", where);
                while (rs2.next()) {
                    int idTraining = rs2.getInt("idTraining");

                    //nborder
                    int nborder = 0;
                    String[][] where2 = new String[2][3];
                    where2[0][0] = (new Integer(rs2.getInt("idCatalogue"))).toString();
                    where2[0][1] = "Integer";
                    where2[0][2] = "idCatalogue";

                    where2[1][0] = (new Integer(idTraining)).toString();
                    where2[1][1] = "Integer";
                    where2[1][2] = "idTraining";

                    RequeteSelectWhere rs6 = new RequeteSelectWhere(db, "trainingCatalogue", where2);
                    if (rs6.next()) {
                        nborder = rs6.getInt("nborder");
                    }
                    rs6.close();

                    TrainingPublished tr = new TrainingPublished(publicationUnit.getIdPublicationUnit(), rs2.getInt("idCatalogue"), idTraining, nborder);
                    TrainingPublishedDB trdb = new TrainingPublishedDB(tr);
                    trdb.loadById();

                    trainings.add(tr);
                }
                rs2.close();
                publicationUnit.setTrainings(trainings);

                //cataloguesPublished
                Vector catalogues = new Vector();
                RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "cataloguePublished", where);
                while (rs4.next()) {
                    int idCatalogue = rs4.getInt("idCatalogue");
                    CataloguePublished cat = new CataloguePublished(idCatalogue, publicationUnit.getIdPublicationUnit());
                    CataloguePublishedDB cdb = new CataloguePublishedDB(cat);
                    cdb.loadById();

                    catalogues.add(cat);
                }
                rs4.close();
                publicationUnit.setCatalogues(catalogues);
            }
        }
        rs.close();

        return loaded;
    }

    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(publicationUnit.getIdPublicationUnit())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idPublicationUnit";

        /* RequeteSelectWhere rs = new RequeteSelectWhere(db, "publicationUnit", where);
         if (rs.next()) {     */
        loaded = true;
        publicationUnit.setName(rs.getString("name"));

        char _type = rs.getChar("type");
        if (_type == PUBLICATION_XML_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_XML);
        else if (_type == PUBLICATION_HTML_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_HTML);
        else if (_type == PUBLICATION_PDF_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_PDF);
        else if (_type == PUBLICATION_SOAP_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_SOAP);
        else if (_type == PUBLICATION_RTF_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_RTF);
        else if (_type == PUBLICATION_XSL_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_XSL);
        else if (_type == PUBLICATION_SOAP_DELETE_CHAR)
            publicationUnit.setType(PublicationUnit.PUBLICATION_SOAP_DELETE);        

        publicationUnit.setDateLastPublished(rs.getDate("dateLastPublished"));

        if (all) {
            String dest = rs.getString("destinationPath");
            if (dest != null)
                publicationUnit.setDestinationPath(dest);

            publicationUnit.setPublishOrganismData(rs.getBoolean("publishOrganismData"));
            publicationUnit.setConsiderValidityDates(rs.getBoolean("considerValidityDates"));

            String props = rs.getString("propertiesFile");
            if (props != null)
                publicationUnit.setPropertiesFile(props);

            String languageCode = rs.getString("languageCode");
            Language ln = new Language(languageCode);
            LanguageDB ldb = new LanguageDB(ln);
            ldb.loadByCode(language);
            publicationUnit.setLanguage(ln);

            String template = rs.getString("templateFile");
            if (template != null)
                publicationUnit.setTemplateFile(template);

            publicationUnit.setFirstCatalogueTitle(rs.getString("firstCatalogueTitle"));

            publicationUnit.setDateCreation(rs.getDate("dateCreation"));
            publicationUnit.setDateMaj(rs.getDate("dateMaj"));

            //trainingsPublished
            Vector trainings = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "trainingPublished", where);
            while (rs2.next()) {
                int idTraining = rs2.getInt("idTraining");

                //nborder
                int nborder = 0;
                String[][] where2 = new String[2][3];
                where2[0][0] = (new Integer(rs2.getInt("idCatalogue"))).toString();
                where2[0][1] = "Integer";
                where2[0][2] = "idCatalogue";

                where2[1][0] = (new Integer(idTraining)).toString();
                where2[1][1] = "Integer";
                where2[1][2] = "idTraining";

                RequeteSelectWhere rs6 = new RequeteSelectWhere(db, "trainingCatalogue", where2);
                if (rs6.next()) {
                    nborder = rs6.getInt("nborder");
                }
                rs6.close();

                TrainingPublished tr = new TrainingPublished(publicationUnit.getIdPublicationUnit(), rs2.getInt("idCatalogue"), idTraining, nborder);
                TrainingPublishedDB trdb = new TrainingPublishedDB(tr);
                trdb.loadById();

                trainings.add(tr);
            }
            rs2.close();
            publicationUnit.setTrainings(trainings);

            //cataloguesPublished
            Vector catalogues = new Vector();
            RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "cataloguePublished", where);
            while (rs4.next()) {
                int idCatalogue = rs4.getInt("idCatalogue");
                CataloguePublished cat = new CataloguePublished(idCatalogue, publicationUnit.getIdPublicationUnit());
                CataloguePublishedDB cdb = new CataloguePublishedDB(cat);
                cdb.loadById();

                catalogues.add(cat);
            }
            rs4.close();
            publicationUnit.setCatalogues(catalogues);
        }
        /* }
         rs.close();   */

        return loaded;
    }


    public boolean unlock() {
        boolean unlock = DatabaseFacilities.unlock("idPublicationUnit", publicationUnit.getIdPublicationUnit(), "publicationUnit");
        return unlock;
    }

    public boolean lock() {
        boolean lock = DatabaseFacilities.lock("idPublicationUnit", publicationUnit.getIdPublicationUnit(), "publicationUnit");
        return lock;
    }

    public boolean isLocked() {
        boolean locked = DatabaseFacilities.isLocked("idPublicationUnit", publicationUnit.getIdPublicationUnit(), "publicationUnit");
        return locked;
    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);

        RequeteInsert ri = new RequeteInsert(db, "publicationUnit", insert);
        ri.close();

        //r�cup�rer l'id
        String[][] where = new String[1][3];
        where[0][0] = publicationUnit.getName();
        where[0][1] = "String";
        where[0][2] = "name";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "publicationUnit", where);
        if (rs.next()) {
            publicationUnit.setIdPublicationUnit(rs.getInt("idPublicationUnit"));
            publicationUnit.setDateCreation(rs.getDate("dateCreation"));
            publicationUnit.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] update = this.getSaveData(false);

        String where[][] = new String[1][3];
        where[0][0] = (new Integer(publicationUnit.getIdPublicationUnit())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idPublicationUnit";

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "publicationUnit", update, where);
        ru.close();

        db.commit();

        //date maj
        publicationUnit.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        TOMADatabase db = TOMADatabase.getInstance();

        //trainingPublished
        RequeteDelete rd = new RequeteDelete(db, "trainingPublished", "idPublicationUnit", (new Integer(publicationUnit.getIdPublicationUnit())));
        rd.close();
        Vector trainings = publicationUnit.getTrainings();
        if (trainings != null) {
            Iterator it = trainings.iterator();
            while (it.hasNext()) {
                TrainingPublished t = (TrainingPublished) it.next();
                TrainingPublishedDB tdb = new TrainingPublishedDB(t);
                if (tdb.testCreate())
                    tdb.create();
            }
        }

        //cataloguePublished
        rd = new RequeteDelete(db, "cataloguePublished", "idPublicationUnit", (new Integer(publicationUnit.getIdPublicationUnit())));
        rd.close();
        Vector catalogues = publicationUnit.getCatalogues();
        if (catalogues != null) {
            Iterator it = catalogues.iterator();
            while (it.hasNext()) {
                CataloguePublished c = (CataloguePublished) it.next();
                CataloguePublishedDB cdb = new CataloguePublishedDB(c);
                if (cdb.testCreate())
                    cdb.create();
            }
        }

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Vector values = new Vector();
        Vector names = new Vector();

        names.add("name");
        values.add(publicationUnit.getName());

        names.add("type");
        int type = publicationUnit.getType();
        if (type == PublicationUnit.PUBLICATION_HTML)
            values.add("H");
        else if (type == PublicationUnit.PUBLICATION_PDF)
            values.add("P");
        else if (type == PublicationUnit.PUBLICATION_XML)
            values.add("X");
        else if (type == PublicationUnit.PUBLICATION_RTF)
            values.add("R");
        else if (type == PublicationUnit.PUBLICATION_SOAP)
            values.add("S");
        else if (type == PublicationUnit.PUBLICATION_XSL)
            values.add("T");
        else if (type == PublicationUnit.PUBLICATION_SOAP_DELETE)
            values.add("D");          
        else
            values.add("X");

        names.add("destinationPath");
        values.add(publicationUnit.getDestinationPath());

        names.add("propertiesFile");
        values.add(publicationUnit.getPropertiesFile());

        names.add("templateFile");
        values.add(publicationUnit.getTemplateFile());

        names.add("publishOrganismData");
        values.add(new Boolean(publicationUnit.getPublishOrganismData()));

        names.add("considerValidityDates");
        values.add(new Boolean(publicationUnit.getConsiderValidityDates()));

        names.add("languageCode");
        Language l = publicationUnit.getLanguage();
        if (l != null)
            values.add(l.getCode());
        else
            values.add(null);

        names.add("firstCatalogueTitle");
        values.add(publicationUnit.getFirstCatalogueTitle());

        names.add("dateLastPublished");
        Date date = publicationUnit.getDateLastPublished();
        values.add(date);

        if (creation)
            DatabaseFacilities.addCreationDates(values, names);
        else
            DatabaseFacilities.addUpdateDates(values, names);

        names.add("lock");
        values.add(Boolean.TRUE);

        Object[][] data = new Object[values.size()][2];
        for (int i = 0; i < values.size(); i++) {
            data[i][0] = names.elementAt(i);
            data[i][1] = values.elementAt(i);
        }

        return data;
    }

    public boolean testConstraints() {
        if (publicationUnit.getName() == null || publicationUnit.getName().equals("")
                || publicationUnit.getLanguage() == null)
            return false;
        else
            return true;
    }

    public boolean testUpdate() {
        if (this.testConstraints()) {
            String[][] where = new String[1][3];
            where[0][0] = publicationUnit.getName();
            where[0][1] = "String";
            where[0][2] = "name";
            boolean test = DatabaseFacilities.testUpdate("publicationUnit", where, "idPublicationUnit", publicationUnit.getIdPublicationUnit());
            return test;
        } else
            return false;
    }

    public boolean testCreate() {
        if (this.testConstraints()) {
            String[][] where = new String[1][3];
            where[0][0] = publicationUnit.getName();
            where[0][1] = "String";
            where[0][2] = "name";
            boolean test = DatabaseFacilities.testCreate("publicationUnit", where);
            return test;
        } else
            return false;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        Integer id = new Integer(publicationUnit.getIdPublicationUnit());

        RequeteDelete rd1 = new RequeteDelete(db, "trainingPublished", "idPublicationUnit", id);
        rd1.close();

        RequeteDelete rd2 = new RequeteDelete(db, "cataloguePublished", "idPublicationUnit", id);
        rd2.close();

        RequeteDelete rd = new RequeteDelete(db, "PublicationUnit", "idPublicationUnit", id);
        rd.close();

        db.commit();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "publicationUnit", "0", "0");
        while (rs.next()) {
            PublicationUnit publicationUnit = new PublicationUnit(rs.getInt("idPublicationUnit"));
            PublicationUnitDB publicationUnitdb = new PublicationUnitDB(publicationUnit);
            publicationUnitdb.delete();
        }
        rs.close();
        db.commit();
    }

}
