// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.TOMA;

import toolbox.sql.SQLTools;


import java.sql.*;

import java.io.*;

import java.lang.String;


public class RequeteSelect implements InterfaceRequeteSelect {


    private apostal.toma.database.TOMADatabase db;


    private ResultSet rs;

    private Statement stmt;


    /**

     * the boolean "withSelectStatement" is only here in order to differentiate

     * this RequeteSelect from the one with "attributeValue" and "attributeName"

     */

    public RequeteSelect(boolean withSelectStatement, apostal.toma.database.TOMADatabase db, String select, String table, String where) {

        this.db = db;

        String requete = "select " + select + " from " + table;

        try {

            stmt = db.getStatement();

            //stmt = (TOMADatabase.connection).createStatement();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while opening statement: " + SQLTools.printSQLException(sqle));

        }

        if (where != null && !where.equals(""))

            requete = requete + " where " + where;


        TOMA.log(TOMA.INFO, "Requete: " + requete);


        try {
            rs = stmt.executeQuery(requete);


        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle, requete));

        } catch (java.lang.NullPointerException ex) {

            //ressayer

            try {

                stmt = db.getStatement();

                rs = stmt.executeQuery(requete);

            } catch (SQLException sqle2) {

                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));

            }

        }


    }// end constructeur


    public RequeteSelect(apostal.toma.database.TOMADatabase db, String table, String where) {

        this.db = db;

        String requete = "select * from " + table;

        try {

            stmt = db.getStatement();

            //stmt = (TOMADatabase.connection).createStatement();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while opening statement: " + SQLTools.printSQLException(sqle));

        }

        if (where != null && !where.equals(""))

            requete = requete + " where " + where;


        TOMA.log(TOMA.INFO, "Requete: " + requete);


        try {
            rs = stmt.executeQuery(requete);


        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle, requete));

        } catch (java.lang.NullPointerException ex) {

            //ressayer

            try {

                stmt = db.getStatement();

                rs = stmt.executeQuery(requete);

            } catch (SQLException sqle2) {

                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));

            }

        }


    }// end constructeur


    public RequeteSelect(apostal.toma.database.TOMADatabase db, String Table, String AttributeName, Object AttributeValue) {

        this.db = db;


        String requete = new String("Select * from ");


        try {

            stmt = db.getStatement();

            //stmt = (TOMADatabase.connection).createStatement();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while opening statement: " + SQLTools.printSQLException(sqle));

        }


        requete = requete + Table + " WHERE " + AttributeName;


        if (AttributeValue == null)

            requete = requete + " IS NULL";

        else if (AttributeValue instanceof String) {

            //filtrer

            AttributeValue = SQLTools.escape((String) AttributeValue);

            requete = requete + " LIKE '" + AttributeValue + "'";

        } else

            requete = requete + " = '" + AttributeValue + "'";


        TOMA.log(TOMA.INFO, "Requete: " + requete);


        try {
            rs = stmt.executeQuery(requete);


        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle, requete));

        } catch (java.lang.NullPointerException ex) {

            //ressayer

            try {

                stmt = db.getStatement();

                rs = stmt.executeQuery(requete);

            } catch (SQLException sqle2) {

                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));

            }

        }


    }// end consutructeur


    public RequeteSelect(apostal.toma.database.TOMADatabase db, String Table) {

        this.db = db;


        String requete = new String("Select * from ");


        try {

            stmt = db.getStatement();

            //stmt = (TOMADatabase.connection).createStatement();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while opening statement: " + SQLTools.printSQLException(sqle));

        }


        requete = requete + Table;

        TOMA.log(TOMA.INFO, "Requete: " + requete);

        try {
            rs = stmt.executeQuery(requete);


        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle, requete));

        } catch (java.lang.NullPointerException ex) {

            //ressayer

            try {

                stmt = db.getStatement();

                rs = stmt.executeQuery(requete);

            } catch (SQLException sqle2) {

                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));

            }

        }

    }// end consutructeur


    public String getString(String s) {
        String sr = null;

        try {
            sr = rs.getString(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }


        return sr;

    }


    public char getChar(String s) {

        char c = ' ';

        try {

            String tmp = rs.getString(s);

            if (tmp.length() > 0)

                c = tmp.charAt(0);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }

        return c;

    }


    public int getInt(String s) {
        int i = 0;

        try {
            i = rs.getInt(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }


        return i;

    }

    public Blob getBlob(String s) {
        Blob b = null;
        try {
            b = rs.getBlob(s);
        } catch (SQLException sqle) {
            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));
        }
        return b;
    }

    public int getInt(int column) {
        int i = 0;

        try {

            i = rs.getInt(column);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }


        return i;

    }


    public int getNullableInt(String s) {

        Object o = null;

        int i = -1;

        try {

            o = rs.getObject(s);

            if (o != null)

                i = rs.getInt(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }

        return i;

    }

    public int getNullableInt(int column) {
        Object o = null;
        int i = -1;
        try {
            o = rs.getObject(column);
            if (o != null)
                i = rs.getInt(column);
        } catch (SQLException sqle) {
            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));
        }
        return i;
    }


    public Object getObject(String s) {
        Object o = null;

        try {
            o = rs.getObject(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }


        return o;

    }


    public boolean getBoolean(String s) {
        boolean b = false;

        try {
            b = rs.getBoolean(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }


        return b;

    }


    public boolean next() {
        boolean b = false;

        try {
            b = rs.next();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }

        return b;


    }


    public Date getDate(String s) {
        Date d = null;

        try {
            d = rs.getDate(s);

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle));

        }

        return d;

    }


    public void close() {
        try {
            rs.close();

            stmt.close();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while closing: " + SQLTools.printSQLException(sqle));

        }


    }


}





