// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.TOMA;

import toolbox.sql.SQLTools;


import java.sql.*;

import java.io.*;

import java.lang.String;


public class RequeteUpdateWhere {


    private apostal.toma.database.TOMADatabase db;


    private int result;

    private PreparedStatement pStmt;


    public RequeteUpdateWhere(apostal.toma.database.TOMADatabase db, String Table, Object[][] ListOfValues, String[][] Criteria) {

        this.db = db;


        String requete = new String("UPDATE ");


        requete = requete + Table + " SET ";


        int NbValues = ListOfValues.length;


        for (int i = 0; i < NbValues; i++) {

            //if(ListOfValues[i][1]!=null)

            requete = requete + ListOfValues[i][0] + " = ?,";

        }

        requete = requete.substring(0, requete.length() - 1);



        //int Ndbrit = Integer.parseInt((String)Criteria[0][0]);

        int Ndbrit = Criteria.length;


        if (Ndbrit > 0)

            requete = requete + " WHERE";


        int i = 0;

        while (i < Ndbrit) {

            requete = requete + " " + Criteria[i][2];


            if (Criteria[i][1].equals("String")) {

                String value = SQLTools.escape(Criteria[i][0]);

                requete = requete + " LIKE '" + value + "' AND";

            } else

                requete = requete + " = " + Criteria[i][0] + " AND";


            i = i + 1;

        }


        requete = requete.substring(0, requete.length() - 3);

        TOMA.log(TOMA.INFO, "Requete: " + requete);


        try {

            pStmt = db.getPreparedStatement(requete);

            //pStmt =(TOMADatabase.connection).prepareStatement(requete);

            for (int j = 0; j < NbValues; j++) {

                Object o = ListOfValues[j][1];

                if (o == null) {

                    TOMA.log(TOMA.INFO, ListOfValues[j][0] + " est null");



                    //faire quand meme l'update

                    //pStmt.setNull(j+1, Types.VARCHAR);

                    pStmt.setNull(j + 1, Types.NULL);

                } else {

                    String cl = o.getClass().getName();

                    if (cl.equals("java.lang.String")) {

                        //String value=SQLTools.escape((String) o);

                        //pas de de escape dans ces cas la

                        String value = (String) o;


                        pStmt.setString(j + 1, value);

                    } else if (cl.equals("java.sql.Date"))

                        pStmt.setDate(j + 1, (java.sql.Date) o);

                    else if (cl.equals("java.lang.Integer"))

                        pStmt.setInt(j + 1, ((Integer) o).intValue());

                    else if (cl.equals("java.lang.Boolean"))

                        pStmt.setBoolean(j + 1, ((Boolean) o).booleanValue());


                    TOMA.log(TOMA.INFO, ListOfValues[j][0] + "=" + o);

                }

            }


            result = pStmt.executeUpdate();


        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle, requete));

            db.setRollbackTrue();

        } catch (java.lang.NullPointerException ex) {

            //ressayer

            try {

                pStmt = db.getPreparedStatement(requete);

                result = pStmt.executeUpdate();

            } catch (SQLException sqle2) {

                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));

            }

        }

    }
    
    /**
     * same but with the "safe" option: if it didn't work, open a second connection and retry
     * this is useful mainly for locks
     **/
    public RequeteUpdateWhere(boolean safe, apostal.toma.database.TOMADatabase db, String Table, Object[][] ListOfValues, String[][] Criteria) {
        this.db = db;
        String requete = new String("UPDATE ");
        requete = requete + Table + " SET ";
        int NbValues = ListOfValues.length;
        for (int i = 0; i < NbValues; i++) {
            requete = requete + ListOfValues[i][0] + " = ?,";
        }
        requete = requete.substring(0, requete.length() - 1);
        int Ndbrit = Criteria.length;
        if (Ndbrit > 0)
            requete = requete + " WHERE";
        int i = 0;
        while (i < Ndbrit) {
            requete = requete + " " + Criteria[i][2];
            if (Criteria[i][1].equals("String")) {
                String value = SQLTools.escape(Criteria[i][0]);
                requete = requete + " LIKE '" + value + "' AND";
            } else
                requete = requete + " = " + Criteria[i][0] + " AND";
            i = i + 1;
        }
        requete = requete.substring(0, requete.length() - 3);
        TOMA.log(TOMA.INFO, "Requete: " + requete);
        try {
            pStmt = db.getPreparedStatement(requete);
            //pStmt =(TOMADatabase.connection).prepareStatement(requete);
            for (int j = 0; j < NbValues; j++) {
                Object o = ListOfValues[j][1];
                if (o == null) {
                    TOMA.log(TOMA.INFO, ListOfValues[j][0] + " est null");
                    //faire quand meme l'update
                    pStmt.setNull(j + 1, Types.NULL);

                } else {
                    String cl = o.getClass().getName();
                    if (cl.equals("java.lang.String")) {
                        //pas de de escape dans ces cas la
                        String value = (String) o;
                        pStmt.setString(j + 1, value);
                    } else if (cl.equals("java.sql.Date"))
                        pStmt.setDate(j + 1, (java.sql.Date) o);
                    else if (cl.equals("java.lang.Integer"))
                        pStmt.setInt(j + 1, ((Integer) o).intValue());
                    else if (cl.equals("java.lang.Boolean"))
                        pStmt.setBoolean(j + 1, ((Boolean) o).booleanValue());
                    TOMA.log(TOMA.INFO, ListOfValues[j][0] + "=" + o);
                }
            }
            result = pStmt.executeUpdate();
        } catch (SQLException sqle) {
            if(safe){
                TOMADatabase otherDB=TOMADatabase.getAnotherConnection();                
                try{
                    pStmt = otherDB.getPreparedStatement(requete);
                    for (int j = 0; j < NbValues; j++) {
                        Object o = ListOfValues[j][1];
                        if (o == null) {
                            TOMA.log(TOMA.INFO, ListOfValues[j][0] + " est null");
                            //faire quand meme l'update
                            pStmt.setNull(j + 1, Types.NULL);
                        } else {
                            String cl = o.getClass().getName();
                            if (cl.equals("java.lang.String")) {
                                //pas de de escape dans ces cas la
                                String value = (String) o;
                                pStmt.setString(j + 1, value);
                            } else if (cl.equals("java.sql.Date"))
                                pStmt.setDate(j + 1, (java.sql.Date) o);
                            else if (cl.equals("java.lang.Integer"))
                                pStmt.setInt(j + 1, ((Integer) o).intValue());
                            else if (cl.equals("java.lang.Boolean"))
                                pStmt.setBoolean(j + 1, ((Boolean) o).booleanValue());
                            TOMA.log(TOMA.INFO, ListOfValues[j][0] + "=" + o);
                        }
                    }
                    result = pStmt.executeUpdate();                
                }catch(SQLException ex){
                    TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle, requete));
                    db.setRollbackTrue();                
                }
            }
            else{            
                TOMA.log(TOMA.SEVERE, SQLTools.printSQLException(sqle, requete));
                db.setRollbackTrue();
            }
        } catch (java.lang.NullPointerException ex) {

            //ressayer
            try {
                pStmt = db.getPreparedStatement(requete);
                result = pStmt.executeUpdate();
            } catch (SQLException sqle2) {
                TOMA.log(TOMA.SEVERE, "SQLException while executing query: " + SQLTools.printSQLException(sqle2, requete));
            }
        }
    }    


    public int getResult() {

        return result;

    }


    public void close() {
        try {

            pStmt.close();

        } catch (SQLException sqle) {

            TOMA.log(TOMA.SEVERE, "SQLException while closing: " + SQLTools.printSQLException(sqle));

        }


    }


}

