// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;


import java.sql.Date;


import java.util.Vector;

import java.util.Iterator;

import apostal.toma.data.Language;

import apostal.toma.data.Location;

import apostal.toma.data.Slot;

/**

 * @(#) Session.java

 */


public abstract class SessionDB implements Modifiable {


    protected Session session;


    public SessionDB(Session session) {

        this.session = session;

    }


    public static boolean exists(int idSession) {

        boolean exists = false;

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(db, "session", "idSession", new Integer(idSession));

        if (rs.next()) {

            exists = true;

        }

        rs.close();


        return exists;

    }


    public static Session getInstance(Language lng, boolean all, String nom) {

        TOMADatabase db = TOMADatabase.getInstance();


        Session s = null;

        RequeteSelect rs = new RequeteSelect(db, "session", "sessionName", nom);

        if (rs.next()) {

            int id = rs.getInt("idSession");

            s = SessionDB.getInstance(lng, all, id);

        }

        rs.close();


        return s;

    }


    public static Session getInstance(Language lng, boolean all, int idSession) {

        Session s = null;

        TOMADatabase db = TOMADatabase.getInstance();


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(idSession)).toString();

        where[0][1] = "Integer";

        where[0][2] = "idSession";


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);

        if (rs.next()) {

            String type = rs.getString("type");

            if (type.equals("C")) {

                s = new CourseSession(idSession);

                CourseSessionDB csdb = new CourseSessionDB((CourseSession) s);

                csdb.loadById(lng, all);

            } else if (type.equals("P")) {

                s = new ProgrammeSession(idSession);

                ProgrammeSessionDB psdb = new ProgrammeSessionDB((ProgrammeSession) s);

                psdb.loadById(lng, all);

            } else if (type.equals("U")) {

                s = new UnitSession(idSession);

                UnitSessionDB usdb = new UnitSessionDB((UnitSession) s);

                usdb.loadById(lng, all);

            }

        }

        rs.close();


        return s;

    }


    public boolean loadById(Language lng, boolean all) {

        boolean loaded = false;

        TOMADatabase db = TOMADatabase.getInstance();


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(session.getIdSession())).toString();

        where[0][1] = "Integer";

        where[0][2] = "idSession";


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);

        if (rs.next()) {

            loaded = true;

            session.setSessionName(rs.getString("sessionName"));


            if (all) {

                Date bd = rs.getDate("beginDate");

                if (bd != null)

                    session.setBeginDate(bd);

                Date ed = rs.getDate("endDate");

                if (ed != null)

                    session.setEndDate(ed);

                String languageCode = rs.getString("languageCode");

                if (languageCode != null) {

                    Language language = new Language(languageCode);

                    LanguageDB ldb = new LanguageDB(language);

                    ldb.loadByCode(lng);


                    session.setLanguage(language);

                }

                String pr = rs.getString("price");

                if (pr != null)

                    session.setPrice(pr);

                String prc = rs.getString("priceComment");

                if (prc != null)

                    session.setPriceComment(prc);

                Date bvd = rs.getDate("beginValidityDate");

                if (bvd != null)

                    session.setBeginValidityDate(bvd);

                Date evd = rs.getDate("endValidityDate");

                if (evd != null)

                    session.setEndValidityDate(evd);

                String cm = rs.getString("comment");

                if (cm != null)

                    session.setComment(cm);


                session.setIdTraining(rs.getInt("idTraining"));


                session.setDateCreation(rs.getDate("dateCreation"));

                session.setDateMaj(rs.getDate("dateMaj"));

            }

        }

        rs.close();


        return loaded;

    }


    public boolean loadByIdAndRS(Language lng, boolean all, InterfaceRequeteSelect rs) {

        boolean loaded = true;

        TOMADatabase db = TOMADatabase.getInstance();


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(session.getIdSession())).toString();

        where[0][1] = "Integer";

        where[0][2] = "idSession";

        /*

        RequeteSelectWhere rs=new RequeteSelectWhere(db, "session", where);

        if(rs.next())

            {

            loaded=true;*/

        session.setSessionName(rs.getString("sessionName"));


        if (all) {

            Date bd = rs.getDate("beginDate");

            if (bd != null)

                session.setBeginDate(bd);

            Date ed = rs.getDate("endDate");

            if (ed != null)

                session.setEndDate(ed);

            String languageCode = rs.getString("languageCode");

            if (languageCode != null) {

                Language language = new Language(languageCode);

                LanguageDB ldb = new LanguageDB(language);

                ldb.loadByCode(lng);


                session.setLanguage(language);

            }

            String pr = rs.getString("price");

            if (pr != null)

                session.setPrice(pr);

            String prc = rs.getString("priceComment");

            if (prc != null)

                session.setPriceComment(prc);

            Date bvd = rs.getDate("beginValidityDate");

            if (bvd != null)

                session.setBeginValidityDate(bvd);

            Date evd = rs.getDate("endValidityDate");

            if (evd != null)

                session.setEndValidityDate(evd);

            String cm = rs.getString("comment");

            if (cm != null)

                session.setComment(cm);


            session.setIdTraining(rs.getInt("idTraining"));


            session.setDateCreation(rs.getDate("dateCreation"));

            session.setDateMaj(rs.getDate("dateMaj"));

        }

        /*  }

      rs.close();*/



        return loaded;

    }


    //pas de lock pour les sessions!
    /*public boolean unlock( )
    {
	boolean unlock=DatabaseFacilities.unlock("idSession", session.getIdSession(), "session");
	return unlock;
    }
    public boolean lock()
    {
	boolean lock=DatabaseFacilities.lock("idSession", session.getIdSession(), "session");
	return lock;
    }
    public boolean isLocked( )
    {
        boolean locked=DatabaseFacilities.isLocked("idSession", session.getIdSession(), "session");
        return locked;
    }*/
    public boolean lock() {
        return true;
    }

    public boolean unlock() {
        return true;
    }

    public boolean isLocked() {
        return false;
    }

    /*public void create( )

    {

	TOMADatabase db=TOMADatabase.getInstance();



	Object[][] insert=this.getSaveData(true);



        RequeteInsert ri=new RequeteInsert(db, "session", insert);

	ri.close();



	//rcuprer l'idSession

	String[][] where=new String[2][3];

	where[0][0]=session.getSessionName();

	where[0][1]="String";

	where[0][2]="sessionName";

	where[1][0]=(new Integer(session.getIdTraining())).toString();

	where[1][1]="Integer";

	where[1][2]="idTraining";

	RequeteSelectWhere rs=new RequeteSelectWhere(db, "session", where);

	if(rs.next())

	    {

		session.setIdSession(rs.getInt("idSession"));

	    }

	rs.close();



	db.commit();

    }*/



    /*public void update( )

    {

	TOMADatabase db=TOMADatabase.getInstance();



	Object[][] update=this.getSaveData(false);



	String[][] where=new String[1][3];

	where[0][0]=(new Integer(session.getIdSession())).toString();

	where[0][1]="Integer";

	where[0][2]="idSession";



        RequeteUpdateWhere ru=new RequeteUpdateWhere(db, "session", update, where);

	ru.close();



	db.commit();

   }*/



    public void setLinks() {

        //nop

    }


    public Object[][] getSaveData(boolean creation) {

        Vector values = new Vector();

        Vector names = new Vector();


        names.add("sessionName");

        values.add(session.getSessionName());


        names.add("beginDate");

        values.add(session.getBeginDate());


        names.add("endDate");

        values.add(session.getEndDate());


        String code = null;

        Language language = session.getLanguage();

        if (language != null) {

            code = language.getCode();

        }

        names.add("languageCode");

        values.add(code);


        names.add("price");

        values.add(session.getPrice());


        names.add("priceComment");

        values.add(session.getPriceComment());


        names.add("beginValidityDate");

        values.add(session.getBeginValidityDate());


        names.add("endValidityDate");

        values.add(session.getEndValidityDate());


        names.add("comment");

        values.add(session.getComment());


        names.add("idTraining");

        if (TrainingDB.exists(session.getIdTraining()))

            values.add(new Integer(session.getIdTraining()));

        else {

            values.add(null);

            session.setIdTraining(-1);

        }


        if (creation)

            DatabaseFacilities.addCreationDates(values, names);

        else

            DatabaseFacilities.addUpdateDates(values, names);


        Object[][] data = new Object[values.size()][2];

        for (int i = 0; i < values.size(); i++) {

            data[i][0] = names.elementAt(i);

            data[i][1] = values.elementAt(i);

        }


        return data;

    }


    public boolean testConstraints() {

        if (session.getSessionName() == null || session.getSessionName().equals("")

                || session.getBeginValidityDate() == null

                || session.getEndValidityDate() == null

        )

            return false;

        else

            return true;

    }


    public boolean testUpdate() {

        if (this.testConstraints()) {

            String[][] where = new String[2][3];

            where[0][0] = session.getSessionName();

            where[0][1] = "String";

            where[0][2] = "sessionName";

            where[1][0] = (new Integer(session.getIdTraining())).toString();

            where[1][1] = "Integer";

            where[1][2] = "idTraining";

            boolean test = DatabaseFacilities.testUpdate("session", where, "idSession", session.getIdSession());

            return test;

        } else

            return false;

    }

    public boolean testCreate() {

        if (this.testConstraints()) {

            String[][] where = new String[2][3];

            where[0][0] = session.getSessionName();

            where[0][1] = "String";

            where[0][2] = "sessionName";

            where[1][0] = (new Integer(session.getIdTraining())).toString();

            where[1][1] = "Integer";

            where[1][2] = "idTraining";

            boolean test = DatabaseFacilities.testCreate("session", where);

            return test;

        } else

            return false;

    }


    public void delete() {

        TOMADatabase db = TOMADatabase.getInstance();

        RequeteDelete rd = new RequeteDelete(db, "session", "idSession", new Integer(session.getIdSession()));

        rd.close();


        db.commit();

    }


}

