// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;


import java.util.Vector;

import java.util.Iterator;

import apostal.toma.data.Training;

import apostal.toma.data.Language;


/**

 * @(#) StandaloneTraining.java

 */


public abstract class StandaloneTrainingDB extends TrainingDB {


    protected StandaloneTraining standaloneTraining;


    public StandaloneTrainingDB(StandaloneTraining standaloneTraining) {

        super(standaloneTraining);

        this.standaloneTraining = standaloneTraining;

    }


    /*************** database access ***********************/

    public boolean loadById(Language language, boolean all) {
        boolean loaded = super.loadById(language, all);
        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";
            RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);
            if (rs.next()) {
                loaded = true;
                String cert = rs.getString("certificatesOrDiplomas");
                if (cert != null) standaloneTraining.setCertificatesOrDiplomas(cert);
                String pr = rs.getString("price");
                if (pr != null) standaloneTraining.setPrice(pr);
                String prc = rs.getString("priceComment");
                if (prc != null) standaloneTraining.setPriceComment(prc);
                String fac = rs.getString("paymentFacilities");
                if (fac != null) standaloneTraining.setPaymentFacilities(fac);
                String inscond = rs.getString("inscriptionConditions");
                if (inscond != null) standaloneTraining.setInscriptionConditions(inscond);
                //audiences
                Vector audiences = new Vector();
                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "audience", where, "nborder");
                while (rs2.next()) {
                    int nborder = rs2.getInt("nborder");
                    audiences.add(rs2.getString("audience"));
                }
                rs2.close();
                standaloneTraining.setAudiences(audiences);
                Vector catalogues = new Vector();
                Vector catOrders = new Vector();
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "trainingCatalogue", where);
                while (rs3.next()) {
                    int idCat = rs3.getInt("idCatalogue");
                    Catalogue c = new Catalogue(idCat);
                    CatalogueDB cdb = new CatalogueDB(c);
                    cdb.loadById(language, false, false);
                    catalogues.add(c);
                    catOrders.add(new Integer(rs3.getInt("nborder")));
                    //catOrders.add(new Integer(c.getNborder()));
                }
                rs3.close();
                standaloneTraining.setCatalogues(catalogues);
                standaloneTraining.setCatOrders(catOrders);
                //domains
                Vector domains = new Vector();
                RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "trainingDomain", where);
                while (rs4.next()) {
                    int idDom = rs4.getInt("idDomain");
                    Domain d = new Domain(idDom);
                    DomainDB ddb = new DomainDB(d);
                    ddb.loadById(language);
                    domains.add(d);
                }
                rs4.close();
                standaloneTraining.setDomains(domains);



                //inscriptionContacts

                Vector inscriptionContacts = new Vector();

                RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "trainingInscriptionContact", where);

                while (rs5.next()) {

                    int idCont = rs5.getInt("idContact");

                    Contact c = new Contact(idCont);

                    ContactDB cdb = new ContactDB(c);

                    cdb.loadById(language, false);

                    inscriptionContacts.add(c);

                }

                rs5.close();

                standaloneTraining.setInscriptionContacts(inscriptionContacts);

            }

            rs.close();


        }

        return loaded;

    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);
        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";
            String cert = rs.getString("certificatesOrDiplomas");
            if (cert != null) standaloneTraining.setCertificatesOrDiplomas(cert);
            String pr = rs.getString("price");
            if (pr != null) standaloneTraining.setPrice(pr);
            String prc = rs.getString("priceComment");
            if (prc != null) standaloneTraining.setPriceComment(prc);
            String fac = rs.getString("paymentFacilities");
            if (fac != null) standaloneTraining.setPaymentFacilities(fac);
            String inscond = rs.getString("inscriptionConditions");
            if (inscond != null) standaloneTraining.setInscriptionConditions(inscond);
            //audiences
            Vector audiences = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "audience", where, "nborder");
            while (rs2.next()) {
                int nborder = rs2.getInt("nborder");
                audiences.add(rs2.getString("audience"));
            }
            rs2.close();
            standaloneTraining.setAudiences(audiences);
            Vector catalogues = new Vector();
            Vector catOrders = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "trainingCatalogue", where);
            while (rs3.next()) {
                int idCat = rs3.getInt("idCatalogue");
                Catalogue c = new Catalogue(idCat);
                CatalogueDB cdb = new CatalogueDB(c);
                cdb.loadById(language, false, false);
                catalogues.add(c);
                catOrders.add(new Integer(rs3.getInt("nborder")));
                //catOrders.add(new Integer(c.getNborder()));
            }
            rs3.close();
            standaloneTraining.setCatalogues(catalogues);
            standaloneTraining.setCatOrders(catOrders);
            //domains
            Vector domains = new Vector();
            RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "trainingDomain", where);
            while (rs4.next()) {
                int idDom = rs4.getInt("idDomain");
                Domain d = new Domain(idDom);
                DomainDB ddb = new DomainDB(d);
                ddb.loadById(language);
                domains.add(d);
            }
            rs4.close();
            standaloneTraining.setDomains(domains);
            //inscriptionContacts
            Vector inscriptionContacts = new Vector();
            RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "trainingInscriptionContact", where);
            while (rs5.next()) {
                int idCont = rs5.getInt("idContact");
                Contact c = new Contact(idCont);
                ContactDB cdb = new ContactDB(c);
                cdb.loadById(language, false);
                inscriptionContacts.add(c);
            }
            rs5.close();
            standaloneTraining.setInscriptionContacts(inscriptionContacts);
        }
        return loaded;

    }


    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRSForPublication(language, all, rs);
        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";
            String cert = rs.getString("certificatesOrDiplomas");
            if (cert != null) standaloneTraining.setCertificatesOrDiplomas(cert);
            String pr = rs.getString("price");
            if (pr != null) standaloneTraining.setPrice(pr);
            String prc = rs.getString("priceComment");
            if (prc != null) standaloneTraining.setPriceComment(prc);
            String fac = rs.getString("paymentFacilities");
            if (fac != null) standaloneTraining.setPaymentFacilities(fac);
            String inscond = rs.getString("inscriptionConditions");
            if (inscond != null) standaloneTraining.setInscriptionConditions(inscond);
            //audiences
            Vector audiences = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "audience", where, "nborder");
            while (rs2.next()) {
                int nborder = rs2.getInt("nborder");
                audiences.add(rs2.getString("audience"));
            }
            rs2.close();
            standaloneTraining.setAudiences(audiences);
            Vector catalogues = new Vector();
            Vector catOrders = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "trainingCatalogue", where);
            while (rs3.next()) {
                int idCat = rs3.getInt("idCatalogue");
                Catalogue c = new Catalogue(idCat);
                CatalogueDB cdb = new CatalogueDB(c);
                cdb.loadById(language, true, false);
                catalogues.add(c);
                catOrders.add(new Integer(rs3.getInt("nborder")));
                //catOrders.add(new Integer(c.getNborder()));
            }
            rs3.close();
            standaloneTraining.setCatalogues(catalogues);
            standaloneTraining.setCatOrders(catOrders);
            //domains
            Vector domains = new Vector();
            RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "trainingDomain", where);
            while (rs4.next()) {
                int idDom = rs4.getInt("idDomain");
                Domain d = new Domain(idDom);
                DomainDB ddb = new DomainDB(d);
                ddb.loadById(language);
                domains.add(d);
            }
            rs4.close();
            standaloneTraining.setDomains(domains);
            //inscriptionContacts
            Vector inscriptionContacts = new Vector();
            RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "trainingInscriptionContact", where);
            while (rs5.next()) {
                int idCont = rs5.getInt("idContact");
                Contact c = new Contact(idCont);
                ContactDB cdb = new ContactDB(c);
                cdb.loadById(language, true);
                inscriptionContacts.add(c);
            }
            rs5.close();
            standaloneTraining.setInscriptionContacts(inscriptionContacts);
        }
        return loaded;
    }


    public void setLinks() {

        super.setLinks();


        TOMADatabase db = TOMADatabase.getInstance();



        //audiences

        RequeteDelete rd = new RequeteDelete(db, "audience", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector audiences = standaloneTraining.getAudiences();

        if (audiences != null) {

            int size = audiences.size();

            for (int i = 0; i < size; i++) {

                String audience = (String) audiences.elementAt(i);


                String[][] wherelink = new String[2][3];

                wherelink[0][0] = (new Integer(i)).toString();

                wherelink[0][1] = "Integer";

                wherelink[0][2] = "nborder";

                wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                wherelink[1][1] = "Integer";

                wherelink[1][2] = "idTraining";

                RequeteSelectWhere rslink = new RequeteSelectWhere(db, "audience", wherelink);

                if (!rslink.next()) {


                    Object[][] insert = new Object[3][2];

                    insert[0][0] = "idTraining";

                    insert[0][1] = new Integer(training.getIdTraining());

                    insert[1][0] = "audience";

                    insert[1][1] = audience;

                    insert[2][0] = "nborder";

                    insert[2][1] = new Integer(i);


                    RequeteInsert ri = new RequeteInsert(db, "audience", insert);

                    ri.close();

                }

                rslink.close();

            }

        }



        //catalogues

        rd = new RequeteDelete(db, "trainingCatalogue", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector catalogues = standaloneTraining.getCatalogues();

        Vector newcats = new Vector();

        if (catalogues != null) {

            int size = catalogues.size();

            for (int i = 0; i < size; i++) {

                Catalogue cat = (Catalogue) catalogues.elementAt(i);


                if (CatalogueDB.exists(cat.getIdCatalogue())) {

                    String[][] wherelink = new String[2][3];

                    wherelink[0][0] = (new Integer(cat.getIdCatalogue())).toString();

                    wherelink[0][1] = "Integer";

                    wherelink[0][2] = "idCatalogue";

                    wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                    wherelink[1][1] = "Integer";

                    wherelink[1][2] = "idTraining";

                    RequeteSelectWhere rslink = new RequeteSelectWhere(db, "trainingCatalogue", wherelink);

                    if (!rslink.next()) {

                        newcats.add(cat);


                        Integer nborder = new Integer(0);

                        Vector catOrders = standaloneTraining.getCatOrders();

                        if (catOrders != null

                                && catOrders.size() > i)

                            nborder = (Integer) catOrders.elementAt(i);


                        Object[][] insert = new Object[3][2];

                        insert[0][0] = "idTraining";

                        insert[0][1] = new Integer(training.getIdTraining());

                        insert[1][0] = "idCatalogue";

                        insert[1][1] = new Integer(cat.getIdCatalogue());

                        insert[2][0] = "nborder";

                        insert[2][1] = nborder;

                        //insert[2][1]=new Integer(i);



                        RequeteInsert ri = new RequeteInsert(db, "trainingCatalogue", insert);

                        ri.close();

                    }

                    rslink.close();

                }

            }

        }

        standaloneTraining.setCatalogues(newcats);



        //domains

        rd = new RequeteDelete(db, "trainingDomain", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector domains = standaloneTraining.getDomains();

        if (domains != null) {

            Iterator it = domains.iterator();

            while (it.hasNext()) {

                Domain d = (Domain) it.next();


                Object[][] insert = new Object[2][2];

                insert[0][0] = "idTraining";

                insert[0][1] = new Integer(training.getIdTraining());

                insert[1][0] = "idDomain";

                insert[1][1] = new Integer(d.getIdDomain());



                //vrifier qu'il n'y est pas dj

                String[][] select = new String[2][3];

                select[0][0] = (new Integer(training.getIdTraining())).toString();

                select[0][2] = "idTraining";

                select[0][1] = "Integer";

                select[1][0] = (new Integer(d.getIdDomain())).toString();

                select[1][2] = "idDomain";

                select[1][1] = "Integer";

                RequeteSelectWhere rs_dom = new RequeteSelectWhere(db, "trainingDomain", select);

                if (!rs_dom.next()) {

                    RequeteInsert ri = new RequeteInsert(db, "trainingDomain", insert);

                    ri.close();

                }

                rs_dom.close();



                //Rem: no subdomains because all the domains and subdomains of the training are directly put into the "domains" vector of the training

            }

        }



        //inscriptionContacts

        rd = new RequeteDelete(db, "trainingInscriptionContact", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector inscriptionContacts = standaloneTraining.getInscriptionContacts();

        Vector newinscont = new Vector();

        if (inscriptionContacts != null) {

            Iterator it = inscriptionContacts.iterator();

            while (it.hasNext()) {

                Contact c = (Contact) it.next();

                if (ContactDB.exists(c.getIdContact())) {


                    String[][] wherelink = new String[2][3];

                    wherelink[0][0] = (new Integer(c.getIdContact())).toString();

                    wherelink[0][1] = "Integer";

                    wherelink[0][2] = "idContact";

                    wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                    wherelink[1][1] = "Integer";

                    wherelink[1][2] = "idTraining";

                    RequeteSelectWhere rslink = new RequeteSelectWhere(db, "trainingInscriptionContact", wherelink);

                    if (!rslink.next()) {


                        newinscont.add(c);


                        Object[][] insert = new Object[2][2];

                        insert[0][0] = "idTraining";

                        insert[0][1] = new Integer(training.getIdTraining());

                        insert[1][0] = "idContact";

                        insert[1][1] = new Integer(c.getIdContact());


                        RequeteInsert ri = new RequeteInsert(db, "trainingInscriptionContact", insert);

                        ri.close();

                    }

                    rslink.close();

                }

            }

        }

        standaloneTraining.setInscriptionContacts(newinscont);


        db.commit();

    }

    public Object[][] getSaveData(boolean creation) {

        Vector values = new Vector();

        Vector names = new Vector();


        Object[][] data1 = super.getSaveData(creation);

        int size = data1.length;

        for (int i = 0; i < size; i++) {

            names.add(data1[i][0]);

            values.add(data1[i][1]);

        }


        names.add("certificatesOrDiplomas");

        values.add(training.getCertificatesOrDiplomas());


        names.add("price");

        values.add(training.getPrice());


        names.add("priceComment");

        values.add(training.getPriceComment());


        names.add("paymentFacilities");

        values.add(training.getPaymentFacilities());


        names.add("inscriptionConditions");

        values.add(training.getInscriptionConditions());


        Object[][] data = new Object[values.size()][2];

        for (int i = 0; i < values.size(); i++) {

            data[i][0] = names.elementAt(i);

            data[i][1] = values.elementAt(i);

        }


        return data;

    }


    public void delete() {

        TOMADatabase db = TOMADatabase.getInstance();


        Integer id = new Integer(training.getIdTraining());


        RequeteDelete rd = new RequeteDelete(db, "trainingInscriptionContact", "idTraining", id);

        rd.close();


        rd = new RequeteDelete(db, "trainingCatalogue", "idTraining", id);

        rd.close();


        rd = new RequeteDelete(db, "trainingDomain", "idTraining", id);

        rd.close();


        rd = new RequeteDelete(db, "audience", "idTraining", id);

        rd.close();


        db.commit();


        super.delete();

    }


    public Vector getUnitsCreatedByCopy(Language lng) {

        TOMADatabase db = TOMADatabase.getInstance();

        Vector units = new Vector();


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(training.getIdTraining())).toString();

        where[0][1] = "Integer";

        where[0][2] = "idTrainingCopied";


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);

        while (rs.next()) {

            int id = rs.getInt("idTraining");

            Unit u = new Unit(id);

            UnitDB udb = new UnitDB(u);

            udb.loadById(lng, false);

            units.add(u);

        }

        rs.close();


        return units;

    }



    /****************** statics **************************/

    /**

     *@return a vector of strings: training.toString()

     **/

    public static Vector getTrainingsWithoutDomains(Language lng, Vector idtrainings) {

        Vector result = new Vector();


        String where = "(";

        if (idtrainings != null) {

            Iterator it = idtrainings.iterator();

            while (it.hasNext()) {

                Integer id = (Integer) it.next();

                where = where + "idTraining='" + id + "' or ";

            }

            //enlever lengthdernier " or" et fermer la parenthse

            where = where.substring(0, where.length() - 4) + ") and idTraining not in (select idTraining from trainingDomain) and (type='C' or type='P')";

        }


        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(true, db, "idTraining", "training", where);

        while (rs.next()) {

            int id = rs.getInt(1);

            Training t = TrainingDB.getInstance(lng, false, id);

            result.add(t.toString());

        }

        rs.close();


        return result;

    }


    /**

     *@return a vector of strings: session.toString() + " " + identifySession+" "+training.toString()

     **/

    public static Vector getSessionsWithoutLanguage(Language lng, String identifySession, Vector idtrainings) {

        Vector result = new Vector();


        String where = "(";

        if (idtrainings != null) {

            Iterator it = idtrainings.iterator();

            while (it.hasNext()) {

                Integer id = (Integer) it.next();

                where = where + "idTraining='" + id + "' or ";

            }

            //enlever lengthdernier " or" et fermer la parenthse

            where = where.substring(0, where.length() - 4) + ") and languageCode is NULL";

        }


        TOMADatabase db = TOMADatabase.getInstance();

        RequeteSelect rs = new RequeteSelect(true, db, "idSession, idTraining", "session", where);

        while (rs.next()) {

            int ids = rs.getInt(1);

            int idt = rs.getInt(2);

            Session s = SessionDB.getInstance(lng, false, ids);

            Training t = TrainingDB.getInstance(lng, false, idt);

            result.add(s.toString() + " " + identifySession + " " + t.toString());

        }

        rs.close();


        return result;

    }

}

