// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;
import apostal.toma.TOMA;

import java.sql.*;
import java.util.*;
import java.io.*;

import toolbox.sql.*;

public class TOMADatabase {
    private static TOMADatabase instance;

    public static TOMADatabase getInstance() {
        if (instance == null)
            instance = new TOMADatabase();

        return instance;
    }

    public static TOMADatabase getInstance(boolean fromServer) {
        if (instance == null)
            instance = new TOMADatabase(fromServer);

        return instance;
    }

    public static void close() {
        if (instance != null) {
            instance.closeConnectionWithoutCommit();
            instance = null;
        }
    }

    public static TOMADatabase getAnotherConnection(){
        TOMADatabase otherInstance=new TOMADatabase();
        return otherInstance;
    }
    
    public void shutdown(boolean compact) {
        try {
            Statement stmt = this.getStatement();
            if (compact)
                stmt.execute("SHUTDOWN COMPACT");
            else
                stmt.execute("SHUTDOWN");
        } catch (Exception ex) {
            TOMA.log(TOMA.SEVERE, "Exception while shutting down database: " + ex.getMessage());
        }
    }

    public static boolean tryConnection() {
        boolean ok = true;

        FileInputStream fichierTest = null;
        FileOutputStream out = null;
        Properties dbProperties = new Properties();

        // Connexion  la base
        String driverName = "org.hsqldb.jdbcDriver";

        //diffrencier si client-serveur
        String baseURL = "jdbc:hsqldb:toma";
        //recharger localement les parametres
        TOMAParameters params = new TOMAParameters();
        params.loadOnlyClientServerData();
        if (params.isClientServer()) {
            //si client-server: "jdbc:hsqldb:hsql://"+host
            baseURL = "jdbc:hsqldb:hsql://" + params.getServer();
        }

        String dbUser = "SA";
        String dbPassword = "";
        try {
            Class.forName(driverName);
        } catch (Exception ex) {
            ok = false;
        }

        Connection myConnection = null;
        try {
            myConnection = DriverManager.getConnection(baseURL, dbUser, dbPassword);
        } catch (SQLException sqle) {
            ok = false;
        }

        if (myConnection == null)
            ok = false;
        else {
            //fermer la connexion ouverte
            try {
                myConnection.close();
            } catch (SQLException sqle) {
            }
        }

        return ok;
    }

    private Connection connection;
    private boolean frollback;

    private TOMADatabase() {
        this(false);
    }

    private TOMADatabase(boolean fromServer) {
        if (fromServer)
            this.openConnectionFromServer();
        else
            this.openConnection();
        frollback = false;
    }


    public Statement getStatement() throws SQLException {
        Statement st = null;
        try {
            st = connection.createStatement();
        } catch (SQLException sqle) {
            this.closeConnection();
            this.openConnection();
            st = connection.createStatement();
        }
        return st;
    }

    public PreparedStatement getPreparedStatement(String requete) throws SQLException {
        PreparedStatement pst = null;
        try {
            pst = connection.prepareStatement(requete);
        } catch (SQLException sqle) {
            this.closeConnection();
            this.openConnection();
            pst = connection.prepareStatement(requete);
        }
        return pst;
    }

    public boolean isConnectionNull() {
        if (connection == null)
            return true;
        else
            return false;
    }

    // Ouverture de la connexion
    public void openConnection() {
        TOMA.log(TOMA.INFO, "Opening Connection");

        FileInputStream fichierTest = null;
        FileOutputStream out = null;
        Properties dbProperties = new Properties();
        String driverName = null;
        String baseURL = null;
        String dbUser = null;
        String dbPassword = null;

        frollback = false;

        // Connexion  la base
        driverName = "org.hsqldb.jdbcDriver";

        //diffrencier si client-serveur
        baseURL = "jdbc:hsqldb:toma";
        //recharger localement les parametres
        TOMAParameters params = new TOMAParameters();
        params.loadOnlyClientServerData();
        if (params.isClientServer()) {
            //si client-server: "jdbc:hsqldb:hsql://"+host
            baseURL = "jdbc:hsqldb:hsql://" + params.getServer();
        }

        dbUser = "SA";
        dbPassword = "";
        try {
            Class.forName(driverName);
        } catch (Exception ex) {
            TOMA.log(TOMA.SEVERE, "problem with the database driver");
        }
        try {
            TOMA.log(TOMA.INFO, "Connection to the database");
            connection = DriverManager.getConnection(baseURL, dbUser, dbPassword);
            connection.setAutoCommit(false);
        } catch (SQLException sqle) {
            TOMA.log(TOMA.INFO, "The connection to the database failed");
            TOMA.log(TOMA.INFO, SQLTools.printSQLException(sqle));
            System.exit(1);
        }
    } // END ouvrirConnexionBase()


    public void openConnectionFromServer() {
        TOMA.log(TOMA.INFO, "Opening Connection");

        FileInputStream fichierTest = null;
        FileOutputStream out = null;
        Properties dbProperties = new Properties();
        String driverName = null;
        String baseURL = null;
        String dbUser = null;
        String dbPassword = null;

        frollback = false;

        // Connexion  la base
        driverName = "org.hsqldb.jdbcDriver";
        baseURL = "jdbc:hsqldb:hsql://localhost";

        dbUser = "SA";
        dbPassword = "";
        try {
            Class.forName(driverName);
        } catch (Exception ex) {
            TOMA.log(TOMA.SEVERE, "problem with the database driver");
        }
        try {
            TOMA.log(TOMA.INFO, "Connection to the database");
            connection = DriverManager.getConnection(baseURL, dbUser, dbPassword);
            connection.setAutoCommit(false);
        } catch (SQLException sqle) {
            TOMA.log(TOMA.INFO, "The connection to the database failed");
            TOMA.log(TOMA.INFO, SQLTools.printSQLException(sqle));
            System.exit(1);
        }
    }

    public void closeConnection() {

        if (connection != null) {
            try {

                if (frollback) {

                    this.rollback();

                } else {

                    this.commit();

                }


                connection.close();

                TOMA.log(TOMA.INFO, "Closing connection to the database");

            } catch (SQLException sqle) {

                sqle.printStackTrace();

                TOMA.log(TOMA.SEVERE, "Problem while closing the connection");

            }

            connection = null;

        }

    }


    public void closeConnectionWithoutCommit() {

        try {

            connection.close();

            TOMA.log(TOMA.INFO, "Closing connection to the database");

        } catch (SQLException sqle) {

            sqle.printStackTrace();

            TOMA.log(TOMA.SEVERE, "Problem while closing the connection");

        }

        connection = null;

    }


    public void commit() {

        if (frollback)

            this.rollback();

        else {


            try {

                connection.commit();

                TOMA.log(TOMA.INFO, "commit");

            } catch (SQLException sqle) {

                sqle.printStackTrace();

                TOMA.log(TOMA.SEVERE, "Problem while commiting");

            }

        }

    }


    public void rollback() {

        try {

            connection.rollback();

            TOMA.log(TOMA.INFO, "rollback");

//remettre la demande de rollback  false

            frollback = false;

        } catch (SQLException sqle) {

            sqle.printStackTrace();

            TOMA.log(TOMA.SEVERE, "Problem while doing rollback");

        }

    }


    public void setRollbackTrue() {

        frollback = true;

        TOMA.log(TOMA.INFO, "TOMADatabase: setting rollback to true");

    }


    /******************** mthodes de test *************************************/


    public void testInsert() {

        Object[][] table = new Object[1][2];


        table[0][0] = "countryCode";

        table[0][1] = "fr";


        RequeteInsert ri = new RequeteInsert(this, "COUNTRY", table);


        this.commit();

    }


    public void testSelect() {

        String[][] where = new String[0][3];

        //RequeteSelectWhere rs=new RequeteSelectWhere(this, "COUNTRY", where);

        RequeteSelectWhere rs = new RequeteSelectWhere(this, "DOMAIN", where);


        while (rs.next()) {

            //System.out.println("coutry: "+rs.getString("countryCode"));

            System.out.println("domain: " + new Integer(rs.getInt("idDomain")));

        }

        rs.close();

    }


    public void testFixed() {

        Language lng = new Language("eng");

        LanguageDB ldb = new LanguageDB(lng);

        ldb.loadByCode("eng");

        Vector domains = DomainDB.loadFirstLevel(lng);


        Iterator it = domains.iterator();

        while (it.hasNext()) {

            Domain d = (Domain) it.next();


            System.out.println("domain: iddomain=" + new Integer(d.getIdDomain()) + ", name=" + d.getName());


            Vector sub = d.getDomains();

            Iterator it2 = sub.iterator();

            while (it2.hasNext()) {

                Domain d2 = (Domain) it2.next();


                System.out.println("subdomain: iddomain=" + new Integer(d2.getIdDomain()) + ", name=" + d2.getName());

            }

        }

    }

}



