// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import java.util.*;
import java.sql.Date;

import apostal.toma.data.Address;
import apostal.toma.data.Language;

/**
 * @(#) Teacher.java
 */

public class TeacherDB implements Modifiable {

    private Teacher teacher;

    public static boolean exists(int idTeacher) {
        boolean exists = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "teacher", "idTeacher", new Integer(idTeacher));
        if (rs.next()) {
            exists = true;
        }
        rs.close();


        return exists;
    }

    public TeacherDB(Teacher teacher) {
        this.teacher = teacher;
    }

    public static Vector load(Language language, boolean all) {
        TOMADatabase db = TOMADatabase.getInstance();

        Vector teachers = new Vector();
        String[][] values = new String[0][3];
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "teacher", values);
        while (rs.next()) {
            int id = rs.getInt("idTeacher");
            Teacher t = new Teacher(id);
            TeacherDB tdb = new TeacherDB(t);
            tdb.loadByIdAndRS(language, all, rs);

            teachers.add(t);
        }
        rs.close();


        return teachers;
    }

    /**
     * returns all the trainings that use this teacher
     */
    public Vector getTrainingsByTeacher(Language lng, boolean all) {
        HashSet found = new HashSet();
        Vector trainings = new Vector();
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "trainingTeacher", "idTeacher", new Integer(teacher.getIdTeacher()));
        while (rs.next()) {
            int id = rs.getInt("idTraining");
            Training t = TrainingDB.getInstance(lng, all, id);
            trainings.add(t);
            found.add(new Integer(id));
        }
        rs.close();
        //teachers dans des sessions
        rs = new RequeteSelect(db, "sessionTeacher", "idTeacher", new Integer(teacher.getIdTeacher()));
        while (rs.next()) {
            int ids = rs.getInt("idSession");
            RequeteSelect rs2 = new RequeteSelect(db, "session", "idSession", new Integer(ids));
            if (rs2.next()) {
                int id = rs2.getInt("idTraining");
                if (!found.contains(new Integer(id))) {
                    Training t = TrainingDB.getInstance(lng, all, id);
                    trainings.add(t);
                    found.add(new Integer(id));
                }
            }
            rs2.close();
        }
        rs.close();

        return trainings;
    }

    public boolean loadByFirstnameLastnameFunctionAndTest(Language language, boolean all) {
        boolean loaded = false;

        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[3][3];
        where[0][0] = teacher.getFirstname();
        where[0][1] = "String";
        where[0][2] = "firstname";
        where[1][0] = teacher.getLastname();
        where[1][1] = "String";
        where[1][2] = "lastname";
        where[2][0] = teacher.getFunction();
        where[2][1] = "String";
        where[2][2] = "function";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "teacher", where);
        if (rs.next()) {
            int id = rs.getInt("idTeacher");
            teacher.setIdTeacher(id);
            this.loadByIdAndRS(language, all, rs);
            loaded = true;
        }
        rs.close();


        return loaded;
    }

    public void loadByFirstnameLastnameFunction(Language language, boolean all) {
        this.loadByFirstnameLastnameFunctionAndTest(language, all);
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(teacher.getIdTeacher())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTeacher";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "teacher", where);
        if (rs.next()) {
            loaded = true;

            String _firstname = rs.getString("firstname");
            if (_firstname != null) teacher.setFirstname(_firstname);
            teacher.setLastname(rs.getString("lastname"));
            String _function = rs.getString("function");
            if (_function != null) teacher.setFunction(_function);

            if (all) {
                String _title = rs.getString("title");
                if (_title != null) teacher.setTitle(_title);
                String _tel = rs.getString("tel");
                if (_tel != null) teacher.setTel(_tel);
                String _email = rs.getString("email");
                if (_email != null) teacher.setEmail(_email);
                String _fax = rs.getString("fax");
                if (_fax != null) teacher.setFax(_fax);
                String _cv = rs.getString("cv");
                if (_cv != null) teacher.setCv(_cv);
                String postCode = rs.getString("postCode");
                String city = rs.getString("city");
                String countryCode = rs.getString("countryCode");
                Country c = new Country(countryCode);
                CountryDB cdb = new CountryDB(c);
                cdb.loadByCode(language);
                if (city != null) //il y a une adresse
                {
                    Vector lines = new Vector();

                    RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "teacherAddressLine", where, "nborder");
                    while (rs2.next()) {
                        String line = rs2.getString("teacherAddressLine");
                        lines.add(line);
                    }
                    rs2.close();

                    Address address = new Address(lines, city, postCode, c);
                    teacher.setAddress(address);
                }
                teacher.setDateCreation(rs.getDate("dateCreation"));
                teacher.setDateMaj(rs.getDate("dateMaj"));

                //competences
                Vector competences = new Vector();
                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "competence", where);
                while (rs3.next()) {
                    competences.add(rs3.getString("competence"));
                }
                rs3.close();
                teacher.setCompetences(competences);

            }
        }
        rs.close();


        return loaded;
    }

    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = true;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(teacher.getIdTeacher())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTeacher";

/*	RequeteSelectWhere rs=new RequeteSelectWhere(db, "teacher", where);
	if(rs.next())
	    {
		loaded=true;*/

        String _firstname = rs.getString("firstname");
        if (_firstname != null) teacher.setFirstname(_firstname);
        teacher.setLastname(rs.getString("lastname"));
        String _function = rs.getString("function");
        if (_function != null) teacher.setFunction(_function);

        if (all) {
            String _title = rs.getString("title");
            if (_title != null) teacher.setTitle(_title);
            String _tel = rs.getString("tel");
            if (_tel != null) teacher.setTel(_tel);
            String _email = rs.getString("email");
            if (_email != null) teacher.setEmail(_email);
            String _fax = rs.getString("fax");
            if (_fax != null) teacher.setFax(_fax);
            String _cv = rs.getString("cv");
            if (_cv != null) teacher.setCv(_cv);
            String postCode = rs.getString("postCode");
            String city = rs.getString("city");
            String countryCode = rs.getString("countryCode");
            Country c = new Country(countryCode);
            CountryDB cdb = new CountryDB(c);
            cdb.loadByCode(language);
            if (city != null) //il y a une adresse
            {
                Vector lines = new Vector();

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "teacherAddressLine", where, "nborder");
                while (rs2.next()) {
                    String line = rs2.getString("teacherAddressLine");
                    lines.add(line);
                }
                rs2.close();

                Address address = new Address(lines, city, postCode, c);
                teacher.setAddress(address);
            }
            teacher.setDateCreation(rs.getDate("dateCreation"));
            teacher.setDateMaj(rs.getDate("dateMaj"));

            //competences
            Vector competences = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "competence", where);
            while (rs3.next()) {
                competences.add(rs3.getString("competence"));
            }
            rs3.close();
            teacher.setCompetences(competences);

        }
        /*   }
       rs.close();*/


        return loaded;
    }


    public boolean loadElementsNotInTedById(Language language) {
        TOMA.log(TOMA.WARNING, "TeacherDB.loadElementsNotInTedById");

        boolean loaded = false;
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(teacher.getIdTeacher())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTeacher";

        RequeteSelectWhere rs = new RequeteSelectWhere(db, "teacher", where);
        if (rs.next()) {
            loaded = true;
            TOMA.log(TOMA.WARNING, "teacher found");

            String _tel = rs.getString("tel");
            if (_tel != null) teacher.setTel(_tel);
            String _email = rs.getString("email");
            if (_email != null) teacher.setEmail(_email);
            String _fax = rs.getString("fax");
            if (_fax != null) teacher.setFax(_fax);
            String postCode = rs.getString("postCode");
            String city = rs.getString("city");
            String countryCode = rs.getString("countryCode");
            Country c = new Country(countryCode);
            CountryDB cdb = new CountryDB(c);
            cdb.loadByCode(language);
            if (city != null) //il y a une adresse
            {
                Vector lines = new Vector();

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "teacherAddressLine", where, "nborder");
                while (rs2.next()) {
                    String line = rs2.getString("teacherAddressLine");
                    lines.add(line);
                }
                rs2.close();

                Address address = new Address(lines, city, postCode, c);
                teacher.setAddress(address);
            }
            teacher.setDateCreation(rs.getDate("dateCreation"));
            teacher.setDateMaj(rs.getDate("dateMaj"));

            //competences: garder les autres...
            //Vector competences=new Vector();
            Vector competences = teacher.getCompetences();
            if (competences == null)
                competences = new Vector();
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "competence", where);
            while (rs3.next()) {
                String comp = rs3.getString("competence");
                if (comp != null && !competences.contains(comp))
                    competences.add(comp);
            }
            rs3.close();
            teacher.setCompetences(competences);
        }
        rs.close();


        return loaded;
    }

    public boolean unlock() {
        boolean unlock = DatabaseFacilities.unlock("idTeacher", teacher.getIdTeacher(), "teacher");
        return unlock;
    }

    public boolean lock() {
        boolean lock = DatabaseFacilities.lock("idTeacher", teacher.getIdTeacher(), "teacher");
        return lock;
    }

    public boolean isLocked() {
        boolean locked = DatabaseFacilities.isLocked("idTeacher", teacher.getIdTeacher(), "teacher");
        return locked;
    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);

        RequeteInsert ri = new RequeteInsert(db, "teacher", insert);
        ri.close();

        //rcuprer l'idTeacher
        String[][] where = new String[3][3];
        where[0][0] = teacher.getFirstname();
        where[0][1] = "String";
        where[0][2] = "firstname";
        where[1][0] = teacher.getLastname();
        where[1][1] = "String";
        where[1][2] = "lastname";
        where[2][0] = teacher.getFunction();
        where[2][1] = "String";
        where[2][2] = "function";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "teacher", where);
        if (rs.next()) {
            teacher.setIdTeacher(rs.getInt("idTeacher"));
            teacher.setDateCreation(rs.getDate("dateCreation"));
            teacher.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();
        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] update = this.getSaveData(false);

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(teacher.getIdTeacher())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTeacher";

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "teacher", update, where);
        ru.close();

        db.commit();

        //date maj
        teacher.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        TOMADatabase db = TOMADatabase.getInstance();

        //address lines
        //enlever toutes celles existant
        RequeteDelete rd = new RequeteDelete(db, "teacherAddressLine", "idTeacher", (new Integer(teacher.getIdTeacher())).toString());
        rd.close();
        //rajouter les nouvelles
        Address address = teacher.getAddress();
        if (address != null) {
            Object[] lines = address.getAddressLines().toArray();
            int length = lines.length;
            for (int i = 0; i < length; i++) {
                String line = (String) lines[i];
                Object[][] value = new Object[3][2];

                value[0][0] = "idTeacher";
                value[0][1] = new Integer(teacher.getIdTeacher());

                value[1][0] = "teacherAddressLine";
                value[1][1] = line;

                value[2][0] = "nborder";
                value[2][1] = new Integer(i);

                RequeteInsert ri2 = new RequeteInsert(db, "teacherAddressLine", value);
                ri2.close();
            }
        }

        //competences

        //vrifier les liens depuis des formations vers ces competences
        //trainingcomp=hashtable de cl=competence et de value=Vector d'id
        Hashtable trainingcomp = new Hashtable();
        RequeteSelect rs = new RequeteSelect(db, "competence", "idTeacher", new Integer(teacher.getIdTeacher()));
        while (rs.next()) {
            int idc = rs.getInt("idCompetence");
            Vector trs = new Vector();
            RequeteSelect rs2 = new RequeteSelect(db, "trainingTeacher", "idCompetence", new Integer(idc));
            while (rs2.next()) {
                trs.add(new Integer(rs2.getInt("idTraining")));
            }
            rs2.close();

            if (!trs.isEmpty()) {
                //enlever les trainingTeacher
                RequeteDelete rdt = new RequeteDelete(db, "trainingTeacher", "idCompetence", (new Integer(idc)).toString());
                rdt.close();

                trainingcomp.put(rs.getString("competence"), trs);
            }
        }
        rs.close();

        rd = new RequeteDelete(db, "competence", "idTeacher", (new Integer(teacher.getIdTeacher())).toString());
        rd.close();
        Vector competences = teacher.getCompetences();


        if (competences != null) {
            Iterator it = competences.iterator();
            while (it.hasNext()) {
                String competence = (String) it.next();
                //vrifier idsec=competence+idteacher
                String[][] where = new String[2][3];
                where[0][0] = competence;
                where[0][1] = "String";
                where[0][2] = "competence";
                where[1][0] = (new Integer(teacher.getIdTeacher())).toString();
                where[1][1] = "Integer";
                where[1][2] = "idTeacher";
                RequeteSelectWhere rs_selectCompetence = new RequeteSelectWhere(db, "competence", where);
                if (!rs_selectCompetence.next()) {
                    //faire l'insert
                    Object[][] insert2 = new Object[2][2];
                    insert2[0][0] = "competence";
                    insert2[0][1] = competence;
                    insert2[1][0] = "idTeacher";
                    insert2[1][1] = new Integer(teacher.getIdTeacher());
                    RequeteInsert ri2 = new RequeteInsert(db, "competence", insert2);
                    ri2.close();
                }
                rs_selectCompetence.close();

                if (trainingcomp.containsKey(competence))
                //il y avait des formations pour cette competence
                {
                    //rcuprer l'idCompetence
                    String[][] wherecomp = new String[2][3];
                    wherecomp[0][0] = competence;
                    wherecomp[0][1] = "String";
                    wherecomp[0][2] = "competence";
                    wherecomp[1][0] = (new Integer(teacher.getIdTeacher())).toString();
                    wherecomp[1][1] = "Integer";
                    wherecomp[1][2] = "idTeacher";
                    RequeteSelectWhere rscomp = new RequeteSelectWhere(db, "competence", wherecomp);
                    int idc = 0;
                    if (rscomp.next()) {
                        idc = rscomp.getInt("idCompetence");
                    }
                    rscomp.close();
                    //insrer les trainingTeacher
                    Vector trs = (Vector) trainingcomp.get(competence);
                    Iterator itt = trs.iterator();
                    while (itt.hasNext()) {
                        Integer idt = (Integer) itt.next();

                        Object[][] insert3 = new Object[3][2];
                        insert3[0][0] = "idCompetence";
                        insert3[0][1] = new Integer(idc);
                        insert3[1][0] = "idTeacher";
                        insert3[1][1] = new Integer(teacher.getIdTeacher());
                        insert3[2][0] = "idTraining";
                        insert3[2][1] = idt;

                        RequeteInsert ri3 = new RequeteInsert(db, "trainingTeacher", insert3);
                        ri3.close();
                    }
                }
                trainingcomp.remove(competence);
            }
        }
        Enumeration enum = trainingcomp.keys();
        while (enum.hasMoreElements()) {
            String key = (String) enum.nextElement();
            Vector trs = (Vector) trainingcomp.get(key);
            Iterator it = trs.iterator();
            while (it.hasNext()) {
                Integer idt = (Integer) it.next();
                Object[][] insert3 = new Object[3][2];
                insert3[0][0] = "idCompetence";
                insert3[0][1] = null;
                insert3[1][0] = "idTeacher";
                insert3[1][1] = new Integer(teacher.getIdTeacher());
                insert3[2][0] = "idTraining";
                insert3[2][1] = idt;
                RequeteInsert ri3 = new RequeteInsert(db, "trainingTeacher", insert3);
                ri3.close();
            }
        }

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Vector values = new Vector();
        Vector names = new Vector();

        values.add(teacher.getTitle());
        names.add("title");

        values.add(teacher.getFirstname());
        names.add("firstname");

        values.add(teacher.getLastname());
        names.add("lastname");

        values.add(teacher.getFunction());
        names.add("function");

        values.add(teacher.getCv());
        names.add("cv");

        values.add(teacher.getTel());
        names.add("tel");

        values.add(teacher.getFax());
        names.add("fax");

        values.add(teacher.getEmail());
        names.add("email");

        Address address = teacher.getAddress();
        if (address != null) {
            String postCode = address.getPostCode();
            String city = address.getCity();
            Country country = address.getCountry();

            values.add(postCode);
            names.add("postCode");

            values.add(city);
            names.add("city");

            names.add("countryCode");
            if (country != null)
                values.add(country.getCode());
            else
                values.add(null);
        } else {
            values.add(null);
            names.add("postCode");

            values.add(null);
            names.add("city");

            values.add(null);
            names.add("countryCode");
        }

        //dates
        if (creation)
            DatabaseFacilities.addCreationDates(values, names);
        else
            DatabaseFacilities.addUpdateDates(values, names);

        //lock: true
        values.add(Boolean.TRUE);
        names.add("lock");

        Object[][] data = new Object[values.size()][2];
        for (int i = 0; i < values.size(); i++) {
            data[i][0] = names.elementAt(i);
            data[i][1] = values.elementAt(i);
        }

        return data;
    }

    public boolean testConstraints() {
        if (teacher.getLastname() == null || teacher.getLastname().equals(""))
            return false;
        else
            return true;
    }

    public boolean testUpdate() {
        if (this.testConstraints()) {
            String[][] where = new String[3][3];
            where[0][0] = teacher.getFirstname();
            where[0][1] = "String";
            where[0][2] = "firstname";
            where[1][0] = teacher.getLastname();
            where[1][1] = "String";
            where[1][2] = "lastname";
            where[2][0] = teacher.getFunction();
            where[2][1] = "String";
            where[2][2] = "function";
            boolean test = DatabaseFacilities.testUpdate("teacher", where, "idTeacher", teacher.getIdTeacher());
            return test;
        } else
            return false;
    }

    public boolean testCreate() {
        if (this.testConstraints()) {
            String[][] where = new String[3][3];
            where[0][0] = teacher.getFirstname();
            where[0][1] = "String";
            where[0][2] = "firstname";
            where[1][0] = teacher.getLastname();
            where[1][1] = "String";
            where[1][2] = "lastname";
            where[2][0] = teacher.getFunction();
            where[2][1] = "String";
            where[2][2] = "function";
            boolean test = DatabaseFacilities.testCreate("teacher", where);
            return test;
        } else
            return false;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        int idTeacher = teacher.getIdTeacher();

        RequeteDelete rd1 = new RequeteDelete(db, "teacherAddressLine", "idTeacher", new Integer(idTeacher));
        rd1.close();

        RequeteDelete rd3 = new RequeteDelete(db, "trainingTeacher", "idTeacher", new Integer(idTeacher));
        rd3.close();

        RequeteDelete rd2 = new RequeteDelete(db, "competence", "idTeacher", new Integer(idTeacher));
        rd2.close();

        RequeteDelete rd = new RequeteDelete(db, "teacher", "idTeacher", new Integer(idTeacher));
        rd.close();

        db.commit();
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "teacher", "0", "0");
        while (rs.next()) {
            Teacher teacher = new Teacher(rs.getInt("idTeacher"));
            TeacherDB teacherdb = new TeacherDB(teacher);
            teacherdb.delete();
        }
        rs.close();
        db.commit();
    }

    public boolean isUsedInTraining() {
        boolean used = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "trainingTeacher", "idTeacher", new Integer(teacher.getIdTeacher()));
        if (rs.next()) {
            used = true;
        }
        rs.close();

        return used;
    }
}
