// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;


import apostal.toma.data.*;


import java.util.Vector;

import java.util.Iterator;

import toolbox.text.ExtendedList;

import java.sql.Date;

import apostal.toma.data.Level;

import apostal.toma.data.ModeOfOrganization;

import apostal.toma.data.Language;

/**

 * @(#) Training.java

 */


public abstract class TrainingDB implements Modifiable {


    protected Training training;


    public TrainingDB(Training training) {

        this.training = training;

    }


    public static boolean exists(int idTraining) {
        boolean exists = false;
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "training", "idTraining", new Integer(idTraining));
        if (rs.next()) {
            exists = true;
        }
        rs.close();
        return exists;
    }


    public static Training getInstance(Language lng, boolean all, String code) {
        TOMADatabase db = TOMADatabase.getInstance();
        Training t = null;
        RequeteSelect rs = new RequeteSelect(db, "training", "code", code);
        if (rs.next()) {
            int id = rs.getInt("idTraining");
            t = TrainingDB.getInstance(lng, all, id);
        }
        rs.close();
        return t;
    }


    public static Training getInstance(Language lng, boolean all, int idTraining) {
        Training t = null;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(idTraining)).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);
        if (rs.next()) {
            String type = rs.getString("type");
            if (type.equals("C")) {
                t = new TrainingCourse(idTraining);
                TrainingCourseDB tdb = new TrainingCourseDB((TrainingCourse) t);
                tdb.loadByIdAndRS(lng, all, rs);
            } else if (type.equals("P")) {
                t = new TrainingProgramme(idTraining);
                TrainingProgrammeDB tdb = new TrainingProgrammeDB((TrainingProgramme) t);
                tdb.loadByIdAndRS(lng, all, rs);
            } else if (type.equals("U")) {
                t = new Unit(idTraining);
                UnitDB tdb = new UnitDB((Unit) t);
                tdb.loadByIdAndRS(lng, all, rs);
            }
        }
        rs.close();
        return t;
    }






    public static Training getInstanceForPublication(Language lng, boolean all, int idTraining) {
        Training t = null;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(idTraining)).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);
        if (rs.next()) {
            String type = rs.getString("type");
            if (type.equals("C")) {
                t = new TrainingCourse(idTraining);
                TrainingCourseDB tdb = new TrainingCourseDB((TrainingCourse) t);
                tdb.loadByIdAndRSForPublication(lng, all, rs);
            } else if (type.equals("P")) {
                t = new TrainingProgramme(idTraining);
                TrainingProgrammeDB tdb = new TrainingProgrammeDB((TrainingProgramme) t);
                tdb.loadByIdAndRSForPublication(lng, all, rs);
            } else if (type.equals("U")) {
                t = new Unit(idTraining);
                UnitDB tdb = new UnitDB((Unit) t);
                tdb.loadByIdAndRSForPublication(lng, all, rs);
            }
        }
        rs.close();
        return t;
    }


    public static Training getInstanceByRS(Language lng, boolean all, int idTraining, InterfaceRequeteSelect rs) {
        Training t = null;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(idTraining)).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        String type = rs.getString("type");
        if (type.equals("C")) {
            t = new TrainingCourse(idTraining);
            TrainingCourseDB tdb = new TrainingCourseDB((TrainingCourse) t);
            tdb.loadById(lng, all);
        } else if (type.equals("P")) {
            t = new TrainingProgramme(idTraining);
            TrainingProgrammeDB tdb = new TrainingProgrammeDB((TrainingProgramme) t);
            tdb.loadById(lng, all);
        } else if (type.equals("U")) {
            t = new Unit(idTraining);
            UnitDB tdb = new UnitDB((Unit) t);
            tdb.loadById(lng, all);
        }
        return t;
    }


    /*************** database access ***********************/

    public boolean loadById(Language language, boolean all) {

        boolean loaded = false;

        TOMADatabase db = TOMADatabase.getInstance();


        String[][] where = new String[1][3];

        where[0][0] = (new Integer(training.getIdTraining())).toString();

        where[0][1] = "Integer";

        where[0][2] = "idTraining";


        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);

        if (rs.next()) {

            loaded = true;

            training.setTitle(rs.getString("title"));

            training.setCode(rs.getString("code"));


            if (all) {

                String part = rs.getString("partnership");

                if (part != null)

                    training.setPartnership(part);



                //objectives

                String objintr = rs.getString("objectivesIntroduction");

                if (objintr != null)

                    training.setObjectivesIntroduction(objintr);

                Vector objectives = new Vector();

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "objectivesObjective", where, "nborder");

                while (rs2.next()) {

                    objectives.add(rs2.getString("objectivesObjective"));

                }

                rs2.close();

                training.setObjectives(objectives);

                String objccl = rs.getString("objectivesConclusion");

                if (objccl != null)

                    training.setObjectivesConclusion(objccl);



                //pdw

                ExtendedList pointsDealtWith = new ExtendedList();

                String pdwintr = rs.getString("pdwIntroduction");

                if (pdwintr != null)

                    pointsDealtWith.setIntroduction(pdwintr);

                RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "pointDealtWith", where, "nborder");

                while (rs3.next()) {

                    ExtendedList l2 = new ExtendedList();

                    String intr2 = rs3.getString("introduction");

                    if (intr2 != null)

                        l2.setIntroduction(intr2);

                    int idp = rs3.getInt("idPointDealtWith");


                    String[][] where2 = new String[1][3];

                    where2[0][0] = (new Integer(idp)).toString();

                    where2[0][1] = "Integer";

                    where2[0][2] = "idPointDealtWith";

                    RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "subPointDealtWith", where2, "nborder");

                    while (rs4.next()) {

                        l2.addElement(rs4.getString("subPointDealtWith"));

                    }

                    rs4.close();


                    String ccl2 = rs3.getString("conclusion");

                    if (ccl2 != null)

                        l2.setConclusion(ccl2);


                    pointsDealtWith.addElement(l2);

                }

                rs3.close();

                String pdwccl = rs.getString("pdwConclusion");

                if (pdwccl != null)

                    pointsDealtWith.setConclusion(pdwccl);


                training.setPointsDealtWith(pointsDealtWith);



                //contentDescription

                String contintr = rs.getString("contentDescriptionIntroduction");

                if (contintr != null)

                    training.setContentDescriptionIntroduction(contintr);

                Vector contentDescription = new Vector();

                RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "contentDescriptionDescription", where, "nborder");

                while (rs5.next()) {

                    contentDescription.add(rs5.getString("contentDescriptionDescription"));

                }

                rs5.close();

                training.setContentDescription(contentDescription);

                String contccl = rs.getString("contentDescriptionConclusion");

                if (contccl != null)

                    training.setContentDescriptionConclusion(contccl);


                String moo = rs.getString("modeOfOrganizationValue");

                if (moo != null) {

                    ModeOfOrganization modeOfOrganization = new ModeOfOrganization(moo);

                    ModeOfOrganizationDB mdb = new ModeOfOrganizationDB(modeOfOrganization);

                    mdb.loadByValue(language);


                    training.setModeOfOrganization(modeOfOrganization);

                }


                String ped = rs.getString("pedagogicalMethods");

                if (ped != null)

                    training.setPedagogicalMethods(ped);


                String coursem = rs.getString("courseMedia");

                if (coursem != null)

                    training.setCourseMedia(coursem);


                String levelv = rs.getString("levelValue");

                if (levelv != null) {

                    Level level = new Level(levelv);

                    LevelDB ldb = new LevelDB(level);

                    ldb.loadByValue(language);


                    training.setLevel(level);

                }


                String ev = rs.getString("evaluation");

                if (ev != null)

                    training.setEvaluation(ev);


                String dur = rs.getString("duration");

                if (dur != null)

                    training.setDuration(dur);


                Date bvd = rs.getDate("beginValidityDate");

                if (bvd != null)

                    training.setBeginValidityDate(bvd);

                Date evd = rs.getDate("endValidityDate");

                if (evd != null)

                    training.setEndValidityDate(evd);

                String cm = rs.getString("comment");

                if (cm != null)

                    training.setComment(cm);

                String cmnot = rs.getString("commentNotPublished");

                if (cmnot != null)

                    training.setCommentNotPublished(cmnot);


                training.setDateCreation(rs.getDate("dateCreation"));

                training.setDateMaj(rs.getDate("dateMaj"));



                //languages

                Vector languages = new Vector();

                RequeteSelectWhere rslang = new RequeteSelectWhere(db, "trainingLanguage", where);

                while (rslang.next()) {

                    Language l = new Language(rslang.getString("languageCode"));

                    LanguageDB ldb = new LanguageDB(l);

                    ldb.loadByCode(language);


                    languages.add(l);

                }

                rslang.close();

                training.setLanguages(languages);



                //slots

                Vector slots = new Vector();

                RequeteSelectWhere rsslot = new RequeteSelectWhere(db, "trainingSlot", where);

                while (rsslot.next()) {

                    Slot s = new Slot(rsslot.getString("slotValue"));

                    SlotDB sdb = new SlotDB(s);

                    sdb.loadByValue(language);


                    slots.add(s);

                }

                rsslot.close();

                training.setSlots(slots);



                //locations

                Vector locations = new Vector();

                RequeteSelectWhere rsloc = new RequeteSelectWhere(db, "trainingLocation", where);

                while (rsloc.next()) {

                    Location loc = new Location(rsloc.getInt("idLocation"));

                    LocationDB ldb = new LocationDB(loc);

                    ldb.loadById(language, false);

                    locations.add(loc);

                }

                rsloc.close();

                training.setLocations(locations);



                //trainingContacts

                Vector trainingContacts = new Vector();

                RequeteSelectWhere rscont = new RequeteSelectWhere(db, "trainingTrainingContact", where);

                while (rscont.next()) {

                    Contact c = new Contact(rscont.getInt("idContact"));

                    ContactDB cdb = new ContactDB(c);

                    cdb.loadById(language, false);

                    trainingContacts.add(c);

                }

                rscont.close();

                training.setTrainingContacts(trainingContacts);



                //teacherCompetences

                Vector teachers = new Vector();

                Vector competences = new Vector();

                RequeteSelectWhere rsteacher = new RequeteSelectWhere(db, "trainingTeacher", where);

                while (rsteacher.next()) {
                    Teacher t = new Teacher(rsteacher.getInt("idTeacher"));
                    TeacherDB tdb = new TeacherDB(t);
                    tdb.loadById(language, false);
                    teachers.add(t);
                    int idc = rsteacher.getInt("idcompetence");

                    RequeteSelect rscomp = new RequeteSelect(db, "competence", "idCompetence", new Integer(idc));
                    String comp = null;
                    if (rscomp.next()) {
                        comp = rscomp.getString("competence");
                    }
                    rscomp.close();
                    competences.add(comp);
                }
                rsteacher.close();
                training.setTeachers(teachers);
                training.setCompetences(competences);



                //keywords

                Vector keywords = new Vector();

                RequeteSelectWhere rskeywords = new RequeteSelectWhere(db, "keyword", where);

                while (rskeywords.next()) {

                    String keyword = rskeywords.getString("keyword");

                    keywords.add(keyword);

                }

                training.setKeywords(keywords);



                //prerequisites

                Vector prerequisites = new Vector();

                RequeteSelectWhere rsprerequisites = new RequeteSelectWhere(db, "prerequisites", where, "nborder");

                while (rsprerequisites.next()) {

                    String prerequisite = rsprerequisites.getString("prerequisites");

                    prerequisites.add(prerequisite);

                }

                training.setPrerequisites(prerequisites);

            }

        }

        rs.close();


        return loaded;

    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = true;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(training.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        training.setTitle(rs.getString("title"));
        training.setCode(rs.getString("code"));
        if (all) {
            String part = rs.getString("partnership");
            if (part != null)
                training.setPartnership(part);
            //objectives
            String objintr = rs.getString("objectivesIntroduction");
            if (objintr != null)
                training.setObjectivesIntroduction(objintr);
            Vector objectives = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "objectivesObjective", where, "nborder");
            while (rs2.next()) {
                objectives.add(rs2.getString("objectivesObjective"));
            }
            rs2.close();
            training.setObjectives(objectives);
            String objccl = rs.getString("objectivesConclusion");
            if (objccl != null)
                training.setObjectivesConclusion(objccl);
            //pdw
            ExtendedList pointsDealtWith = new ExtendedList();
            String pdwintr = rs.getString("pdwIntroduction");
            if (pdwintr != null)
                pointsDealtWith.setIntroduction(pdwintr);
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "pointDealtWith", where, "nborder");
            while (rs3.next()) {
                ExtendedList l2 = new ExtendedList();
                String intr2 = rs3.getString("introduction");
                if (intr2 != null)
                    l2.setIntroduction(intr2);
                int idp = rs3.getInt("idPointDealtWith");
                String[][] where2 = new String[1][3];
                where2[0][0] = (new Integer(idp)).toString();
                where2[0][1] = "Integer";
                where2[0][2] = "idPointDealtWith";
                RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "subPointDealtWith", where2, "nborder");
                while (rs4.next()) {
                    l2.addElement(rs4.getString("subPointDealtWith"));
                }
                rs4.close();
                String ccl2 = rs3.getString("conclusion");
                if (ccl2 != null)
                    l2.setConclusion(ccl2);
                pointsDealtWith.addElement(l2);
            }
            rs3.close();
            String pdwccl = rs.getString("pdwConclusion");
            if (pdwccl != null)
                pointsDealtWith.setConclusion(pdwccl);
            training.setPointsDealtWith(pointsDealtWith);
            //contentDescription
            String contintr = rs.getString("contentDescriptionIntroduction");
            if (contintr != null)
                training.setContentDescriptionIntroduction(contintr);
            Vector contentDescription = new Vector();
            RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "contentDescriptionDescription", where, "nborder");
            while (rs5.next()) {
                contentDescription.add(rs5.getString("contentDescriptionDescription"));
            }
            rs5.close();
            training.setContentDescription(contentDescription);
            String contccl = rs.getString("contentDescriptionConclusion");
            if (contccl != null)
                training.setContentDescriptionConclusion(contccl);
            String moo = rs.getString("modeOfOrganizationValue");
            if (moo != null) {
                ModeOfOrganization modeOfOrganization = new ModeOfOrganization(moo);
                ModeOfOrganizationDB mdb = new ModeOfOrganizationDB(modeOfOrganization);
                mdb.loadByValue(language);
                training.setModeOfOrganization(modeOfOrganization);
            }
            String ped = rs.getString("pedagogicalMethods");
            if (ped != null)
                training.setPedagogicalMethods(ped);
            String coursem = rs.getString("courseMedia");
            if (coursem != null)
                training.setCourseMedia(coursem);
            String levelv = rs.getString("levelValue");
            if (levelv != null) {
                Level level = new Level(levelv);
                LevelDB ldb = new LevelDB(level);
                ldb.loadByValue(language);
                training.setLevel(level);
            }
            String ev = rs.getString("evaluation");
            if (ev != null)
                training.setEvaluation(ev);
            String dur = rs.getString("duration");
            if (dur != null)
                training.setDuration(dur);
            Date bvd = rs.getDate("beginValidityDate");
            if (bvd != null)
                training.setBeginValidityDate(bvd);
            Date evd = rs.getDate("endValidityDate");
            if (evd != null)
                training.setEndValidityDate(evd);
            String cm = rs.getString("comment");
            if (cm != null)
                training.setComment(cm);
            String cmnot = rs.getString("commentNotPublished");
            if (cmnot != null)
                training.setCommentNotPublished(cmnot);
            training.setDateCreation(rs.getDate("dateCreation"));
            training.setDateMaj(rs.getDate("dateMaj"));
            //languages
            Vector languages = new Vector();
            RequeteSelectWhere rslang = new RequeteSelectWhere(db, "trainingLanguage", where);
            while (rslang.next()) {
                Language l = new Language(rslang.getString("languageCode"));
                LanguageDB ldb = new LanguageDB(l);
                ldb.loadByCode(language);
                languages.add(l);
            }
            rslang.close();
            training.setLanguages(languages);
            //slots
            Vector slots = new Vector();
            RequeteSelectWhere rsslot = new RequeteSelectWhere(db, "trainingSlot", where);
            while (rsslot.next()) {
                Slot s = new Slot(rsslot.getString("slotValue"));
                SlotDB sdb = new SlotDB(s);
                sdb.loadByValue(language);
                slots.add(s);
            }
            rsslot.close();
            training.setSlots(slots);
            //locations
            Vector locations = new Vector();
            RequeteSelectWhere rsloc = new RequeteSelectWhere(db, "trainingLocation", where);
            while (rsloc.next()) {
                Location loc = new Location(rsloc.getInt("idLocation"));
                LocationDB ldb = new LocationDB(loc);
                ldb.loadById(language, false);
                locations.add(loc);
            }
            rsloc.close();
            training.setLocations(locations);
            //trainingContacts
            Vector trainingContacts = new Vector();
            RequeteSelectWhere rscont = new RequeteSelectWhere(db, "trainingTrainingContact", where);
            while (rscont.next()) {
                Contact c = new Contact(rscont.getInt("idContact"));
                ContactDB cdb = new ContactDB(c);
                cdb.loadById(language, false);
                trainingContacts.add(c);
            }
            rscont.close();
            training.setTrainingContacts(trainingContacts);
            //teacherCompetences
            Vector teachers = new Vector();
            Vector competences = new Vector();
            RequeteSelectWhere rsteacher = new RequeteSelectWhere(db, "trainingTeacher", where);
            while (rsteacher.next()) {
                Teacher t = new Teacher(rsteacher.getInt("idTeacher"));
                TeacherDB tdb = new TeacherDB(t);
                tdb.loadById(language, false);
                teachers.add(t);
                int idc = rsteacher.getInt("idcompetence");
                RequeteSelect rscomp = new RequeteSelect(db, "competence", "idCompetence", new Integer(idc));
                String comp = null;
                if (rscomp.next()) {
                    comp = rscomp.getString("competence");
                }
                rscomp.close();
                competences.add(comp);
            }
            rsteacher.close();
            training.setTeachers(teachers);
            training.setCompetences(competences);
            //keywords
            Vector keywords = new Vector();
            RequeteSelectWhere rskeywords = new RequeteSelectWhere(db, "keyword", where);
            while (rskeywords.next()) {
                String keyword = rskeywords.getString("keyword");
                keywords.add(keyword);
            }
            training.setKeywords(keywords);
            //prerequisites
            Vector prerequisites = new Vector();
            RequeteSelectWhere rsprerequisites = new RequeteSelectWhere(db, "prerequisites", where, "nborder");
            while (rsprerequisites.next()) {
                String prerequisite = rsprerequisites.getString("prerequisites");
                prerequisites.add(prerequisite);
            }
            training.setPrerequisites(prerequisites);
        }
        return loaded;
    }


    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = true;
        TOMADatabase db = TOMADatabase.getInstance();
        String[][] where = new String[1][3];
        where[0][0] = (new Integer(training.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";
        training.setTitle(rs.getString("title"));
        training.setCode(rs.getString("code"));
        if (all) {
            String part = rs.getString("partnership");
            if (part != null)
                training.setPartnership(part);
            //objectives
            String objintr = rs.getString("objectivesIntroduction");
            if (objintr != null)
                training.setObjectivesIntroduction(objintr);
            Vector objectives = new Vector();
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "objectivesObjective", where, "nborder");
            while (rs2.next()) {
                objectives.add(rs2.getString("objectivesObjective"));
            }
            rs2.close();
            training.setObjectives(objectives);
            String objccl = rs.getString("objectivesConclusion");
            if (objccl != null)
                training.setObjectivesConclusion(objccl);
            //pdw
            ExtendedList pointsDealtWith = new ExtendedList();
            String pdwintr = rs.getString("pdwIntroduction");
            if (pdwintr != null)
                pointsDealtWith.setIntroduction(pdwintr);
            RequeteSelectWhere rs3 = new RequeteSelectWhere(db, "pointDealtWith", where, "nborder");
            while (rs3.next()) {
                ExtendedList l2 = new ExtendedList();
                String intr2 = rs3.getString("introduction");
                if (intr2 != null)
                    l2.setIntroduction(intr2);
                int idp = rs3.getInt("idPointDealtWith");
                String[][] where2 = new String[1][3];
                where2[0][0] = (new Integer(idp)).toString();
                where2[0][1] = "Integer";
                where2[0][2] = "idPointDealtWith";
                RequeteSelectWhere rs4 = new RequeteSelectWhere(db, "subPointDealtWith", where2, "nborder");
                while (rs4.next()) {
                    l2.addElement(rs4.getString("subPointDealtWith"));
                }
                rs4.close();
                String ccl2 = rs3.getString("conclusion");
                if (ccl2 != null)
                    l2.setConclusion(ccl2);
                pointsDealtWith.addElement(l2);
            }
            rs3.close();
            String pdwccl = rs.getString("pdwConclusion");
            if (pdwccl != null)
                pointsDealtWith.setConclusion(pdwccl);
            training.setPointsDealtWith(pointsDealtWith);
            //contentDescription
            String contintr = rs.getString("contentDescriptionIntroduction");
            if (contintr != null)
                training.setContentDescriptionIntroduction(contintr);
            Vector contentDescription = new Vector();
            RequeteSelectWhere rs5 = new RequeteSelectWhere(db, "contentDescriptionDescription", where, "nborder");
            while (rs5.next()) {
                contentDescription.add(rs5.getString("contentDescriptionDescription"));
            }
            rs5.close();
            training.setContentDescription(contentDescription);
            String contccl = rs.getString("contentDescriptionConclusion");
            if (contccl != null)
                training.setContentDescriptionConclusion(contccl);
            String moo = rs.getString("modeOfOrganizationValue");
            if (moo != null) {
                ModeOfOrganization modeOfOrganization = new ModeOfOrganization(moo);
                ModeOfOrganizationDB mdb = new ModeOfOrganizationDB(modeOfOrganization);
                mdb.loadByValue(language);
                training.setModeOfOrganization(modeOfOrganization);
            }
            String ped = rs.getString("pedagogicalMethods");
            if (ped != null)
                training.setPedagogicalMethods(ped);
            String coursem = rs.getString("courseMedia");
            if (coursem != null)
                training.setCourseMedia(coursem);
            String levelv = rs.getString("levelValue");
            if (levelv != null) {
                Level level = new Level(levelv);
                LevelDB ldb = new LevelDB(level);
                ldb.loadByValue(language);
                training.setLevel(level);
            }
            String ev = rs.getString("evaluation");
            if (ev != null)
                training.setEvaluation(ev);
            String dur = rs.getString("duration");
            if (dur != null)
                training.setDuration(dur);
            Date bvd = rs.getDate("beginValidityDate");
            if (bvd != null)
                training.setBeginValidityDate(bvd);
            Date evd = rs.getDate("endValidityDate");
            if (evd != null)
                training.setEndValidityDate(evd);
            String cm = rs.getString("comment");
            if (cm != null)
                training.setComment(cm);
            String cmnot = rs.getString("commentNotPublished");
            if (cmnot != null)
                training.setCommentNotPublished(cmnot);
            training.setDateCreation(rs.getDate("dateCreation"));
            training.setDateMaj(rs.getDate("dateMaj"));
            //languages
            Vector languages = new Vector();
            RequeteSelectWhere rslang = new RequeteSelectWhere(db, "trainingLanguage", where);
            while (rslang.next()) {
                Language l = new Language(rslang.getString("languageCode"));
                LanguageDB ldb = new LanguageDB(l);
                ldb.loadByCode(language);
                languages.add(l);
            }
            rslang.close();
            training.setLanguages(languages);
            //slots
            Vector slots = new Vector();
            RequeteSelectWhere rsslot = new RequeteSelectWhere(db, "trainingSlot", where);
            while (rsslot.next()) {
                Slot s = new Slot(rsslot.getString("slotValue"));
                SlotDB sdb = new SlotDB(s);
                sdb.loadByValue(language);
                slots.add(s);
            }
            rsslot.close();
            training.setSlots(slots);
            //locations
            Vector locations = new Vector();
            RequeteSelectWhere rsloc = new RequeteSelectWhere(db, "trainingLocation", where);
            while (rsloc.next()) {
                Location loc = new Location(rsloc.getInt("idLocation"));
                LocationDB ldb = new LocationDB(loc);
                ldb.loadById(language, true);
                locations.add(loc);
            }
            rsloc.close();
            training.setLocations(locations);
            //trainingContacts
            Vector trainingContacts = new Vector();
            RequeteSelectWhere rscont = new RequeteSelectWhere(db, "trainingTrainingContact", where);
            while (rscont.next()) {
                Contact c = new Contact(rscont.getInt("idContact"));
                ContactDB cdb = new ContactDB(c);
                cdb.loadById(language, true);
                trainingContacts.add(c);
            }
            rscont.close();
            training.setTrainingContacts(trainingContacts);
            //teacherCompetences
            Vector teachers = new Vector();
            Vector competences = new Vector();
            RequeteSelectWhere rsteacher = new RequeteSelectWhere(db, "trainingTeacher", where);
            while (rsteacher.next()) {
                Teacher t = new Teacher(rsteacher.getInt("idTeacher"));
                TeacherDB tdb = new TeacherDB(t);
                tdb.loadById(language, true);
                teachers.add(t);
                int idc = rsteacher.getInt("idcompetence");
                RequeteSelect rscomp = new RequeteSelect(db, "competence", "idCompetence", new Integer(idc));
                String comp = null;
                if (rscomp.next()) {
                    comp = rscomp.getString("competence");
                }
                rscomp.close();
                competences.add(comp);
            }
            rsteacher.close();
            training.setTeachers(teachers);
            training.setCompetences(competences);
            //keywords
            Vector keywords = new Vector();
            RequeteSelectWhere rskeywords = new RequeteSelectWhere(db, "keyword", where);
            while (rskeywords.next()) {
                String keyword = rskeywords.getString("keyword");
                keywords.add(keyword);
            }
            training.setKeywords(keywords);
            //prerequisites
            Vector prerequisites = new Vector();
            RequeteSelectWhere rsprerequisites = new RequeteSelectWhere(db, "prerequisites", where, "nborder");
            while (rsprerequisites.next()) {
                String prerequisite = rsprerequisites.getString("prerequisites");
                prerequisites.add(prerequisite);
            }
            training.setPrerequisites(prerequisites);
        }
        return loaded;
    }


    public boolean loadByCodeAndTest(Language lng, boolean all) {

        boolean loaded = false;

        TOMADatabase db = TOMADatabase.getInstance();


        RequeteSelect rs = new RequeteSelect(db, "training", "code", training.getCode());

        boolean found = false;

        if (rs.next()) {

            int id = rs.getInt("idTraining");

            training.setIdTraining(id);

            found = true;

        }

        rs.close();


        if (found) {

            this.loadById(lng, all);

            loaded = true;

        }

        return loaded;

    }

    public void loadByCode(Language lng, boolean all) {

        this.loadByCodeAndTest(lng, all);

    }

    public boolean unlock() {

        boolean unlock = DatabaseFacilities.unlock("idTraining", training.getIdTraining(), "training");

        return unlock;

    }

    public boolean lock() {

        boolean lock = DatabaseFacilities.lock("idTraining", training.getIdTraining(), "training");

        return lock;

    }


    public boolean isLocked() {

        boolean locked = DatabaseFacilities.isLocked("idTraining", training.getIdTraining(), "training");

        return locked;

    }



    /*public void create( )

    {

	TOMADatabase db=TOMADatabase.getInstance();



	Object[][] insert=this.getSaveData(true);



        RequeteInsert ri=new RequeteInsert(db, "training", insert);

	ri.close();



	//rcuprer l'idTraining

	String[][] where=new String[1][3];

	where[0][0]=training.getCode();

	where[0][1]="String";

	where[0][2]="code";

	RequeteSelectWhere rs=new RequeteSelectWhere(db, "training", where);

	if(rs.next())

	    {

		training.setIdTraining(rs.getInt("idTraining"));

	    }

	rs.close();



	db.commit();

	this.setLinks();

    }*/



    /*public void update( )

    {

	TOMADatabase db=TOMADatabase.getInstance();



	Object[][] update=this.getSaveData(false);



	String[][] where=new String[1][3];

	where[0][0]=(new Integer(training.getIdTraining())).toString();

	where[0][1]="Integer";

	where[0][2]="IdTraining";



        RequeteUpdateWhere ru=new RequeteUpdateWhere(db, "training", update, where);

	ru.close();



	db.commit();

	this.setLinks();

    }*/



    public void setLinks() {

        TOMADatabase db = TOMADatabase.getInstance();



        //objectives

        RequeteDelete rd = new RequeteDelete(db, "objectivesObjective", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector objectives = training.getObjectives();

        if (objectives != null) {

            int length = objectives.size();

            for (int i = 0; i < length; i++) {

                String objective = (String) objectives.elementAt(i);


                if (objective != null && !objective.equals("")) {

                    Object[][] insert2 = new Object[3][2];

                    insert2[0][0] = "idTraining";

                    insert2[0][1] = new Integer(training.getIdTraining());

                    insert2[1][0] = "objectivesObjective";

                    insert2[1][1] = objective;

                    insert2[2][0] = "nborder";

                    insert2[2][1] = new Integer(i);


                    RequeteInsert ri2 = new RequeteInsert(db, "objectivesObjective", insert2);

                    ri2.close();

                }

            }

        }



        //contentDescription

        rd = new RequeteDelete(db, "contentDescriptionDescription", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector contentDescription = training.getContentDescription();

        if (contentDescription != null) {

            int length = contentDescription.size();

            for (int i = 0; i < length; i++) {

                String description = (String) contentDescription.elementAt(i);


                if (description != null && !description.equals("")) {

                    Object[][] insert2 = new Object[3][2];

                    insert2[0][0] = "idTraining";

                    insert2[0][1] = new Integer(training.getIdTraining());

                    insert2[1][0] = "contentDescriptionDescription";

                    insert2[1][1] = description;

                    insert2[2][0] = "nborder";

                    insert2[2][1] = new Integer(i);


                    RequeteInsert ri2 = new RequeteInsert(db, "contentDescriptionDescription", insert2);

                    ri2.close();

                }

            }

        }



        //pdw

        RequeteSelect rspdw = new RequeteSelect(db, "pointDealtWith", "idTraining", new Integer(training.getIdTraining()));

        while (rspdw.next()) {

            int idPdw = rspdw.getInt("idPointDealtWith");

            RequeteDelete rd1 = new RequeteDelete(db, "subPointDealtWith", "idPointDealtWith", (new Integer(idPdw)).toString());

            rd1.close();

        }

        rspdw.close();


        rd = new RequeteDelete(db, "pointDealtWith", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        ExtendedList pdw = training.getPointsDealtWith();

        if (pdw != null && pdw.getList() != null) {

            Vector list = pdw.getList();

            int length = list.size();

            for (int i = 0; i < length; i++) {

                ExtendedList l = (ExtendedList) list.elementAt(i);


                Object[][] insert2 = new Object[4][2];

                insert2[0][0] = "idTraining";

                insert2[0][1] = new Integer(training.getIdTraining());

                insert2[1][0] = "introduction";

                insert2[1][1] = l.getIntroduction();

                insert2[2][0] = "conclusion";

                insert2[2][1] = l.getConclusion();

                insert2[3][0] = "nborder";

                insert2[3][1] = new Integer(i);

                RequeteInsert ri2 = new RequeteInsert(db, "pointDealtWith", insert2);

                ri2.close();


                String[][] wherepdw = new String[2][3];

                wherepdw[0][0] = (new Integer(training.getIdTraining())).toString();

                wherepdw[0][1] = "Integer";

                wherepdw[0][2] = "idTraining";

                wherepdw[1][0] = (new Integer(i)).toString();

                wherepdw[1][1] = "Integer";

                wherepdw[1][2] = "nborder";

                RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "pointDealtWith", wherepdw);

                int idPdw = 0;

                if (rs2.next()) {

                    idPdw = rs2.getInt("idPointDealtWith");

                }

                rs2.close();


                Vector list2 = l.getList();

                if (list2 != null) {

                    int size2 = list2.size();

                    for (int j = 0; j < size2; j++) {

                        String point = (String) list2.elementAt(j);


                        if (point != null && !point.equals("")) {

                            Object[][] insert3 = new Object[3][2];

                            insert3[0][0] = "idPointDealtWith";

                            insert3[0][1] = new Integer(idPdw);

                            insert3[1][0] = "subPointDealtWith";

                            insert3[1][1] = point;

                            insert3[2][0] = "nborder";

                            insert3[2][1] = new Integer(j);

                            RequeteInsert ri3 = new RequeteInsert(db, "subPointDealtWith", insert3);

                            ri3.close();

                        }

                    }

                }

            }

        }



        //keywords

        rd = new RequeteDelete(db, "keyword", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector keywords = training.getKeywords();

        if (keywords != null) {

            Iterator it = keywords.iterator();

            while (it.hasNext()) {

                String k = (String) it.next();


                if (k != null && !k.equals("")) {


                    String[][] wherekw = new String[2][3];

                    wherekw[0][0] = (new Integer(training.getIdTraining())).toString();

                    wherekw[0][1] = "Integer";

                    wherekw[0][2] = "idTraining";

                    wherekw[1][0] = k;

                    wherekw[1][1] = "String";

                    wherekw[1][2] = "keyword";

                    RequeteSelectWhere rskw = new RequeteSelectWhere(db, "keyword", wherekw);

                    if (!rskw.next()) {

                        Object[][] insert2 = new Object[2][2];

                        insert2[0][0] = "idTraining";

                        insert2[0][1] = new Integer(training.getIdTraining());

                        insert2[1][0] = "keyword";

                        insert2[1][1] = k;

                        RequeteInsert ri2 = new RequeteInsert(db, "keyword", insert2);

                        ri2.close();

                    }

                    rskw.close();

                }

            }

        }



        //prerequisites

        rd = new RequeteDelete(db, "prerequisites", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector prerequisites = training.getPrerequisites();

        if (prerequisites != null) {

            int size = prerequisites.size();

            for (int i = 0; i < size; i++) {

                String k = (String) prerequisites.elementAt(i);


                if (k != null && !k.equals("")) {


                    String[][] wherelink = new String[2][3];

                    wherelink[0][0] = (new Integer(i)).toString();

                    wherelink[0][1] = "Integer";

                    wherelink[0][2] = "nborder";

                    wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                    wherelink[1][1] = "Integer";

                    wherelink[1][2] = "idTraining";

                    RequeteSelectWhere rslink = new RequeteSelectWhere(db, "prerequisites", wherelink);

                    if (!rslink.next()) {


                        Object[][] insert2 = new Object[3][2];

                        insert2[0][0] = "idTraining";

                        insert2[0][1] = new Integer(training.getIdTraining());

                        insert2[1][0] = "prerequisites";

                        insert2[1][1] = k;

                        insert2[2][0] = "nborder";

                        insert2[2][1] = new Integer(i);

                        RequeteInsert ri2 = new RequeteInsert(db, "prerequisites", insert2);

                        ri2.close();

                    }

                    rslink.close();

                }

            }

        }



        //languages

        rd = new RequeteDelete(db, "trainingLanguage", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector languages = training.getLanguages();

        if (languages != null) {

            Iterator it = languages.iterator();

            while (it.hasNext()) {

                Language l = (Language) it.next();


                String[][] wherelink = new String[2][3];

                wherelink[0][0] = l.getCode();

                wherelink[0][1] = "String";

                wherelink[0][2] = "languageCode";

                wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                wherelink[1][1] = "Integer";

                wherelink[1][2] = "idTraining";

                RequeteSelectWhere rslink = new RequeteSelectWhere(db, "trainingLanguage", wherelink);

                if (!rslink.next()) {


                    Object[][] insert2 = new Object[2][2];

                    insert2[0][0] = "idTraining";

                    insert2[0][1] = new Integer(training.getIdTraining());

                    insert2[1][0] = "languageCode";

                    insert2[1][1] = l.getCode();

                    RequeteInsert ri2 = new RequeteInsert(db, "trainingLanguage", insert2);

                    ri2.close();

                }

                rslink.close();

            }

        }



        //slots

        rd = new RequeteDelete(db, "trainingSlot", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector slots = training.getSlots();

        if (slots != null) {

            Iterator it = slots.iterator();

            while (it.hasNext()) {

                Slot l = (Slot) it.next();


                String[][] wherelink = new String[2][3];

                wherelink[0][0] = l.getValue();

                wherelink[0][1] = "String";

                wherelink[0][2] = "slotValue";

                wherelink[1][0] = (new Integer(training.getIdTraining())).toString();

                wherelink[1][1] = "Integer";

                wherelink[1][2] = "idTraining";

                RequeteSelectWhere rslink = new RequeteSelectWhere(db, "trainingSlot", wherelink);

                if (!rslink.next()) {

                    Object[][] insert2 = new Object[2][2];

                    insert2[0][0] = "idTraining";

                    insert2[0][1] = new Integer(training.getIdTraining());

                    insert2[1][0] = "slotValue";

                    insert2[1][1] = l.getValue();

                    RequeteInsert ri2 = new RequeteInsert(db, "trainingSlot", insert2);

                    ri2.close();

                }

                rslink.close();


            }

        }



        //teachers

        rd = new RequeteDelete(db, "trainingTeacher", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector teachers = training.getTeachers();

        Vector competences = training.getCompetences();

        Vector newteachers = new Vector();

        Vector newcomps = new Vector();

        if (teachers != null) {

            int size = teachers.size();

            for (int i = 0; i < size; i++) {

                Teacher l = (Teacher) teachers.elementAt(i);


                if (TeacherDB.exists(l.getIdTeacher())) {

                    String[][] wherete = new String[2][3];

                    wherete[0][0] = (new Integer(l.getIdTeacher())).toString();

                    wherete[0][1] = "Integer";

                    wherete[0][2] = "idTeacher";

                    wherete[1][0] = (new Integer(training.getIdTraining())).toString();

                    wherete[1][1] = "Integer";

                    wherete[1][2] = "idTraining";

                    RequeteSelectWhere rste = new RequeteSelectWhere(db, "trainingTeacher", wherete);

                    if (!rste.next()) {


                        newteachers.add(l);


                        String comp = null;

                        if (competences != null && competences.size() > i) {

                            comp = (String) competences.elementAt(i);

                            newcomps.add(comp);

                        }


                        int idcomp = 0;

                        String[][] wherecomp = new String[2][3];

                        wherecomp[0][0] = comp;

                        wherecomp[0][1] = "String";

                        wherecomp[0][2] = "competence";

                        wherecomp[1][0] = (new Integer(l.getIdTeacher())).toString();

                        wherecomp[1][1] = "Integer";

                        wherecomp[1][2] = "idTeacher";

                        RequeteSelectWhere rscomp = new RequeteSelectWhere(db, "competence", wherecomp);

                        boolean comp_found = false;

                        if (rscomp.next()) {

                            idcomp = rscomp.getInt("idCompetence");

                            comp_found = true;

                        }

                        rscomp.close();


                        Object[][] insert2 = null;

                        if (!comp_found) {

                            insert2 = new Object[2][2];

                            insert2[0][0] = "idTraining";

                            insert2[0][1] = new Integer(training.getIdTraining());

                            insert2[1][0] = "idTeacher";

                            insert2[1][1] = new Integer(l.getIdTeacher());



                            //si comp est null: pas une erreur

                            if (comp != null) {

                                //apostal.toma.TOMA.log(apostal.toma.TOMA.SEVERE, "competence not found: "+comp);

                                apostal.toma.TOMA.log(apostal.toma.TOMA.SEVERE, "competence not found: \"" + comp + "\" for training: \"" + training + "\", teacher: \"" + l + "\", i=" + new Integer(i));

                            }

                        } else {

                            insert2 = new Object[3][2];

                            insert2[0][0] = "idTraining";

                            insert2[0][1] = new Integer(training.getIdTraining());

                            insert2[1][0] = "idTeacher";

                            insert2[1][1] = new Integer(l.getIdTeacher());

                            insert2[2][0] = "idCompetence";

                            insert2[2][1] = new Integer(idcomp);

                        }

                        RequeteInsert ri2 = new RequeteInsert(db, "trainingTeacher", insert2);

                        ri2.close();

                    }

                    rste.close();

                }

            }

        }

        training.setTeachers(newteachers);

        training.setCompetences(newcomps);



        //trainingContacts

        rd = new RequeteDelete(db, "trainingTrainingContact", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector trainingContacts = training.getTrainingContacts();

        Vector newtrcont = new Vector();

        if (trainingContacts != null) {

            Iterator it = trainingContacts.iterator();

            while (it.hasNext()) {

                Contact c = (Contact) it.next();


                if (ContactDB.exists(c.getIdContact())) {


                    String[][] wherecont = new String[2][3];

                    wherecont[0][0] = (new Integer(c.getIdContact())).toString();

                    wherecont[0][1] = "Integer";

                    wherecont[0][2] = "idContact";

                    wherecont[1][0] = (new Integer(training.getIdTraining())).toString();

                    wherecont[1][1] = "Integer";

                    wherecont[1][2] = "idTraining";

                    RequeteSelectWhere rscont = new RequeteSelectWhere(db, "trainingTrainingContact", wherecont);

                    if (!rscont.next()) {

                        newtrcont.add(c);


                        Object[][] insert2 = new Object[2][2];

                        insert2[0][0] = "idTraining";

                        insert2[0][1] = new Integer(training.getIdTraining());

                        insert2[1][0] = "idContact";

                        insert2[1][1] = new Integer(c.getIdContact());

                        RequeteInsert ri2 = new RequeteInsert(db, "trainingTrainingContact", insert2);

                        ri2.close();

                    }

                    rscont.close();

                }

            }

        }

        training.setTrainingContacts(newtrcont);



        //locations

        rd = new RequeteDelete(db, "trainingLocation", "idTraining", (new Integer(training.getIdTraining())).toString());

        rd.close();

        Vector locations = training.getLocations();

        Vector newlocs = new Vector();

        if (locations != null) {

            Iterator it = locations.iterator();

            while (it.hasNext()) {

                Location l = (Location) it.next();


                if (LocationDB.exists(l.getIdLocation())) {

                    String[][] whereloc = new String[2][3];

                    whereloc[0][0] = (new Integer(l.getIdLocation())).toString();

                    whereloc[0][1] = "Integer";

                    whereloc[0][2] = "idLocation";

                    whereloc[1][0] = (new Integer(training.getIdTraining())).toString();

                    whereloc[1][1] = "Integer";

                    whereloc[1][2] = "idTraining";

                    RequeteSelectWhere rsloc = new RequeteSelectWhere(db, "trainingLocation", whereloc);

                    if (!rsloc.next()) {

                        newlocs.add(l);


                        Object[][] insert2 = new Object[2][2];

                        insert2[0][0] = "idTraining";

                        insert2[0][1] = new Integer(training.getIdTraining());

                        insert2[1][0] = "idLocation";

                        insert2[1][1] = new Integer(l.getIdLocation());

                        RequeteInsert ri2 = new RequeteInsert(db, "trainingLocation", insert2);

                        ri2.close();

                    }

                    rsloc.close();

                }

            }

        }

        training.setLocations(newlocs);


        db.commit();

    }


    public Object[][] getSaveData(boolean creation) {

        Vector values = new Vector();

        Vector names = new Vector();


        names.add("title");

        values.add(training.getTitle());


        names.add("code");

        values.add(training.getCode());


        names.add("partnership");

        values.add(training.getPartnership());


        names.add("objectivesIntroduction");

        values.add(training.getObjectivesIntroduction());


        names.add("objectivesConclusion");

        values.add(training.getObjectivesConclusion());


        names.add("pdwIntroduction");

        names.add("pdwConclusion");

        ExtendedList list = training.getPointsDealtWith();

        if (list != null) {

            values.add(list.getIntroduction());

            values.add(list.getConclusion());

        } else {

            values.add(null);

            values.add(null);

        }


        names.add("contentDescriptionIntroduction");

        values.add(training.getContentDescriptionIntroduction());


        names.add("contentDescriptionConclusion");

        values.add(training.getContentDescriptionConclusion());


        ModeOfOrganization moo = training.getModeOfOrganization();

        names.add("modeOfOrganizationValue");

        if (moo != null)

            values.add(moo.getValue());

        else

            values.add(null);


        names.add("pedagogicalMethods");

        values.add(training.getPedagogicalMethods());


        names.add("courseMedia");

        values.add(training.getCourseMedia());


        Level level = training.getLevel();

        names.add("levelValue");

        if (level != null)

            values.add(level.getValue());

        else

            values.add(null);


        names.add("evaluation");

        values.add(training.getEvaluation());


        names.add("duration");

        values.add(training.getDuration());


        names.add("beginValidityDate");

        Date beginValidityDate = training.getBeginValidityDate();

        if (beginValidityDate != null)

            values.add(beginValidityDate);

        else

            values.add(null);


        names.add("endValidityDate");

        Date endValidityDate = training.getEndValidityDate();

        if (endValidityDate != null)

            values.add(endValidityDate);

        else

            values.add(null);


        names.add("comment");

        values.add(training.getComment());


        names.add("commentNotPublished");

        values.add(training.getCommentNotPublished());



        //dates

        if (creation)

            DatabaseFacilities.addCreationDates(values, names);

        else

            DatabaseFacilities.addUpdateDates(values, names);



        //lock: false

        values.add(Boolean.FALSE);

        names.add("lock");


        Object[][] data = new Object[values.size()][2];

        for (int i = 0; i < values.size(); i++) {

            data[i][0] = names.elementAt(i);

            data[i][1] = values.elementAt(i);

        }


        return data;

    }


    public boolean testUpdate() {

        if (this.testConstraints()) {

            String[][] where = new String[1][3];

            where[0][0] = training.getCode();

            where[0][1] = "String";

            where[0][2] = "code";

            boolean test = DatabaseFacilities.testUpdate("training", where, "idTraining", training.getIdTraining());

            return test;

        } else

            return false;

    }


    public boolean testCreate() {

        if (this.testConstraints()) {

            String[][] where = new String[1][3];

            where[0][0] = training.getCode();

            where[0][1] = "String";

            where[0][2] = "code";

            boolean test = DatabaseFacilities.testCreate("training", where);

            return test;

        } else

            return false;

    }


    private boolean testConstraints() {

        if (training.getTitle() == null || training.getTitle().equals("")

                || training.getCode() == null || training.getCode().equals("")

                || training.getBeginValidityDate() == null

                || training.getEndValidityDate() == null

        )

            return false;

        else

            return true;

    }


    public void delete() {

        TOMADatabase db = TOMADatabase.getInstance();


        Integer idTraining = new Integer(training.getIdTraining());


        RequeteDelete rd = new RequeteDelete(db, "trainingCatalogue", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingPublished", "idTraining", idTraining);

        rd.close();


        RequeteSelect rs = new RequeteSelect(db, "pointDealtWith", "idTraining", idTraining);

        while (rs.next()) {

            int idpdw = rs.getInt("idPointDealtWith");


            RequeteDelete rdpdw = new RequeteDelete(db, "SubPointDealtWith", "idPointDealtWith", new Integer(idpdw));

            rdpdw.close();

        }

        rs.close();

        rd = new RequeteDelete(db, "pointDealtWith", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "audience", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "objectivesObjective", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "contentDescriptionDescription", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "keyword", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "prerequisites", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingLocation", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingDomain", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingLanguage", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingSlot", "idTraining", idTraining);

        rd.close();


        RequeteSelect rs_session = new RequeteSelect(db, "session", "idTraining", idTraining);

        while (rs_session.next()) {

            int id = rs_session.getInt("idSession");

            char type = rs_session.getChar("type");

            if (type == 'P') {

                ProgrammeSession ps = new ProgrammeSession(id);

                ProgrammeSessionDB psdb = new ProgrammeSessionDB(ps);

                psdb.delete();

            } else if (type == 'U') {

                UnitSession ps = new UnitSession(id);

                UnitSessionDB usdb = new UnitSessionDB(ps);

                usdb.delete();

            } else {

                ProgrammeSession ps = new ProgrammeSession(id);

                ProgrammeSessionDB psdb = new ProgrammeSessionDB(ps);

                psdb.delete();

            }

        }

        rs_session.close();


        rd = new RequeteDelete(db, "trainingTeacher", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingTrainingContact", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "trainingInscriptionContact", "idTraining", idTraining);

        rd.close();


        rd = new RequeteDelete(db, "training", "idTraining", idTraining);

        rd.close();


        db.commit();

    }


}

