// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;

import apostal.toma.data.Language;

/**
 * @(#) TrainingProgramme.java
 */

public class TrainingProgrammeDB extends StandaloneTrainingDB {
    private TrainingProgramme trainingProgramme;

    public TrainingProgrammeDB(TrainingProgramme trainingProgramme) {
        super(trainingProgramme);

        this.trainingProgramme = trainingProgramme;
    }

    /*************** database access ***********************/
    public boolean loadById(Language language, boolean all) {
        boolean loaded = super.loadById(language, all);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //programmeSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector programmeSessions = new Vector();
            RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
            while (rs.next()) {
                ProgrammeSession s = new ProgrammeSession(rs.getInt("idSession"));
                ProgrammeSessionDB pdb = new ProgrammeSessionDB(s);
                pdb.loadByIdAndRS(language, false, rs);

                programmeSessions.add(s);
            }
            rs.close();
            trainingProgramme.setProgrammeSessions(programmeSessions);

            //units
            Vector units = new Vector();
            String[][] where2 = new String[1][3];
            where2[0][0] = (new Integer(training.getIdTraining())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idProgramme";
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where2, "unitNbOrder");
            while (rs2.next()) {
                Unit u = new Unit(rs2.getInt("idTraining"));
                UnitDB udb = new UnitDB(u);
                udb.loadByIdAndRS(language, false, rs2);

                units.add(u);
            }
            rs2.close();
            trainingProgramme.setUnits(units);


        }
        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);
        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //programmeSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector programmeSessions = new Vector();
            RequeteSelectWhere rs1 = new RequeteSelectWhere(db, "session", where);
            while (rs1.next()) {
                ProgrammeSession s = new ProgrammeSession(rs1.getInt("idSession"));
                ProgrammeSessionDB pdb = new ProgrammeSessionDB(s);
                pdb.loadByIdAndRS(language, false, rs1);

                programmeSessions.add(s);
            }
            rs1.close();
            trainingProgramme.setProgrammeSessions(programmeSessions);
            //units
            Vector units = new Vector();
            String[][] where2 = new String[1][3];
            where2[0][0] = (new Integer(training.getIdTraining())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idProgramme";
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where2, "unitNbOrder");
            while (rs2.next()) {
                Unit u = new Unit(rs2.getInt("idTraining"));
                UnitDB udb = new UnitDB(u);
                udb.loadByIdAndRS(language, false, rs2);
                units.add(u);
            }
            rs2.close();
            trainingProgramme.setUnits(units);
        }
        return loaded;
    }

    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRSForPublication(language, all, rs);
        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //programmeSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector programmeSessions = new Vector();
            RequeteSelectWhere rs1 = new RequeteSelectWhere(db, "session", where);
            while (rs1.next()) {
                ProgrammeSession s = new ProgrammeSession(rs1.getInt("idSession"));
                ProgrammeSessionDB pdb = new ProgrammeSessionDB(s);
                pdb.loadByIdAndRSForPublication(language, true,rs1);
                programmeSessions.add(s);
            }
            rs1.close();
            trainingProgramme.setProgrammeSessions(programmeSessions);
            //units
            Vector units = new Vector();
            String[][] where2 = new String[1][3];
            where2[0][0] = (new Integer(training.getIdTraining())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idProgramme";
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where2, "unitNbOrder");
            while (rs2.next()) {
                Unit u = new Unit(rs2.getInt("idTraining"));
                UnitDB udb = new UnitDB(u);
                udb.loadByIdAndRSForPublication(language, true,rs2);
                units.add(u);
            }
            rs2.close();
            trainingProgramme.setUnits(units);
        }
        return loaded;
    }

    public void create() {
        //super.create();

        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);
        RequeteInsert ri = new RequeteInsert(db, "training", insert);
        ri.close();

        String[][] where = new String[1][3];
        where[0][0] = training.getCode();
        where[0][1] = "String";
        where[0][2] = "code";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);
        if (rs.next()) {
            training.setIdTraining(rs.getInt("idTraining"));
            training.setDateCreation(rs.getDate("dateCreation"));
            training.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        //super.update();

        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(training.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";

        Object[][] update = this.getSaveData(false);

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "training", update, where);
        ru.close();

        db.commit();

        //date maj
        training.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        super.setLinks();

        TOMADatabase db = TOMADatabase.getInstance();

        //programmeSessions
        /*RequeteDelete rd=new RequeteDelete(db, "session", "idTraining", (new Integer(training.getIdTraining())).toString());
          rd.close();
          Vector programmeSessions=trainingProgramme.getProgrammeSessions();
          if(programmeSessions!=null)
          {
          Iterator it=programmeSessions.iterator();
          while(it.hasNext())
          {
          ProgrammeSession s=(ProgrammeSession) it.next();
          ProgrammeSessionDB sdb=new ProgrammeSessionDB(s);
          sdb.create();
          }
          }*/

        //units
        /*rd=new RequeteDelete(db, "training", "idProgramme", (new Integer(training.getIdTraining())).toString());
          rd.close();
          Vector units=trainingProgramme.getUnits();
          if(units!=null)
          {
          Iterator it=units.iterator();
          while(it.hasNext())
          {
          Unit u=(Unit) it.next();
          }
          }*/

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        Object[][] data1 = super.getSaveData(creation);
        int size = data1.length;
        Object[][] data = new Object[size + 1][2];
        for (int i = 0; i < size; i++) {
            data[i][0] = data1[i][0];
            data[i][1] = data1[i][1];
        }

        data[size][0] = "type";
        data[size][1] = "P";

        return data;
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        Integer idt = new Integer(training.getIdTraining());

        //programmeSessions
        RequeteSelect rs = new RequeteSelect(db, "session", "idTraining", idt);
        while (rs.next()) {
            ProgrammeSession session = new ProgrammeSession(rs.getInt("idSession"));
            ProgrammeSessionDB pdb = new ProgrammeSessionDB(session);
            pdb.delete();
        }
        rs.close();

        //units
        RequeteSelect rs_unit = new RequeteSelect(db, "training", "idProgramme", idt);
        while (rs_unit.next()) {
            Unit unit = new Unit(rs_unit.getInt("idTraining"));
            UnitDB udb = new UnitDB(unit);
            udb.delete();
        }
        rs_unit.close();

        db.commit();

        super.delete();
    }

    /**
     * loads the training programmes
     */
    public static Vector load(Language lng, boolean all) {
        Vector trainings = new Vector();
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "training", "type", "P");
        while (rs.next()) {
            TrainingProgramme t = new TrainingProgramme(rs.getInt("idTraining"));
            TrainingProgrammeDB tdb = new TrainingProgrammeDB(t);
            tdb.loadByIdAndRS(lng, all,rs);
            trainings.add(t);
        }
        rs.close();


        return trainings;
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "training", "type", "P");
        while (rs.next()) {
            TrainingProgramme trainingProgramme = new TrainingProgramme(rs.getInt("idTraining"));
            TrainingProgrammeDB trainingProgrammedb = new TrainingProgrammeDB(trainingProgramme);
            trainingProgrammedb.delete();
        }
        rs.close();
        db.commit();
    }
}
