// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import toolbox.util.HashtableSort;

import java.sql.Date;

/**
 * @(#) TrainingPublishedDB.java
 */

public class TrainingPublishedDB {

    private TrainingPublished trainingPublished;

    public TrainingPublishedDB(TrainingPublished trainingPublished) {
        this.trainingPublished = trainingPublished;
    }

    public void loadById() {
        TOMADatabase db = TOMADatabase.getInstance();
        //title
        RequeteSelect rs = new RequeteSelect(db, "training", "idTraining", new Integer(trainingPublished.getIdTraining()));
        if (rs.next()) {
            trainingPublished.setTitle(rs.getString("title"));

            //nborder
            int nborder = 0;
            String[][] where2 = new String[2][3];
            where2[0][0] = (new Integer(trainingPublished.getIdCatalogue())).toString();
            where2[0][1] = "Integer";
            where2[0][2] = "idCatalogue";

            where2[1][0] = (new Integer(trainingPublished.getIdTraining())).toString();
            where2[1][1] = "Integer";
            where2[1][2] = "idTraining";

            RequeteSelectWhere rs6 = new RequeteSelectWhere(db, "trainingCatalogue", where2);
            if (rs6.next()) {
                trainingPublished.setNborder(rs6.getInt("nborder"));
            }
            rs6.close();

//publishWithoutCatalogue
            String[][] wherepwc = new String[3][3];
            wherepwc[0][0] = (new Integer(trainingPublished.getIdCatalogue())).toString();
            wherepwc[0][1] = "Integer";
            wherepwc[0][2] = "idCatalogue";
            wherepwc[1][0] = (new Integer(trainingPublished.getIdTraining())).toString();
            wherepwc[1][1] = "Integer";
            wherepwc[1][2] = "idTraining";
            wherepwc[2][0] = (new Integer(trainingPublished.getIdPublicationUnit())).toString();
            wherepwc[2][1] = "Integer";
            wherepwc[2][2] = "idPublicationUnit";
            RequeteSelectWhere rspwc = new RequeteSelectWhere(db, "trainingPublished", wherepwc);
            if (rspwc.next()) {
                trainingPublished.setPublishWithoutCatalogue(rspwc.getBoolean("publishWithoutCatalogue"));
            }
            rspwc.close();
        }
        rs.close();
    }

    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = new Object[4][2];
        insert[0][0] = "idCatalogue";
        insert[0][1] = new Integer(trainingPublished.getIdCatalogue());
        insert[1][0] = "idPublicationUnit";
        insert[1][1] = new Integer(trainingPublished.getIdPublicationUnit());
        insert[2][0] = "idTraining";
        insert[2][1] = new Integer(trainingPublished.getIdTraining());
        insert[3][0] = "publishWithoutCatalogue";
        insert[3][1] = new Boolean(trainingPublished.getPublishWithoutCatalogue());

        RequeteInsert ri = new RequeteInsert(db, "trainingPublished", insert);
        ri.close();

        db.commit();
    }

    public boolean testCreate() {
        String[][] where = new String[4][3];
        where[0][0] = (new Integer(trainingPublished.getIdCatalogue())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idCatalogue";
        where[1][0] = (new Integer(trainingPublished.getIdTraining())).toString();
        where[1][1] = "Integer";
        where[1][2] = "idTraining";
        where[2][0] = (new Integer(trainingPublished.getIdPublicationUnit())).toString();
        where[2][1] = "Integer";
        where[2][2] = "idPublicationUnit";
        where[3][0] = (new Boolean(trainingPublished.getPublishWithoutCatalogue())).toString();
        where[3][1] = "Boolean";
        where[3][2] = "publishWithoutCatalogue";
        boolean test = DatabaseFacilities.testCreate("trainingPublished", where);
        return test;
    }

}
