// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.database;

import apostal.toma.data.*;

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.data.Training;
import apostal.toma.data.Language;

/**
 * @(#) Unit.java
 */

public class UnitDB extends TrainingDB {
    private Unit unit;

    public UnitDB(Unit unit) {
        super(unit);

        this.unit = unit;
    }

    public boolean loadById(Language language, boolean all) {
        boolean loaded = super.loadById(language, all);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //unitSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector unitSessions = new Vector();
            RequeteSelectWhere rs = new RequeteSelectWhere(db, "session", where);
            while (rs.next()) {
                UnitSession s = new UnitSession(rs.getInt("idSession"));
                UnitSessionDB udb = new UnitSessionDB(s);
                udb.loadByIdAndRS(language, false, rs);

                unitSessions.add(s);
            }
            rs.close();
            unit.setUnitSessions(unitSessions);

            //nborder
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where);
            if (rs2.next()) {
                unit.setNborder(rs2.getInt("UnitNborder"));
                unit.setIdProgramme(rs2.getInt("idProgramme"));
                unit.setIdTrainingCopied(rs2.getInt("idTrainingCopied"));
            }
            rs2.close();


        }
        return loaded;
    }


    public boolean loadByIdAndRS(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRS(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //unitSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector unitSessions = new Vector();
            RequeteSelectWhere rs1 = new RequeteSelectWhere(db, "session", where);
            while (rs1.next()) {
                UnitSession s = new UnitSession(rs1.getInt("idSession"));
                UnitSessionDB udb = new UnitSessionDB(s);
                udb.loadByIdAndRS(language, false, rs1);

                unitSessions.add(s);
            }
            rs1.close();
            unit.setUnitSessions(unitSessions);

            //nborder
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where);
            if (rs2.next()) {
                unit.setNborder(rs2.getInt("UnitNborder"));
                unit.setIdProgramme(rs2.getInt("idProgramme"));
                unit.setIdTrainingCopied(rs2.getInt("idTrainingCopied"));
            }
            rs2.close();


        }
        return loaded;
    }


    public boolean loadByIdAndRSForPublication(Language language, boolean all, InterfaceRequeteSelect rs) {
        boolean loaded = super.loadByIdAndRSForPublication(language, all, rs);

        if (all) {
            TOMADatabase db = TOMADatabase.getInstance();

            //unitSessions
            String[][] where = new String[1][3];
            where[0][0] = (new Integer(training.getIdTraining())).toString();
            where[0][1] = "Integer";
            where[0][2] = "idTraining";

            Vector unitSessions = new Vector();
            RequeteSelectWhere rs1 = new RequeteSelectWhere(db, "session", where);
            while (rs1.next()) {
                UnitSession s = new UnitSession(rs1.getInt("idSession"));
                UnitSessionDB udb = new UnitSessionDB(s);
                udb.loadByIdAndRSForPublication(language, true,rs1);

                unitSessions.add(s);
            }
            rs1.close();
            unit.setUnitSessions(unitSessions);

            //nborder
            RequeteSelectWhere rs2 = new RequeteSelectWhere(db, "training", where);
            if (rs2.next()) {
                unit.setNborder(rs2.getInt("UnitNborder"));
                unit.setIdProgramme(rs2.getInt("idProgramme"));
                unit.setIdTrainingCopied(rs2.getInt("idTrainingCopied"));
            }
            rs2.close();


        }
        return loaded;
    }


    public void create() {
        TOMADatabase db = TOMADatabase.getInstance();

        Object[][] insert = this.getSaveData(true);
        RequeteInsert ri = new RequeteInsert(db, "training", insert);
        ri.close();

        String[][] where = new String[1][3];
        where[0][0] = training.getCode();
        where[0][1] = "String";
        where[0][2] = "code";
        RequeteSelectWhere rs = new RequeteSelectWhere(db, "training", where);
        if (rs.next()) {
            training.setIdTraining(rs.getInt("idTraining"));
            training.setDateCreation(rs.getDate("dateCreation"));
            training.setDateMaj(rs.getDate("dateMaj"));
        }
        rs.close();

        db.commit();

        this.setLinks();
        this.unlock();
    }

    public void update() {
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(training.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";

        Object[][] update = this.getSaveData(false);

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "training", update, where);
        ru.close();

        db.commit();

        //date maj
        training.setDateMaj(DatabaseFacilities.getDate());

        this.setLinks();
    }

    public void setLinks() {
        super.setLinks();

        TOMADatabase db = TOMADatabase.getInstance();

        //unitSessions
        /*RequeteDelete rd=new RequeteDelete(db, "session", "idTraining", (new Integer(training.getIdTraining())).toString());
          rd.close();
          Vector unitSessions=unit.getUnitSessions();
          if(unitSessions!=null)
          {
          Iterator it=unitSessions.iterator();
          while(it.hasNext())
          {
          UnitSession s=(UnitSession) it.next();
          UnitSessionDB sdb=new UnitSessionDB(s);
          sdb.create();
          }
          }*/

        db.commit();
    }

    public Object[][] getSaveData(boolean creation) {
        int idP = unit.getIdProgramme();
        boolean exists_idP = TrainingDB.exists(idP);
        int idTC = unit.getIdTrainingCopied();
        boolean exists_idTC = TrainingDB.exists(idTC);

        Object[][] data1 = super.getSaveData(creation);
        int size = data1.length;
        int newsize = size + 2;
        if (exists_idP)
            newsize++;
        if (exists_idTC)
            newsize++;

        Object[][] data = new Object[newsize][2];
        for (int i = 0; i < size; i++) {
            data[i][0] = data1[i][0];
            data[i][1] = data1[i][1];
        }

        data[size][0] = "type";
        data[size][1] = "U";

        data[size + 1][0] = "unitNborder";
        data[size + 1][1] = new Integer(unit.getNborder());

        if (exists_idP) {
            data[size + 2][0] = "idProgramme";
            data[size + 2][1] = new Integer(idP);
        } else
            unit.setIdProgramme(-1);

        if (exists_idTC) {
            data[size + 3][0] = "idTrainingCopied";
            data[size + 3][1] = new Integer(idTC);
        } else {
            unit.setIdTrainingCopied(-1);
        }

        return data;
    }

    public void updateOrder() {
        TOMADatabase db = TOMADatabase.getInstance();

        String[][] where = new String[1][3];
        where[0][0] = (new Integer(training.getIdTraining())).toString();
        where[0][1] = "Integer";
        where[0][2] = "idTraining";

        Object[][] update = new Object[1][2];
        update[0][0] = "unitNborder";
        update[0][1] = new Integer(unit.getNborder());

        RequeteUpdateWhere ru = new RequeteUpdateWhere(db, "training", update, where);
        ru.close();

        db.commit();
    }

    public void delete() {
        TOMADatabase db = TOMADatabase.getInstance();

        //unitSessions
        RequeteSelect rs = new RequeteSelect(db, "session", "idTraining", new Integer(training.getIdTraining()));
        while (rs.next()) {
            UnitSession session = new UnitSession(rs.getInt("idSession"));
            UnitSessionDB udb = new UnitSessionDB(session);
            udb.delete();
        }
        rs.close();

        db.commit();

        super.delete();
    }


    /**
     * loads the units
     */
    public static Vector load(Language lng, boolean all) {
        Vector trainings = new Vector();
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "training", "type", "U");
        while (rs.next()) {
            Unit t = new Unit(rs.getInt("idTraining"));
            UnitDB tdb = new UnitDB(t);
            tdb.loadByIdAndRS(lng, all,rs);
            trainings.add(t);
        }
        rs.close();


        return trainings;
    }

    public static void deleteAll() {
        TOMADatabase db = TOMADatabase.getInstance();
        RequeteSelect rs = new RequeteSelect(db, "training", "type", "U");
        while (rs.next()) {
            Unit u = new Unit(rs.getInt("idTraining"));
            UnitDB udb = new UnitDB(u);
            udb.delete();
        }
        rs.close();
        db.commit();
    }
}
