// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.datacontrol;


import apostal.toma.database.CatalogueDB;
import apostal.toma.data.Catalogue;
import apostal.toma.data.Training;
import apostal.toma.data.Language;
import java.util.Vector;
import apostal.toma.TOMA;



public class CatalogueControl {
    private CatalogueDB catalogueDB;

    //Load de tous les catalogues
    public Catalogue loadCatalogue(boolean all) 
    {
	Catalogue catalogue = catalogueDB.getRootCatalogue(TOMA.getInstance().getTomaParameters().getLanguage(),all);
	return catalogue;
    }
   
    //Load d'un Catalogue
    public Catalogue loadCatalogue(int id) {
	return this.loadCatalogue(id, true, true);
    }

    //Load d'un Catalogue
    public Catalogue loadCatalogue(int id, boolean all, boolean withLists) {
      Catalogue c = new Catalogue(id);
      catalogueDB = new CatalogueDB(c);
      catalogueDB.loadById(TOMA.getInstance().getTomaParameters().getLanguage(), all, withLists);
      return c;
    }

    //Load d'un Catalogue
    public Catalogue loadCatalogue(Catalogue c) {
	return this.loadCatalogue(c, true, true);   
    }

    //Load d'un Catalogue
    public Catalogue loadCatalogue(Catalogue c, boolean all, boolean withLists) {           
      //Catalogue catalogue = catalogueDB.getRootCatalogue(TOMA.getInstance().getTomaParameters().getLanguage(),all, withLists);
	CatalogueDB cdb=new CatalogueDB(c);
	cdb.loadById(TOMA.getInstance().getTomaParameters().getLanguage(), all, withLists);
	return c;
    }

    // Creation d'un catalogue dans la base de donnes
    public boolean createCatalogue(Catalogue c) {
      catalogueDB = new CatalogueDB(c);
      catalogueDB.create();
      return true;
    }

    public void deleteCatalogue(Catalogue c) {
      catalogueDB = new CatalogueDB(c);
      catalogueDB.delete();
    }

    public void saveCatalogue(Catalogue c) {
      catalogueDB = new CatalogueDB(c);
      catalogueDB.update();
    }

    public void lock(Catalogue c)
    {
      catalogueDB = new CatalogueDB(c);
      catalogueDB.lock();
    }

    public void unlock(Catalogue c)
    {
      catalogueDB = new CatalogueDB(c);
      catalogueDB.unlock();
    }

    public boolean isLocked(Catalogue c)
    {
      boolean lock = true;
      catalogueDB = new CatalogueDB(c);
      lock = catalogueDB.isLocked();
      return lock;
    }

    public boolean testCreate(Catalogue c)
    {
      boolean create = true;
      catalogueDB = new CatalogueDB(c);
      create = catalogueDB.testCreate();
      return create;
    }

    public boolean testUpdate(Catalogue c)
    {
      boolean update = true;
      catalogueDB = new CatalogueDB(c);
      update = catalogueDB.testUpdate();
      return update;
    }
    
  // Mettre tous les trainings du catalogue c sur le desktop
    public void putDesktop(Catalogue c)
    {
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();
        
      /*Catalogue desktop = new Catalogue(0);
      catalogueDB = new CatalogueDB(desktop);
      catalogueDB.loadById(lng,true);*/
      Catalogue desktop=CatalogueDB.getRootCatalogue(lng, true);
      Vector vdesktop = desktop.getTrainings();
      Vector vtrainings = c.getTrainings();
      for (int i=0; i<vtrainings.size(); i++)
      {
          vdesktop.addElement(vtrainings.elementAt(i));
      }
      
      CatalogueDB catalogueDB=new CatalogueDB(desktop);
      catalogueDB.update();
      catalogueDB.unlock();
    }

    //Mettre le training t du catalogue c sur le desktop
    public void moveDesktop(Catalogue c, Training t)
    {
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();
      
      /*Catalogue desktop = new Catalogue(0);
      catalogueDB = new CatalogueDB(desktop);
      catalogueDB.loadById(TOMA.getInstance().getTomaParameters().getLanguage(),true);*/
      Catalogue desktop=CatalogueDB.getRootCatalogue(lng, true);
      
      Vector vdesktop = desktop.getTrainings();
      vdesktop.addElement(t);
      CatalogueDB catalogueDB=new CatalogueDB(desktop);      
      catalogueDB.update();
      catalogueDB.unlock();
      deleteTraining(c,t);
    }

    public void deleteTraining(Catalogue c, Training t)
    {
      catalogueDB = new CatalogueDB(c);
      Vector vtrainings = c.getTrainings();
      for(int i=0; i<vtrainings.size(); i++)
      {
        if(t.getIdTraining()==((Training)vtrainings.elementAt(i)).getIdTraining())
        {
          vtrainings.removeElementAt(i);
        }
      }
      c.setTrainings(vtrainings);
      catalogueDB.update();
    }

    public void addTraining(Catalogue c, Training t)
    {
      catalogueDB = new CatalogueDB(c);
      Vector vtrainings = c.getTrainings();
      vtrainings.addElement(t);
      catalogueDB.update();
    }

  }

