// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.datacontrol;



import java.util.Vector;
import java.util.Iterator;

import java.awt.event.ActionListener;
import apostal.ted.TrainingXML;
import apostal.ted.*;
import apostal.toma.view.TOMAFonts;
import apostal.toma.TOMA;
import apostal.toma.database.TrainingDB;
import apostal.toma.view.ImportTrainingView;
import apostal.toma.view.LocationsView;
import apostal.toma.database.LocationDB;
import apostal.toma.database.TeacherDB;
import apostal.toma.database.ContactDB;
import apostal.toma.database.DomainDB;
import apostal.toma.database.AreaDB;
import apostal.toma.database.UnitDB;
import apostal.toma.database.StandaloneTrainingDB;
import apostal.toma.database.TrainingCourseDB;
import apostal.toma.database.TrainingProgrammeDB;
import apostal.toma.data.Teacher;
import apostal.toma.data.Location;
import apostal.toma.data.Contact;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TrainingProgramme;
import apostal.toma.data.Training;
import apostal.toma.data.Area;
import apostal.toma.data.Domain;
import apostal.toma.data.Unit;
import apostal.toma.view.TOMAQuestion;
import apostal.toma.external.ObjecttoImport;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAFileChooser;
import apostal.toma.view.TOMAFileFilter;
import java.io.File;
import javax.swing.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.OrganismDB;
import apostal.toma.data.Organism;
import apostal.toma.data.TOMAConstants;

public class ImportTEDControl
{
    private TOMAFileChooser fc;
    protected TOMALabels labels = new TOMALabels();
    private TrainingCourseXML trainingCourse;
    private ImportTrainingView importView;
    private LocationsView locationsView;
    private LocationDB locationDB;
    private TeacherDB teacherDB;
    private ContactDB contactsDB;

    public void importTED() {
      importTraining(trainingCourse);
    }

    public void openFile()
    {
             fc = new TOMAFileChooser(locationsView, labels.get("apostal.toma.import.open"), labels.get("apostal.toma.import.ok"), labels.get("apostal.toma.import.cancel"));
             TOMAFileFilter filter = new TOMAFileFilter(TOMAFileFilter.xml);
             fc.addTOMAFileFilter(filter);
             int test = fc.showOpenDialog();
             if(test == TOMAFileChooser.APPROVE)
             {
                 File file = fc.getSelectedFile();
                 if(file!=null)
                 {
                     //try
                     //{

                         Vector trainings = getXML(file);
                         for(int i=0; i<trainings.size();i++)
                         {
                             importView = new ImportTrainingView();
                             TrainingXML t = (TrainingXML)trainings.elementAt(i);
                             Vector[] alldata=this.getReducedDataVectors(t);
                             importView.setData(t, alldata[0], alldata[1], alldata[2]);
                             importView.show();
                         }
                     //}
                     //catch(NullPointerException np)
                     //{
                     //  TOMA.log(TOMA.INFO, "File " +file +" not valid ");
                     //  showError();
                     //}
                 }
              }
    }

    public Vector[] getReducedDataVectors(TrainingXML t)
    {
      Vector teachers=new Vector();
      if(t.getTeachers()!=null)
        teachers=(Vector) t.getTeachers().clone();

      Vector locations=new Vector();
      if(t.getLocations()!=null)
        locations=(Vector) t.getLocations().clone();

      Vector contacts=new Vector();
      if(t.getTrainingContacts()!=null)
        contacts=(Vector) t.getTrainingContacts().clone();

      Vector tempcontacts = t.getInscriptionContacts();
      if(tempcontacts!=null)
      {
        Iterator it = tempcontacts.iterator();
        while(it.hasNext())
        {
          InscriptionContactXML icontact = (InscriptionContactXML) it.next();
          if ((icontact!=null)&&(!contacts.contains(icontact)))
          {
            contacts.add(icontact);
          }
        }
      }

      if(t instanceof apostal.ted.TrainingCourseXML)
      {
        TrainingCourseXML tc=(TrainingCourseXML) t;
        Vector sessions=tc.getCourseSessions();
        if(sessions!=null)
        {
          Iterator it=sessions.iterator();
          while(it.hasNext())
          {
            CourseSessionXML cs=(CourseSessionXML) it.next();
            if(cs!=null)
            {
                if(cs.getTeachers()!=null)
                {
                  Iterator it2=cs.getTeachers().iterator();
                  while(it2.hasNext())
                  {
                    TeacherXML teacher=(TeacherXML) it2.next();
                    if(!teachers.contains(teacher))
                      teachers.add(teacher);
                  }
                }
                if(cs.getLocation()!=null && !locations.contains(cs.getLocation()))
                  locations.add(cs.getLocation());
            }
          }
        }
      }
        else
        {
          TrainingProgrammeXML tp=(TrainingProgrammeXML) t;
          Vector sessions=tp.getProgrammeSessions();
          if(sessions!=null)
          {
            Iterator it=sessions.iterator();
            while(it.hasNext())
            {
              ProgrammeSessionXML session=(ProgrammeSessionXML) it.next();
              if(session!=null && session.getLocations()!=null)
              {
                Iterator it2=session.getLocations().iterator();
                while(it2.hasNext())
                {
                  LocationXML location=(LocationXML) it2.next();
                  if(!locations.contains(location))
                    locations.add(location);
                }
              }
            }
          }
          if(tp.getUnits()!=null)
          {
            Iterator it=tp.getUnits().iterator();
            while(it.hasNext())
            {
              UnitXML unit=(UnitXML) it.next();
              if(unit!=null)
              {
                if(unit.getTeachers()!=null)
                {
                  Iterator it2=unit.getTeachers().iterator();
                  while(it2.hasNext())
                  {
                    TeacherXML teacher=(TeacherXML) it2.next();
                    if(!teachers.contains(teacher))
                      teachers.add(teacher);
                  }
                }
                if(unit.getTrainingContacts()!=null)
                {
                  Iterator it2=unit.getTrainingContacts().iterator();
                  while(it2.hasNext())
                  {
                    ContactXML contact=(ContactXML) it2.next();
                    if(!contacts.contains(contact))
                      contacts.add(contact);
                  }
                }
                if(unit.getLocations()!=null)
                {
                  Iterator it2=unit.getLocations().iterator();
                  while(it2.hasNext())
                  {
                    LocationXML location=(LocationXML) it2.next();
                    if(!locations.contains(location))
                      locations.add(location);
                  }
                }

                if(unit.getUnitSessions()!=null)
                {
                  Iterator it2=unit.getUnitSessions().iterator();
                  while(it2.hasNext())
                  {
                    UnitSessionXML session=(UnitSessionXML) it2.next();
                    if(session!=null)
                    {
                      if(session.getTeachers()!=null)
                        {
                        Iterator it3=session.getTeachers().iterator();
                        while(it3.hasNext())
                        {
                          TeacherXML teacher=(TeacherXML) it3.next();
                          if(!teachers.contains(teacher))
                            teachers.add(teacher);
                        }
                      }

                      if(session.getLocation()!=null && !locations.contains(session.getLocation()))
                        locations.add(session.getLocation());
                    }
                  }
                }
              }
            }
          }
        }

      Vector[] result=new Vector[3];
      result[0]=teachers;
      result[1]=locations;
      result[2]=contacts;
      return result;
    }

    //pas un fichier conforme a ted
    public void showError()
    {
       TOMAError error = new TOMAError(labels.get("apostal.toma.import.noted"), labels.get("apostal.toma.import.tederror"));
    }

    //problme pour ouvrir le fichier
    public void showError2()
    {
      TOMAError error = new TOMAError(labels.get("apostal.toma.import.noopen"), labels.get("apostal.toma.import.tederror"));
    }

    public Vector getXML(File source){
          Vector trainings = new Vector();
          Vector trainingC = new Vector();
          Vector trainingP = new Vector();
          LoadXML loadXML = new LoadXML(source.toString());
          try
          {
               loadXML.setDifferentTedFilename("ted.xml",TOMAConstants.tedFilename);
               TOMA.log(TOMA.WARNING,  "Error: " +loadXML.getValidationMessage());
               TedXML tedXML = loadXML.load();
               trainingC = tedXML.getTrainingCourses();
               trainingP = tedXML.getTrainingProgrammes();

          }
          catch(NullPointerException np)
          {
                String error = loadXML.getValidationMessage();
                if (error!=null)
                  showError();
                else
                  showError2();
          }
          trainings = addVectors(trainingC, trainingP);
          return trainings;
    }

    public Vector addVectors(Vector v1, Vector v2)
    {
      for (int i=0; i<v2.size(); i++)
      {
        v1.addElement(v2.elementAt(i));
      }
      return v1;
    }


    //Load de toutes les locations de la BD
    public Vector loadLocations(boolean all)
    {
      Vector vlocations = new Vector();
      vlocations = locationDB.load(TOMA.getInstance().getTomaParameters().getLanguage(),all);
      return vlocations;
    }
    //Load de tous les teachers de la BD
    public Vector loadTeachers(boolean all)
    {
      Vector vteachers = new Vector();
      vteachers = teacherDB.load(TOMA.getInstance().getTomaParameters().getLanguage(),all);
      return vteachers;
    }

    //Load de tous les contacts de la BD
    public Vector loadContacts(boolean all)
    {
      Vector vcontacts = new Vector();
      vcontacts = ContactDB.load(TOMA.getInstance().getTomaParameters().getLanguage(), all);
      return vcontacts;
    }

    // Initialise le vecteur qui contient les choix des utilisateur
    // mme taille que nombre de teachers, locations, contacts
    // au dbut initilis  "not import"
    public Vector init(Vector source)
    {
      Vector vtoinit = new Vector();
      ObjecttoImport toImport;
      for(int i=0; i<source.size();i++)
      {
        toImport = new ObjecttoImport();
        toImport.setImporter(false);
        toImport.setCreator(-1);
        toImport.setObject(source.elementAt(i));
        //toImport.setFixedObject(source.elementAt(i));
        vtoinit.addElement(toImport);
      }
      return vtoinit;
    }


    public void loadData()
    {
      trainingCourse.getCode();
    }

    //afficher le code


    //afficher le partenariat


    //afficher un cycle

    /**

     * Imports a training from the "TrainingXML" format.

     * For the teachers:

     * - the teachers that must not be imported are not in the training

     * - the teachers that must be created are in the training, but without any key

     * - the teachers that must be imported and that must replace other teachers are given with the key of the teacher to be replaced

     * For the contacts: idem

     * For the locations: idem

     * For the catalogues:

     * - the catalogue that is to be used is entered, with his title

     */

    //Test si la location a importer existe dj
    public boolean testLocations(TrainingXML training)
    {
      //if test=true possible de creer
      boolean test = true;
      Vector locations = training.getLocations();
      LocationXML l = new LocationXML();
      for (int i=0; i<locations.size(); i++)
      {
        l = (LocationXML)locations.elementAt(i);
        //pour tous les locations sans key
        String key = l.getKey();
        String denom = l.getDenomination();
          Location loc = new Location();
          loc.setDenomination(denom);
          LocationDB ldb = new LocationDB(loc);
          boolean temptest = ldb.testCreate();
          if ((key!="")&&(!temptest))
          {
            //denom  remplacer la mme que denom  importer
            importView = new ImportTrainingView();
            temptest = importView.testEqualLocations(l);
          }
          test = test && temptest;
          if (!temptest)
          {
            TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.loc_problem") +denom  +labels.get("apostal.toma.import.problem_end") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
          }
      }
      return test;
    }

     //Test si la unit a importer existe dj
    public boolean testUnits(TrainingXML training)
    {
      boolean test = true;
      try
      {
        TrainingProgrammeXML tp = (TrainingProgrammeXML)training;
        //if test=true possible de creer

        Vector units = tp.getUnits();
        UnitXML u = new UnitXML();
        for (int i=0; i<units.size(); i++)
        {
          u = (UnitXML)units.elementAt(i);
          u.setKey("");
          String code = u.getCode();
          String title = u.getTitle();
          Unit un = new Unit();
          un.setCode(code);
          un.setTitle(title);
          UnitDB udb = new UnitDB(un);
          boolean temptest = udb.testCreate();
          test = test && temptest;
          TOMA.log(TOMA.WARNING, "Test: " +test +" pour unit: " +(UnitXML)units.elementAt(i));
          if (!temptest)
          {
            TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.un_problem") +" " +code +" " +labels.get("apostal.toma.import.problem_end") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
          }
        }
      }
      catch(ClassCastException cc){}
      return test;
    }



    //Test si le teacher a importer existe  dj
    public boolean testTeachers(TrainingXML training)
    {
      //if test=true possible de creer
      boolean test = true;
      Vector teachers = training.getTeachers();
      TeacherXML t = new TeacherXML();
      for(int i=0; i<teachers.size(); i++)
      {
        t = (TeacherXML)teachers.elementAt(i);
        //pour tous les teachers sans key
        String key = t.getKey();
        String firstname = t.getFirstname();
        String lastname = t.getLastname();
        String function = t.getFunction();
        if(key!=null)
        {
          Teacher teach = new Teacher();
          teach.setFirstname(firstname);
          teach.setLastname(lastname);
          teach.setFunction(function);
          TeacherDB tdb = new TeacherDB(teach);
          boolean temptest = tdb.testCreate();
          if ((key!="")&&(!temptest))
          {
            importView = new ImportTrainingView();
            //denom  remplacer la mme que denom  importer
            temptest = importView.testEqualTeachers(t);
          }
          test = test && temptest;
          if (!temptest)
          {
            TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.teach_problem") +lastname  +labels.get("apostal.toma.import.problem_end") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
          }
        }

      }
      return test;
    }

    //Test si le contact a importer existe dj
    public boolean testContacts(TrainingXML training)
    {
      //if test=true possible de creer
      boolean test = true;
      // *** TrainingContacts
      Vector trcontacts = training.getTrainingContacts();
      ContactXML trc = new ContactXML();
      //debug
      Vector temp = training.getInscriptionContacts();
      TOMA.log(TOMA.WARNING, "TrainingContact.size: "  +trcontacts.size());
      TOMA.log(TOMA.WARNING, "InscriptionContact.size: "  +temp.size());
      for(int i=0; i<trcontacts.size(); i++)
      {
        trc = (ContactXML)trcontacts.elementAt(i);
        TOMA.log(TOMA.WARNING, "Training Contact: " +trc);
        //pour tous les contacts sans key
        String key = trc.getKey();
        String firstname = trc.getFirstname();
        String lastname = trc.getLastname();
        String email = trc.getEmail();
        String tel = trc.getTel();
        if (key!=null)
        {
          Contact c = new Contact();
          c.setFirstname(firstname);
          c.setLastname(lastname);
          c.setEmail(email);
          c.setTel(tel);
          ContactDB cdb = new ContactDB(c);
          boolean temptest = cdb.testCreate();
          if ((key!="")&&(!temptest))
          {
            importView = new ImportTrainingView();
            //denom  remplacer la mme que denom  importer
            temptest = importView.testEqualContacts(trc);
          }
          test = test && temptest;
          if (!temptest)
          {
            TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.contact_problem") +lastname  +labels.get("apostal.toma.import.problem_end") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
          }
        }
      }
      // *** InscrptionContacts
      Vector inscontacts = training.getInscriptionContacts();
      ContactXML insc = new ContactXML();
      for(int i=0; i<inscontacts.size(); i++)
      {
        insc = (ContactXML)inscontacts.elementAt(i);
        //pour tous les locstions sans key
        String key = insc.getKey();
        String firstname = insc.getFirstname();
        String lastname = insc.getLastname();
        String email = insc.getEmail();
        String tel = insc.getTel();
        if(key!=null)
        {
          Contact c = new Contact();
          c.setFirstname(firstname);
          c.setLastname(lastname);
          c.setEmail(email);
          c.setTel(tel);
          ContactDB cdb = new ContactDB(c);
          boolean temptest = cdb.testCreate();
          if ((key!="")&&(!temptest))
          {
            importView = new ImportTrainingView();
            //denom  remplacer la mme que denom  importer
            temptest = importView.testEqualContacts(insc);
          }
          test = test && temptest;
          if (!temptest)
          {
            TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.contact_problem") +lastname  +labels.get("apostal.toma.import.problem_end") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
          }
        }
      }
      return test;
    }
    public void testArea(TrainingXML training)
    {
      //Donnes de training
      Vector v_locations = training.getLocations();
      for(int i=0; i<v_locations.size(); i++)
      {
        AreaXML area = ((LocationXML)v_locations.elementAt(i)).getArea();
        testArea(area);
      }
    }

    public void setKey(ObjecttoImport obj)
    {
        Object o = obj.getObject();
        String classname = o.getClass().getName();
        if (classname.equals("apostal.ted.TrainingContactXML"))
        {

        }
        else
        {

        }
    }


     public void testArea(AreaXML area)
    {/*
      //Donnes de la base de donnes
      boolean test = false;
      Area a = new Area();
      AreaDB adb = new AreaDB(a);
      String title = area.getName();
      TOMA.log(TOMA.WARNING, "Title: " +title);
      Vector v_areas = adb.getAreasByName(title);
      for(int i=0; i<v_areas.size(); i++)
      {
        a = (Area)v_areas.elementAt(i);
        if (a.getName().compareTo(area.getName())==0)
        {
          TOMA.log(TOMA.WARNING, "Area found" +area.getName());
        }
      }
      AreaXML ar = area.getArea();
      if (ar!=null)
      {
        testArea(ar);
      }*/
    }




    //Test si le domain/area est reconnu par TOMA
    public void testDomains(TrainingXML training)
    {
      boolean test = false;
      boolean message = false;
      //Donnes de training
      Vector v_dom = training.getDomains();
      Vector v_dom_s = (Vector)v_dom.clone();
      //Tester si le domaine se trouve dans la base de donnes
      for (int i=0; i<v_dom_s.size(); i++)
      {
        DomainXML domain = (DomainXML)v_dom_s.elementAt(i);
        test = testDomain(domain);
        if (!test)
        {
          v_dom.removeElementAt(i);
          message = true;
        }
      }
      if(message)
      {
           TOMAError error = new TOMAError(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.nodomain") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.problem"));
      }
    }

    public boolean testDomain(DomainXML domain)
    {
      //Donnes de la base de donnes
      boolean test = false;
      Domain d = new Domain();
      DomainDB ddb = new DomainDB(d);
      String title = domain.getTitle();
      Vector v_domains = ddb.getDomainsByName(title);
      for(int i=0; i<v_domains.size(); i++)
      {
        d = (Domain)v_domains.elementAt(i);
        if (d.getName().compareTo(domain.getTitle())==0)
        {
          TOMA.log(TOMA.WARNING, "Domain found" +domain.getTitle());
          test = true;
        }
        else
        {
          TOMA.log(TOMA.WARNING, "Domain  NOT found" +domain.getTitle());
          test = false;
        }
      }
      DomainXML dom = domain.getDomain();
      if ((dom!=null)&&(test=true))
      {
        test = testDomain(dom);
      }
      return test;
    }

    //Tester les diffrentes lments avant d'importer
    //false=cancel
    public boolean testTraining(TrainingXML training)
    {
      boolean cancel = false;
      //Test avec formation de test
      String code = training.getCode();
      TrainingCourse t_test = new TrainingCourse();
      t_test.setCode(code);
      t_test.setTitle("Formation test");
      TrainingCourseDB tdb = new TrainingCourseDB(t_test);
      return tdb.testCreate();
    }


    //Test si la formation a importer a le mme organisme que TOMA
    // sinon le nom de l'organisme  importer
    public void testOrganism(TrainingXML training)
    {
      String denomdb = "";
      //Nom de l'organisme  importer:
      String denom = training.getOrganism().getDenomination();

      //Nom de l'organisme
      Organism org = OrganismDB.getOrganism(TOMA.getInstance().getTomaParameters().getLanguage(), true);
      try
      {
        denomdb = org.getDenomination();
      }
      catch(NullPointerException np){}
      if (denom.compareToIgnoreCase(denomdb)!=0)
      {
        if(denom.compareToIgnoreCase(training.getPartnership())!=0)
        {
          String concat = training.getPartnership() + " - " +denom;
          training.setPartnership(concat);
        }
      }
    }


    //Delete Training with code
    public void deleteTraining(TrainingXML training)
    {
      String code = training.getCode();
      Training t = TrainingDB.getInstance(TOMA.getInstance().getTomaParameters().getLanguage(), false, code);

      String name = t.getClass().getName();
      StandaloneTrainingDB tdb = null;
      if(name.equals("apostal.toma.data.TrainingCourse"))
      {
	      tdb=new TrainingCourseDB((TrainingCourse) t);
      }
      else if(name.equals("apostal.toma.data.TrainingProgramme"))
      {
	      tdb=new TrainingProgrammeDB((TrainingProgramme) t);
      }

      tdb.delete();

      boolean test = tdb.testCreate();
    }

    public boolean replaceTraining(TrainingXML training)
    {

        TOMAQuestion question = new TOMAQuestion(TOMAFonts.htmlBegin +labels.get("apostal.toma.import.code_problem") +TOMAFonts.htmlEnd, labels.get("apostal.toma.import.codeheader"), JOptionPane.OK_CANCEL_OPTION);
        int back = question.getResult();
        if (back==0)
        {
           return true;
        }
        else
        {
          return false;
        }
    }

    //return true si egaux
    public boolean compareString(String s1, String s2)
    {
      if (s1!=null && s2!=null){
        if(s1.compareTo(s2)==0)
            return true;
        else
            return false;
      } else
          return false;
    }

    public boolean equalscontact(ContactXML c1, ContactXML c2)
    {
      boolean test = true;
      test = test && compareString(c1.getFirstname(), c2.getFirstname());
      test = test && compareString(c1.getLastname(), c2.getLastname());
      test = test && compareString(c1.getEmail(), c2.getEmail());
      test = test && compareString(c1.getTel(), c2.getTel());
      return test;
    }

    //Test si contact se trouve dj dans la combobox
    public boolean testItem(JComboBox jcb, ContactXML c)
    {
      boolean test = false;
      for(int i=0; i<jcb.getItemCount(); i++)
      {
        if (equalscontact((ContactXML)jcb.getItemAt(i),c))
        {
          test = true;
        }
      }
      return test;
    }

    public Vector getdoubleContacts(Vector items, ContactXML contact)
    {
      Vector vcontact = new Vector();
      for(int i=0; i<items.size(); i++)
      {
        if (equalscontact((ContactXML)items.elementAt(i),contact))
        {
          vcontact.addElement(items.elementAt(i));
        }
      }
      return vcontact;
    }

    public void importTraining(TrainingXML training) {

    }



    public void importTEDFile() {

    }


}

