// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.datacontrol;


import apostal.toma.database.LocationDB;
import apostal.toma.database.AreaDB;
import apostal.toma.data.Location;
import apostal.toma.data.Area;
import apostal.toma.data.Country;
import apostal.toma.data.Language;
import apostal.toma.TOMA;
import java.util.Vector;

import toolbox.util.*;

public class LocationsControl {
    private LocationDB locationDB;

    //Load de toutes les locations
    public Vector loadLocations(boolean all) {
      Vector vlocations = new Vector();
      vlocations = locationDB.load(TOMA.getInstance().getTomaParameters().getLanguage(),all);
      
      ToStringComparator comp=new ToStringComparator();
      QuickSort sort=new QuickSort(comp);
      vlocations=sort.qsort(vlocations);      
      
      return vlocations;
    }

    /*public Location loadLocation() {
      Location location = new Location();
      Vector vlocations = new Vector();
      vlocations = locationDB.load(new Language("eng"),true);
      return vlocations;
    }*/

    // Creation d'un lieu dans la base de donnes
    public boolean createLocation(Location l) {
      locationDB = new LocationDB(l);
      locationDB.create();
      return true;
    }

    public void deleteLocation(Location l) {
      locationDB = new LocationDB(l);
      locationDB.delete();
    }

    public void saveLocation(Location l) {
      locationDB = new LocationDB(l);
      locationDB.update();
    }

    public void loadLocation(Location l, boolean all)
    {
        Language lng=TOMA.getInstance().getTomaParameters().getLanguage();
      locationDB = new LocationDB(l);    
      locationDB.loadById(lng, all);
    }
    
    public void lockLocation(Location l)
    {
      locationDB = new LocationDB(l);
      locationDB.lock();
    }

    public void unlockLocation(Location l)
    {
      locationDB = new LocationDB(l);
      locationDB.unlock();
    }

    public boolean getLock(Location l)
    {
      boolean lock = true;
      locationDB = new LocationDB(l);
      lock = locationDB.isLocked();
      return lock;      
    }
    
    public boolean isUsedInTraining(int id)
    {
        Location t=new Location(id);
        LocationDB tdb=new LocationDB(t);
        return tdb.isUsedInTraining();
    }       
    
    public Vector getAreasByCountry(Country c)
    {
        return AreaDB.loadFirstLevelByCountry(TOMA.getInstance().getTomaParameters().getLanguage(), c);
    }
    
    public Vector getSubAreas(Area a)
    {
        if(a!=null)
        {
            AreaDB adb=new AreaDB(a);
            adb.loadSubLevel(TOMA.getInstance().getTomaParameters().getLanguage());
            return a.getAreas();
        }
        else
        {
            TOMA.log(TOMA.INFO, "LocationsControl.getSubAreas with area=null");                    
            return new Vector();
        }
    }    
    
    public Area getSuperArea(Area a)
    {
        Area superarea=null;
        if(a!=null && a.getIdSuperArea()>0)
        {
            superarea=new Area(a.getIdSuperArea());
            AreaDB adb=new AreaDB(superarea);
            adb.loadById(TOMA.getInstance().getTomaParameters().getLanguage());
        }
        return superarea;
    }   
    
    public Area[] getFirstAndSecondArea(Area a)
    {
        Area superarea=a;
        Area firstarea=a;
        Area secondarea=null;
        do
        {
            superarea=this.getSuperArea(superarea);                        
            if(superarea!=null)
            {
                secondarea=firstarea;                
                firstarea=superarea;
            }
        }
        while(superarea!=null);
        
        Area[] areas=new Area[2];
        areas[0]=firstarea;
        areas[1]=secondarea;
        
        return areas;
    }    
}

