// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.datacontrol;

import apostal.toma.TOMA;
import apostal.toma.data.Training;
import apostal.toma.data.PublicationUnit;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMAParameters;
import apostal.toma.data.Language;
import apostal.toma.external.XMLPublication;
import apostal.toma.database.PublicationUnitDB;
import apostal.toma.database.LanguageDB;
import apostal.toma.database.CatalogueDB;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAOk;
import apostal.toma.viewcontrol.TOMAWaitThread;
import apostal.toma.viewcontrol.XMLPublicationEventHandler;

import java.io.File;
import java.util.Vector;

import toolbox.util.*;

public class PublicationsControl {
	private PublicationUnitDB publicationUnitDB;
	
    /*public void loadPublicationUnit() {
    }*/

    public void deletePublicationUnit(PublicationUnit pub) {
    	publicationUnitDB = new PublicationUnitDB(pub);
    	publicationUnitDB.delete();
    }

    public boolean createPublicationUnit(PublicationUnit pub) {
      	publicationUnitDB = new PublicationUnitDB(pub);
      	publicationUnitDB.create();
      	this.unlockPublicationUnit(pub);
      	return true;
    }

    public void savePublicationUnit(PublicationUnit pub) {
    	publicationUnitDB = new PublicationUnitDB(pub);
    	publicationUnitDB.update();
    	this.unlockPublicationUnit(pub);
    }

    public void publish(PublicationUnit publicationUnit) {
    }

    
    public void export(Training t, File f,boolean addFirstCat)
    {
     	TOMALabels labels = new TOMALabels();
     	TOMA.log(TOMA.WARNING, "exporting training");
      	if(f!=null)
      	{
			String path=f.getPath();
            PublicationUnit pub=new PublicationUnit();
            pub.setName("XML Export");
            pub.setType(PublicationUnit.PUBLICATION_XML);
            pub.setDestinationPath(path);
            pub.setConsiderValidityDates(false);
            Language lng=TOMA.getInstance().getTomaParameters().getExportationLanguage();
            pub.setLanguage(lng);
            pub.setPublishOrganismData(true);
            pub.setFirstCatalogueTitle("TOMA");
                          
			XMLPublication publication=new XMLPublication(pub);
            TOMAWaitThread waitCheck=new TOMAWaitThread(labels.get("apostal.toma.publication.publish.checkCompliance.message"), labels.get("apostal.toma.publication.publish.checkCompliance.title"));
            waitCheck.start();
            try{waitCheck.join();}catch(Exception ex){}
            publication.checkSingleTraining(t,lng);
            waitCheck.close();            
            Vector warnings=publication.getErrors();
            boolean continuer=true;
            if(warnings!=null && !warnings.isEmpty())
            {
            	TOMA.log(TOMA.WARNING, "il y a eu des problmes XML");
                //demander si on veut continuer
                XMLPublicationEventHandler xmlpub=new XMLPublicationEventHandler();
                continuer=xmlpub.interpretInternalXMLPublication(warnings);
             }
             if(continuer){                 
                        TOMAWaitThread wait = new TOMAWaitThread(labels.get("apostal.toma.publication.export.message"),labels.get("apostal.toma.publication.export.title"));
	    		wait.start();
                        try{wait.join();}catch(Exception ex){}
    			publication.publishSingleTraining(t,addFirstCat);
    			wait.close();
                        
    			if (publication.getResult()==1){
           			TOMAError error = new TOMAError(publication.getErrorMessage(),labels.get("apostal.toma.publication.error.export.title"));
           		}
           		else{
           			TOMAOk ok = new TOMAOk(labels.get("apostal.toma.publication.export.ok.message"),labels.get("apostal.toma.publication.export.ok.title"));
           		}
    		}          
      	}
      	else
      	{
			TOMAError error = new TOMAError(labels.get("apostal.toma.export.errors.filenotfound"),labels.get("apostal.toma.publication.error.export.title"));
        	
      	}
      	
    }
    
    
    public static Vector getExportLanguages()
    {
        TOMAParameters params=TOMA.getInstance().getTomaParameters();
        Language actualLanguage=params.getLanguage();
		return LanguageDB.loadSomeLanguages(actualLanguage, false, false, true);
    }
    
    
    public static Language getLanguageByCode(String code)

    {
        TOMAParameters params=TOMA.getInstance().getTomaParameters();
        Language actualLanguage=params.getLanguage();
        Language language=new Language(code);
		LanguageDB ldb=new LanguageDB(language);
		ldb.loadByCode(actualLanguage);
		return language;
    }
    
    public Vector loadPublicationUnits(boolean all){
    	Vector vpublications = new Vector();
      	vpublications = publicationUnitDB.load(TOMA.getInstance().getTomaParameters().getLanguage(),all);

      ToStringComparator comp=new ToStringComparator();
      QuickSort sort=new QuickSort(comp);
      vpublications=sort.qsort(vpublications);        
        
        return vpublications;
    }
    
    public void lockPublicationUnit(PublicationUnit p)
    {
      publicationUnitDB = new PublicationUnitDB(p);
      publicationUnitDB.lock();
    }

    public void unlockPublicationUnit(PublicationUnit p)
    {
      publicationUnitDB = new PublicationUnitDB(p);
      publicationUnitDB.unlock();
    }

    public boolean getLock(PublicationUnit p)
    {
      boolean lock = true;
      publicationUnitDB = new PublicationUnitDB(p);
      lock = publicationUnitDB.isLocked();
      return lock;      
    }
    
    public void loadPublicationUnit(PublicationUnit p, boolean all)
    {
        Language lng=TOMA.getInstance().getTomaParameters().getLanguage();
        publicationUnitDB = new PublicationUnitDB(p);    
        publicationUnitDB.loadById(lng, all);
    }    
}
