// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.datacontrol;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import apostal.toma.TOMA;

import apostal.toma.data.TrainingCourse;
import apostal.toma.data.Language;
import apostal.toma.data.Catalogue;
import apostal.toma.data.CourseSession;

import apostal.toma.database.TrainingCourseDB;
import apostal.toma.database.CourseSessionDB;
import apostal.toma.database.CatalogueDB;

import apostal.toma.external.XMLPublication;

import java.io.File;

import java.util.Vector;
import java.util.Iterator;

public class TrainingCourseControl extends TrainingControl
{
  private CourseSessionControl csc;
  public TrainingCourseControl()
  {

  }

  public void lock(TrainingCourse t)
  {
    TrainingCourseDB tdb=new TrainingCourseDB(t);
    tdb.lock();
  }

  public void unlock(TrainingCourse t)
  {
    TrainingCourseDB tdb=new TrainingCourseDB(t);
    tdb.unlock();
  }

  public boolean isLocked(TrainingCourse t)
  {
    TrainingCourseDB tdb=new TrainingCourseDB(t);
    return tdb.isLocked();
  }

    /**
     *     charger la formation
     */
    public TrainingCourse loadTraining(int idTraining) {
      //TOMA.printTime("loading tc");
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();
      TrainingCourse tc=new TrainingCourse(idTraining);
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);
      tcdb.loadById(ln, true);
      //TOMA.printTime("tc loaded");
      return tc;
    }

    public void loadTraining(TrainingCourse tc) {
      //TOMA.printTime("loading tc");
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);
      tcdb.loadById(ln, true);
      //TOMA.printTime("tc loaded");
    }

    public void loadTrainingWithSessions(TrainingCourse tc)
    {
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);
      tcdb.loadById(ln, true);

      if(tc.getCourseSessions()!=null)
      {
	CourseSessionControl control=new CourseSessionControl();
        Iterator iter = tc.getCourseSessions().iterator();
	while (iter.hasNext())
	{
	  CourseSession s = (CourseSession) iter.next();
	  control.loadSession(s);
	}
      }
    }

    public boolean duplicate(TrainingCourse t, boolean withSessions)
    {
      boolean ok=true;
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();
      if(t!=null)
      {
        //changer le catalogue de la formation
        Vector catalogues=new Vector();
        Catalogue c=CatalogueDB.getRootCatalogue(TOMA.getInstance().getTomaParameters().getLanguage(), false);
        catalogues.add(c);
        t.setCatalogues(catalogues);
        Vector sessions = t.getCourseSessions();
        TrainingCourseDB tdb=new TrainingCourseDB(t);
        ok=tdb.testCreate();
        if(ok)
        {
            tdb.create();
            tdb.unlock();
            if (withSessions){
                tdb.loadById(ln,false);
                int id = t.getIdTraining();
                csc = new CourseSessionControl();
                Iterator it = sessions.iterator();
                while (it.hasNext()){
                    CourseSession cs = (CourseSession)it.next();
                    CourseSessionDB csDB = new CourseSessionDB(cs);
                    csDB.loadById(ln,true);
                    CourseSession newSession = new CourseSession();
                    newSession = cs;
                    cs.setIdTraining(id);
                    csDB = new CourseSessionDB(newSession);
                    if (csDB.testCreate()){
                        csDB.create();
                        csDB.unlock();
                    }
                }
            }
        }
        else
        {
            ok=false;
        }


      }
      else
        ok=false;

      return ok;
    }

    public void delete(TrainingCourse tc) {
	  TrainingCourseDB tcdb=new TrainingCourseDB(tc);
	  tcdb.delete();
    }

    public boolean testSave(TrainingCourse tc)
    {
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);

      boolean ok=tcdb.testUpdate();
      /*boolean ok=true;

      //vrifier le code
      TrainingCourse tc2=new TrainingCourse(tc.getIdTraining());      
      TrainingCourseDB tc2db=new TrainingCourseDB(tc2);
      tc2db.loadById(TOMA.getInstance().getTomaParameters().getLanguage(), false);
      if(!tc2.getCode().equals(tc.getCode()))
      //le code a chang -> vrifier
      {
	  String code=tc.getCode();
	  if(code==null || code.equals("") || !tcdb.testUpdate())
	  {
	    //erreur de code & pas de sauvegarde
	    ok=false;
	  }
      }*/

      return ok;
    }

    public void save(TrainingCourse tc) {
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);
      tcdb.update();
    }

    public boolean testCreate(TrainingCourse t)
    {
      boolean create = true;
      TrainingCourseDB tdb=new TrainingCourseDB(t);
      create = tdb.testCreate();
      return create;
    }

    public void create(TrainingCourse tc) {
      TrainingCourseDB tcdb=new TrainingCourseDB(tc);
      tcdb.create();
    }
}