// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */
package apostal.toma.datacontrol;

import java.util.HashSet;

import java.util.Vector;

import java.util.Iterator;

import java.lang.String;

import apostal.toma.TOMA;

import apostal.toma.data.TrainingProgramme;

import apostal.toma.data.TrainingCourse;

import apostal.toma.data.Training;

import apostal.toma.data.Unit;

import apostal.toma.data.Language;

import apostal.toma.data.TOMALabels;

import apostal.toma.data.ProgrammeSession;

import apostal.toma.data.CourseSession;

import apostal.toma.data.UnitSession;

import apostal.toma.data.Catalogue;

import apostal.toma.database.ProgrammeSessionDB;

import apostal.toma.database.TrainingProgrammeDB;

import apostal.toma.database.TrainingCourseDB;

import apostal.toma.database.UnitSessionDB;

import apostal.toma.database.UnitDB;

import apostal.toma.database.CatalogueDB;


/**

 * Controls the operations when a training programme is openend.

 * It also control the operations when a unit in a training programme is opened.

 */

public class TrainingProgrammeControl extends TrainingControl {

    public TrainingProgramme loadTraining(int idTraining)
    {
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();

      TrainingProgramme t=new TrainingProgramme(idTraining);

      this.loadTraining(t);

      return t;
    }


    public void loadTraining(TrainingProgramme t)
    {
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();
      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);
      tdb.loadById(ln, true);

      //units
      Vector units=t.getUnits();
      if(units!=null)
      {
        Iterator iter = units.iterator();
        while (iter.hasNext())
        {
	  Unit u = (Unit) iter.next();
	  UnitDB udb=new UnitDB(u);
	  udb.loadById(ln, true);
        }
      }
    }

    public void loadTrainingWithSessions(TrainingProgramme t)
    {
      Language ln=TOMA.getInstance().getTomaParameters().getLanguage();

      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

      tdb.loadById(ln, true);

      if(t.getProgrammeSessions()!=null)

      {
	ProgrammeSessionControl control=new ProgrammeSessionControl();

        Iterator iter = t.getProgrammeSessions().iterator();

	while (iter.hasNext())

	{

	  ProgrammeSession s = (ProgrammeSession) iter.next();

	  control.loadSession(s);

	}
      }

      //units
      Vector units=t.getUnits();
      if(units!=null)
      {

	UnitControl control=new UnitControl();

        Iterator iter = units.iterator();

        while (iter.hasNext())

        {

	  Unit u = (Unit) iter.next();

	  control.loadUnitWithSessions(u);

        }

      }

    }



  public void lock(TrainingProgramme t)

  {

    //units

    if(t.getUnits()!=null)

    {

      Iterator iter = t.getUnits().iterator();

      while (iter.hasNext())

      {

	Unit u = (Unit) iter.next();

	UnitDB udb=new UnitDB(u);

	udb.lock();

      }

    }



    //tp

    TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

    tdb.lock();

  }



  public void unlock(TrainingProgramme t)

  {

    //units

    if(t.getUnits()!=null)

    {

      Iterator iter = t.getUnits().iterator();

      while (iter.hasNext())

      {

	Unit u = (Unit) iter.next();

	UnitDB udb=new UnitDB(u);

	udb.unlock();

      }

    }



    //tp

    TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

    tdb.unlock();

  }



  public boolean isLocked(TrainingProgramme t)

  {

    TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

    return tdb.isLocked();

  }



    public Training duplicate(TrainingProgramme t, boolean withSession)
    {
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();
      boolean ok=true;
      Training value=null;
      if(t!=null)
      {
	  //changer le catalogue de la formation
        Vector catalogues=new Vector();
        Catalogue c=CatalogueDB.getRootCatalogue(lng, false);
        catalogues.add(c);
        t.setCatalogues(catalogues);
        Vector progSessions = new Vector();
        progSessions = t.getProgrammeSessions();
          //tester les valeurs
        TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);
        ok=tdb.testCreate();
      	if(ok)
        {
          //tester les units
          HashSet codes=new HashSet();
          codes.add(t.getCode());
          Vector units=t.getUnits();
          if(units!=null)
          {
            Iterator iter = units.iterator();
            while (iter.hasNext() && ok)
            {
              Unit unit = (Unit) iter.next();
              UnitDB udb=new UnitDB(unit);
              ok=udb.testCreate();
              //si le code a dj t choisi pour un autre module ou pour le cycle
              if(!ok || (ok && codes.contains(unit.getCode())))
              {
                ok=false;
                value=unit;
              }
              else
              	codes.add(unit.getCode());
            }
    	  }
          if(ok)
          {
            tdb.create();
            //update des idProgramme
            int id=t.getIdTraining();
            if (withSession){
            Iterator itProgSession = progSessions.iterator();
            while (itProgSession.hasNext()){
                ProgrammeSession progSession  = (ProgrammeSession)itProgSession.next();
                ProgrammeSessionDB prsDB = new ProgrammeSessionDB(progSession);
                prsDB.loadById(lng,true);
                progSession.setIdTraining(id);
                prsDB = new ProgrammeSessionDB(progSession);
                if(prsDB.testCreate()){
                    prsDB.create();
                    prsDB.unlock();
                }
            }
            }
            Iterator iter = units.iterator();
            while (iter.hasNext())
            {
                Unit u = (Unit) iter.next();
                Vector unitSessions = u.getUnitSessions();
                u.setIdProgramme(id);
                u.setIdTrainingCopied(-1);
                UnitDB udb=new UnitDB(u);
                udb.create();
                if (withSession) {
                int idUnit = u.getIdTraining();
                Iterator itUnitSession = unitSessions.iterator();
                while (itUnitSession.hasNext()){
                    UnitSession unitSession = (UnitSession)itUnitSession.next();
                    UnitSessionDB usDB = new UnitSessionDB(unitSession);
                    usDB.loadById(lng,true);
                    unitSession.setIdTraining(idUnit);
                    usDB = new UnitSessionDB(unitSession);
                    if (usDB.testCreate()){
                        usDB.create();
                        usDB.unlock();
                    }
                }
                }

                udb.unlock();
            }
            tdb.unlock();
          }

	}

	else

	{

	    ok=false;

	    value=t;

	}

      }

      else

      {

          ok=false;

          value=t;

      }



      return value;

    }



    public void delete(TrainingProgramme t)

    {

	  TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

	  tdb.delete();

    }



    public boolean testSave(TrainingProgramme t)
    {

      boolean ok=true;

      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

      ok=tdb.testUpdate();

      /*//todo: vrifier le code
      TrainingProgramme t2=new TrainingProgramme(t.getIdTraining());
      TrainingProgrammeDB t2db=new TrainingProgrammeDB(t2);
      t2db.loadById(TOMA.getInstance().getTomaParameters().getLanguage(), false);
      if(!t2.getCode().equals(t.getCode()))
      //le code a chang -> vrifier
      {
	  String code=t.getCode();
	  if(code==null || code.equals("") || !tdb.testUpdate())
	  {
	    //erreur de code & pas de sauvegarde
	    ok=false;
	  }
      }*/

      return ok;

    }



    public void save(TrainingProgramme t)

    {

      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

      tdb.update();

    }

    public boolean testCreate(TrainingProgramme t)
    {
      boolean create = true;
      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);
      create = tdb.testCreate();
      return create;
    }


    public void create(TrainingProgramme t)

    {

      TrainingProgrammeDB tdb=new TrainingProgrammeDB(t);

      tdb.create();

    }


    public boolean createUnit(TrainingProgramme tp, Unit u)

    {

      boolean ok=true;

      if(u!=null)

      {

        u.setIdProgramme(tp.getIdTraining());



	//maj du nbOrder

	Vector units=tp.getUnits();

	int nbUnits=units.size();

	u.setNborder(nbUnits);



	//tester les valeurs

	UnitDB udb=new UnitDB(u);

	if(udb.testCreate())

	{

	  udb.create();

	  udb.lock();



	  //maj training

	  units.add(u);

	  tp.setUnits(units);

	}

	else

	{

	  ok=false;

	}

      }

      else

	ok=false;



      return ok;

    }



    public Unit createUnitWithTrainingCourse(TrainingProgramme tp, TrainingCourse t)

    {

      Unit unit=null;



      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();



      if(t!=null)

      {

	unit=new Unit();

	unit.setTitle(t.getTitle());

	unit.setCode(t.getCode());

	unit.setPartnership(t.getPartnership());

	unit.setObjectivesIntroduction(t.getObjectivesIntroduction());

	unit.setObjectives(t.getObjectives());

	unit.setObjectivesConclusion(t.getObjectivesConclusion());

	unit.setPointsDealtWith(t.getPointsDealtWith());

	unit.setContentDescriptionIntroduction(t.getContentDescriptionIntroduction());

	unit.setContentDescription(t.getContentDescription());

	unit.setContentDescriptionConclusion(t.getContentDescriptionConclusion());

	unit.setModeOfOrganization(t.getModeOfOrganization());

	unit.setPedagogicalMethods(t.getPedagogicalMethods());

	unit.setCourseMedia(t.getCourseMedia());

	unit.setLevel(t.getLevel());

	unit.setEvaluation(t.getEvaluation());

	unit.setCertificatesOrDiplomas(t.getCertificatesOrDiplomas());

	unit.setDuration(t.getDuration());

	unit.setPrice(t.getPrice());

	unit.setPriceComment(t.getPriceComment());

	unit.setPaymentFacilities(t.getPaymentFacilities());

	unit.setInscriptionConditions(t.getInscriptionConditions());

	unit.setBeginValidityDate(t.getBeginValidityDate());

	unit.setEndValidityDate(t.getEndValidityDate());

	unit.setComment(t.getComment());

	unit.setCommentNotPublished(t.getCommentNotPublished());



	unit.setKeywords(t.getKeywords());

	unit.setPrerequisites(t.getPrerequisites());

	unit.setTrainingContacts(t.getTrainingContacts());

	unit.setTeachers(t.getTeachers());

	unit.setCompetences(t.getCompetences());

	unit.setLocations(t.getLocations());

	unit.setSlots(t.getSlots());

	unit.setLanguages(t.getLanguages());



	//info diffrentes

	unit.setIdProgramme(tp.getIdTraining());

	unit.setIdTrainingCopied(t.getIdTraining());



	int nb=0;

	Vector units=tp.getUnits();

	if(units!=null)

	  nb=units.size();

	unit.setNborder(nb);



	//sessions

	Vector sessions=new Vector();

	unit.setUnitSessions(sessions);



	UnitDB udb=new UnitDB(unit);



	if(udb.testCreate())

	{

	  udb.create();

	  udb.lock();



	  /*

	  //sessions

	  if(t.getCourseSessions()!=null)

	  {

	    Vector sessions=new Vector();

	    Iterator iter = t.getCourseSessions().iterator();

	    while (iter.hasNext())

	    {

	      CourseSession cs = (CourseSession) iter.next();



	      UnitSession s=new UnitSession();

	      s.setSessionName(cs.getSessionName());

	      s.setTextualCalendar(cs.getTextualCalendar());

	      s.setBeginDate(cs.getBeginDate());

	      s.setEndDate(cs.getEndDate());

	      s.setLanguage(cs.getLanguage());

	      s.setPrice(cs.getPrice());

	      s.setPriceComment(cs.getPriceComment());

	      s.setLocation(cs.getLocation());

	      s.setSlot(cs.getSlot());

	      s.setBeginValidityDate(cs.getBeginValidityDate());

	      s.setEndValidityDate(cs.getEndValidityDate());

	      s.setComment(cs.getComment());



	      s.setSeances(cs.getSeances());

	      s.setTeachers(cs.getTeachers());



	      //valeurs diffrentes

	      s.setIdTraining(tp.getIdTraining());

	      //s.setIdProgrammeSession();



	      UnitSessionDB sdb=new UnitSessionDB(s);

	      sdb.create();



	      sessions.add(s);

	    }

	    unit.setUnitSessions(sessions);

	  }*/



	  //maj training

	  units.add(unit);

	  tp.setUnits(units);

	}

	else

	{

	  unit=null;

	}

    }



    return unit;

    }

}

