// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;


import apostal.toma.TOMA;
import apostal.toma.XMLHelper;

import apostal.toma.data.PublicationUnit;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAFonts;
import net.sf.saxon.TransformerFactoryImpl;

import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintWriter;

import java.util.Vector;
import java.util.Iterator;

public class GenericXSLPublication extends Publication {

    private String catXML;
    private String errorMessage;
    private int result;
    private TOMALabels labels;

    public GenericXSLPublication(PublicationUnit publicationUnit) {
        super(publicationUnit);
        result = 0;
        labels = new TOMALabels();
    }

    public int getResult() {
        return result;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void publish(boolean addFirstCat) {
            String destinationFile = publicationUnit.getDestinationPath();
            String propertiesFile = publicationUnit.getPropertiesFile();
            
            File props = new File(propertiesFile);
            if (!props.exists() || !props.isFile()) {
                result = 1;
                errorMessage = errorMessage + "<P>" + labels.get("apostal.toma.publication.publish.error.properties_not_exist") + "</P>";
            }
            File fileDestination = new File(destinationFile);
            if (!fileDestination.exists()) {
                try {
                    fileDestination.createNewFile();
                } catch (IOException ioEx) {
                    result = 1;
                    errorMessage = errorMessage + "<P>" + labels.get("apostal.toma.publication.publish.error.directory_not_exist") + "</P>";
                }
            }                            
                        
            Document propsDoc=XMLHelper.readDocument(propertiesFile);
            if(propsDoc!=null){
                Element xslTransfo=propsDoc.getDocumentElement();            
            
                //check if we need to use namespaces
                Element stylesheetEl=XMLHelper.getSingleElementByTagName(xslTransfo, "Stylesheet");
                boolean useNamespaces=false;
                if(stylesheetEl!=null){
                    useNamespaces=(new Boolean(stylesheetEl.getAttribute("useNamespaces"))).booleanValue();
                }
                
                //generate TED
                try{
                    String destinationTempDir = props.getParent();            
                    String tedFile = new String(destinationTempDir + File.separatorChar + "tempTed.xml");                
                    String catFile = new String(destinationTempDir + File.separatorChar + "tempCat.xml");
                    this.generateTedXML(tedFile, addFirstCat, useNamespaces);
                    catXML = this.processCatalogues();
                    PrintWriter out = new PrintWriter(new FileOutputStream(catFile));
                    out.print(catXML);
                    out.close();
                    
                    //make transformation
                    this.makeXSLTransformation(tedFile, destinationFile, xslTransfo);                    
                } catch (Exception e) {
                    TOMA.log(e);
                }            
            }
    }        
    
    public void makeXSLTransformation(String tedFile, String destinationFile, Element propertiesEl) {
        errorMessage = TOMAFonts.htmlBegin;
        try {
            errorMessage = TOMAFonts.htmlEnd;
            if (result == 0) {
                errorMessage = null;

                //read properties from XML element of properties file
                String xslFile=null;
                Vector parameters=new Vector();
                //boolean useNamespaces=true;
                NodeList stylsheets=propertiesEl.getElementsByTagName("Stylesheet");
                if(stylsheets.getLength()>0){
                    Element stylesheet=(Element) stylsheets.item(0);
                    xslFile=XMLHelper.getTextualNodeValue(stylesheet);
                    //use namespaces or not
                    //String ns=stylesheet.getAttribute("useNamespaces");
                    //useNamespaces=(new Boolean(ns)).booleanValue();
                }
                
                NodeList parametersEl=propertiesEl.getElementsByTagName("Parameters");
                if(parametersEl.getLength()>0){
                    NodeList paramsList=((Element) parametersEl.item(0)).getElementsByTagName("Parameter");
                    int nb=paramsList.getLength();
                    for(int i=0;i<nb;i++){
                        Element parameter=(Element) paramsList.item(i);
                        Element paramName=XMLHelper.getFirstDescendantByName(parameter, "Name");
                        Element paramValue=XMLHelper.getFirstDescendantByName(parameter, "Value");
                        String[] paramString=new String[2];
                        paramString[0]=XMLHelper.getTextualNodeValue(paramName);
                        paramString[1]=XMLHelper.getTextualNodeValue(paramValue);
                        parameters.add(paramString);
                    }
                }
            
                if(xslFile!=null && !xslFile.equals("")){          
                    
                    //do XSL transformation
                    TransformerFactoryImpl factory = new TransformerFactoryImpl();
                    Templates sheet = factory.newTemplates(new StreamSource(new File(xslFile)));
                    Transformer transformer = sheet.newTransformer();
                    
                    Iterator it=parameters.iterator();
                    while(it.hasNext()){
                        String[] param=(String[]) it.next();
                        String paramName=param[0];
                        String paramValue=param[1];
                        transformer.setParameter(paramName, paramValue);
                    }                    
                    
                    //transform into temp file
                    //transformer.transform(new StreamSource(new File(tedFile)), new StreamResult(new File(resultFile)));
                    //transform directly into destination file
                    transformer.transform(new StreamSource(new File(tedFile)), new StreamResult(new File(destinationFile)));
                }
                else{
                   TOMA.log(TOMA.WARNING, "No stylesheet found");
                   errorMessage = errorMessage + "<P>" + labels.get("apostal.toma.publication.publish.error.template_not_exist") + "</P>";
                }
            }

        } catch (Exception e) {
            if (result == 0) {
                result = 1;
                errorMessage = e.getMessage();
                e.printStackTrace();
            }
        }


    }
}

