// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external;


import apostal.toma.data.Language;
import apostal.toma.data.PublicationUnit;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAFonts;
import net.sf.saxon.TransformerFactoryImpl;
import net.sf.saxon.om.NamePool;
import net.sf.saxon.value.StringValue;
import org.jfor.jfor.converter.Converter;
import org.xml.sax.InputSource;

import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import java.io.*;
import java.net.MalformedURLException;
import java.net.URL;





public class RTFPublication extends Publication {
	protected NamePool namePool = NamePool.getDefaultNamePool();
	private String catXML;
	private String errorMessage;
	private int result;
	private TOMALabels labels;
	
	public RTFPublication(PublicationUnit publicationUnit){
		super(publicationUnit);
		result = 0;
		labels = new TOMALabels();
	}
	
	public int getResult(){
		return result;
	}
	public String getErrorMessage(){
		return errorMessage;
	}
	
	public void publish(boolean addFirstCat) {
		try {
			errorMessage = TOMAFonts.htmlBegin;
			String destinationFile = publicationUnit.getDestinationPath();
			String templateFile = publicationUnit.getTemplateFile();
			String propertiesFile = publicationUnit.getPropertiesFile();			
			//Vector trainings = this.trainingsToPublish;
			File path= new File(templateFile);
			if (!path.exists() || !path.isFile()){
				result = 1;
				errorMessage = errorMessage + "<P>" + labels.get("apostal.toma.publication.publish.error.template_not_exist") +"</P>";;
			} 
			File props = new File(propertiesFile);
			if (!props.exists() || !props.isFile()){
				result = 1;
				errorMessage = errorMessage +"<P>" + labels.get("apostal.toma.publication.publish.error.properties_not_exist") +"</P>";
			} else {
				propertiesFile = ((URL)props.toURL()).toString();
			}		
			File fileDestination = new File(destinationFile);
			if (!fileDestination.exists()){
				try {
					fileDestination.createNewFile();					
				}
				catch(IOException ioEx){
					result = 1;		
					errorMessage = errorMessage +"<P>"+ labels.get("apostal.toma.publication.publish.error.directory_not_exist") +"</P>";
				}				
			}
			errorMessage = errorMessage + TOMAFonts.htmlEnd;
			if (result==0){
				String destinationTempFile = path.getParent();
				String tedFile = new String(destinationTempFile + File.separatorChar + "tempTed.xml");;
				String catFile = new String(destinationTempFile + File.separatorChar + "tempCat.xml");
				String foTempFile = new String(destinationTempFile + File.separatorChar + "temp.fo");
				//InputSource input = null;
				Writer output = null;
				//Vector trainings = this.getTrainingToPublish(this.publicationUnit);
				//this.generateTedXML(trainings,tedFile,addFirstCat);
                this.generateTedXML(tedFile,addFirstCat, true);
				catXML = this.processCatalogues();
		    	PrintWriter out = new PrintWriter(new FileOutputStream(catFile));
            	out.print(catXML);
            	out.close();
                File catFiles = new File(catFile);
                File tedFiles = new File(tedFile);
                String tedFilesString = (tedFiles.toURL()).toString();
                String catFilesString = (catFiles.toURL()).toString();
        		TransformerFactoryImpl factory = new TransformerFactoryImpl();
		   		Templates sheet = factory.newTemplates(new StreamSource(new File(templateFile)));
        		Transformer transformer = sheet.newTransformer();
        		transformer.setParameter("properties",new StringValue(propertiesFile));
        		Language language = publicationUnit.getLanguage();
        		String code = language.getCode();
        		Boolean publish_org = new Boolean(publicationUnit.getPublishOrganismData());
        		transformer.setParameter("publish_org",new StringValue(publish_org.toString()));
        		transformer.setParameter("lang",new StringValue(code));
                transformer.setParameter("catTemp",new StringValue(catFilesString));
                transformer.setParameter("tedTemp",new StringValue(tedFilesString));
       	   		transformer.transform(new StreamSource(new File(tedFile)),new StreamResult(new File(foTempFile)));
                InputSource input = new InputSource(RTFPublication.fileToUrl(foTempFile));
                output = new BufferedWriter(new FileWriter(destinationFile));
                new Converter(input,output,Converter.createConverterOption ());

                output.close();
				
			}
        }
        catch (Exception e) {
        	if (result==0){
        			result = 1;
        			errorMessage= e.getMessage();
                    e.printStackTrace();
        		}
        }
        
    }

    /** Convert from a filename to a file URL. */
	private static String fileToUrl(String filename)
	throws MalformedURLException
	{
		return toURL (new File (filename)).toString ();
	}

	/**
	 * Converts this abstract pathname into a <code>file:</code> URL.  The
	 * exact form of the URL is system-dependent.  If it can be determined that
	 * the file denoted by this abstract pathname is a directory, then the
	 * resulting URL will end with a slash.
	 *
	 * @return a URL object representing the equivalent file URL.
	 * @throws MalformedURLException if the path cannot be parsed as a URL.
	 * @see     java.net.URL
	 * @since   1.2
	 */
	private static URL toURL (File file) throws MalformedURLException {
		String path = file.getAbsolutePath();
		if (File.separatorChar != '/') {
			path = path.replace(File.separatorChar, '/');
		}
		if (!path.startsWith("/")) {
			path = "/" + path;
		}
		if (!path.endsWith("/") && file.isDirectory()) {
			path = path + "/";
		}
		return new URL("file", "", path);
	}
}
