/*
    Copyright 2004,2005 CRP Henri Tudor
    
    This file is part of Efficient's animator tool, "efficient.animator".
    Efficient project: http://efficient.citi.tudor.lu

    Efficient.animator is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Efficient.animator is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Efficient.animator; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * SOAPCallParameter.java
 * 
 * Created on Nov 4, 2005 by sof
 *
 */
package apostal.toma.external;

import apostal.toma.XMLHelper;

import org.w3c.dom.Element;

public class SOAPCallParameter {

    public final static int USER_PARAM=0;
    public final static int PASSWORD_PARAM=1;
    public final static int STRINGDOCUMENT_PARAM=2;
    public final static int DATAHANDLERDOCUMENT_PARAM=3;
    public final static int TRAININGCODE_PARAM=4;
	public final static int CONSTANT_PARAM=5;
	
    private int parameterType;
    private String parameterName;
	
	//if the parameter is a CONSTANT_PARAM only
	private String constantValue;
	
	/**
	* constructor parsing the parameter from an XML properties file
	**/
    public SOAPCallParameter(Element el){
        //get type
        if(el.getNodeName().equals("UserParameter"))
            parameterType=SOAPCallParameter.USER_PARAM;
        else if(el.getNodeName().equals("PasswordParameter"))
            parameterType=SOAPCallParameter.PASSWORD_PARAM;
        else if(el.getNodeName().equals("StringDocumentParameter"))
            parameterType=SOAPCallParameter.STRINGDOCUMENT_PARAM;           
        else if(el.getNodeName().equals("DataHandlerDocumentParameter"))
            parameterType=SOAPCallParameter.DATAHANDLERDOCUMENT_PARAM;
        else if(el.getNodeName().equals("TrainignCodeParameter"))
            parameterType=SOAPCallParameter.TRAININGCODE_PARAM;
		else if(el.getNodeName().equals("ConstantParameter")){
            parameterType=SOAPCallParameter.CONSTANT_PARAM;
			constantValue=el.getAttribute("value");
		}
		
        //get name
        parameterName=el.getAttribute("name");
    }
	/**
	* constructor giving the parameter directly
	**/
	public SOAPCallParameter(int parameterType, String parameterName){
		this.parameterType=parameterType;
		this.parameterName=parameterName;
	}
	public SOAPCallParameter(int parameterType, String parameterName, String constantValue){
		this.parameterType=parameterType;
		this.parameterName=parameterName;
		this.constantValue=constantValue;
	}	
	
    
    public int getParameterType(){
        return parameterType;
    }
    public String getParameterName(){
        return parameterName;
    }
	public String getConstantValue(){
		return constantValue;
	}

    public String toString() {
        String s="";
        if(this.parameterType==USER_PARAM)
            s="User Parameter";
        else if(this.parameterType==PASSWORD_PARAM)
            s="Password Parameter";
        else if(this.parameterType==STRINGDOCUMENT_PARAM)
            s="String Document Parameter";
        else if(this.parameterType==DATAHANDLERDOCUMENT_PARAM)
            s="DataHandler Document Parameter";
        else if(this.parameterType==TRAININGCODE_PARAM)
            s="Training Code Parameter";
        else if(this.parameterType==CONSTANT_PARAM)
            s="Constant Parameter, value="+this.getConstantValue();		
        s=s+" , parameter name="+this.getParameterName();
        return s;
    }
}
