// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;

import apostal.toma.TOMA;
import apostal.toma.XMLHelper;
import apostal.toma.data.*;
import apostal.toma.database.StandaloneTrainingDB;
import apostal.toma.external.tedtoma.TedTomaConversion;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAFonts;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.File;
import java.util.Iterator;
import java.util.Vector;

public class SOAPDeletePublication extends Publication{
	
    private SyrecosLogin syrecosLogin;
    private TOMALabels labels;
    private PublicationUnit publicationUnit;
    private SOAPClient client;    
    private Vector warnings;
    private String messages;
    private boolean result;
    private Vector callParameters;	
	
	private Vector trainingsToDelete=new Vector();
	
	public SOAPDeletePublication(PublicationUnit publicationUnit){
		super(publicationUnit);
	}
	public SOAPDeletePublication(SyrecosLogin syrecosLogin, PublicationUnit publicationUnit)
    {
		super(publicationUnit);
		this.syrecosLogin=syrecosLogin;
		this.publicationUnit=publicationUnit;
      	labels=new TOMALabels();
    }
	
/**
 * this methods reads the properties file and creates the SOAPClient
 **/
	public void preparePublication()
	{
		//read the properties file
		String url=null;
		String target=null;
		String method=null;
		String soapAction=null;
	      DocumentBuilder docBuilder = null;
        	try {
			
			String propsFile=publicationUnit.getPropertiesFile();
			TOMA.log(TOMA.ALL, "SOAP properties file: "+propsFile);
			
            DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
            docBuilder = docBuilderFactory.newDocumentBuilder();
            Document doc = docBuilder.parse(propsFile);
            doc.getDocumentElement().normalize();
            
            Element webServices=doc.getDocumentElement();
            if(webServices!=null)
            {
            	NodeList list=webServices.getElementsByTagName("DeleteTrainingWebService");
            	if(list!=null && list.getLength()>0)
            	{
		            Element encodingWebService=(Element) list.item(0);
    		                               
		            if(encodingWebService!=null)
        		    {
            			url=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "URL");
		            	target=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Target");
        		    	method=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Method");                        
						soapAction=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "SOAPAction");
						
                        //get parameters
                        Element paramsEl=XMLHelper.getSingleElementByTagName(encodingWebService, "CallParameters");
                        if(paramsEl!=null){                            
                            //get the parameters
                            callParameters=new Vector();
                            NodeList params=paramsEl.getChildNodes();
                            int nb=params.getLength();
                            for(int i=0;i<nb;i++){
                                Node n=params.item(i);
                                if(n.getNodeType()==Node.ELEMENT_NODE){
                                    SOAPCallParameter param=new SOAPCallParameter((Element) n);
                                    callParameters.add(param);
                                }
                            }
                        }
		            }            
            	}
            }
        }
        catch (Exception ex){
            TOMA.log(TOMA.SEVERE, "Exception while reading the result from SOAPDeletePublication");
            TOMA.log(ex);
            TOMAError error=new TOMAError(labels.get("apostal.toma.external.soap.propertiesFileProblem"), labels.get("apostal.toma.external.soap "));
            return;
        }		
      
      	client=new SOAPClient(url, target, method, soapAction);		
      	TOMA.log(TOMA.WARNING, "SOAPClient created with: url="+url+", target="+target+", method="+method+", soapAction="+soapAction);
	}	
	
	/**
	redefine publish method to call the "delete" web service
	**/
	public void publishXML(boolean addFirstCat)
    {
      TOMA.log(TOMA.ALL, "SOAPDeletePublication: debut publish");
	  
      trainingsToDelete=this.getTrainingToPublish(publicationUnit);
	}
	
 /**
     * make the SOAP call
     */
    public void publish()
    {
       if(client!=null && syrecosLogin!=null)
       {
		   messages=TOMAFonts.htmlBegin+labels.get("apostal.toma.external.soapDelete.result")+"<BR>";
		   result=true;
		   
		   //for each training
		   Iterator it=trainingsToDelete.iterator();
		   while(it.hasNext()){
			   Training t=(Training) it.next();	   
			   
			   //call delete
			   boolean aResult=client.deleteATraining(syrecosLogin.getLogin(), syrecosLogin.getPassword(), t.getCode(), callParameters);
			   
			   //interpret result			   
			   messages=messages+"<p>"+labels.get("apostal.toma.external.soapDelete.deleteTraining")+" '"+t.getTitle()+"' ("+labels.get("apostal.toma.trainingview.code")+"="+t.getCode()+"): ";
			   if(aResult)
				   messages=messages+" "+labels.get("apostal.toma.external.soapDelete.trainingDeleted")+"</p>";
			   else{
				   messages=messages+" "+labels.get("apostal.toma.external.soapDelete.trainingNotDeleted")+"</p>";
				   result=false;
			   }
		   }
		   messages=messages+TOMAFonts.htmlEnd;
	   }
	   else
       {
        	if(client==null)
            	TOMA.log(TOMA.SEVERE, "SOAPDeletePublication.publish, SOAPClient=null");
	        else if(syrecosLogin==null)
    	        TOMA.log(TOMA.SEVERE, "SOAPDeletePublication.publish, syrecosLogin=null");
       }	   
	}

	public String getMessages()
    {
    	return messages;
    }
    public boolean getResult()
    {
    	return result;
    }	
}
