// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external;

import apostal.toma.TOMA;
import apostal.toma.XMLHelper;
import apostal.toma.data.TOMAConstants;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAError;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import java.io.File;

public class SOAPExtraction
{
	private TOMALabels labels;
	private String _login;
	private String _pwd;
	private String _filename;
	private SOAPClient client;
	
	public SOAPExtraction(String login, String pwd, String filename)
	{
		this._login=login;
		this._pwd=pwd;
		this._filename=filename;
		labels=new TOMALabels();
		
		this.prepareExtraction();
	}
	
	/**
	* this methods reads the properties file and creates the SOAPClient
	**/
	public void prepareExtraction()
	{
		//read the properties file
		String url=null;
		String target=null;
		String method=null;
		DocumentBuilder docBuilder = null;
        	try {
			DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
			docBuilder = docBuilderFactory.newDocumentBuilder();
			Document doc = docBuilder.parse(TOMAConstants.propertiesFileSOAP);
			doc.getDocumentElement().normalize();
			
			Element webServices=doc.getDocumentElement();
			
			if(webServices!=null)
			{
				NodeList list=webServices.getElementsByTagName("ExtractionWebService");
				if(list!=null && list.getLength()>0)
				{
					Element extractionWebService=(Element) list.item(0);
					
					if(extractionWebService!=null)
					{
						url=XMLHelper.getSingleTextualElementValueByTagName(extractionWebService, "URL");
						target=XMLHelper.getSingleTextualElementValueByTagName(extractionWebService, "Target");
						method=XMLHelper.getSingleTextualElementValueByTagName(extractionWebService, "Method");
					}            
				}
			}
		}
		catch (Exception ex)
		{
			TOMA.log(TOMA.SEVERE, "Exception while reading the result from SOAPPublication");
			TOMAError error=new TOMAError(labels.get("apostal.toma.external.soap.propertiesFileProblem"), labels.get("apostal.toma.external.soap "));
		}		
		client=new SOAPClient(url, target, method);	
		TOMA.log(TOMA.WARNING, "SOAPClient created with: url="+url+", target="+target+", method="+method);
	}
	
	public boolean extract()
	{
		boolean ok=false;
		if(client!=null && _login!=null)
		{
			ok=client.extract(_login, _pwd, _filename);		
			TOMA.log(TOMA.WARNING, "extraction effectu�e, ok="+ok);
		}
		else if(client==null)
			TOMA.log(TOMA.SEVERE, "SOAPExtration.extract, SOAPEncodingClient=null");
		else if(_login==null)
			TOMA.log(TOMA.SEVERE, "SOAPExtration.extract, login=null");
		
		return ok;
	}    
}
