package apostal.toma.external;

/**
 * @author sof
 * date: Sep 23, 2002
 */
import apostal.toma.TOMA;
import apostal.toma.XMLHelper;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAFonts;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.File;

public class SOAPMessageDecoder {

	private TOMALabels labels;
	private Element encoding;

	public SOAPMessageDecoder(File f)
	{
		if(f!=null)
		{		
		    //read the log
		    DocumentBuilder docBuilder = null;
        	try {
        	    DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
        	    docBuilder = docBuilderFactory.newDocumentBuilder();
        	    Document doc = docBuilder.parse(f);
        	    doc.getDocumentElement().normalize();
        	    encoding=doc.getDocumentElement();            
        	}
        	catch (Exception ex)
            {
				TOMA.log(TOMA.SEVERE, "Exception while reading the result from SOAPPublication");
            }
		}
		    
         //open the labels
         labels=new TOMALabels();         
	} 
	
	public boolean getResult()
	{
		boolean ok=false;
	
		if(encoding!=null)
		{
			String r=XMLHelper.getSingleTextualElementValueByTagName(encoding, "Result");
			if(r!=null && r.equals("true"))
				ok=true;
		}
		
		return ok;
	}

	public String getMessages()
	{
		String message=TOMAFonts.htmlBegin;
		
		if(encoding!=null)
		{
			Element userError=XMLHelper.getSingleElementByTagName(encoding, "UserError");
			NodeList list=encoding.getElementsByTagName("MissingElement");			
			int length=list.getLength();
			if(userError!=null || length>0)
			{
				message=message+labels.get("apostal.toma.external.soap.problem");;
			}
			else if(!this.getResult())
			{
			//no error but result=false
				message=message+labels.get("apostal.toma.external.soap.error.unknownError");
			}
			else
				message=message+labels.get("apostal.toma.external.soap.ok");
			
			message=message+"<BR/>";	
			
			if(userError!=null || length>0)
			{
				message=message+"<UL>";
				
				//user rights
				if(userError!=null)
				{			
					String login=XMLHelper.getSingleTextualElementValueByTagName(userError, "Login");
					String pwd=XMLHelper.getSingleTextualElementValueByTagName(userError, "Password");
				
					//build the message
					message=message+"<LI>"+labels.get("apostal.toma.external.soap.userproblem");		
				}
		
				//missing elements
				for(int i=0;i<length;i++)
				{
					Element missingElement=(Element) list.item(i);
					String elName=XMLHelper.getSingleTextualElementValueByTagName(missingElement, "ElementName");
					String pName=XMLHelper.getSingleTextualElementValueByTagName(missingElement, "ParentName");
					String pIdName=XMLHelper.getSingleTextualElementValueByTagName(missingElement, "ParentIdName");
					String pIdValue=XMLHelper.getSingleTextualElementValueByTagName(missingElement, "ParentIdValue");
					
					//build the message
					message=message+"<LI>"+labels.get("apostal.toma.external.soap.missingElement")+" "+elName+" "+labels.get("apostal.toma.external.soap.parentName")+" "+pName+" "+labels.get("apostal.toma.external.soap.idName")+" "+pIdName+" "+labels.get("apostal.toma.external.soap.idValue")+" "+pIdValue;
				}

				message=message+"</UL>";
			}
			////////// WARNINGS ////////////

			//too large column
			list=encoding.getElementsByTagName("TooLargeColumn");
			length=list.getLength();
			
			if(length>0)
			{
				message=message+"<BR/>"+labels.get("apostal.toma.external.soap.warning")+"<UL>";
			
			for(int i=0;i<length;i++)
			{			
				Element tooLarge=(Element) list.item(i);
				String elName=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ElementName");
				String elValue=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ElementValue");
				String elSize=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ElementSize");				
				String elMaxSize=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ElementMaxSize");				
				String pName=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ParentName");
				String pIdName=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ParentIdName");
				String pIdValue=XMLHelper.getSingleTextualElementValueByTagName(tooLarge, "ParentIdValue");
				
				//build the message
				message=message+"<LI>"+labels.get("apostal.toma.external.soap.tooLargeElement")+"<BR/>"+labels.get("apostal.toma.external.soap.elementName")+" "+elName+" "+labels.get("apostal.toma.external.soap.elementValue")+"<BR/><I>"+elValue+"</I><BR/>"+labels.get("apostal.toma.external.soap.parentName")+" "+pName+" "+labels.get("apostal.toma.external.soap.idName")+" "+pIdName+" "+labels.get("apostal.toma.external.soap.idValue")+" "+pIdValue+" "+labels.get("apostal.toma.external.soap.maxSize")+" "+elMaxSize+" "+labels.get("apostal.toma.external.soap.size")+" "+elSize;
			}
				message=message+"</UL>";
			}
		}
		else
			message=message+labels.get("apostal.toma.external.soap.error.unknownError");
					
		message=message+TOMAFonts.htmlEnd;
					
		return message;
	}
    
    public String getSimpleMessage(boolean result){
        //get a simplified message based only on the value of "result
        String message=TOMAFonts.htmlBegin;
        
        if(result)
            message=message+labels.get("apostal.toma.external.soap.ok");
        else
            message=message+labels.get("apostal.toma.external.soap.error.unknownError");        
        
        message=message+TOMAFonts.htmlEnd;
        
        return message;
    }
}
