// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;

import apostal.toma.TOMA;
import apostal.toma.XMLHelper;
import apostal.toma.data.*;
import apostal.toma.database.StandaloneTrainingDB;
import apostal.toma.external.tedtoma.TedTomaConversion;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAFonts;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.File;
import java.util.Iterator;
import java.util.Vector;

public class SOAPPublication extends Publication
{
    private SyrecosLogin syrecosLogin;
    private TOMALabels labels;
    private PublicationUnit publicationUnit;
    private SOAPClient client;    
    private Vector warnings;
    private String messages;
    private boolean result;
    
    private Vector callParameters;
    private boolean booleanResult;
    private Element xslTransformationPropertyElement;
	
	public SOAPPublication(PublicationUnit publicationUnit){
		super(publicationUnit);
	}

    public SOAPPublication(SyrecosLogin syrecosLogin, PublicationUnit publicationUnit)
    {
      super(publicationUnit);
      this.syrecosLogin=syrecosLogin;
      this.publicationUnit=publicationUnit;
      labels=new TOMALabels();
    }

    public Vector getTrainings()
    {
      return publicationUnit.getTrainings();
    }

/**
 * this methods reads the properties file and creates the SOAPClient
 **/
	public void preparePublication()
	{
		//read the properties file
		String url=null;
		String target=null;
		String method=null;
		String soapAction=null;
	      DocumentBuilder docBuilder = null;
        	try {
			
			String propsFile=publicationUnit.getPropertiesFile();
			TOMA.log(TOMA.ALL, "SOAP properties file: "+propsFile);
			
            DocumentBuilderFactory docBuilderFactory=DocumentBuilderFactory.newInstance();
            docBuilder = docBuilderFactory.newDocumentBuilder();
            Document doc = docBuilder.parse(propsFile);
            doc.getDocumentElement().normalize();
            
            Element webServices=doc.getDocumentElement();
            if(webServices!=null)
            {
            	NodeList list=webServices.getElementsByTagName("EncodingWebService");
            	if(list!=null && list.getLength()>0)
            	{
		            Element encodingWebService=(Element) list.item(0);
    		                               
		            if(encodingWebService!=null)
        		    {
            			url=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "URL");
		            	target=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Target");
        		    	method=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "Method");                        
						soapAction=XMLHelper.getSingleTextualElementValueByTagName(encodingWebService, "SOAPAction");
						
                        //get parameters
                        Element paramsEl=XMLHelper.getSingleElementByTagName(encodingWebService, "CallParameters");
                        booleanResult=false;
                        if(paramsEl!=null){
                            //get the return type
                            String returnType=paramsEl.getAttribute("returnType");
                            if(returnType!=null && returnType.equals("boolean"))
                                booleanResult=true;
                            
                            //get the parameters
                            callParameters=new Vector();
                            NodeList params=paramsEl.getChildNodes();
                            int nb=params.getLength();
                            for(int i=0;i<nb;i++){
                                Node n=params.item(i);
                                if(n.getNodeType()==Node.ELEMENT_NODE){
                                    SOAPCallParameter param=new SOAPCallParameter((Element) n);
                                    callParameters.add(param);
                                }
                            }
                        }
                        
                        //check if an XSL transformation is asked
                        Element xslTransfo=XMLHelper.getSingleElementByTagName(encodingWebService, "XSLTransformation");
                        if(xslTransfo!=null){
                            xslTransformationPropertyElement=xslTransfo;
                        }
		            }            
            	}
            }
        }
        catch (Exception ex){
            TOMA.log(TOMA.SEVERE, "Exception while reading the result from SOAPPublication");
            TOMA.log(ex);
            TOMAError error=new TOMAError(labels.get("apostal.toma.external.soap.propertiesFileProblem"), labels.get("apostal.toma.external.soap "));
            return;
        }		
      
      	client=new SOAPClient(url, target, method, soapAction);		
      	TOMA.log(TOMA.WARNING, "SOAPClient created with: url="+url+", target="+target+", method="+method+", soapAction="+soapAction);
	}

    /**
     * gets the XML
     * + make the eventual transformation if needed
     * This method is called before publish
     * @param addFirstCat
     */
    public void publishXML(boolean addFirstCat)
    {
      TOMA.log(TOMA.ALL, "SOAPPublication: debut publish");

      Language lng=publicationUnit.getLanguage();
      Vector trainings=this.getTrainings();
      Vector tr=this.getTrainingToPublish(publicationUnit);
      this.checkCompliance(publicationUnit);      
      warnings=TedTomaConversion.getErrors();
      
      this.generateTedXML(TOMAConstants.temporaryXMLFile,addFirstCat, false);
      TOMA.log(TOMA.WARNING, "fichier XML écrit");
      
      //eventually make an XSL transformation
      if(xslTransformationPropertyElement!=null){          
          TOMA.log(TOMA.ALL, "SOAPPublication: doing an XSL transformation at the same time");          
          GenericXSLPublication xslPub=new GenericXSLPublication(publicationUnit);          
          xslPub.makeXSLTransformation(TOMAConstants.temporaryXMLFile, TOMAConstants.temporaryXMLFile, xslTransformationPropertyElement);
      }
      
      if(warnings!=null && !warnings.isEmpty())
		TOMA.log(TOMA.WARNING, "il y a eu des problèmes XML");
      else
		TOMA.log(TOMA.WARNING, "pas de pb XML");
    }

    /**
     * make the SOAP call
     */
    public void publish()
    {
       if(client!=null && syrecosLogin!=null)
       {
          if(booleanResult){
              //boolean result
              result=client.deleteAndEncodeBoolean(syrecosLogin.getLogin(), syrecosLogin.getPassword(), TOMAConstants.temporaryXMLFile, callParameters);
              
              SOAPMessageDecoder decoder=new SOAPMessageDecoder(null);
              messages=decoder.getSimpleMessage(result);
          }
          else{ //File result           
              File log=client.deleteAndEncode(syrecosLogin.getLogin(), syrecosLogin.getPassword(), TOMAConstants.temporaryXMLFile, callParameters);		
              TOMA.log(TOMA.WARNING, "transfo effectuée");
		  
              SOAPMessageDecoder decoder=new SOAPMessageDecoder(log);
              messages=decoder.getMessages();
              result=decoder.getResult();
          }
       }
       else
       {
        	if(client==null)
            	TOMA.log(TOMA.SEVERE, "SOAPPublication.publish, SOAPClient=null");
	        else if(syrecosLogin==null)
    	        TOMA.log(TOMA.SEVERE, "SOAPPublication.publish, syrecosLogin=null");
       }
    }

    public Vector getXMLWarnings()
    {
      return warnings;
    }
    
    public String getMessages()
    {
    	return messages;
    }
    public boolean getResult()
    {
    	return result;
    }

    /**
     * @returns a table with:
     * on the first position, the trainings that do not have a domain
     * on the second position, the sessions that do not have a language
     */
    public Vector[] getWarnings(Vector trainings)
    {
      Vector[] result=new Vector[2];        
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

      //transformer le vecteur de trainingPublished en vecteur d'id
      if(trainings!=null)
      {     
        Vector idtrainings=new Vector();
        Iterator it=trainings.iterator();
        while(it.hasNext())
        {
            TrainingPublished t=(TrainingPublished) it.next();
            idtrainings.add(new Integer(t.getIdTraining()));
        }          
          
      Vector domains_warnings=StandaloneTrainingDB.getTrainingsWithoutDomains(lng, idtrainings);
      Vector languages_warnings=StandaloneTrainingDB.getSessionsWithoutLanguage(lng, labels.get("apostal.toma.external.syrecos.identifyTraining"), idtrainings);           
                        
      result[0]=domains_warnings;
      result[1]=languages_warnings;
      }
      return result;
    }
}
