// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;

import apostal.toma.data.TOMAConstants;
import org.apache.soap.Constants;
import org.apache.soap.rpc.Call;
import org.apache.soap.rpc.Parameter;
import org.apache.soap.rpc.Response;

import javax.activation.DataHandler;
import javax.activation.DataSource;
import javax.activation.FileDataSource;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.Vector;
/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class SyrecosEncodingClient
{
  public SyrecosEncodingClient()
  {
  }

  /**
   * encodes the file "filename" into syrecos, for the user & pwd provided.
   * @returns the message if there was no error or a software error, null otherwise
   */
  public String deleteAndEncode(String user, String pwd, String filename)
  {
    String s=null;
    try{
    Call call=new Call();

    //target
    String target=TOMAConstants.syrecosEncodingTarget;
    call.setTargetObjectURI(target);

    //method
    String method=TOMAConstants.syrecosEncodingMethod;
    call.setMethodName(method);

    //parameters
    Vector params=new Vector();

    String encoding=Constants.NS_URI_SOAP_ENC;

    Parameter userParam=new Parameter("user", String.class, user, encoding);
    params.add(userParam);
    Parameter pwdParam=new Parameter("pwd", String.class, pwd, encoding);
    params.add(pwdParam);

    FileDataSource data=new FileDataSource(filename);
    Parameter dataParam=new Parameter("data", DataSource.class , data, encoding);
    params.add(dataParam);

    call.setParams(params);

    //invocation
    URL router=new URL(TOMAConstants.syrecosURL);
    Response response=call.invoke(router, target);

    //rcupration du rsultat
    if(response.generatedFault())
    {
      s=null;
    }
    else //a a march
    {
      Parameter param=response.getReturnValue();
      if(param!=null)
      {
	  s=(String) param.getValue();
	  if(s==null || s.equals(""))
	    s="ok";
      }
    }

    }catch(java.lang.Exception ex)
    {
      ex.printStackTrace();
      s=null;
    }

    return s;
  }

  public Vector testEncoding(String user, String pwd, String filename)
  {
    Vector v=new Vector();
    try{
    Call call=new Call();

    //target
    String target=TOMAConstants.syrecosEncodingTarget;
    call.setTargetObjectURI(target);

    //method
    String method=TOMAConstants.syrecosEncodingTestMethod;
    call.setMethodName(method);

    //parameters
    Vector params=new Vector();

    String encoding=Constants.NS_URI_SOAP_ENC;

    Parameter userParam=new Parameter("user", String.class, user, encoding);
    params.add(userParam);
    Parameter pwdParam=new Parameter("pwd", String.class, pwd, encoding);
    params.add(pwdParam);

    FileDataSource data=new FileDataSource(filename);
    Parameter dataParam=new Parameter("data", DataSource.class , data, encoding);
    params.add(dataParam);

    call.setParams(params);

    //invocation
    URL router=new URL(TOMAConstants.syrecosURL);
    Response response=call.invoke(router, target);

    //rcupration du rsultat
    if(response.generatedFault())
    {
      v.add("SOAP.problem");
      /*javax.mail.BodyPart part=response.getBodyPart(0);
      System.out.println("content="+part.getContent());*/
	try
            {
                java.io.FileWriter writer=new java.io.FileWriter("soap_error");
                writer.write("Response: "+response.toString()+"\n");

                org.apache.soap.Fault f=response.getFault();
                writer.write("Fault: "+f.toString()+"\n");
                writer.write("Fault string: "+f.getFaultString()+"\n");

                writer.flush();
                writer.close();
            }
        catch(Exception e)
            {
                e.printStackTrace();
            }
    }
    else //a a march
    {
      Parameter param=response.getReturnValue();
      if(param!=null)
      {
	DataHandler handler=(DataHandler) param.getValue();
	InputStream in=handler.getInputStream();
	InputStreamReader reader=new InputStreamReader(in);
	BufferedReader r=new BufferedReader(reader);
	String line=null;
	do
	{
	  line=r.readLine();
	  if(line!=null)
	    v.add(line);
	}
	while(line!=null);
      }
    }

    }catch(java.lang.Exception ex)
    {
      ex.printStackTrace();
      v.add("SyrecosEncodingClient.problem");
    }

    return v;
  }
}
