// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import apostal.toma.TOMA;
import apostal.toma.data.*;
import apostal.toma.database.SessionDB;
import apostal.toma.database.TrainingDB;
import apostal.toma.database.TrainingProgrammeDB;

import java.util.StringTokenizer;

public class SyrecosMessageDecoder
{
  private TOMALabels labels;

  //types de messages possibles
  public final static int LOADXML=0;
  public final static int TEDTOSYRECOS=1;
  public final static int ROLLBACK=2;
  public final static int FINISHED=3;
  public final static int CHECKUSER=4;
  public final static int DROIT=5;
  public final static int VALEUR=6;
  public final static int IDSEC=7;
  public final static int IDENTIFICATION=8;
  public final static int NOM=9;
  public final static int UNKNOWN=10;

  public SyrecosMessageDecoder()
  {
    labels=new TOMALabels();
  }

  public int getMessageType(String line)
  {
	String message="";
	int type=SyrecosMessageDecoder.UNKNOWN;
	if(line!=null && !line.equals(""))
	    {
		int debut=line.indexOf("INFO: ");
		message=line.substring(debut+6);
	    	//on obtient plus que le message

		String[] noms=this.getNomsMessage(message);
		String[] arguments=this.getArgumentsMessage(message);
		int nb_noms=noms.length;
		int nb_args=arguments.length;

		String result="";
		StringTokenizer tokenizer=new StringTokenizer(message, ".");

		if(nb_noms>0)
		{
		  if(noms[0].equals("LoadXML"))
		      type=SyrecosMessageDecoder.LOADXML;
		  else if(noms[0].equals("TedToSyrecos"))
		      type=SyrecosMessageDecoder.TEDTOSYRECOS;
		  else if(noms[0].equals("SaveData"))
		  {
		    if(noms[1].equals("Finished"))
		      type=SyrecosMessageDecoder.FINISHED;
		    else if(noms[1].equals("Rollback"))
		      type=SyrecosMessageDecoder.ROLLBACK;
		    else if(noms[1].equals("CheckUser"))
		      type=SyrecosMessageDecoder.CHECKUSER;
		    else if(noms[1].equals("Droit"))
		      type=SyrecosMessageDecoder.DROIT;
		    else if(noms[1].equals("Valeur"))
		      type=SyrecosMessageDecoder.VALEUR;
		    else if(noms[1].equals("Idsec"))
		      type=SyrecosMessageDecoder.IDSEC;
		    else if(noms[1].equals("IdentificationElement"))
		      type=SyrecosMessageDecoder.IDENTIFICATION;
		    else if(noms[1].equals("NomElement"))
		      type=SyrecosMessageDecoder.NOM;
		  }
		}
	    }
	return type;
  }

    public String decode(String line)
    {
	String result="";
	if(line!=null && !line.equals(""))
	    {
		int debut=line.indexOf("INFO: ");
		result=line.substring(debut+6);
	    	//on obtient plus que le message

		result=this.decodeMessage(result);
	    }

	return result;
    }

    public String decodeMessage(String message)
    {
	String[] noms=this.getNomsMessage(message);
	String[] arguments=this.getArgumentsMessage(message);

	int nb_noms=noms.length;
	int nb_args=arguments.length;

	String result="";
	StringTokenizer tokenizer=new StringTokenizer(message, ".");

	if(nb_noms>0)
	    {
		if(noms[0].equals("LoadXML"))
		    {
			if(nb_noms>1)
			    {
				if(noms[1].equals("Parser"))
				    {
					//result="The training could not be saved due to a problem on the server";
					result=labels.get("apostal.toma.external.syrecos.serverproblem");
				    }
				else if(noms[1].equals("API"))
				    {
					//result="The training could not be saved due to a problem on the server";
					result=labels.get("apostal.toma.external.syrecos.serverproblem");
				    }
				else if(noms[1].equals("Validation"))
				    {
					if(nb_args>0)
					    {
						//result="The XML file contained an error: "+arguments[0];
						result=labels.get("apostal.toma.external.syrecos.xmlproblem")+arguments[0];
					    }
				    }
			    }
		    }
		else if(noms[0].equals("TedToSyrecos"))
		    {
			if(nb_noms>1)
			    {
				if(noms[1].equals("Mapping"))
				    {
					//result="The training could not be saved due to a problem on the server";
					result=labels.get("apostal.toma.external.syrecos.serverproblem");
				    }
			    }
		    }
		else if(noms[0].equals("SaveData"))
		    {
			if(nb_noms>1)
			    {
				/*if(noms[1].equals("Finished"))
				    {
					//result="The training has been saved on Syrecos";
					result=labels.get("apostal.toma.external.syrecos.finished");
				    }
				else if(noms[1].equals("Rollback"))
				    {
					//result="There was a problem during the saving. Please correct the training and try again";
					result=labels.get("apostal.toma.external.syrecos.rollback");
				    }
				else */if(noms[1].equals("CheckUser"))
				    {
					if(nb_noms>2)
					    {
						if(noms[2].equals("Rights"))
						    {
							//result="You do not have the rights to perform this operation. Please login as a different user or ask an administrator to change your rights.";
							result=labels.get("apostal.toma.external.syrecos.userrights");
						    }
						else
						    {
							//result="You have supplied an incorrect user. Please login as a different user";
							result=labels.get("apostal.toma.external.syrecos.userproblem");
						    }
					    }
				    }

				else if(noms[1].equals("Droit"))
				    {
					if(nb_noms>2 && nb_args>0)
					    {
						String classe=this.decodeClassName((String) noms[2]);
						String objet=(String) arguments[0];

						//result="You do not have the rights to save an object of type "+classe+" (object "+objet+")";
						result=labels.get("apostal.toma.external.syrecos.rights")+classe+" ("+objet+")";
					    }
				    }
				else if(noms[1].equals("Valeur"))
				    {
					if(nb_noms>3 && nb_args>0)
					    {
						String classe=this.decodeClassName((String) noms[2]);
						String champ=this.decodeFieldName((String) noms[2], (String) noms[3]);
						String objet=(String) arguments[0];
						if(nb_args>1)
						    {
							String s=(String) arguments[0];

							//String max=(String) arguments[length-1];
							String max=(String) this.getLastNotNullElement(arguments);
							//result=labels.get("apostal.toma.external.syrecos.problemwithfield")+"\""+champ+"\" : "+labels.get("apostal.toma.external.syrecos.problemvaluewithmax")+" ("+max+")";
							result=labels.get("apostal.toma.external.syrecos.problemwithfield")+"\""+champ+"\" : "+labels.get("apostal.toma.external.syrecos.problemvaluewithmax")+" ("+labels.get("apostal.toma.external.syrecos.max")+max+")";
						    }
						else
						    {
							result=labels.get("apostal.toma.external.syrecos.problemwithfield")+"\""+champ+"\" : "+labels.get("apostal.toma.external.syrecos.problemvalue");
						    }
					    }
				    }
				else if(noms[1].equals("Idsec"))
				    {
					if(nb_noms>2)
					    {
						String classe_init=(String) noms[2];
						String classe=this.decodeClassName(classe_init);
						//result="There is a problem with an element of type "+classe+" (for the field "+MessageDecoder.getIdsecName(classe_init)+"): this value already exists in the database. Please choose another one.";
						result=labels.get("apostal.toma.external.syrecos.problemwithclass")+classe+" ("+labels.get("apostal.toma.external.syrecos.problemwithfield")+this.getIdsecName(classe_init)+")"+labels.get("apostal.toma.external.syrecos.idsec");
					    }
				    }
				else if(noms[1].equals("IdentificationElement"))
				    {
					result=this.decodeIdentification(noms[2], this.getAllArgumentsMessage(message));
				    }
				else if(noms[1].equals("NomElement"))
				    {
					result=this.decodeNom(noms[2], this.getAllArgumentsMessage(message));
				    }
			    }
		    }
	    }

	return result;
    }

    public String decodeNom(String classe, String valeur)
    {
      String result="";
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

      if(classe.equals("Formation"))
      {
	result=labels.get("apostal.toma.external.syrecos.identifyTraining")+"\""+valeur+"\"";
      }
      else if(classe.equals("Animateur"))
      {
	result=labels.get("apostal.toma.external.syrecos.identifyTeacher")+"\""+valeur+"\"";
      }
      else if(classe.equals("Lieu"))
      {
	result=labels.get("apostal.toma.external.syrecos.identifyLocation")+"\""+valeur+"\"";
      }
      else if(classe.equals("Cat1") || classe.equals("Cat2") || classe.equals("Cat3"))
      {
	result=labels.get("apostal.toma.external.syrecos.identifyCatalogue")+"\""+valeur+"\"";
      }
      else if(classe.equals("Sessmod") || classe.equals("Sesscycle"))
      {
	  result=result+labels.get("apostal.toma.external.syrecos.identifySession")+"\""+valeur+"\"";
      }
      else if(classe.equals("Persref"))
      {
	result=labels.get("apostal.toma.external.syrecos.identifyPersref")+"\""+valeur+"\"";
      }

      return result;
    }

    public String decodeIdentification(String classe, String valeur)
    {
      String result="";
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

      if(classe.equals("Formation"))
      //ne faire qqchose que si c'est un unit
      {
	String code=valeur;
	Training t=TrainingDB.getInstance(lng, true, code);
	//true car il faut charger l'idProgramme

	if(t!=null)
	{
	  String className=t.getClass().getName();
	  if(className.equals("apostal.toma.data.Unit"))
	  {
	    Unit u=(Unit) t;
	    int idp=u.getIdProgramme();
	    TrainingProgramme tp=new TrainingProgramme(idp);
	    TrainingProgrammeDB tpdb=new TrainingProgrammeDB(tp);
	    tpdb.loadById(lng, false);
	    result=" "+labels.get("apostal.toma.external.syrecos.identifyUnit2")+"\""+tp.toString()+"\"";
	  }
	}

      }
      /*else if(classe.equals("Animateur"))
      {
        String nom=valeurs[0];
        String prenom=valeurs[1];
        String fonction=valeurs[2];

	Teacher t=new Teacher();
	t.setLastname(nom);
	t.setFirstname(prenom);
	t.setFunction(fonction);
	TeacherDB tdb=new TeacherDB(t);
	tdb.loadByFirstnameLastnameFunction(lng, false);

	result=labels.get("apostal.toma.external.syrecos.identifyTeacher")+"\""+t.toString()+"\"";
      }
      else if(classe.equals("Lieu"))
      {
        String denom=valeurs[0];

	Location l=new Location();
	l.setDenomination(denom);
	LocationDB ldb=new LocationDB(l);
	ldb.loadByDenomination(lng, false);

	result=labels.get("apostal.toma.external.syrecos.identifyLocation")+"\""+l.toString()+"\"";
      }
      else if(classe.equals("Cat1") || classe.equals("Cat2") || classe.equals("Cat3"))
      {
        String titre=valeurs[0];

	Catalogue c=new Catalogue();
	c.setTitle(titre);
	CatalogueDB cdb=new CatalogueDB(c);
	cdb.loadByTitle(lng, false);

	result=labels.get("apostal.toma.external.syrecos.identifyCatalogue")+"\""+c.toString()+"\"";
      }*/
      else if(classe.equals("Sessmod") || classe.equals("Sesscycle"))
      //prciser la formation, et meme le cycle dans le cas d'un unitSession
      {
        String name=valeur;

	Session s=SessionDB.getInstance(lng, true, name);
	//true car il faut charger idTraining

	if(s!=null)
	{
	int id=s.getIdTraining();

	String className=s.getClass().getName();
	if(className.equals("apostal.toma.data.CourseSession"))
	{
	  //identifier le tc
	  Training t=TrainingDB.getInstance(lng, false, id);
	  result=" "+labels.get("apostal.toma.external.syrecos.identifyCourseSession2")+"\""+t.toString()+"\"";
	}
	else if(className.equals("apostal.toma.data.UnitSession"))
	{
	  //identifier le unit
	  Training t=TrainingDB.getInstance(lng, true, id);
	  //true car il faut charger idProgramme
	  result=" "+labels.get("apostal.toma.external.syrecos.identifyUnitSession2")+"\""+t.toString()+"\" ";

	  //identifier le tp
	  Unit u=(Unit) t;
	  int idp=u.getIdProgramme();
	  TrainingProgramme tp=new TrainingProgramme(idp);
	  TrainingProgrammeDB tpdb=new TrainingProgrammeDB(tp);
	  tpdb.loadById(lng, false);
	  result=result+labels.get("apostal.toma.external.syrecos.identifyUnitSession3")+"\""+tp.toString()+"\"";
	}
	else if(className.equals("apostal.toma.data.ProgrammeSession"))
	{
	  //retrouver le tp
	  Training t=TrainingDB.getInstance(lng, false, id);
	  result=" "+labels.get("apostal.toma.external.syrecos.identifySesscycle2")+"\""+t.toString()+"\"";
	}
	}
      }
      /*else if(classe.equals("Persref"))
      {
        String login=valeurs[0];

	//todo: redcouper:nom (30) + prenom (30) + numtel (30) + email (60)
	if(login.length()>=150)
	{
	String lastname=login.substring(0, 30);
	lastname=lastname.trim();
	String firstname=login.substring(30, 60);
	firstname=firstname.trim();
	String tel=login.substring(60, 90);
	tel=tel.trim();
	String email=login.substring(90, 150);
	email=email.trim();

	Contact c=new Contact();
	c.setFirstname(firstname);
	c.setLastname(lastname);
	c.setTel(tel);
	c.setEmail(email);
	ContactDB cdb=new ContactDB(c);
	cdb.loadByFirstnameLastnameTelEmail(lng, false);

	result=labels.get("apostal.toma.external.syrecos.identifyPersref")+"\""+c.toString()+"\"";
	}
	else
	result=labels.get("apostal.toma.external.syrecos.identifyPersref")+"\""+login+"\"";
      }*/

      return result;
    }

    public String decodeClassName(String className)
    {
	String result=className;

	if(className.equals("Formation"))
	    result=labels.get("apostal.toma.external.syrecos.training");
	else if(className.equals("Lieu"))
	    result=labels.get("apostal.toma.external.syrecos.location");
	else if(className.equals("Cat1") || className.equals("Cat2") || className.equals("Cat3"))
	    result=labels.get("apostal.toma.external.syrecos.catalogue");
	else if(className.equals("Domaine") || className.equals("Theme") || className.equals("Matiere"))
	    result=labels.get("apostal.toma.external.syrecos.domain");
	else if(className.equals("Sessmod"))
	    result=labels.get("apostal.toma.external.syrecos.courseOrUnitSession");
	else if(className.equals("Animateur"))
	    result=labels.get("apostal.toma.external.syrecos.teacher");
	else if(className.equals("Persref"))
	    result=labels.get("apostal.toma.external.syrecos.contact");
	else if(className.equals("Organisme"))
	    result=labels.get("apostal.toma.external.syrecos.organism");

	return result;
    }

    public String decodeFieldName(String classe, String champ)
    {
	String val=champ;
	if(classe!=null)
	    {
		if(classe.equals("Animateur"))
		    {
			if(champ.equals("nomanim"))
			    val=labels.get("apostal.toma.teacher.lastname");
			else if(champ.equals("prenomanim"))
			    val=labels.get("apostal.toma.teacher.firstname");
			else if(champ.equals("organisme"))
			    val=labels.get("apostal.toma.organism");
			else if(champ.equals("cvanim"))
			    val=labels.get("apostal.toma.teacher.cv");
			else if(champ.equals("fonction"))
			    val=labels.get("apostal.toma.teacher.function");
		    }
		else if(classe.equals("Cat1") ||classe.equals("Cat2") || classe.equals("Cat3") )
		    {
			if(champ.equals("titrecat"))
			    val=labels.get("apostal.toma.catalogue.title");
			else if(champ.equals("desccat"))
			    val=labels.get("apostal.toma.catalogue.description");
			else if(champ.equals("organisme"))
			    val=labels.get("apostal.toma.organism");
		    }
		else if(classe.equals("Competence"))
		    {
			if(champ.equals("desccomp"))
			    val=labels.get("apostal.toma.teacher.competences");
		    }
		else if(classe.equals("Formation"))
		    {
			if(champ.equals("codeforma"))
			    val=labels.get("apostal.toma.trainingview.code");
			else if(champ.equals("organisme"))
			    val=labels.get("apostal.toma.organism");
			else if(champ.equals("titreforma"))
			    val=labels.get("apostal.toma.trainingview.title");
			else if(champ.equals("datedebpub"))
			    val=labels.get("apostal.toma.trainingview.beginValidityDate");
			else if(champ.equals("datefinpub"))
			    val=labels.get("apostal.toma.trainingview.endValidityDate");
			else if(champ.equals("niveau"))
			    val=labels.get("apostal.toma.trainingview.level");
			else if(champ.equals("codecate"))
			    val=labels.get("apostal.toma.trainingview.modeOfOrganization");
			else if(champ.equals("partenariat"))
			    val=labels.get("apostal.toma.trainingview.partnership");
			else if(champ.equals("prereq"))
			    val=labels.get("apostal.toma.trainingview.prerequisites");
			else if(champ.equals("pubcible"))
			    val=labels.get("apostal.toma.trainingview.audiences");
			else if(champ.equals("controleconn"))
			    val=labels.get("apostal.toma.trainingview.evaluation");
			else if(champ.equals("certifdiplome"))
			    val=labels.get("apostal.toma.trainingview.certificatesOrDiplomas");
			else if(champ.equals("dureeforma"))
			    val=labels.get("apostal.toma.trainingview.duration");
			else if(champ.equals("prixforma"))
			    val=labels.get("apostal.toma.trainingview.price");
			else if(champ.equals("comprix"))
			    val=labels.get("apostal.toma.trainingview.priceComment");
			else if(champ.equals("modpay"))
			    val=labels.get("apostal.toma.trainingview.paymentFacilities");
			else if(champ.equals("condinsc"))
			    val=labels.get("apostal.toma.trainingview.inscriptionConditions");
			else if(champ.equals("objectifs"))
			    val=labels.get("apostal.toma.trainingview.objectives");
			else if(champ.equals("contenumodnonseq"))
			    val=labels.get("apostal.toma.trainingview.pointsDealtWith");
			else if(champ.equals("descforma"))
			    val=labels.get("apostal.toma.trainingview.content");
			else if(champ.equals("moyensped"))
			    val=labels.get("apostal.toma.trainingview.pedagogicalMethods");
			else if(champ.equals("support"))
			    val=labels.get("apostal.toma.trainingview.courseMedia");
			else if(champ.equals("tosearch"))
			    val=labels.get("apostal.toma.trainingview.keywords");
		    }
		else if(classe.equals("Lieu"))
		    {
			if(champ.equals("codelieu"))
			    val=labels.get("apostal.toma.location.denomination");
			else if(champ.equals("denomlieu"))
			    val=labels.get("apostal.toma.location.completename");
			else if(champ.equals("organisme"))
			    val=labels.get("apostal.toma.organism");
			else if(champ.equals("region"))
			    val=labels.get("apostal.toma.location.area");
			else if(champ.equals("adr1"))
			    val=labels.get("apostal.toma.location.address_lines");
			else if(champ.equals("adr2"))
			    val=labels.get("apostal.toma.location.address_lines");
			else if(champ.equals("codepostal"))
			    val=labels.get("apostal.toma.location.postcode");
			else if(champ.equals("loca"))
			    val=labels.get("apostal.toma.location.city");
			else if(champ.equals("numtel"))
			    val=labels.get("apostal.toma.location.telephone");
			else if(champ.equals("numfax"))
			    val=labels.get("apostal.toma.location.fax");
			else if(champ.equals("email"))
			    val=labels.get("apostal.toma.location.email");
			else if(champ.equals("facilites"))
			    val=labels.get("apostal.toma.location.access_facilities");
			else if(champ.equals("descaccess"))
			    val=labels.get("apostal.toma.location.access_description");
			else if(champ.equals("remaccess"))
			    val=labels.get("apostal.toma.location.acccess_comment");
		    }
		else if(classe.equals("Organisme"))
		    {
			if(champ.equals("denomination"))
			    val=labels.get("apostal.toma.organism.denomination");
		    }
		else if(classe.equals("Persref"))
		    {
			if(champ.equals("login"))
			    val=labels.get("apostal.toma.contact.lastname")+", "+labels.get("apostal.toma.contact.firstname");
			else if(champ.equals("codeciv"))
			    val=labels.get("apostal.toma.contact.title");
			else if(champ.equals("nom"))
			    val=labels.get("apostal.toma.contact.lastname");
			else if(champ.equals("prenom"))
			    val=labels.get("apostal.toma.contact.firstname");
			else if(champ.equals("adr1"))
			    val=labels.get("apostal.toma.contact.addresslines");
			else if(champ.equals("adr2"))
			    val=labels.get("apostal.toma.contact.addresslines");
			else if(champ.equals("codepays"))
			    val=labels.get("apostal.toma.contact.country");
			else if(champ.equals("codepostal"))
			    val=labels.get("apostal.toma.contact.postcode");
			else if(champ.equals("loca"))
			    val=labels.get("apostal.toma.contact.city");
			else if(champ.equals("numtel"))
			    val=labels.get("apostal.toma.contact.tel");
			else if(champ.equals("numfax"))
			    val=labels.get("apostal.toma.contact.fax");
			else if(champ.equals("email"))
			    val=labels.get("apostal.toma.contact.email");
		    }
		else if(classe.equals("Seance"))
		    {
			if(champ.equals("dateseance"))
			    val=labels.get("apostal.toma.sessionview.seance.date");
			else if(champ.equals("hordeb"))
			    val=labels.get("apostal.toma.sessionview.seance.beginTime");
			else if(champ.equals("horfin"))
			    val=labels.get("apostal.toma.sessionview.seance.endTime");

		    }
		else if(classe.equals("Sesscycle"))
		    {

		    }
		else if(classe.equals("Sessmod"))
		    {
			if(champ.equals("codesessmod"))
			    val=labels.get("apostal.toma.sessionview.name");
			else if(champ.equals("langue"))
			    val=labels.get("apostal.toma.sessionview.language");
			else if(champ.equals("datedebpub"))
			    val=labels.get("apostal.toma.sessionview.beginValidityDate");
			else if(champ.equals("datefinpub"))
			    val=labels.get("apostal.toma.sessionview.endValidityDate");
			else if(champ.equals("caltxt"))
			    val=labels.get("apostal.toma.sessionview.textualCalendar");
			else if(champ.equals("prixsessmod"))
			    val=labels.get("apostal.toma.sessionview.price");
			else if(champ.equals("comprixsessmod"))
			    val=labels.get("apostal.toma.sessionview.priceComment");
		    }
	    }
	return val;
    }

    public String getIdsecName(String className)
    {
	String result=className;

	if(className.equals("Formation"))
	    result=labels.get("apostal.toma.trainingview.code");
	else if(className.equals("Lieu"))
	    result=labels.get("apostal.toma.location.denomination");
	else if(className.equals("Cat1") || className.equals("Cat2") || className.equals("Cat3"))
	    result=labels.get("apostal.toma.catalogue.title");
	else if(className.equals("Domaine") || className.equals("Theme") || className.equals("Matiere"))
	    result=labels.get("apostal.toma.trainingview.domain.title");
	else if(className.equals("SessionModule"))
	    result=labels.get("apostal.toma.sessionview.sessionname");
	else if(className.equals("Animateur"))
	    result=labels.get("apostal.toma.teacher.lastname")+", "+labels.get("apostal.toma.teacher.firstname")+", "+labels.get("apostal.toma.teacher.function")+", "+labels.get("apostal.toma.organism");
	else if(className.equals("Persref"))
	    result=labels.get("apostal.toma.contact.lastname")+", "+labels.get("apostal.toma.contact.firstname")+", "+labels.get("apostal.toma.contact.telephone")+", "+labels.get("apostal.toma.contact.email");
	else if(className.equals("Organisme"))
	    result=labels.get("apostal.toma.organism.denomination");

	return result;
    }

    public String[] getNomsMessage(String message)
    {
	String[] noms=null;
	String msg=new String(message);
	int index=message.indexOf(" ");
	if(index!=-1)
	{
	    msg=message.substring(0, index);
	}

	StringTokenizer tokenizer=new StringTokenizer(msg, ".");
	noms=new String[tokenizer.countTokens()+1];
	int i=0;
	while(tokenizer.hasMoreElements())
	{
	    String elt=(String) tokenizer.nextElement();
	    noms[i]=elt;
	    i++;
	}

	return noms;
    }

    public String[] getArgumentsMessage(String message)
    {
	String[] args=null;
	String msg=new String(message);
	int index=message.indexOf(" ");
	if(index!=-1)
	{
	    msg=message.substring(index+1);
	}

	StringTokenizer tokenizer=new StringTokenizer(msg, " ");
	args=new String[tokenizer.countTokens()+1];
	int i=0;
	while(tokenizer.hasMoreElements())
	{
	    String elt=(String) tokenizer.nextElement();
	    args[i]=elt;
	    i++;
	}

	return args;
    }

   public String getAllArgumentsMessage(String message)
    {
	String msg=new String(message);
	int index=message.indexOf(" ");
	if(index!=-1)
	{
	    msg=message.substring(index+1);
	}

	return msg;
    }

  private Object getLastNotNullElement(Object[] data)
  {
    int length=data.length;
    int i=length-1;
    Object o=null;
    while(i>=0 && o==null)
    {
      o=data[i];
      i--;
    }
    return o;
  }
}