// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external;

import apostal.toma.TOMA;
import apostal.toma.data.*;
import apostal.toma.database.StandaloneTrainingDB;
import apostal.toma.external.tedtoma.TedTomaConversion;

import java.util.Iterator;
import java.util.Vector;

public class SyrecosPublication extends Publication
{
    private SyrecosLogin syrecosLogin;
    private TOMALabels labels;
    private PublicationUnit publicationUnit;
    private Vector errors;
    private Vector warnings;
    private SyrecosEncodingClient client;

	public SyrecosPublication(PublicationUnit publicationUnit){
		super(publicationUnit);
	}

    public SyrecosPublication(SyrecosLogin syrecosLogin, PublicationUnit publicationUnit)
    {
      super(publicationUnit);
      this.syrecosLogin=syrecosLogin;
      this.publicationUnit=publicationUnit;
      labels=new TOMALabels();
    }

    public Vector getTrainings()
    {
      return publicationUnit.getTrainings();
    }

    public void publishXML(boolean addFirstCat)
    {
      TOMA.log(TOMA.WARNING, "debut publish");

      Language lng=publicationUnit.getLanguage();

      errors=new Vector();
      warnings=new Vector();
      client=new SyrecosEncodingClient();

      //r�cup�rer les trainings
      Vector trainings=this.getTrainings();
      Vector tr=this.getTrainingToPublish(publicationUnit);

      //�crire dans le fichier XML
      /*XMLPublication publication=new XMLPublication(publicationUnit, TOMAConstants.temporaryXMLFile);
      publication.publish();
      errors=publication.getErrors();*/
      this.checkCompliance(publicationUnit);
      warnings=TedTomaConversion.getErrors();
      this.generateTedXML(tr, TOMAConstants.temporaryXMLFile,addFirstCat, true);
      TOMA.log(TOMA.WARNING, "fichier XML �crit");
      
      if(warnings!=null && !warnings.isEmpty())
	TOMA.log(TOMA.WARNING, "il y a eu des probl�mes XML");
      else
	TOMA.log(TOMA.WARNING, "pas de pb XML");
    }

    public void publish()
    {
       if(client!=null && syrecosLogin!=null)
       {
        
      Vector messages=client.testEncoding(syrecosLogin.getLogin(), syrecosLogin.getPassword(), TOMAConstants.temporaryXMLFile);
      errors=this.decodeMessages(messages);

      TOMA.log(TOMA.WARNING, "test effectu�");

      //si pas d'erreur: continuer
      if(errors.isEmpty())
	{
	  TOMA.log(TOMA.WARNING, "faire la transformation");

	  //envoyer le fichier XML � Syrecos
	  String result=client.deleteAndEncode(syrecosLogin.getLogin(), syrecosLogin.getPassword(), TOMAConstants.temporaryXMLFile);
	  if(!result.equals("ok"))
	    errors.add(result);

	  TOMA.log(TOMA.WARNING, "transfo effectu�e: result="+result);
	}
       }
       else
       {
        if(client==null)
            TOMA.log(TOMA.INFO, "SyrecosPublication.publish, SyrecosEncodingClient=null");
        else if(syrecosLogin==null)
            TOMA.log(TOMA.INFO, "SyrecosPublication.publish, syrecosLogin=null");            
       }
    }

    public Vector getErrors()
    {
      return errors;
    }

    public Vector getWarnings()
    {
      return warnings;
    }
    /**
     * decodes the different messages received.
     * if the type of the message is Nom:
     *  - if there is an identification message, it decodes it
     *  - it continues to decode until a new Nom message
     *  This is not outputted if there was nothing else than the nom, or the nom and the identification
     * @returns the decoded messages
     */
    public static Vector decodeMessages(Vector lines)
    {
        Vector result=new Vector();
	if(lines!=null)
	{
	  SyrecosMessageDecoder decoder=new SyrecosMessageDecoder();
	  int size=lines.size();
	  for(int i=0;i<size;i++)
	  {
	    String line = (String) lines.elementAt(i);
	    int type=decoder.getMessageType(line);
	    if(type==SyrecosMessageDecoder.NOM)
	    {
	      result.add(decoder.decode(line)+": ");

	      //analyser le reste
	      if(i<size-1)
	      {
		boolean somethingPut=false;

	        type=decoder.getMessageType((String) lines.elementAt(i+1));
		boolean nextIsNom=(type==SyrecosMessageDecoder.NOM);

		while(!nextIsNom && i<size-1)
	        {
		    i++;
	            line=(String) lines.elementAt(i);
		    String l=decoder.decode(line);
		    type=decoder.getMessageType(line);

		    if(type!=SyrecosMessageDecoder.FINISHED
		    && type!=SyrecosMessageDecoder.ROLLBACK)
		    {
		      if(type==SyrecosMessageDecoder.IDENTIFICATION)
		      {
			if(l!=null && !l.equals(""))
			{
			  //le rajouter, mais � la suite de la derni�re ligne:
			  //r�cup�rer le dernier �l�ment
			  String last=(String) result.lastElement();
			  //l'enlever
			  int indexLast=result.indexOf(last);
			  result.removeElementAt(indexLast);
			  //enlever le  ":" + concat�ner
			  last=last.substring(0, last.length()-2)+l+": ";
		  	  result.add(last);
			}
		      }
		      else
		      {
		        result.add("     "+l);
		        somethingPut=true;
		      }
		    }

		    if(i<size-1)
		      nextIsNom=(decoder.getMessageType((String) lines.elementAt(i+1))==SyrecosMessageDecoder.NOM);
	        }

		//si rien n'a �t� mis d'autre que nom ou id
		if(!somethingPut)
		{
		  //enlever le dernier �l�ment
		  result.removeElementAt(result.size()-1);
		}
	      }

	    }
	    else if(type!=SyrecosMessageDecoder.FINISHED
	    && type!=SyrecosMessageDecoder.ROLLBACK)
	      result.add(decoder.decode(line));
	  }
	}
	return result;
    }

    /**
     * @returns a table with:
     * on the first position, the trainings that do not have a domain
     * on the second position, the sessions that do not have a language
     */
    public Vector[] getWarnings(Vector trainings)
    {
      /*Vector domains_warnings=new Vector();
      Vector languages_warnings=new Vector();*/
      Vector[] result=new Vector[2];        
      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

      //transformer le vecteur de trainingPublished en vecteur d'id
      if(trainings!=null)
      {     
        Vector idtrainings=new Vector();
        Iterator it=trainings.iterator();
        while(it.hasNext())
        {
            TrainingPublished t=(TrainingPublished) it.next();
            idtrainings.add(new Integer(t.getIdTraining()));
        }          
          
      Vector domains_warnings=StandaloneTrainingDB.getTrainingsWithoutDomains(lng, idtrainings);
      Vector languages_warnings=StandaloneTrainingDB.getSessionsWithoutLanguage(lng, labels.get("apostal.toma.external.syrecos.identifyTraining"), idtrainings);           
      
      /*
        Iterator iter = trainings.iterator();
        while (iter.hasNext())
        {
	  TrainingPublished tpub= (TrainingPublished) iter.next();
	  int id=tpub.getIdTraining();
	  Training t=TrainingDB.getInstance(lng,true,id);
	  if(t!=null)
	  {
	    String classe=t.getClass().getName();
	    if(classe.equals("apostal.toma.data.TrainingCourse"))
	    {
	      TrainingCourse tc=(TrainingCourse) t;

	      if(tc.getDomains()==null || tc.getDomains().isEmpty())
	        domains_warnings.add(tc);

	      Vector sessions=tc.getCourseSessions();
	      if(sessions!=null)
	      {
	        Iterator iter2 = sessions.iterator();
	        while (iter2.hasNext())
	        {
		  CourseSession cs = (CourseSession) iter2.next();
		  CourseSessionDB csdb=new CourseSessionDB(cs);
		  csdb.loadById(lng, true);

		  if(cs.getLanguage()==null)
		    languages_warnings.add(cs+" "+labels.get("apostal.toma.external.syrecos.identifyTraining")+" "+tc);
	        }
	      }
	    }
	    if(classe.equals("apostal.toma.data.TrainingProgramme"))
	    {
	      TrainingProgramme tp=(TrainingProgramme) t;

	      if(tp.getDomains()==null || tp.getDomains().isEmpty())
	        domains_warnings.add(tp);

	      Vector sessions=tp.getProgrammeSessions();
	      if(sessions!=null)
	      {
	        Iterator iter2 = sessions.iterator();
	        while (iter2.hasNext())
	        {
		  ProgrammeSession ps = (ProgrammeSession) iter2.next();
		  ProgrammeSessionDB psdb=new ProgrammeSessionDB(ps);
		  psdb.loadById(lng, true);
		  if(ps.getLanguage()==null)
		    languages_warnings.add(ps+" "+labels.get("apostal.toma.external.syrecos.identifyTraining")+" "+tp);
	        }
	      }
	    }


	  }
        }
      */
                  
      result[0]=domains_warnings;
      result[1]=languages_warnings;
      }
      return result;
    }
}
