// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external;

import apostal.ted.*;
import apostal.toma.TOMA;
import apostal.toma.data.*;
import apostal.toma.database.*;
import apostal.toma.external.tedtoma.CatalogueConversion;
import apostal.toma.external.tedtoma.OrganismConversion;
import apostal.toma.external.tedtoma.TedTomaConversion;

import java.util.Iterator;
import java.util.Vector;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class XMLImport
{
	/*** DEBUG ***/
	public static void main(String argv[]){
		if(argv.length>0){
			String filename=argv[0];
			XMLImport imp=new XMLImport();
			System.out.println("Importing file "+filename);
			imp.doFirstImport(filename);
		}
		else
			System.out.println("Missing argument: XMLImport filename");
	}

	/*** END DEBUG ***/

  private String filename;

  public XMLImport()
  {
  }

  /**
   * do the first import in TOMA: does not ask what to do about references but
   * saves all in TOMA.
   * If something exists in TOMA, it uses it (finding it by its secondary keys)
   */
  public void doFirstImport(String filename)
  {
    this.filename=filename;

    LoadXML load=new LoadXML(filename);
    TedXML ted=load.load();

    if(ted.getTrainingCourses()!=null && ted.getTrainingCourses().size()>0)
        {
            TrainingCourseXML tc=(TrainingCourseXML) ted.getTrainingCourses().elementAt(0);
            TOMA.log(TOMA.WARNING, "XMLImport.doFirstImport.A, tc.title="+tc.getTitle());
        }

    //precaution: delete everything that was in TOMA?
    // + create a root catalogue
    DatabaseFacilities.removeAllData();

    if(ted!=null)
    {
      //changer les codes des units
      ted.changeUnitsCodes();

      //organisme
      OrganismXML org=null;
      if(ted.getTrainingCourses()!=null && !ted.getTrainingCourses().isEmpty())
      {
	TrainingCourseXML tc=(TrainingCourseXML) ted.getTrainingCourses().elementAt(0);
        org=tc.getOrganism();
      }
      else if(ted.getTrainingProgrammes()!=null && !ted.getTrainingProgrammes().isEmpty())
      {
	TrainingProgrammeXML tp=(TrainingProgrammeXML) ted.getTrainingProgrammes().elementAt(0);
        org=tp.getOrganism();
      }
      if(org!=null)
      {
	OrganismConversion orgaconv=new OrganismConversion();
        Organism o=orgaconv.tedToToma(org);

	OrganismDB odb=new OrganismDB(o);
	odb.create();
      }

      //trainings
      TedTomaConversion conversion=new TedTomaConversion();
      Vector trainings=conversion.tedToToma(ted);
      if(trainings!=null)
      {
	  Vector newtrainings=(Vector) trainings.clone();
	  Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

	  Iterator iter = trainings.iterator();
	  while (iter.hasNext())
	  {
	    Training t= (Training) iter.next();

	    //teachers
	    Vector teachers=t.getTeachers();
	    if(teachers!=null)
	    {
	      Vector newteachers=(Vector) teachers.clone();
	      Iterator iter_teachers = teachers.iterator();
	      while (iter_teachers.hasNext())
	      {
		Teacher teacher = (Teacher) iter_teachers.next();

	        if(!this.testAndSaveTeacher(lng, teacher))
		  newteachers.remove(teacher);
	      }
	      t.setTeachers(newteachers);
	    }

	    //locations
	    Vector locations=t.getLocations();
	    if(locations!=null)
	    {
	      Vector newlocations=(Vector) locations.clone();
	      Iterator iter_loc = locations.iterator();
	      while (iter_loc.hasNext())
	      {
	        Location loc = (Location) iter_loc.next();

	        if(!this.testAndSaveLocation(lng, loc))
		  newlocations.remove(loc);
	      }
	      t.setLocations(newlocations);
	    }


	    String className=t.getClass().getName();
	    if(className.equals("apostal.toma.data.TrainingCourse")
	    || className.equals("apostal.toma.data.TrainingProgramme"))
	    {
	      //TrainingCourse tc=(TrainingCourse) t;
	      StandaloneTraining st=(StandaloneTraining) t;

	      //contacts
	      Vector inscriptionContacts=st.getInscriptionContacts();
	      if(inscriptionContacts!=null)
	      {
	      Vector newinscriptionContacts=(Vector) inscriptionContacts.clone();
	      Iterator iter_incCont = inscriptionContacts.iterator();
	      while (iter_incCont.hasNext())
	      {
		Contact c = (Contact) iter_incCont.next();

		if(!this.testAndSaveContact(lng, c))
		  newinscriptionContacts.remove(c);
	      }
		st.setInscriptionContacts(newinscriptionContacts);
	      }
	      Vector trainingContacts=st.getTrainingContacts();
	      if(trainingContacts!=null)
	      {
	      Vector newtrainingContacts=(Vector) trainingContacts.clone();
	      Iterator iter_trCont = trainingContacts.iterator();
	      while (iter_trCont.hasNext())
	      {
		Contact c = (Contact) iter_trCont.next();

		if(!this.testAndSaveContact(lng, c))
		  newtrainingContacts.remove(c);
	      }
		st.setTrainingContacts(newtrainingContacts);
	      }

	    //catalogues
	    Object o=ted.getTrainingByCode(t.getCode());
	    try{
	        TrainingXML txml=(TrainingXML) o;
		TOMA.log(TOMA.WARNING, "XMLImport: for code="+t.getCode()+", txml found: "+txml.getCode());

	        if(txml.getCatalogues()!=null && !txml.getCatalogues().isEmpty())
		    {
			Vector catalogues=new Vector();
			Vector catOrders=new Vector();
			Iterator iter_cat = txml.getCatalogues().iterator();
			//1er id=celui du desktop
			int id=CatalogueDB.getRootCatalogue(lng, false).getIdCatalogue();
			//Catalogue newcat=null;
			while (iter_cat.hasNext() && id>=0)
			    {
				CatalogueXML cat= (CatalogueXML) iter_cat.next();

			        TOMA.log(TOMA.WARNING, "contained in the cat: "+cat.getTitle());

				this.treatCatalogue(lng, cat, catalogues, null, id, catOrders, -1);
			    }
			st.setCatalogues(catalogues);
			st.setCatOrders(catOrders);
		    }
	        else
		    {
			Catalogue c0=CatalogueDB.getRootCatalogue(lng, false);
			Vector catalogues=new Vector();
			catalogues.add(c0);
			st.setCatalogues(catalogues);

			Vector catOrders=new Vector();
			CatalogueDB cdb=new CatalogueDB(c0);
			int max=cdb.getMaxTrainingOrder();
			Integer order=null;
			if(max>=0)
			  order=new Integer(max+1);
			catOrders.add(order);
			st.setCatOrders(catOrders);
		    }

	    }catch(java.lang.ClassCastException ex)
		{
		    //rien
		}

	      if(className.equals("apostal.toma.data.TrainingCourse"))
	      {
	        TrainingCourse tc=(TrainingCourse) t;

		//trainingCourse
		if(!this.testAndSaveTrainingCourse(lng, tc))
		  newtrainings.remove(t);
		else
		    {
			//sessions
			Vector courseSessions=tc.getCourseSessions();
			if(courseSessions!=null)
			    {
				Vector newcourseSessions=(Vector) courseSessions.clone();
				Iterator iter_sess = courseSessions.iterator();
				while (iter_sess.hasNext())
				    {
					CourseSession sess= (CourseSession) iter_sess.next();

					sess.setIdTraining(tc.getIdTraining());

					if(!this.testAndSaveCourseSession(lng, sess))
					    newcourseSessions.remove(sess);
				    }
				tc.setCourseSessions(newcourseSessions);
			    }
		    }
	      }
	      else if(className.equals("apostal.toma.data.TrainingProgramme"))
	      {
		TrainingProgramme tp=(TrainingProgramme) t;

		//trainingProgramme
		if(!this.testAndSaveTrainingProgramme(lng, tp))
		    newtrainings.remove(t);
		else
		    {
			//sessions
			Vector programmeSessions=tp.getProgrammeSessions();
			if(programmeSessions!=null)
			    {
				Vector newprogrammeSessions=(Vector) programmeSessions.clone();
				Iterator iter_sess = programmeSessions.iterator();
				while (iter_sess.hasNext())
				    {
					ProgrammeSession sess= (ProgrammeSession) iter_sess.next();
					sess.setIdTraining(tp.getIdTraining());

					if(!this.testAndSaveProgrammeSession(lng, sess))
					    newprogrammeSessions.remove(sess);
				    }
				tp.setProgrammeSessions(newprogrammeSessions);
			    }

			//units
			Vector units=tp.getUnits();
			if(units!=null)
			    {
				Vector newunits=(Vector) units.clone();

				Iterator iter_units = units.iterator();
				while (iter_units.hasNext())
				    {
					Unit u = (Unit) iter_units.next();

					u.setIdProgramme(tp.getIdTraining());

					//locations
					Vector unitlocations=u.getLocations();
					if(unitlocations!=null)
					    {
						Vector newlocations=(Vector) unitlocations.clone();
						Iterator iter_loc = unitlocations.iterator();
						while (iter_loc.hasNext())
						    {
							Location loc = (Location) iter_loc.next();

							if(!this.testAndSaveLocation(lng, loc))
							    newlocations.remove(loc);
						    }
						u.setLocations(newlocations);
					    }

					//contact
					Vector unitTrainingContacts=u.getTrainingContacts();
					if(unitTrainingContacts!=null)
					    {
						Vector newunitTrainingContacts=(Vector) unitTrainingContacts.clone();
						Iterator iter_trCont = unitTrainingContacts.iterator();
						while (iter_trCont.hasNext())
						    {
							Contact c = (Contact) iter_trCont.next();

							if(!this.testAndSaveContact(lng, c))
							    newunitTrainingContacts.remove(c);
						    }
						u.setTrainingContacts(newunitTrainingContacts);
					    }

					//teachers
					Vector unitteachers=u.getTeachers();
					if(unitteachers!=null)
					    {
						Vector newteachers=(Vector) unitteachers.clone();
						Iterator iter_teachers = unitteachers.iterator();
						while (iter_teachers.hasNext())
						    {
							Teacher teacher = (Teacher) iter_teachers.next();

							if(!this.testAndSaveTeacher(lng, teacher))
							    newteachers.remove(teacher);
						    }
						t.setTeachers(newteachers);
					    }

					//unit
					if(!this.testAndSaveUnit(lng, u))
					    newunits.remove(u);
					else
					    {
						//sessions
						Vector unitSessions=u.getUnitSessions();
						if(unitSessions!=null)
						    {
							Vector newunitSessions=(Vector) unitSessions.clone();
							Iterator iter_sess = unitSessions.iterator();
							while (iter_sess.hasNext())
							    {
								UnitSession sess= (UnitSession) iter_sess.next();
								sess.setIdTraining(u.getIdTraining());

								//programme sessions
								//retrouver de quel unitSessionXML il s'agit, prendre le nom
					    		        //puis parcourir tous les programme session jusqu' obtenir le meme nom
					    		    	String pname=ted.getProgrammeSessionNameByUnitSessionName(sess.getSessionName());
					    		    	int idps=-1;
					    		    	Iterator iter_psn = tp.getProgrammeSessions().iterator();
					    		    	while (iter_psn.hasNext() && idps==-1)
								{
					    		    	   ProgrammeSession ps = (ProgrammeSession) iter_psn.next();
					    		    	   if(ps.getSessionName().equals(pname))
					    		    	   {
					    		    	      idps=ps.getIdSession();
					    		    	   }
					    		    	}
					    		    	if(idps>-1)
					    		    	  sess.setIdProgrammeSession(idps);

								if(!this.testAndSaveUnitSession(lng, sess))
								    newunitSessions.remove(sess);
							    }
							u.setUnitSessions(newunitSessions);
						    }
					    }

				    }
				tp.setUnits(newunits);
			    }
		    }
	      }
	      else
	      {
	        TOMA.log(TOMA.SEVERE, "XMLImport, className="+className);
	      }
	    }


	  }

	  DatabaseFacilities.unlockAll();
      }
    }
  }

  /**
  * fast automatic import of a TED file:
  * trainings with the same code are updated
  * locations, contacts and teachers are loaded from their secondary ids, and updated
  * the first catalogue of each training is searched in all the catalogues, and then its subcatalogues are created/updated
  **/
  public void fastImport(String filename){
		this.filename=filename;

		LoadXML load=new LoadXML(filename);
		TedXML ted=load.load();

		Catalogue c0=CatalogueDB.getRootCatalogue(new Language(Language.defaultLanguageCode), false);
		
    if(ted!=null)
    {
      
      //trainings
      TedTomaConversion conversion=new TedTomaConversion();
      Vector trainings=conversion.tedToToma(ted);
      if(trainings!=null)
      {
	  Vector newtrainings=(Vector) trainings.clone();
	  Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

	  Iterator iter = trainings.iterator();
	  while (iter.hasNext())
	  {
	    Training t= (Training) iter.next();

	    //teachers
	    Vector teachers=t.getTeachers();
	    if(teachers!=null)
	    {
	      Vector newteachers=(Vector) teachers.clone();
	      Iterator iter_teachers = teachers.iterator();
	      while (iter_teachers.hasNext())
	      {
		Teacher teacher = (Teacher) iter_teachers.next();

	        if(!this.testAndSaveTeacher(lng, teacher))
		  newteachers.remove(teacher);
	      }
	      t.setTeachers(newteachers);
	    }

	    //locations
	    Vector locations=t.getLocations();
	    if(locations!=null)
	    {
	      Vector newlocations=(Vector) locations.clone();
	      Iterator iter_loc = locations.iterator();
	      while (iter_loc.hasNext())
	      {
	        Location loc = (Location) iter_loc.next();

	        if(!this.testAndSaveLocation(lng, loc))
		  newlocations.remove(loc);
	      }
	      t.setLocations(newlocations);
	    }


	    String className=t.getClass().getName();
	    if(className.equals("apostal.toma.data.TrainingCourse")
	    || className.equals("apostal.toma.data.TrainingProgramme"))
	    {
	      //TrainingCourse tc=(TrainingCourse) t;
	      StandaloneTraining st=(StandaloneTraining) t;

	      //contacts
	      Vector inscriptionContacts=st.getInscriptionContacts();
	      if(inscriptionContacts!=null)
	      {
	      Vector newinscriptionContacts=(Vector) inscriptionContacts.clone();
	      Iterator iter_incCont = inscriptionContacts.iterator();
	      while (iter_incCont.hasNext())
	      {
		Contact c = (Contact) iter_incCont.next();

		if(!this.testAndSaveContact(lng, c))
		  newinscriptionContacts.remove(c);
	      }
		st.setInscriptionContacts(newinscriptionContacts);
	      }
	      Vector trainingContacts=st.getTrainingContacts();
	      if(trainingContacts!=null)
	      {
	      Vector newtrainingContacts=(Vector) trainingContacts.clone();
	      Iterator iter_trCont = trainingContacts.iterator();
	      while (iter_trCont.hasNext())
	      {
		Contact c = (Contact) iter_trCont.next();

		if(!this.testAndSaveContact(lng, c))
		  newtrainingContacts.remove(c);
	      }
		st.setTrainingContacts(newtrainingContacts);
	      }

	    ///////////catalogues
	    
	    
	    Object o=ted.getTrainingByCode(t.getCode());
	    try{
	        TrainingXML txml=(TrainingXML) o;
		TOMA.log(TOMA.WARNING, "XMLImport: for code="+t.getCode()+", txml found: "+txml.getCode());

		//find the catalogue with the specified name
	    	/*Catalogue myCat=CatalogueDB.getCatalogueByTitle(new Language(Language.defaultLanguageCode), catalogueTitle, true);		
		if(myCat==null)
			TOMA.log(TOMA.WARNING, "catalogue not found!");*/
		
	        if(txml.getCatalogues()!=null && !txml.getCatalogues().isEmpty())
		    {
			Vector catalogues=new Vector();
			Vector catOrders=new Vector();
			
			//1rst catalogue: find it
			
			    
			st.setCatalogues(catalogues);
			st.setCatOrders(catOrders);
		    }
	        else //no catalogue specified
		    {
			Vector catalogues=new Vector();
			catalogues.add(c0);
			st.setCatalogues(catalogues);

			Vector catOrders=new Vector();
			CatalogueDB cdb=new CatalogueDB(c0);
			int max=cdb.getMaxTrainingOrder();
			Integer order=null;
			if(max>=0)
			  order=new Integer(max+1);
			catOrders.add(order);
			st.setCatOrders(catOrders);
		    }

	    }catch(java.lang.ClassCastException ex)
		{
		    //rien
		}

	      if(className.equals("apostal.toma.data.TrainingCourse"))
	      {
	        TrainingCourse tc=(TrainingCourse) t;

		//trainingCourse
		if(!this.testAndSaveTrainingCourse(lng, tc))
		  newtrainings.remove(t);
		else
		    {
			//sessions
			Vector courseSessions=tc.getCourseSessions();
			if(courseSessions!=null)
			    {
				Vector newcourseSessions=(Vector) courseSessions.clone();
				Iterator iter_sess = courseSessions.iterator();
				while (iter_sess.hasNext())
				    {
					CourseSession sess= (CourseSession) iter_sess.next();

					sess.setIdTraining(tc.getIdTraining());

					if(!this.testAndSaveCourseSession(lng, sess))
					    newcourseSessions.remove(sess);
				    }
				tc.setCourseSessions(newcourseSessions);
			    }
		    }
	      }
	      else if(className.equals("apostal.toma.data.TrainingProgramme"))
	      {
		TrainingProgramme tp=(TrainingProgramme) t;

		//trainingProgramme
		if(!this.testAndSaveTrainingProgramme(lng, tp))
		    newtrainings.remove(t);
		else
		    {
			//sessions
			Vector programmeSessions=tp.getProgrammeSessions();
			if(programmeSessions!=null)
			    {
				Vector newprogrammeSessions=(Vector) programmeSessions.clone();
				Iterator iter_sess = programmeSessions.iterator();
				while (iter_sess.hasNext())
				    {
					ProgrammeSession sess= (ProgrammeSession) iter_sess.next();
					sess.setIdTraining(tp.getIdTraining());

					if(!this.testAndSaveProgrammeSession(lng, sess))
					    newprogrammeSessions.remove(sess);
				    }
				tp.setProgrammeSessions(newprogrammeSessions);
			    }

			//units
			Vector units=tp.getUnits();
			if(units!=null)
			    {
				Vector newunits=(Vector) units.clone();

				Iterator iter_units = units.iterator();
				while (iter_units.hasNext())
				    {
					Unit u = (Unit) iter_units.next();

					u.setIdProgramme(tp.getIdTraining());

					//locations
					Vector unitlocations=u.getLocations();
					if(unitlocations!=null)
					    {
						Vector newlocations=(Vector) unitlocations.clone();
						Iterator iter_loc = unitlocations.iterator();
						while (iter_loc.hasNext())
						    {
							Location loc = (Location) iter_loc.next();

							if(!this.testAndSaveLocation(lng, loc))
							    newlocations.remove(loc);
						    }
						u.setLocations(newlocations);
					    }

					//contact
					Vector unitTrainingContacts=u.getTrainingContacts();
					if(unitTrainingContacts!=null)
					    {
						Vector newunitTrainingContacts=(Vector) unitTrainingContacts.clone();
						Iterator iter_trCont = unitTrainingContacts.iterator();
						while (iter_trCont.hasNext())
						    {
							Contact c = (Contact) iter_trCont.next();

							if(!this.testAndSaveContact(lng, c))
							    newunitTrainingContacts.remove(c);
						    }
						u.setTrainingContacts(newunitTrainingContacts);
					    }

					//teachers
					Vector unitteachers=u.getTeachers();
					if(unitteachers!=null)
					    {
						Vector newteachers=(Vector) unitteachers.clone();
						Iterator iter_teachers = unitteachers.iterator();
						while (iter_teachers.hasNext())
						    {
							Teacher teacher = (Teacher) iter_teachers.next();

							if(!this.testAndSaveTeacher(lng, teacher))
							    newteachers.remove(teacher);
						    }
						t.setTeachers(newteachers);
					    }

					//unit
					if(!this.testAndSaveUnit(lng, u))
					    newunits.remove(u);
					else
					    {
						//sessions
						Vector unitSessions=u.getUnitSessions();
						if(unitSessions!=null)
						    {
							Vector newunitSessions=(Vector) unitSessions.clone();
							Iterator iter_sess = unitSessions.iterator();
							while (iter_sess.hasNext())
							    {
								UnitSession sess= (UnitSession) iter_sess.next();
								sess.setIdTraining(u.getIdTraining());

								//programme sessions
								//retrouver de quel unitSessionXML il s'agit, prendre le nom
					    		        //puis parcourir tous les programme session jusqu' obtenir le meme nom
					    		    	String pname=ted.getProgrammeSessionNameByUnitSessionName(sess.getSessionName());
					    		    	int idps=-1;
					    		    	Iterator iter_psn = tp.getProgrammeSessions().iterator();
					    		    	while (iter_psn.hasNext() && idps==-1)
								{
					    		    	   ProgrammeSession ps = (ProgrammeSession) iter_psn.next();
					    		    	   if(ps.getSessionName().equals(pname))
					    		    	   {
					    		    	      idps=ps.getIdSession();
					    		    	   }
					    		    	}
					    		    	if(idps>-1)
					    		    	  sess.setIdProgrammeSession(idps);

								if(!this.testAndSaveUnitSession(lng, sess))
								    newunitSessions.remove(sess);
							    }
							u.setUnitSessions(newunitSessions);
						    }
					    }

				    }
				tp.setUnits(newunits);
			    }
		    }
	      }
	      else
	      {
	        TOMA.log(TOMA.SEVERE, "XMLImport, className="+className);
	      }
	    }


	  }

	  DatabaseFacilities.unlockAll();
      }
    }
	}  
  
  /**
   * treat the catalogues
   *@param nborderCat : the order of this cat in its preceding cat
   **/
    private void treatCatalogue(Language lng, CatalogueXML cat, Vector catalogues, Catalogue newcat, int id, Vector catOrders, int nborderCat)
    {
	TOMA.log(TOMA.WARNING,"XMLImport.treatCatalogue, id="+new Integer(id)+", nbOrderCat="+new Integer(nborderCat));

	//Catalogue newcat2=this.testAndSaveCatalogueXML(lng, cat, id);
	Object[] result=this.testAndSaveCatalogueXML(lng, cat, id, nborderCat);
	Catalogue newcat2=(Catalogue) result[0];

	if(newcat2==null)
	    {
		id=-1;
	    }
	else
	    {
		//si id=-1 -> fin
		id=newcat2.getIdCatalogue();
		if(id==-1 || cat.getCatalogue()==null)
		    {
			catalogues.add(newcat2);
                        Integer order=(Integer) result[1];
                        if(order==null)
                        {
                            CatalogueDB cdb=new CatalogueDB(newcat2);
                            order=new Integer(cdb.getMaxTrainingOrder()+1);
                        }
			catOrders.add(order);
			TOMA.log(TOMA.WARNING, "added "+order+" in catOrders");
		    }
		else if(cat.getCatalogue()!=null)
		    {
                        //rcuprer le "order" de cat
                        int orderCat=cat.getOrder();
                        TOMA.log(TOMA.WARNING, "XMLImport.treatCatalogue, cat.getOrder="+new Integer(orderCat));

			this.treatCatalogue(lng, cat.getCatalogue(), catalogues, newcat2, id, catOrders, orderCat);
		    }
	    }
    }

  //private Catalogue testAndSaveCatalogueXML(Language lng, CatalogueXML c, int id)
  private Object[] testAndSaveCatalogueXML(Language lng, CatalogueXML c, int id, int nborderCat)
  {
      TOMA.log(TOMA.WARNING,"XMLImport.testAndSaveCatalogueXML, id="+new Integer(id));

      Object[] result=new Object[2];

      CatalogueConversion conversion=new CatalogueConversion();
      Catalogue cat=conversion.tedToToma(c);

      if(id>=0)
        cat.setIdSuperCatalogue(id);

      CatalogueDB cdb=new CatalogueDB(cat);
      boolean loaded=cdb.loadByTitleAndTest(lng, false, false);
      if(loaded)
	  {
	      //charger les trainings existants!!! + evt le nborder
	      if(nborderCat>-1)
                cdb.loadElementsNotInTedById(lng, false);
              else
                cdb.loadElementsNotInTedById(lng, true);

	      if(cdb.testUpdate())
		  cdb.update();
	  }
      else if(!loaded && cdb.testCreate())
	  {
            //if(nborderCat>-1)
             cat.setNborder(nborderCat);
            /*else
              cdb.setNextNborder();*/

            cdb.create();
	  }
      else
	  {

	     cat=null;
	     TOMA.log(TOMA.SEVERE, "could not create nor update catalogue :"+cat);
	  }

      result[0]=cat;
      int nborder=conversion.getNborder();
      if(nborder>-1)
      {
	  result[1]=new Integer(nborder);
      }
      else
      {
	  result[1]=null;
      }
      return result;
  }

  private boolean testAndSaveTrainingCourse(Language lng, TrainingCourse tc)
  {
    boolean ok=true;
    TrainingCourseDB tDB=new TrainingCourseDB(tc);
    boolean loaded=tDB.loadByCodeAndTest(lng,false);

    if(loaded && tDB.testUpdate())
    {
      tDB.update();
    }
    else if(!loaded && tDB.testCreate())
    {
      tDB.create();
    }
    else
    {
      ok=false;
      TOMA.log(TOMA.SEVERE, "could not create nor update training course:"+tc);
    }

    return ok;
  }

  private boolean testAndSaveTrainingProgramme(Language lng, TrainingProgramme tc)
  {
    boolean ok=true;
    TrainingProgrammeDB tDB=new TrainingProgrammeDB(tc);
    boolean loaded=tDB.loadByCodeAndTest(lng,false);

    if(loaded && tDB.testUpdate())
      tDB.update();
    else if(!loaded && tDB.testCreate())
      tDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update training programme:"+tc);
	}

    return ok;
  }

  private boolean testAndSaveUnit(Language lng, Unit tc)
  {
    boolean ok=true;
    UnitDB tDB=new UnitDB(tc);
    boolean loaded=tDB.loadByCodeAndTest(lng,false);

    if(loaded && tDB.testUpdate())
      tDB.update();
    else if(!loaded && tDB.testCreate())
      tDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update unit:"+tc);
	}

    return ok;
  }

  private boolean testAndSaveTeacher(Language lng, Teacher teacher)
  {
    boolean ok=true;
    TeacherDB teacherDB=new TeacherDB(teacher);
    boolean loaded=teacherDB.loadByFirstnameLastnameFunctionAndTest(lng,false);

    if(loaded && teacherDB.testUpdate()){
      teacherDB.update();
      //teacherDB.unlock();
    }
    else if(!loaded && teacherDB.testCreate()){
      teacherDB.create();
      //teacherDB.unlock();
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update teacher:"+teacher);
	}

    return ok;
  }

  private boolean testAndSaveLocation(Language lng, Location loc)
  {
    boolean ok=true;
    LocationDB locDB=new LocationDB(loc);
    boolean loaded=locDB.loadByDenominationAndTest(lng,false);

    if(loaded && locDB.testUpdate()){
      locDB.update();
      //locDB.unlock();
    }
    else if(!loaded && locDB.testCreate()){
      locDB.create();
      //locDB.unlock();
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update location:"+loc);
	}

    return ok;
  }

  private boolean testAndSaveContact(Language lng, Contact c)
  {
    boolean ok=true;
    ContactDB cDB=new ContactDB(c);
    boolean loaded=cDB.loadByFirstnameLastnameTelEmailAndTest(lng, false);

    if(loaded && cDB.testUpdate()){
      cDB.update();
      //cDB.unlock();
    }
    else if(!loaded && cDB.testCreate()){
      cDB.create();
      //cDB.unlock();
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update contact:"+c);
	}

    return ok;
  }

  private boolean testAndSaveCourseSession(Language lng, CourseSession c)
  {
    boolean ok=true;
    CourseSessionDB cDB=new CourseSessionDB(c);
    boolean loaded=cDB.loadBySessionNameAndTest(lng, false);

    if(loaded && cDB.testUpdate())
      cDB.update();
    else if(!loaded && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update course session:"+c);
	}

    return ok;
  }

  private boolean testAndSaveProgrammeSession(Language lng, ProgrammeSession c)
  {
    boolean ok=true;
    ProgrammeSessionDB cDB=new ProgrammeSessionDB(c);
    boolean loaded=cDB.loadBySessionNameAndTest(lng, false);

    if(loaded && cDB.testUpdate())
      cDB.update();
    else if(!loaded && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update programme session:"+c);
	}

    return ok;
  }

  private boolean testAndSaveUnitSession(Language lng, UnitSession c)
  {
    boolean ok=true;
    UnitSessionDB cDB=new UnitSessionDB(c);
    boolean loaded=cDB.loadBySessionNameAndTest(lng, false);

    if(loaded && cDB.testUpdate())
      cDB.update();
    else if(!loaded && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update unit session:"+c);
	}

    return ok;
  }

    /*********************************************************************/
    /********************** Import de formations *************************/
    /*********************************************************************/
    public void importTraining(TrainingXML t, Vector catalogues)
    {
      TedXML ted=new TedXML();
      String className=t.getClass().getName();
      if(className.equals("apostal.ted.TrainingCourseXML"))
        ted.addTrainingCourse((TrainingCourseXML) t);
      else if(className.equals("apostal.ted.TrainingProgrammeXML"))
        ted.addTrainingProgramme((TrainingProgrammeXML) t);

      Language lng=TOMA.getInstance().getTomaParameters().getLanguage();

      TedTomaConversion conversion=new TedTomaConversion();
      Vector trainings=conversion.tedToToma(ted);

      if(trainings!=null && trainings.size()>0)
      {
        Training tr=(Training) trainings.elementAt(0);
	className=tr.getClass().getName();

	//teachers
	Vector teachers=new Vector();
	if(tr.getTeachers()!=null)
	    {
		Iterator it=tr.getTeachers().iterator();
		while(it.hasNext())
		    {
			Teacher teacher=(Teacher) it.next();
		        if(this.testAndSaveTeacherById(lng, teacher))
			  teachers.add(teacher);
		    }
	    }
	tr.setTeachers(teachers);

	//locations
	Vector locs=new Vector();
	if(tr.getLocations()!=null)
	{
	  Iterator iter = tr.getLocations().iterator();
	  while (iter.hasNext())
	  {
	    Location loc = (Location) iter.next();
	    if(this.testAndSaveLocationById(lng, loc))
	      locs.add(loc);
	  }
	}
	tr.setLocations(locs);

	//training contacts
	Vector trcontacts=new Vector();
	if(tr.getTrainingContacts()!=null)
	{
	  Iterator iter = tr.getTrainingContacts().iterator();
	  while (iter.hasNext())
	  {
	    Contact contact = (Contact) iter.next();
	    if(this.testAndSaveContactById(lng, contact))
	      trcontacts.add(contact);
	  }
	}
	tr.setTrainingContacts(trcontacts);

	try
	{
	  StandaloneTraining st=(StandaloneTraining) tr;

	  //catalogue
	  st.setCatalogues(catalogues);

	  //inscription contacts
	  Vector inscontacts=new Vector();
	  if(st.getInscriptionContacts()!=null)
	  {
	    Iterator iter = st.getInscriptionContacts().iterator();
	   while (iter.hasNext())
	    {
	      Contact contact = (Contact) iter.next();
	      if(this.testAndSaveContactById(lng, contact))
		inscontacts.add(contact);
	    }
	  }
	  st.setInscriptionContacts(inscontacts);

	if(className.equals("apostal.toma.data.TrainingCourse"))
	{
	  TrainingCourse tc=(TrainingCourse) tr;

	  if(this.testAndSaveTrainingCourseById(lng, tc))
	  {
	    //session
	    Vector sessions=new Vector();
	    if(tc.getCourseSessions()!=null)
	    {
	      Iterator iter = tc.getCourseSessions().iterator();
	      while (iter.hasNext())
	      {
	        CourseSession cs = (CourseSession) iter.next();

		cs.setIdTraining(tc.getIdTraining());

		//location
		Location loc=cs.getLocation();
		try
    {
      if(!this.testAndSaveLocationById(lng, loc))
        cs.setLocation(null);
    }
    catch(NullPointerException np){}
		//teachers
		Vector newSessionTeachers=new Vector();
		if(cs.getTeachers()!=null)
		{
		  Iterator iter_te = cs.getTeachers().iterator();
		  while (iter_te.hasNext())
		  {
		    Teacher teacher = (Teacher) iter_te.next();
		    if(this.testAndSaveTeacherById(lng, teacher))
		      newSessionTeachers.add(teacher);
		  }
		}
		cs.setTeachers(newSessionTeachers);

	        if(this.testAndSaveCourseSessionById(lng, cs))
		  sessions.add(cs);
	      }
	    }
	    tc.setCourseSessions(sessions);
	  }

	}
	else if(className.equals("apostal.toma.data.TrainingProgramme"))
	{
	  TrainingProgramme tp=(TrainingProgramme) tr;

	  if(this.testAndSaveTrainingProgrammeById(lng, tp))
	  {
	  //session
	  Vector sessions=new Vector();
	  if(tp.getProgrammeSessions()!=null)
	  {
	    Iterator iter = tp.getProgrammeSessions().iterator();
	    while (iter.hasNext())
	    {
	      ProgrammeSession ps = (ProgrammeSession) iter.next();

	      ps.setIdTraining(tp.getIdTraining());

	      //locations
	      Vector newSessionLocations=new Vector();
	      if(ps.getLocations()!=null)
	      {
		      Iterator iter_lo = ps.getLocations().iterator();
		      while (iter_lo.hasNext())
		      {
		        Location location = (Location) iter_lo.next();
		        if(this.testAndSaveLocationById(lng, location))
		         newSessionLocations.add(location);
		      }
	      }
	      ps.setLocations(newSessionLocations);

	      if(this.testAndSaveProgrammeSessionById(lng, ps))
		sessions.add(ps);
	    }
	  }
	  tp.setProgrammeSessions(sessions);

	  //units
	  Vector units=new Vector();
	  if(tp.getUnits()!=null)
	  {
	    Iterator iter_units = tp.getUnits().iterator();
	    while (iter_units.hasNext())
	    {
	      Unit u = (Unit) iter_units.next();

	      u.setIdProgramme(tp.getIdTraining());

	      //teachers
	      Vector u_teachers=new Vector();
	      if(u.getTeachers()!=null)
	      {
		  Iterator it=u.getTeachers().iterator();
		  while(it.hasNext())
		    {
			Teacher teacher=(Teacher) it.next();
		        if(this.testAndSaveTeacherById(lng, teacher))
			  u_teachers.add(teacher);
		    }
	      }
	      u.setTeachers(u_teachers);

	      //locations
	      Vector u_locs=new Vector();
	      if(u.getLocations()!=null)
	      {
	        Iterator iter = u.getLocations().iterator();
	        while (iter.hasNext())
	        {
	          Location loc = (Location) iter.next();
	          if(this.testAndSaveLocationById(lng, loc))
		    u_locs.add(loc);
	       }
	      }
	      u.setLocations(u_locs);

	      //training contacts
	      Vector u_trcontacts=new Vector();
	      if(u.getTrainingContacts()!=null)
	      {
	       Iterator iter = u.getTrainingContacts().iterator();
	       while (iter.hasNext())
	       {
	         Contact contact = (Contact) iter.next();
	         if(this.testAndSaveContactById(lng, contact))
		  u_trcontacts.add(contact);
		}
	      }
	      u.setTrainingContacts(u_trcontacts);


	      if(this.testAndSaveUnitById(lng, u))
	      {
		units.add(u);

	        //session
	        Vector u_sessions=new Vector();
	        if(u.getUnitSessions()!=null)
	        {
		  Iterator iter = u.getUnitSessions().iterator();
		  while (iter.hasNext())
		  {
		    UnitSession us = (UnitSession) iter.next();

		    us.setIdTraining(u.getIdTraining());

		    //location
		    Location loc=us.getLocation();
		    if(!this.testAndSaveLocationById(lng, loc))
		      us.setLocation(null);

		    //teachers
		    Vector newSessionTeachers=new Vector();
		    if(us.getTeachers()!=null)
		    {
		      Iterator iter_te = us.getTeachers().iterator();
		      while (iter_te.hasNext())
		      {
		        Teacher teacher = (Teacher) iter_te.next();
		        if(this.testAndSaveTeacherById(lng, teacher))
		         newSessionTeachers.add(teacher);
		      }
		    }
		    us.setTeachers(newSessionTeachers);

		    //programme sessions
		    //retrouver de quel unitSessionXML il s'agit, prendre le nom
		    //puis parcourir tous les programme session jusqu' obtenir le meme nom
		    String pname=ted.getProgrammeSessionNameByUnitSessionName(us.getSessionName());
		    int idps=-1;
		    Iterator iter_psn = tp.getProgrammeSessions().iterator();
		    while (iter_psn.hasNext() && idps==-1)
		    {
		      ProgrammeSession ps = (ProgrammeSession) iter_psn.next();
		      if(ps.getSessionName().equals(pname))
		      {
			idps=ps.getIdSession();
		      }
		    }
		    if(idps>-1)
		      us.setIdProgrammeSession(idps);

		    if(this.testAndSaveUnitSessionById(lng, us))
		      u_sessions.add(us);
		  }
	        }
	        u.setUnitSessions(u_sessions);
	      }
	    }
	  }
	  tp.setUnits(units);

	  }

	}
	else
	  TOMA.log(TOMA.SEVERE, "XMLImport: StandaloneTraining neither TrainingCourse nor TrainingProgramme");

	}
	catch(java.lang.ClassCastException ex)
	{
	  TOMA.log(TOMA.SEVERE, "XMLImport:The training was not a standalone training");
	}

      }
  }

  /**
   * mthodes "testAndSave...ById(lng, ...):
   * si l'id est superieur  -1 et testUpdate: update
   * sinon si l'id == -1: c'est une creation
   *      - pour teacher, location, contact: chargement par idsec
   *      (pour les creation qui ont deja ete cres dans cette instance. Dans ce cas,
   *      les valeurs ont dj t sauvs donc les nouvelles valeurs -de la 1ere sauvegarde- sont charges)
   *      - si testCreate: create
   * sinon renvoyer false
   * renvoyer true;
   */

  private boolean testAndSaveTrainingCourseById(Language lng, TrainingCourse tc)
  {
    if(tc==null)
      return false;
    else
    {
    boolean ok=true;
    TrainingCourseDB tDB=new TrainingCourseDB(tc);

    if(tc.getIdTraining()>-1 && tDB.testUpdate())
    {
      tDB.update();
    }
    else if(tc.getIdTraining()==-1 && tDB.testCreate())
    {
      tDB.create();
    }
    else
    {
      ok=false;
      TOMA.log(TOMA.SEVERE, "could not create nor update training course:"+tc);
    }

    return ok;
    }
  }

  private boolean testAndSaveTrainingProgrammeById(Language lng, TrainingProgramme tc)
  {
    if(tc==null)
      return false;
    else
    {
    boolean ok=true;
    TrainingProgrammeDB tDB=new TrainingProgrammeDB(tc);

    if(tc.getIdTraining()>-1 && tDB.testUpdate())
      tDB.update();
    else if(tc.getIdTraining()==-1 && tDB.testCreate())
    {
      tDB.create();
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update training programme:"+tc);
	}

    return ok;
    }
  }

  private boolean testAndSaveUnitById(Language lng, Unit tc)
  {
    if(tc==null)
      return false;
    else
    {
    boolean ok=true;
    UnitDB tDB=new UnitDB(tc);

    if(tc.getIdTraining()>-1 && tDB.testUpdate())
      tDB.update();
    else if(tc.getIdTraining()==-1 && tDB.testCreate())
    {
      tDB.create();
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update unit:"+tc);
	}

    return ok;
    }
  }

  private boolean testAndSaveTeacherById(Language lng, Teacher teacher)
  {
    if(teacher==null)
      return false;
    else
    {
    boolean ok=true;
    TeacherDB teacherDB=new TeacherDB(teacher);

    if(teacher.getIdTeacher()>-1 && teacherDB.testUpdate())
    {
	  //charger aussi les lments qui ne peuvent jamais etre dans le TED
	  //c-a-d: competences, adresse, tel, fax, email
	  teacherDB.loadElementsNotInTedById(lng);

	  teacherDB.update();
    }
    else if(teacher.getIdTeacher()==-1)
    {
      if(teacherDB.testCreate())
        teacherDB.create();
      else //il a dj t sauv
      {
	  teacherDB.loadByFirstnameLastnameFunction(lng, false);
	  if(teacherDB.testUpdate())
	    teacherDB.update();
      }
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update teacher:"+teacher);
	}

    return ok;
    }
  }

  private boolean testAndSaveLocationById(Language lng, Location loc)
  {
    if(loc==null)
      return false;
    else
    {
    boolean ok=true;
    LocationDB locDB=new LocationDB(loc);
    int loc_id = loc.getIdLocation();
    if(loc_id>-1 && locDB.testUpdate())
      locDB.update();
    else if(loc.getIdLocation()==-1)
    {
      if(locDB.testCreate())
        locDB.create();
      else
      {
	locDB.loadByDenomination(lng, false);
	if(locDB.testUpdate())
	  locDB.update();
      }
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update location:"+loc);
	}

    return ok;
    }
  }

  private boolean testAndSaveContactById(Language lng, Contact c)
  {
    if(c==null)
      return false;
    else
    {
    boolean ok=true;
    ContactDB cDB=new ContactDB(c);

    if(c.getIdContact()>-1 && cDB.testUpdate())
      cDB.update();
    else if(c.getIdContact()==-1)
    {
      if(cDB.testCreate())
        cDB.create();
      else
      {
	cDB.loadByFirstnameLastnameTelEmail(lng, false);
	if(cDB.testUpdate())
	  cDB.update();
      }
    }
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update contact:"+c);
	}

    return ok;
    }
  }

 private boolean testAndSaveCourseSessionById(Language lng, CourseSession c)
  {
    if(c==null)
      return false;
    else
    {
    boolean ok=true;
    CourseSessionDB cDB=new CourseSessionDB(c);

    if(c.getIdSession()>-1 && cDB.testUpdate())
      cDB.update();
    else if(c.getIdSession()==-1 && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update course session:"+c);
	}

    return ok;
    }
  }

  private boolean testAndSaveProgrammeSessionById(Language lng, ProgrammeSession c)
  {
    if(c==null)
      return false;
    else
    {
    boolean ok=true;
    ProgrammeSessionDB cDB=new ProgrammeSessionDB(c);

    if(c.getIdSession()>-1 && cDB.testUpdate())
      cDB.update();
    else if(c.getIdSession()==-1 && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update programme session:"+c);
	}

    return ok;
    }
  }

  private boolean testAndSaveUnitSessionById(Language lng, UnitSession c)
  {
    if(c==null)
      return false;
    else
    {
    boolean ok=true;
    UnitSessionDB cDB=new UnitSessionDB(c);

    if(c.getIdSession()>-1 && cDB.testUpdate())
      cDB.update();
    else if(c.getIdSession()==-1 && cDB.testCreate())
      cDB.create();
    else
	{
	    ok=false;
	    TOMA.log(TOMA.SEVERE, "could not create nor update unit session:"+c);
	}

    return ok;
    }
  }

}
