// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.AddressXML;
import apostal.ted.CountryXML;
import apostal.toma.data.Address;
import apostal.toma.data.Country;
import apostal.toma.data.TOMALabels;

import java.util.Vector;

public class AddressConversion {

    private CountryConversion cc;
    TOMALabels labels;

    public AddressConversion() {
        labels = new TOMALabels();
        cc = new CountryConversion();
    }

    public boolean checkTedCompliance(Address a, String message, boolean generation) {
        String newMessage = labels.get("apostal.toma.tomatoted.address") + " " + message;
        boolean compliance = true;
        if (a != null) {
            if (a.getPostCode() == null || a.getPostCode().equals("")) {
                if (!generation) {

                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.address.postCode") + " " + newMessage);
                }
                compliance = false;
            }
            if (a.getCity() == null || a.getCity().equals("")) {
                if (!generation) {
                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.address.city") + " " + newMessage);
                }
                compliance = false;
            }
            if (a.getAddressLines() == null || (a.getAddressLines()).size() == 0) {
                if (!generation) {
                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.address.addressline") + " " + newMessage);
                }
                compliance = false;
            }
            if (a.getCountry() == null || !cc.checkTedCompliance(a.getCountry())) {
                if (!generation) {
                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.address.country") + " " + newMessage);
                }
                compliance = false;
            }
        } else
            compliance = false;
        return compliance;
    }

    public AddressXML tomaToTed(Address a) {
        AddressXML address = null;

        String postCode = a.getPostCode();
        String city = a.getCity();
        Vector addressLines = a.getAddressLines();
        Country country = a.getCountry();
        if (cc.checkTedCompliance(country) && city != null && addressLines != null && postCode != null) {
            address = new AddressXML(addressLines, postCode, city, cc.tomaToTed(country));
        }

        return address;

    }

    public Address tedToToma(AddressXML a) {
        String postCode = a.getPostCode();
        String city = a.getCity();
        Vector addressLines = a.getAddressLines();
        CountryXML country = a.getCountry();
        Address address = new Address(addressLines, city, postCode, cc.tedToToma(country));
        return address;

    }
}