// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.CatalogueXML;
import apostal.toma.TOMA;
import apostal.toma.data.Catalogue;
import apostal.toma.data.Language;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.CatalogueDB;
import apostal.toma.external.Publication;

import java.util.Vector;

public class CatalogueConversion {

    private int nborder = -1;

    TOMALabels labels;

    public CatalogueConversion() {
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Catalogue c, String message) {
        boolean compliance = true;
        if (c != null) {
            if (c.getTitle() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.catalogue.title") + " " + message);
            }
        } else
            compliance = false;
        return compliance;
    }

    public CatalogueXML tomaToTed(Catalogue c, CatalogueXML sousCatXML, int orderCat, String catalogueFictif, Language lang, boolean syrecos, boolean addFirstCat) {
        int id = c.getIdCatalogue();
        String description = c.getDescription();
        String title = c.getTitle();
        int order = orderCat;
        int superCat = c.getIdSuperCatalogue();
        CatalogueXML catalogue = sousCatXML;
        if (this.isCatSelected(id)) {
            if (title != null) {
                CatalogueXML catalogueTemp = new CatalogueXML(title);
                if (description != null) {
                    catalogueTemp.setDescription(description);
                }
                catalogueTemp.setKey(String.valueOf(id));
                if (sousCatXML != null) {
                    catalogueTemp.setCatalogue(sousCatXML);
                }
                catalogueTemp.setOrder(order);
                Catalogue superCatToma = new Catalogue(superCat);
                CatalogueDB cDB = new CatalogueDB(superCatToma);
                cDB.loadById(lang, true, false);
                catalogue = this.tomaToTed(superCatToma, catalogueTemp, superCatToma.getNborder(), catalogueFictif, lang, syrecos, addFirstCat);
            }
        } else {
            if (addFirstCat && !syrecos) {
                CatalogueXML catXML = new CatalogueXML(catalogueFictif);
                catXML.setKey("-1");
                if (sousCatXML != null) {
                    catXML.setCatalogue(sousCatXML);
                }
                catalogue = catXML;
            }/* else if (syrecos) {
                CatalogueXML catXML = new CatalogueXML(catalogueFictif);
                catXML.setKey("-1");
                if (sousCatXML != null) {
                    catXML.setCatalogue(sousCatXML);
                }
                catalogue = catXML;
            }   */
        }
        return catalogue;
    }

    private boolean isCatSelected(int id) {
        boolean select = false;
        int[] tabInt = Publication.tabCatalogueSelected;
        if (tabInt != null) {
            int i = 0;
            while (i < tabInt.length && select == false) {
                if (id == tabInt[i]) {
                    select = true;
                }
                i++;
            }
        }
        return select;
    }

    public Catalogue tedToToma(CatalogueXML c) {

        String description = c.getDescription();
        String title = c.getTitle();
        CatalogueXML catalogueXML = c.getCatalogue();
        Catalogue catalogue = new Catalogue();
        if (catalogueXML != null) {
            Vector catalogues = new Vector();
            catalogues.add(this.tedToToma(catalogueXML));
            catalogue.setCatalogues(catalogues);
        }
        if (title != null) catalogue.setTitle(title);
        if (description != null) catalogue.setDescription(description);

        String key = c.getKey();
        if (key != null && !key.equals("")) {
            try {
                int id = Integer.parseInt(key);
                catalogue.setIdCatalogue(id);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "CatalogueConversion, key not a number: " + key);
            }
        }

        nborder = c.getOrder();

        return catalogue;
    }

    public int getNborder() {
        return nborder;
    }
}
