// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.AddressXML;
import apostal.ted.ContactXML;
import apostal.toma.TOMA;
import apostal.toma.data.Address;
import apostal.toma.data.Contact;
import apostal.toma.data.TOMALabels;


public class ContactConversion {
    private AddressConversion addrConvert;
    TOMALabels labels;

    public ContactConversion() {
        addrConvert = new AddressConversion();
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Contact c, String message) {
        boolean compliance = true;
        String newMessage = labels.get("apostal.toma.tomatoted.contact.address") + " " + c.getLastname() + " " + message;

        if (c != null) {
            if (c.getLastname() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.contact.lastName") + " " + labels.get("apostal.toma.tomatoted.contact") + " " + message);
            }
            if (c.getAddress() != null) {
                addrConvert.checkTedCompliance(c.getAddress(), newMessage, false);

            }
        } else
            compliance = false;
        return compliance;
    }

    public ContactXML tomaToTed(Contact c) {
        String email = c.getEmail();
        String fax = c.getFax();
        String firstName = c.getFirstname();
        String lastName = c.getLastname();
        String tel = c.getTel();
        String title = c.getTitle();
        String function = c.getFunction();
        Address address = c.getAddress();
        ContactXML contact = null;
        if (lastName != null) {
            contact = new ContactXML(lastName);
            if (firstName != null)
                contact.setFirstname(firstName);
            if (title != null)
                contact.setTitle(title);
            if (function != null)
                contact.setFunction(function);
            if (tel != null)
                contact.setTel(tel);
            if (fax != null)
                contact.setFax(fax);
            if (email != null)
                contact.setEmail(email);
            if (addrConvert.checkTedCompliance(address, "", true))
                contact.setAddress(addrConvert.tomaToTed(address));
        }

        return contact;
    }

    public Contact tedToToma(ContactXML c) {
        String email = c.getEmail();
        String fax = c.getFax();
        String firstName = c.getFirstname();
        String lastName = c.getLastname();
        String tel = c.getTel();
        String title = c.getTitle();
        String function = c.getFunction();
        AddressXML address = c.getAddress();

        Contact contact = new Contact();

        String key = c.getKey();
        if (key != null && !key.equals("")) {
            try {
                int id = Integer.parseInt(key);
                contact.setIdContact(id);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "ContactConversion, key not a number: " + key);
            }
        }

        if (lastName != null)
            contact.setLastname(lastName);
        if (firstName != null)
            contact.setFirstname(firstName);
        if (title != null)
            contact.setTitle(title);
        if (function != null)
            contact.setFunction(function);
        if (tel != null)
            contact.setTel(tel);
        if (fax != null)
            contact.setFax(fax);
        if (email != null)
            contact.setEmail(email);
        if (address != null)
            contact.setAddress(addrConvert.tedToToma(address));

        return contact;
    }
}
