// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.*;
import apostal.toma.database.LanguageDB;
import apostal.toma.database.LocationDB;
import apostal.toma.database.TeacherDB;

import java.util.Iterator;
import java.util.Vector;

public class CourseSessionConversion {

    private SlotConversion slotConvert;
    private LocationConversion locConvert;
    private LanguageConversion langueConvert;
    private TeacherConversion teacherConvert;
    private SeanceConversion seanceConvert;
    private DateConversion dateConvert;
    TOMALabels labels;
    private LocationDB locDB;
    private TeacherDB teacherDB;

    public CourseSessionConversion() {
        slotConvert = new SlotConversion();
        locConvert = new LocationConversion();
        langueConvert = new LanguageConversion();
        teacherConvert = new TeacherConversion();
        seanceConvert = new SeanceConversion();
        dateConvert = new DateConversion();
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(CourseSession s, String message, Language lang) {
        boolean compliance = true;
        if (s != null) {
            if (s.getBeginValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
            }
            if (s.getEndValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
            }
            if (s.getBeginDate() == null || s.getEndDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
            }
            if (s.getSlot() == null || !slotConvert.checkTedCompliance(s.getSlot())) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.slot") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
            }
            if (s.getTeachers() != null && !s.getTeachers().isEmpty()) {
                Iterator it = s.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    /*teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang,true); */
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
                    teacherConvert.checkTedCompliance(tcs, newMessage);
                }
            }
            if (s.getLocation() != null) {
                Location loc = s.getLocation();
                /*locDB = new LocationDB(loc);
                locDB.loadById(lang,true);  */
                String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
                locConvert.checkTedCompliance(loc, newMessage);
            }
            if (s.getSeances() != null && !s.getSeances().isEmpty()) {
                Iterator it = s.getSeances().iterator();
                Seance seance;
                while (it.hasNext()) {
                    seance = (Seance) it.next();
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() + " " + message);
                    seanceConvert.checkTedCompliance(seance, newMessage);
                }
            }
        } else {
            compliance = false;
        }
        return compliance;
    }

    /*   public boolean checkTedCompliance(CourseSession s,String message,Language lang) {
              boolean compliance = true;
           if (s!=null){
               if (s.getBeginValidityDate()==null){
                   compliance = false;
                   TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+" "+ s.getSessionName() +" " + message);
               }
               if (s.getEndValidityDate()==null){
                   compliance = false;
                   TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ s.getSessionName() +" " + message);
               }
               if (s.getBeginDate()==null || s.getEndDate()==null){
                   compliance=false;
                   TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ s.getSessionName() +" " + message);
               }
               if (s.getSlot()==null || !slotConvert.checkTedCompliance(s.getSlot())){
                   compliance = false;
                   TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.slot") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " " + s.getSessionName() +" " + message);
               }
               if (s.getTeachers() != null && !s.getTeachers().isEmpty()){
                   Iterator it = s.getTeachers().iterator();
                   Teacher tcs;
                   while (it.hasNext()){
                       tcs = (Teacher)it.next();
                       teacherDB = new TeacherDB(tcs);
                       teacherDB.loadById(lang,true);
                       String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " +s.getSessionName() +" " +  message);
                       teacherConvert.checkTedCompliance(tcs,newMessage);
                   }
               }
               if (s.getLocation()!=null){
                   Location loc = s.getLocation();
                   locDB = new LocationDB(loc);
                   locDB.loadById(lang,true);
                   String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") +" " +s.getSessionName() + " " +  message);
                   locConvert.checkTedCompliance(loc,newMessage);
               }
               if (s.getSeances()!=null && !s.getSeances().isEmpty()){
                   Iterator it = s.getSeances().iterator();
                   Seance seance;
                   while (it.hasNext()){
                       seance = (Seance)it.next();
                       String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + s.getSessionName() +" " +  message);
                       seanceConvert.checkTedCompliance(seance,newMessage);
                   }
               }
           } else {
               compliance=false;
           }
           return compliance;
          } */


 /*   public CourseSessionXML tomaToTed(CourseSession s, TrainingCourse t, Language lang) {

        String comment = s.getComment();
        String price = s.getPrice();
        String priceComment = s.getPriceComment();
        String sessionName = s.getSessionName();
        String textualCalendar = s.getTextualCalendar();
        Language language = s.getLanguage();
        Location location = s.getLocation();
        Vector teachers = s.getTeachers();
        Vector seances = s.getSeances();
        Slot slot = s.getSlot();
        java.sql.Date beginDate = s.getBeginDate();
        java.sql.Date endDate = s.getEndDate();
        java.sql.Date beginValidityDate = s.getBeginValidityDate();
        java.sql.Date endValidityDate = s.getEndValidityDate();
        DateXML dateTemp = new DateXML();

        CourseSessionXML courseSession = new CourseSessionXML();

        if (location != null) {
            LocationDB lDB = new LocationDB(location);
            lDB.loadById(lang, true);
            //if (locConvert.checkTedCompliance(location))
            courseSession.setLocation(locConvert.tomaToTed(location, lang));
        }

        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                //if (teacherConvert.checkTedCompliance(teacher,""))
                courseSession.addTeacher(teacherConvert.tomaToTed(teacher, t, lang));
            }
        }

        BeginValidityDateXML validityDateXML;
        EndValidityDateXML endValidityDateXML;

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getBeginValidityDate());
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            s.setBeginValidityDate(t.getBeginValidityDate());
        }
        courseSession.setBeginValidityDate(validityDateXML);
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getEndValidityDate());
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            s.setEndValidityDate(t.getEndValidityDate());
        }
        courseSession.setEndValidityDate(endValidityDateXML);

        if (seances != null) {
            Iterator it = seances.iterator();
            Seance seance;
            while (it.hasNext()) {
                seance = (Seance) it.next();
                courseSession.addSeance(seanceConvert.tomaToTed(seance, s));
            }
        }
        BeginDateXML beginDateXML = new BeginDateXML();
        ;
        EndDateXML endDateXML = new EndDateXML();
        if (beginDate != null && endDate != null) {
            dateTemp = dateConvert.tomaToTed(beginDate);
            beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            dateTemp = dateConvert.tomaToTed(endDate);
            endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());

        } else {
            if (beginDate == null) {
                dateTemp = dateConvert.tomaToTed(s.getBeginValidityDate());
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(beginDate);
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
            if (endDate == null) {
                dateTemp = dateConvert.tomaToTed(s.getEndValidityDate());
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(endDate);
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
        }
        DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML, endDateXML);
        courseSession.setDateInterval(intervalXML);

        //if (slotConvert.checkTedCompliance(slot))
        courseSession.setSlot(slotConvert.tomaToTed(slot));
        if (langueConvert.checkTedCompliance(language)) {
            LanguageDB langDB = new LanguageDB(language);
            langDB.loadByCode(lang);
            courseSession.setLanguage(langueConvert.tomaToTed(language));
        }
        if (comment != null)
            courseSession.setComment(comment);
        if (price != null)
            courseSession.setPrice(price);
        if (priceComment != null)
            courseSession.setPriceComment(priceComment);
        if (sessionName != null)
            courseSession.setSessionName(sessionName);
        if (textualCalendar != null)
            courseSession.setTextualCalendar(textualCalendar);

        return courseSession;
    }   */

    public CourseSessionXML tomaToTed(CourseSession s, TrainingCourse t, Language lang) {

        String comment = s.getComment();
        String price = s.getPrice();
        String priceComment = s.getPriceComment();
        String sessionName = s.getSessionName();
        String textualCalendar = s.getTextualCalendar();
        Language language = s.getLanguage();
        Location location = s.getLocation();
        Vector teachers = s.getTeachers();
        Vector seances = s.getSeances();
        Slot slot = s.getSlot();
        java.sql.Date beginDate = s.getBeginDate();
        java.sql.Date endDate = s.getEndDate();
        java.sql.Date beginValidityDate = s.getBeginValidityDate();
        java.sql.Date endValidityDate = s.getEndValidityDate();
        DateXML dateTemp = new DateXML();

        CourseSessionXML courseSession = new CourseSessionXML();

        if (location != null) {
          /*  LocationDB lDB = new LocationDB(location);
            lDB.loadById(lang, true);  */
            //if (locConvert.checkTedCompliance(location))
            courseSession.setLocation(locConvert.tomaToTed(location, lang));
        }

        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                //if (teacherConvert.checkTedCompliance(teacher,""))
                courseSession.addTeacher(teacherConvert.tomaToTed(teacher, t, lang));
            }
        }

        BeginValidityDateXML validityDateXML;
        EndValidityDateXML endValidityDateXML;

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getBeginValidityDate());
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            s.setBeginValidityDate(t.getBeginValidityDate());
        }
        courseSession.setBeginValidityDate(validityDateXML);
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getEndValidityDate());
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            s.setEndValidityDate(t.getEndValidityDate());
        }
        courseSession.setEndValidityDate(endValidityDateXML);

        if (seances != null) {
            Iterator it = seances.iterator();
            Seance seance;
            while (it.hasNext()) {
                seance = (Seance) it.next();
                courseSession.addSeance(seanceConvert.tomaToTed(seance, s));
            }
        }
        BeginDateXML beginDateXML = new BeginDateXML();
        ;
        EndDateXML endDateXML = new EndDateXML();
        if (beginDate != null && endDate != null) {
            dateTemp = dateConvert.tomaToTed(beginDate);
            beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            dateTemp = dateConvert.tomaToTed(endDate);
            endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());

        } else {
            if (beginDate == null) {
                dateTemp = dateConvert.tomaToTed(s.getBeginValidityDate());
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(beginDate);
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
            if (endDate == null) {
                dateTemp = dateConvert.tomaToTed(s.getEndValidityDate());
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(endDate);
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
        }
        DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML, endDateXML);
        courseSession.setDateInterval(intervalXML);

        //if (slotConvert.checkTedCompliance(slot))
        courseSession.setSlot(slotConvert.tomaToTed(slot));
        if (langueConvert.checkTedCompliance(language)) {
            LanguageDB langDB = new LanguageDB(language);
            langDB.loadByCode(lang);
            courseSession.setLanguage(langueConvert.tomaToTed(language));
        }
        if (comment != null)
            courseSession.setComment(comment);
        if (price != null)
            courseSession.setPrice(price);
        if (priceComment != null)
            courseSession.setPriceComment(priceComment);
        if (sessionName != null)
            courseSession.setSessionName(sessionName);
        if (textualCalendar != null)
            courseSession.setTextualCalendar(textualCalendar);

        return courseSession;
    }

    public CourseSession tedToToma(CourseSessionXML s) {

        String comment = s.getComment();
        String price = s.getPrice();
        String priceComment = s.getPriceComment();
        String sessionName = s.getSessionName();
        String textualCalendar = s.getTextualCalendar();
        Vector teachers = s.getTeachers();
        Vector seances = s.getSeances();
        LanguageXML languageXML = s.getLanguage();
        LocationXML locationXML = s.getLocation();
        SlotXML slotXML = s.getSlot();
        BeginValidityDateXML validityDate = s.getBeginValidityDate();
        EndValidityDateXML endValidityDate = s.getEndValidityDate();
        DateIntervalXML interval = s.getDateInterval();
        BeginDateXML beginDate = interval.getBeginDate();
        EndDateXML endDate = interval.getEndDate();

        CourseSession courseSession = new CourseSession();


        if (beginDate != null)
            courseSession.setBeginDate((new DateConversion()).tedToToma(beginDate));
        if (endDate != null)
            courseSession.setEndDate((new DateConversion()).tedToToma(endDate));
        if (validityDate != null)
            courseSession.setBeginValidityDate((new DateConversion()).tedToToma(validityDate));
        if (endValidityDate != null)
            courseSession.setEndValidityDate((new DateConversion()).tedToToma(endValidityDate));
        if (textualCalendar != null)
            courseSession.setTextualCalendar(textualCalendar);
        if (comment != null)
            courseSession.setComment(comment);
        if (price != null)
            courseSession.setPrice(price);
        if (priceComment != null)
            courseSession.setPriceComment(priceComment);
        if (sessionName != null)
            courseSession.setSessionName(sessionName);
        if (slotXML != null)
            courseSession.setSlot(slotConvert.tedToToma(slotXML));
        if (locationXML != null)
            courseSession.setLocation(locConvert.tedToToma(locationXML));
        if (languageXML != null)
            courseSession.setLanguage(langueConvert.tedToToma(languageXML));


        if (teachers != null) {
            Iterator it = teachers.iterator();
            Vector teachersToma = new Vector();
            TeacherXML teacher;
            while (it.hasNext()) {
                teacher = (TeacherXML) it.next();
                teachersToma.add(teacherConvert.tedToToma(teacher));
            }
            courseSession.setTeachers(teachersToma);
        }

        if (seances != null) {
            Iterator it = seances.iterator();
            Vector seancesToma = new Vector();
            SeanceXML seance;
            while (it.hasNext()) {
                seance = (SeanceXML) it.next();
                seancesToma.add(seanceConvert.tedToToma(seance));
            }
            courseSession.setSeances(seancesToma);
        }


        return courseSession;
    }
}
