// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.AddressXML;
import apostal.ted.AreaXML;
import apostal.ted.LocationXML;
import apostal.toma.TOMA;
import apostal.toma.data.*;

import java.util.Iterator;
import java.util.Vector;

public class LocationConversion {

    AddressConversion addrConvert = new AddressConversion();
    AreaConversion areaConvert = new AreaConversion();
    TOMALabels labels;

    public LocationConversion() {
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Location l, String message) {
        boolean compliance = true;
        if (l != null) {
            if (l.getDenomination() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.location.denomination") + " " + labels.get("apostal.toma.tomatoted.location") + " " + message);
            }
            if (l.getAddress() != null) {
                String newMesage = labels.get("apostal.toma.tomatoted.location.address") + " " + l.getDenomination() + " " + message + " ";
                if (!addrConvert.checkTedCompliance(l.getAddress(), newMesage, false)) {
                    compliance = false;

                }
            } else {
                compliance = false;
            }
        } else {
            compliance = false;
        }

        return compliance;
    }


    public LocationXML tomaToTed(Location l, Language lang) {

        String accessDescription = l.getAccessDescription();
        String accessComment = l.getAccessComment();
        String accessFacilities = l.getAccessFacilities();
        Address address = l.getAddress();
        Area area = l.getArea();
        String completeName = l.getCompleteName();
        String denomination = l.getDenomination();
        String email = l.getEmail();
        String fax = l.getFax();
        Vector images = l.getImages();
        String tel = l.getTel();

        LocationXML location = null;
        if (denomination != null) {
            location = new LocationXML();
            location.setDenomination(denomination);

            if (accessDescription != null)
                location.setAccessDescription(accessDescription);
            if (accessComment != null)
                location.setAccessComment(accessComment);
            if (accessFacilities != null)
                location.setAccessFacilities(accessFacilities);
            if (tel != null)
                location.setTel(tel);
            if (fax != null)
                location.setFax(fax);
            if (email != null)
                location.setEmail(email);
            if (completeName != null)
                location.setCompleteName(completeName);
            if (addrConvert.checkTedCompliance(address, "", true)) {
                location.setAddress(addrConvert.tomaToTed(address));
            } else {
                String addrLine = new String("6, rue Coudenhove-Kalergi");
                Vector lines = new Vector();
                lines.add(addrLine);
                address = new Address(lines, "Luxembourg", "L-1359", new Country("LU"));
                location.setAddress(addrConvert.tomaToTed(address));
            }
            if (area != null)
                location.setArea(areaConvert.tomaToTed(area, null, lang));
            if (images != null) {
                Iterator it = images.iterator();
                while (it.hasNext()) {
                    location.addImage((String) it.next());
                }
            }
        }
        return location;

    }

    public Location tedToToma(LocationXML l) {

        String accessDescription = l.getAccessDescription();
        String accessComment = l.getAccessComment();
        String accessFacilities = l.getAccessFacilities();
        AddressXML addressXML = l.getAddress();
        AreaXML areaXML = l.getArea();
        String completeName = l.getCompleteName();
        String denomination = l.getDenomination();
        String email = l.getEmail();
        String fax = l.getFax();
        Vector images = l.getImages();
        String tel = l.getTel();

        Location location = new Location();

        String key = l.getKey();
        if (key != null && !key.equals("")) {
            try {
                int id = Integer.parseInt(key);
                location.setIdLocation(id);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "LocationConversion, key not a number: " + key);
            }
        }

        if (accessDescription != null)
            location.setAccessDescription(accessDescription);
        if (accessComment != null)
            location.setAccessComment(accessComment);
        if (accessFacilities != null)
            location.setAccessFacilities(accessFacilities);
        if (tel != null)
            location.setTel(tel);
        if (fax != null)
            location.setFax(fax);
        if (email != null)
            location.setEmail(email);
        if (denomination != null)
            location.setDenomination(denomination);
        if (completeName != null)
            location.setCompleteName(completeName);

        location.setAddress(addrConvert.tedToToma(addressXML));
        if (images != null)
            location.setImages(images);
        if (areaXML != null) {
            location.setArea(areaConvert.tedToToma(areaXML));
        }

        return location;
    }
}
