// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.AddressXML;
import apostal.ted.OrganismXML;
import apostal.toma.TOMA;
import apostal.toma.data.Address;
import apostal.toma.data.Organism;
import apostal.toma.data.TOMALabels;

import java.util.Iterator;
import java.util.Vector;

public class OrganismConversion {

    private AddressConversion adrConvert = new AddressConversion();
    TOMALabels labels;

    public OrganismConversion() {
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Organism o, String message) {
        boolean compliance = true;
        if (o != null) {
            if (o.getDenomination() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.organism.denomination") + " " + labels.get("apostal.toma.tomatoted.organism") + " " + message);
            }
            if (o.getAddresses() != null) {

                Iterator it = o.getAddresses().iterator();
                Address address;
                boolean presence = false;
                while (it.hasNext() && !presence) {
                    address = (Address) it.next();
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.organism.address") + " " + message);
                    if (adrConvert.checkTedCompliance(address, newMessage, false)) {
                        presence = true;
                    }
                }
                compliance = presence;


            }
        } else
            compliance = false;
        return compliance;

    }

    public OrganismXML tomaToTed(Organism o, boolean publish) {

        String completeName = o.getCompleteName();
        String denomination = o.getDenomination();
        String presentation = o.getPresentation();
        String url = o.getUrl();
        int key = o.getIdOrganism();

        Vector addresses = o.getAddresses();

        OrganismXML organism = null;
        if (denomination != null)
            organism = new OrganismXML(denomination);
        else {
            organism = new OrganismXML("organism");
            TOMA.log(TOMA.WARNING, "OrganismConversion.tomaToTed: the organism didn't have a denomination. 'organism' was used instead");
        }
        if (publish) {
            if (completeName != null)
                organism.setCompleteName(completeName);
            if (presentation != null)
                organism.setPresentation(presentation);
            if (url != null)
                organism.setUrl(url);
            if (addresses != null) {
                Iterator it = addresses.iterator();
                Address address;
                while (it.hasNext()) {
                    address = (Address) it.next();
                    if (adrConvert.checkTedCompliance(address, "", true)) {
                        organism.addAddress(adrConvert.tomaToTed(address));
                    }
                }
            }
        }

        return organism;
    }

    public Organism tedToToma(OrganismXML o) {

        String completeName = o.getCompleteName();
        String denomination = o.getDenomination();
        String presentation = o.getPresentation();
        String url = o.getUrl();
        Vector addresses = o.getAddresss();

        Organism organism = new Organism();

        String key = o.getKey();
        if (key != null && !key.equals("")) {
            try {
                int idOrganism = Integer.parseInt(key);
                organism.setIdOrganism(idOrganism);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "OrganismConversion, key not a number: " + key);
            }
        }

        if (completeName != null)
            organism.setCompleteName(completeName);
        if (presentation != null)
            organism.setPresentation(presentation);
        if (url != null)
            organism.setUrl(url);
        if (denomination != null)
            organism.setDenomination(denomination);

        if (addresses != null) {
            Iterator it = addresses.iterator();
            Vector addressesToma = new Vector();
            AddressXML address;
            while (it.hasNext()) {
                address = (AddressXML) it.next();
                addressesToma.add(adrConvert.tedToToma(address));
            }
            organism.setAddresses(addressesToma);
        }

        return organism;
    }
}
