// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.*;
import apostal.toma.database.CatalogueDB;
import apostal.toma.database.ContactDB;
import apostal.toma.database.LocationDB;
import apostal.toma.database.TeacherDB;

import java.util.Iterator;
import java.util.Vector;

public class ProgrammeSessionConversion {

    private SlotConversion slotConvert;
    private LocationConversion locConvert;
    private LanguageConversion langueConvert;
    private DateConversion dateConvert;
    TOMALabels labels;
   /* private LocationDB locDB;
    private TeacherDB teacherDB;
    private ContactDB contactDB;
    private CatalogueDB catalogueDB;  */

    public ProgrammeSessionConversion() {
        slotConvert = new SlotConversion();
        locConvert = new LocationConversion();
        langueConvert = new LanguageConversion();
        dateConvert = new DateConversion();
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(ProgrammeSession p, String message) {
        boolean compliance = true;
        if (p != null) {
            if (p.getSessionName() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.name") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + p.getSessionName() + " " + message);
            }

            if (p.getBeginValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + p.getSessionName() + " " + message);
            }
            if (p.getEndValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + p.getSessionName() + " " + message);
            }
            if (p.getBeginDate() == null || p.getEndDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + p.getSessionName() + " " + message);
            }
            if (p.getLocations() != null && !p.getLocations().isEmpty()) {
                Iterator it = p.getLocations().iterator();
                Location loc;
                while (it.hasNext()) {
                    loc = (Location) it.next();
                    /*	locDB = new LocationDB(loc);
                        locDB.loadById(new Language("fra"),true);  */
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + p.getSessionName() + " " + message);
                    locConvert.checkTedCompliance(loc, newMessage);
                }
            }

        } else {
            compliance = false;
        }
        return compliance;
    }

    /*public boolean checkTedCompliance(ProgrammeSession p, String message) {
    	boolean compliance = true;
    	if (p!=null){
    		if (p.getSessionName()==null) {
    			compliance = false;
    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.name") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ p.getSessionName() + " " + message);
    		}

    		if (p.getBeginValidityDate()==null){
    			compliance = false;
    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.beginValidityDate") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ p.getSessionName() + " " + message);
    		}
    		if (p.getEndValidityDate()==null){
    			compliance = false;
    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.endValidityDate") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ p.getSessionName() + " " + message);
    		}
    		if (p.getBeginDate()==null || p.getEndDate()==null){
    			compliance=false;
    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") +" " + labels.get("apostal.toma.tomatoted.trainingCourse.session")+ " "+ p.getSessionName() + " " + message);
    		}
    		if (p.getLocations()!=null && !p.getLocations().isEmpty()){
	    		Iterator it = p.getLocations().iterator();
	    		Location loc;
	    		while (it.hasNext()){
	    			loc = (Location)it.next();
	    			locDB = new LocationDB(loc);
	    			locDB.loadById(new Language("fra"),true);
	    			String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " "+ p.getSessionName() + " " +  message);
	    			locConvert.checkTedCompliance(loc,newMessage);
	    		}
	    	}

    	} else {
    		compliance=false;
    	}
    	return compliance;
    }   */


    public ProgrammeSessionXML tomaToTed(ProgrammeSession p, TrainingProgramme t, Language lang) {

        String comment = p.getComment();
        String price = p.getPrice();
        String priceComment = p.getPriceComment();
        String sessionName = p.getSessionName();
        Language language = p.getLanguage();
        Vector locations = p.getLocations();
        Vector slots = p.getSlots();
        java.sql.Date beginDate = p.getBeginDate();
        java.sql.Date endDate = p.getEndDate();
        java.sql.Date beginValidityDate = p.getBeginValidityDate();
        java.sql.Date endValidityDate = p.getEndValidityDate();
        DateXML dateTemp = new DateXML();


        ProgrammeSessionXML programmeSession = new ProgrammeSessionXML();

        if (slots != null) {
            Iterator it = slots.iterator();
            Slot slot;
            while (it.hasNext()) {
                slot = (Slot) it.next();
                if (slotConvert.checkTedCompliance(slot))
                    programmeSession.addSlot(slotConvert.tomaToTed(slot));
            }

        }

        BeginValidityDateXML validityDateXML;
        EndValidityDateXML endValidityDateXML;

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getBeginValidityDate());
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            p.setBeginValidityDate(t.getBeginValidityDate());
        }
        programmeSession.setBeginValidityDate(validityDateXML);
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(t.getEndValidityDate());
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            p.setEndValidityDate(t.getEndValidityDate());
        }
        programmeSession.setEndValidityDate(endValidityDateXML);

        BeginDateXML beginDateXML = new BeginDateXML();

        EndDateXML endDateXML = new EndDateXML();
        if (beginDate != null && endDate != null) {
            dateTemp = dateConvert.tomaToTed(beginDate);
            beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            dateTemp = dateConvert.tomaToTed(endDate);
            endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());

        } else {
            if (beginDate == null) {
                dateTemp = dateConvert.tomaToTed(p.getBeginValidityDate());
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(beginDate);
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
            if (endDate == null) {
                dateTemp = dateConvert.tomaToTed(p.getEndValidityDate());
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(endDate);
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
        }
        DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML, endDateXML);
        programmeSession.setDateInterval(intervalXML);

        if (locations != null) {
            Iterator it = locations.iterator();
            Location location;
            while (it.hasNext()) {
                location = (Location) it.next();
                LocationDB lDB = new LocationDB(location);
                lDB.loadById(lang, true);
                //if (locConvert.checkTedCompliance(location))
                programmeSession.addLocation(locConvert.tomaToTed(location, lang));
            }

        }

/*	if (beginDate!=null && endDate!=null){
     		dateTemp = dateConvert.tomaToTed(beginDate);
     		BeginDateXML beginDateXML = new BeginDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		dateTemp = dateConvert.tomaToTed(endDate);
     		EndDateXML endDateXML = new EndDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML,endDateXML);
     		programmeSession.setDateInterval(intervalXML);
     	}else {
    		dateTemp = dateConvert.tomaToTed(beginValidityDate);
     		BeginDateXML beginDateXML = new BeginDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		dateTemp = dateConvert.tomaToTed(endValidityDate);
     		EndDateXML endDateXML = new EndDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML,endDateXML);
     		programmeSession.setDateInterval(intervalXML);
	   	}
     	if (beginValidityDate!=null){
     		dateTemp = dateConvert.tomaToTed(beginValidityDate);
     		BeginValidityDateXML validityDateXML = new BeginValidityDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		programmeSession.setBeginValidityDate(validityDateXML);
     	}
     	if (endValidityDate!=null){
     		dateTemp = dateConvert.tomaToTed(endValidityDate);
     		EndValidityDateXML endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear());
     		programmeSession.setEndValidityDate(endValidityDateXML);
     	}
     	*/
        if (langueConvert.checkTedCompliance(language))
            programmeSession.setLanguage(langueConvert.tomaToTed(language));
        if (comment != null)
            programmeSession.setComment(comment);
        if (price != null)
            programmeSession.setPrice(price);
        if (priceComment != null)
            programmeSession.setPriceComment(priceComment);
        if (sessionName != null)
            programmeSession.setSessionName(sessionName);


        return programmeSession;
    }

    public ProgrammeSession tedToToma(ProgrammeSessionXML p) {

        String comment = p.getComment();
        String price = p.getPrice();
        String priceComment = p.getPriceComment();
        String sessionName = p.getSessionName();
        LanguageXML languageXML = p.getLanguage();
        Vector locations = p.getLocations();
        Vector slots = p.getSlots();
        BeginValidityDateXML validityDate = p.getBeginValidityDate();
        EndValidityDateXML endValidityDate = p.getEndValidityDate();
        DateIntervalXML interval = p.getDateInterval();
        BeginDateXML beginDate = interval.getBeginDate();
        EndDateXML endDate = interval.getEndDate();


        ProgrammeSession programmeSession = new ProgrammeSession();

        if (beginDate != null)
            programmeSession.setBeginDate((new DateConversion()).tedToToma(beginDate));
        if (endDate != null)
            programmeSession.setEndDate((new DateConversion()).tedToToma(endDate));
        if (validityDate != null)
            programmeSession.setBeginValidityDate((new DateConversion()).tedToToma(validityDate));
        if (endValidityDate != null)
            programmeSession.setEndValidityDate((new DateConversion()).tedToToma(endValidityDate));
        if (comment != null)
            programmeSession.setComment(comment);
        if (price != null)
            programmeSession.setPrice(price);
        if (priceComment != null)
            programmeSession.setPriceComment(priceComment);
        if (sessionName != null)
            programmeSession.setSessionName(sessionName);
        if (languageXML != null)
            programmeSession.setLanguage(langueConvert.tedToToma(languageXML));

        if (locations != null) {
            Iterator it = locations.iterator();
            LocationXML locationXML;
            Vector locationsToma = new Vector();
            while (it.hasNext()) {
                locationXML = (LocationXML) it.next();
                locationsToma.add(locConvert.tedToToma(locationXML));
            }
            programmeSession.setLocations(locationsToma);
        }

        if (slots != null) {
            Iterator it = slots.iterator();
            SlotXML slotXML;
            Vector slotsToma = new Vector();
            while (it.hasNext()) {
                slotXML = (SlotXML) it.next();
                slotsToma.add(slotConvert.tedToToma(slotXML));
            }
            programmeSession.setSlots(slotsToma);
        }


        return programmeSession;
    }
}