// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.Seance;
import apostal.toma.data.Session;
import apostal.toma.data.TOMALabels;

public class SeanceConversion {
    private TOMALabels labels;

    public SeanceConversion() {
        labels = new TOMALabels();
    }


    public boolean checkTedCompliance(Seance s, String message) {
        boolean compliance = true;
        if (s != null) {
            if (s.getBeginHour() < 0 || s.getBeginMinute() < 0 || s.getEndHour() < 0 || s.getEndMinute() < 0) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.seance.timeInterval") + " " + labels.get("apostal.toma.tomatoted.seance") + " " + message);
                compliance = false;
            }
            if (s.getSeanceDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.seance.date") + " " + labels.get("apostal.toma.tomatoted.seance") + " " + message);
            }
        } else {
            compliance = false;
        }
        return compliance;
    }

    public SeanceXML tomaToTed(Seance s, Session ses) {
        DateConversion dateConvert = new DateConversion();
        java.sql.Date dateSeance = s.getSeanceDate();
        int beginHour = s.getBeginHour();
        int beginMinute = s.getBeginMinute();
        int endHour = s.getEndHour();
        int endMinute = s.getEndMinute();

        SeanceXML seance = new SeanceXML();
        DateXML dateTemp = new DateXML();
        if (dateSeance != null) {
            dateTemp = dateConvert.tomaToTed(dateSeance);
        } else {
            dateTemp = dateConvert.tomaToTed(ses.getBeginDate());
        }
        if (beginHour < 0 || beginHour > 23) {
            beginHour = 8;
        }
        if (endHour < 0 || endHour > 23) {
            endHour = 17;
        }

        BeginTimeXML beginTime = new BeginTimeXML(Integer.toString(beginHour), Integer.toString(beginMinute));
        EndTimeXML endTime = new EndTimeXML(Integer.toString(endHour), Integer.toString(endMinute));


        seance.setDateSeance(new DateSeanceXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));
        seance.setTimeInterval(new TimeIntervalXML(beginTime, endTime));
        return seance;
    }

    public Seance tedToToma(SeanceXML s) {

        DateXML date = s.getDateSeance();
        TimeIntervalXML timeInterval = s.getTimeInterval();
        BeginTimeXML beginTime = timeInterval.getBeginTime();
        EndTimeXML endTime = timeInterval.getEndTime();
        String beginHour = beginTime.getHour();
        String beginMinute = beginTime.getMinute();
        String endHour = endTime.getHour();
        String endMinute = endTime.getMinute();

        Seance seance = new Seance();
        seance.setBeginHour(Integer.parseInt(beginHour));
        seance.setBeginMinute(Integer.parseInt(beginMinute));
        seance.setEndHour(Integer.parseInt(endHour));
        seance.setEndMinute(Integer.parseInt(endMinute));
        seance.setSeanceDate((new DateConversion()).tedToToma(date));

        return seance;
    }
}
