// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.*;
import apostal.toma.database.DomainDB;

import java.util.Iterator;
import java.util.Vector;

public abstract class StandAloneTrainingConversion extends TrainingConversion {

    static CatalogueConversion catConvert = new CatalogueConversion();
    static DomainConversion domConvert = new DomainConversion();

    public boolean checkTedCompliance(StandaloneTraining t) {
        return true;
    }

    /***************************************/
    /**** mthodes utile pour TomaToTed ****/
    /***************************************/


    public static void addCatalogues(TrainingXML training, StandaloneTraining t, String catalogueFictif, Language lang, boolean syrecos, boolean addFirstCat) {

        Vector catalogues = t.getCatalogues();
        if (catalogues != null) {
            Iterator it = catalogues.iterator();
            Catalogue catalogue;
            while (it.hasNext()) {
                catalogue = (Catalogue) it.next();
                //	CatalogueDB cDB = new CatalogueDB(catalogue);
                //	cDB.loadById(new Language("fra"),true);
                if (catConvert.checkTedCompliance(catalogue, ""))
                    training.addCatalogue(catConvert.tomaToTed(catalogue, null, catalogue.getNborder(), catalogueFictif, lang, syrecos, addFirstCat));
            }
        }

    }


    public static void addAudiences(TrainingXML training, StandaloneTraining t) {
        Vector audiences = t.getAudiences();
        if (audiences != null) {
            Iterator it = audiences.iterator();
            while (it.hasNext()) {
                String audience = (String) it.next();
                training.addAudience(audience);
            }
        }
    }

    public static void addInscriptionContacts(TrainingXML training, StandaloneTraining t, Language lang) {

        Vector contacts = t.getInscriptionContacts();
        if (contacts != null) {
            Iterator it = contacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
              /*  ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);     */
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = new ContactConversion().tomaToTed(contact);
                    training.addInscriptionContact(new InscriptionContactXML(contactXML));
                }
            }
        }
    }


   /* public static void addInscriptionContacts(TrainingXML training, StandaloneTraining t, Language lang) {

        Vector contacts = t.getInscriptionContacts();
        if (contacts != null) {
            Iterator it = contacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
                ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = new ContactConversion().tomaToTed(contact);
                    training.addInscriptionContact(new InscriptionContactXML(contactXML));
                }
            }
        }
    }*/


    public static void addDomains(TrainingXML training, StandaloneTraining t, Language lang) {

        Vector domains = t.getDomains();
        if (domains != null) {
            Vector lastLevelDomains = DomainDB.reduceToLastLevelsDomains(lang, domains);
            Iterator it = lastLevelDomains.iterator();
            Domain domain;
            DomainXML contactXML;
            while (it.hasNext()) {
                domain = (Domain) it.next();
                if (domConvert.checkTedCompliance(domain)) {
                    DomainXML dom = domConvert.tomaToTed(domain, null, lang);
                    training.addDomain(dom);
                }
            }
        }
    }
    /***************************************/
    /**** mthodes utile pour tedToToma ****/
    /***************************************/


    public static void addCataloguesToma(TrainingXML training, StandaloneTraining t) {
        Vector catalogues = training.getCatalogues();
        if (catalogues != null) {
            Iterator it = catalogues.iterator();
            Vector cataloguesToma = new Vector();
            CatalogueXML catalogueXML;
            while (it.hasNext()) {
                catalogueXML = (CatalogueXML) it.next();
                cataloguesToma.add(catConvert.tedToToma(catalogueXML));
            }
            t.setCatalogues(cataloguesToma);
        }

    }


    public static void addAudiencesToma(TrainingXML training, StandaloneTraining t) {
        Vector audiences = training.getAudiences();
        if (audiences != null) {
            t.setAudiences(audiences);
        }
    }

    public static void addInscriptionContactsToma(TrainingXML training, StandaloneTraining t) {
        Vector contacts = training.getInscriptionContacts();
        if (contacts != null) {
            Iterator it = contacts.iterator();
            ContactXML contactXML;
            Vector contactsToma = new Vector();
            while (it.hasNext()) {
                contactXML = (ContactXML) it.next();
                contactsToma.add(contactConvert.tedToToma(contactXML));
            }
            t.setInscriptionContacts(contactsToma);
        }
    }

    public static void addDomainsToma(TrainingXML training, StandaloneTraining t) {

        Vector domains = training.getDomains();
        if (domains != null) {
            Vector domainToma = new Vector();
            DomainXML domainXML;
            Domain domain;
            Iterator it = domains.iterator();
            while (it.hasNext()) {
                domainXML = (DomainXML) it.next();
                /*domain = domConvert.tedToToma(domainXML);
                domainToma.add(domain);*/
                Vector doms = domConvert.tedToToma(domainXML);
                domainToma.addAll(doms);
            }
            t.setDomains(domainToma);
        }

    }


}
