// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.TeacherXML;
import apostal.toma.TOMA;
import apostal.toma.data.Language;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.Teacher;
import apostal.toma.data.Training;
import apostal.toma.database.TeacherDB;

import java.util.Iterator;
import java.util.Vector;

public class TeacherConversion {

    //utile pour tedToToma, pour stocker la competence
    private String compet = null;

    TOMALabels labels;

    public TeacherConversion() {
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Teacher t, String message) {
        boolean compliance = true;
        if (t != null) {
            if (t.getLastname() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.teacher.lastname") + " " + message);
                return false;
            }
        } else
            compliance = false;
        return compliance;
    }

    public TeacherXML tomaToTed(Teacher t, Training training, Language lang) {

        TeacherDB tDB = new TeacherDB(t);
        tDB.loadById(lang, true);
        String lastName = t.getLastname();
        String firstName = t.getFirstname();
        String function = t.getFunction();
        String cv = t.getCv();
        String title = t.getTitle();
        Vector competences = t.getCompetences();
        String competence = null;
        if (training != null) {
            Vector competencesTraining = training.getCompetences();
            if (competences != null && competencesTraining != null) {
                Iterator it = competences.iterator();
                while (it.hasNext() && (competence == null || competence.equals(""))) {
                    String comp = (String) it.next();
                    Iterator ite = competencesTraining.iterator();
                    while (ite.hasNext() && (competence == null || competence.equals(""))) {
                        String trainingComp = (String) ite.next();
                        if (comp.equals(trainingComp)) {
                            competence = comp;
                        }
                    }
                }

            }

        }
        TeacherXML teacher = null;
        if (lastName != null) {
            teacher = new TeacherXML(lastName);

            if (firstName != null) {
                teacher.setFirstname(firstName);
            }
            if (function != null && !function.equals("")) {
                teacher.setFunction(function);
            }
            if (cv != null) {
                teacher.setCv(cv);
            }
            if (title != null) {
                teacher.setTitle(title);
            }
            if (competence != null) {
                teacher.setCompetence(competence);
            }
        }
        return teacher;
    }

    public Teacher tedToToma(TeacherXML t) {

        String lastName = t.getLastname();
        String firstName = t.getFirstname();
        String function = t.getFunction();
        String cv = t.getCv();
        String title = t.getTitle();
        String competence = t.getCompetence();

        Teacher teacher = new Teacher();

        String key = t.getKey();
        if (key != null && !key.equals("")) {
            try {
                int idTeacher = Integer.parseInt(key);
                teacher.setIdTeacher(idTeacher);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "TeacherConversion, key not a number: " + key);
            }
        }

        if (lastName != null) {
            teacher.setLastname(lastName);
        }
        if (firstName != null) {
            teacher.setFirstname(firstName);
        }
        if (function != null) {
            teacher.setFunction(function);
        }
        if (cv != null) {
            teacher.setCv(cv);
        }
        if (title != null) {
            teacher.setTitle(title);
        }

        this.compet = competence;
        if (competence != null) {
            Vector competences = new Vector();
            competences.add(competence);
            teacher.setCompetences(competences);
        }

        return teacher;
    }

    /**
     * to be used only after the "tedToToma" method has been called
     */
    public String getCompetence() {
        return compet;
    }
}
