// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.*;
import apostal.toma.database.LanguageDB;
import toolbox.text.ExtendedList;

import java.util.Iterator;
import java.util.Vector;


public abstract class TrainingConversion {

    static LanguageConversion langueConvert = new LanguageConversion();
    static TeacherConversion teacherConvert = new TeacherConversion();
    static LocationConversion locConvert = new LocationConversion();
    static SlotConversion slotConvert = new SlotConversion();
    static ContactConversion contactConvert = new ContactConversion();
    TOMALabels labels = new TOMALabels();

    public boolean checkTedCompliance(Training t) {
        return true;
    }


    /***************************************/
    /**** mthodes utile pour TomaToTed ****/
    /***************************************/

    public static void addLocations(TrainingXML training, Training t, Language lang) {
        Vector locations = t.getLocations();
        if (locations != null) {
            Iterator it = locations.iterator();
            Location location;
            while (it.hasNext()) {
                location = (Location) it.next();
              /*  LocationDB lDB = new LocationDB(location);
                lDB.loadById(lang, true); */
                if (locConvert.checkTedCompliance(location, "TESts"))
                    training.addLocation(locConvert.tomaToTed(location, lang));
            }
        }
    }

   /* public static void addLocations(TrainingXML training, Training t, Language lang) {
        Vector locations = t.getLocations();
        if (locations != null) {
            Iterator it = locations.iterator();
            Location location;
            while (it.hasNext()) {
                location = (Location) it.next();
                LocationDB lDB = new LocationDB(location);
                lDB.loadById(lang, true);
                if (locConvert.checkTedCompliance(location, "TESts"))
                    training.addLocation(locConvert.tomaToTed(location, lang));
            }
        }
    }          */

    public static void addLanguages(TrainingXML training, Training t, Language lang) {
        Vector languages = t.getLanguages();
        if (languages == null) {
            languages = new Vector();
            t.setLanguages(languages);
        }
        if (languages.size() == 0) {
            languages.add(lang);
        }
        LanguageDB lDB;
        if (languages != null) {
            Iterator it = languages.iterator();
            Language language;
            while (it.hasNext()) {
                language = (Language) it.next();
                lDB = new LanguageDB(language);
                lDB.loadByCode(lang);
                if (langueConvert.checkTedCompliance(language)) {
                    LanguageXML langu = langueConvert.tomaToTed(language);
                    training.addLanguage(langu);
                }
            }
        }
    }

    public static void addKeywords(TrainingXML training, Training t) {
        Vector keywords = t.getKeywords();
        if (keywords != null) {
            Iterator it = keywords.iterator();
            while (it.hasNext()) {
                String keyword = (String) it.next();
                training.addKeyword(keyword);
            }
        }
    }

    public static void addSlots(TrainingXML training, Training t) {
        Vector slots = t.getSlots();
        if (slots != null) {
            Iterator it = slots.iterator();
            Slot slot;
            while (it.hasNext()) {
                slot = (Slot) it.next();
                if (slotConvert.checkTedCompliance(slot))
                    training.addSlot(slotConvert.tomaToTed(slot));
            }
        }
    }

    public static void addContacts(TrainingXML training, Training t, Language lang) {
        Vector contacts = t.getTrainingContacts();
        if (contacts != null) {
            Iterator it = contacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
                /*ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);  */
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = contactConvert.tomaToTed(contact);
                    training.addTrainingContact(new TrainingContactXML(contactXML));
                }
            }
        }
    }

   /* public static void addContacts(TrainingXML training, Training t, Language lang) {
        Vector contacts = t.getTrainingContacts();
        if (contacts != null) {
            Iterator it = contacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
                ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = contactConvert.tomaToTed(contact);
                    training.addTrainingContact(new TrainingContactXML(contactXML));
                }
            }
        }
    }      */

    public static void setContentDesc(TrainingXML training, Training t) {
        Vector contentDescription = t.getContentDescription();
        String introduction = t.getContentDescriptionIntroduction();
        String conclusion = t.getContentDescriptionConclusion();
        ContentDescriptionXML contentDescXML = new ContentDescriptionXML();
        if (conclusion != null)
            contentDescXML.setConclusion(conclusion);
        if (introduction != null)
            contentDescXML.setIntroduction(introduction);

        if (contentDescription != null) {
            Iterator it = contentDescription.iterator();
            while (it.hasNext()) {
                String subDesc = (String) it.next();
                contentDescXML.addSubDescription(subDesc);
            }
        }
        if (conclusion != null || introduction != null || contentDescription != null)
            training.setContentDescription(contentDescXML);
    }


    public static void setObjectivesTed(TrainingXML training, Training t) {
        Vector objectives = t.getObjectives();
        String introduction = t.getObjectivesIntroduction();
        String conclusion = t.getObjectivesConclusion();
        ObjectivesXML objectivesXML = new ObjectivesXML();

        if (conclusion != null)
            objectivesXML.setConclusion(conclusion);
        if (introduction != null)
            objectivesXML.setIntroduction(introduction);

        if (objectives != null) {
            Iterator it = objectives.iterator();
            String subOject;
            while (it.hasNext()) {
                subOject = (String) it.next();
                objectivesXML.addObjective(subOject);
            }
        }
        if (conclusion != null || introduction != null || objectives != null)
            training.setObjectives(objectivesXML);
    }

    public static void addAllPrerequies(TrainingXML training, Training t) {
        Vector prerequies = t.getPrerequisites();
        if (prerequies != null) {
            Iterator it = prerequies.iterator();
            String prerequisites;
            while (it.hasNext()) {
                prerequisites = (String) it.next();
                training.addPrerequisites(prerequisites);
            }
        }
    }

    public static void addPointsDealtWith(TrainingXML training, Training t) {
        ExtendedList points = t.getPointsDealtWith();
        if (points != null) {
            String introduction = points.getIntroduction();
            String conclusion = points.getConclusion();
            Vector listePoints = points.getList();
            int taillePDW = 0;
            if (listePoints != null) {
                taillePDW = listePoints.size();
            }
            if ((listePoints != null && taillePDW != 0) || introduction != null || conclusion != null) {
                PointsDealtWithXML pointsXML = new PointsDealtWithXML();
                if (conclusion != null)
                    pointsXML.setConclusion(conclusion);
                if (introduction != null)
                    pointsXML.setIntroduction(introduction);
                if (listePoints != null) {
                    Iterator it = listePoints.iterator();
                    while (it.hasNext()) {
                        ExtendedList exl = (ExtendedList) it.next();
                        PointDealtWithXML pdwXML = new PointDealtWithXML();
                        if (exl.getConclusion() != null)
                            pdwXML.setConclusion(exl.getConclusion());
                        if (exl.getIntroduction() != null)
                            pdwXML.setIntroduction(exl.getIntroduction());
                        Vector subPoints = exl.getList();
                        if (subPoints != null) {
                            Iterator ite = subPoints.iterator();
                            while (ite.hasNext()) {
                                String subPoint = (String) ite.next();
                                pdwXML.addSubPointDealtWith(subPoint);
                            }
                        }
                        pointsXML.addPointDealtWith(pdwXML);
                    }
                }
                training.setPointsDealtWith(pointsXML);
            }
        }
    }

    public static void addTeachers(TrainingXML training, Training t, Language lang) {
        Vector teachers = t.getTeachers();
        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                if (teacherConvert.checkTedCompliance(teacher, ""))
                    training.addTeacher(teacherConvert.tomaToTed(teacher, t, lang));
            }
        }
    }

    /***************************************/
    /**** mthodes utile pour TomaToTed ****/
    /***************************************/

    public static void addTeachersToma(TrainingXML training, Training t) {
        Vector teachers = training.getTeachers();
        if (teachers != null) {
            Iterator it = teachers.iterator();
            Vector teachersToma = new Vector();
            Vector compToma = new Vector();
            TeacherXML teacher;
            while (it.hasNext()) {
                teacher = (TeacherXML) it.next();
                teachersToma.add(teacherConvert.tedToToma(teacher));
                compToma.add(teacherConvert.getCompetence());
            }
            t.setTeachers(teachersToma);
            t.setCompetences(compToma);
        }

    }

    public static void addAllPrerequiesToma(TrainingXML training, Training t) {
        Vector prerequies = training.getPrerequisitess();
        if (prerequies != null) {
            t.setPrerequisites(prerequies);
        }
    }


    public static void setObjectivesToma(TrainingXML training, Training t) {
        ObjectivesXML objectivesXML = training.getObjectives();
        if (objectivesXML != null) {
            String intro = objectivesXML.getIntroduction();
            String conclusion = objectivesXML.getConclusion();
            Vector objectives = objectivesXML.getObjectives();
            if (conclusion != null)
                t.setObjectivesConclusion(conclusion);
            if (intro != null)
                t.setObjectivesIntroduction(intro);
            if (objectives != null) {
                t.setObjectives(objectives);
            }
        }
    }

    public static void setContentDescToma(TrainingXML training, Training t) {

        ContentDescriptionXML contentDescXML = training.getContentDescription();
        if (contentDescXML != null) {
            String introduction = contentDescXML.getIntroduction();
            String conclusion = contentDescXML.getConclusion();
            Vector contentDescription = contentDescXML.getSubDescriptions();
            if (introduction != null)
                t.setContentDescriptionIntroduction(introduction);
            if (conclusion != null)
                t.setContentDescriptionConclusion(conclusion);
            if (contentDescription != null) {
                t.setContentDescription(contentDescription);
            }
        }
    }

    public static void addContactsToma(TrainingXML training, Training t) {
        Vector contacts = training.getTrainingContacts();

        if (contacts != null) {
            Iterator it = contacts.iterator();
            Contact contact;
            ContactXML contactXML;
            Vector contactsToma = new Vector();
            while (it.hasNext()) {
                contactXML = (ContactXML) it.next();
                contact = contactConvert.tedToToma(contactXML);
                contactsToma.add(contact);
            }
            t.setTrainingContacts(contactsToma);
        }
    }

    public static void addKeywordsToma(TrainingXML training, Training t) {
        Vector keywords = training.getKeywords();
        if (keywords != null) {
            t.setKeywords(keywords);
        }
    }

    public static void addSlotsToma(TrainingXML training, Training t) {
        Vector slots = training.getSlots();

        if (slots != null) {
            Iterator it = slots.iterator();
            SlotXML slotXML;
            Vector slotsToma = new Vector();
            while (it.hasNext()) {
                slotXML = (SlotXML) it.next();
                slotsToma.add(slotConvert.tedToToma(slotXML));
            }
            t.setSlots(slotsToma);
        }
    }


    public static void addLocationsToma(TrainingXML training, Training t) {
        Vector locations = training.getLocations();
        if (locations != null) {
            Iterator it = locations.iterator();
            LocationXML locationXML;
            Vector locationsToma = new Vector();
            while (it.hasNext()) {
                locationXML = (LocationXML) it.next();
                locationsToma.add(locConvert.tedToToma(locationXML));
            }
            t.setLocations(locationsToma);
        }
    }

    public static void addLanguagesToma(TrainingXML training, Training t) {
        Vector languages = training.getLanguages();
        if (languages != null) {
            Iterator it = languages.iterator();
            LanguageXML languageXML;
            Vector languagesToma = new Vector();
            while (it.hasNext()) {
                languageXML = (LanguageXML) it.next();
                languagesToma.add(langueConvert.tedToToma(languageXML));
            }
            t.setLanguages(languagesToma);
        }
    }

    public static void addPointsDealtWithToma(TrainingXML training, Training t) {
        PointsDealtWithXML points = training.getPointsDealtWith();
        if (points != null) {
            String intro = points.getIntroduction();
            String conclusion = points.getConclusion();
            PointDealtWithXML point;
            Vector pointDealtWithVector = points.getPointDealtWiths();
            ExtendedList extList = new ExtendedList();
            extList.setConclusion(conclusion);
            extList.setIntroduction(intro);
            String subIntro;
            String subConclusion;
            Vector subPoints = new Vector();
            if (pointDealtWithVector != null) {
                Iterator it = pointDealtWithVector.iterator();
                ExtendedList subExtList;
                while (it.hasNext()) {
                    point = (PointDealtWithXML) it.next();
                    subExtList = new ExtendedList();
                    subConclusion = point.getConclusion();
                    subIntro = point.getIntroduction();
                    subPoints = point.getSubPointDealtWiths();
                    if (subPoints != null) {
                        Iterator ite = subPoints.iterator();
                        while (ite.hasNext()) {
                            subExtList.addElement((String) ite.next());
                        }
                    }
                    subExtList.setConclusion(subConclusion);
                    subExtList.setIntroduction(subIntro);
                    extList.addElement(subExtList);
                }

            }
            t.setPointsDealtWith(extList);
        }
    }


}
