// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;


import apostal.ted.*;
import apostal.toma.TOMA;
import apostal.toma.data.*;
import apostal.toma.database.*;

import java.util.Calendar;
import java.util.Date;
import java.util.Iterator;
import java.util.Vector;


public class TrainingProgrammeConversion extends StandAloneTrainingConversion {

    TeacherConversion teacherConvert = new TeacherConversion();
    ContactConversion contactConvert = new ContactConversion();
    CatalogueConversion catConvert = new CatalogueConversion();
    LocationConversion locConvert = new LocationConversion();


    private ModeOfOrganizationConversion mooConvert;
    private LevelConversion levelConvert;
    private UnitConversion unitConvert;
    private ProgrammeSessionConversion psConvert;
    private DateConversion dateConvert;
    private OrganismConversion orgConvert;
    TOMALabels labels;


    public TrainingProgrammeConversion() {
        mooConvert = new ModeOfOrganizationConversion();
        levelConvert = new LevelConversion();
        unitConvert = new UnitConversion();
        psConvert = new ProgrammeSessionConversion();
        dateConvert = new DateConversion();
        orgConvert = new OrganismConversion();
        labels = new TOMALabels();

    }

    public boolean checkTedCompliance(TrainingProgramme t, Language lang) {
        boolean compliance = true;
        if (t != null) {
            if (t.getTitle() == null) compliance = false;
            if (t.getModeOfOrganization() != null) {
                if (!mooConvert.checkTedCompliance(t.getModeOfOrganization())) {
                    compliance = false;
                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.modeOfOrganization") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " + t.getTitle());
                }
            } else
                compliance = false;
            if (t.getLevel() != null) {
                if (!levelConvert.checkTedCompliance(t.getLevel())) {
                    compliance = false;
                    TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.level") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " + t.getTitle());
                }

            } else
                compliance = false;
            if (t.getLanguages() != null && t.getLanguages().size() > 0) {
                Iterator it = t.getLanguages().iterator();
                Language language;
                while (it.hasNext()) {
                    language = (Language) it.next();
                    if (!langueConvert.checkTedCompliance(language)) compliance = false;
                }
            } else
                compliance = false;
            if (t.getBeginValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " + t.getTitle());
            }
            if (t.getEndValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate"));
            }
            if (t.getProgrammeSessions() != null && !t.getProgrammeSessions().isEmpty()) {
                Iterator it = t.getProgrammeSessions().iterator();
                ProgrammeSession cs;
                while (it.hasNext()) {
                    cs = (ProgrammeSession) it.next();
                    /*prDB = new ProgrammeSessionDB(cs);
                    prDB.loadById(lang,true); */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    psConvert.checkTedCompliance(cs, message);
                }
            }

            if (t.getLanguages() != null && t.getLanguages().size() > 0) {
                Iterator it = t.getLanguages().iterator();
                Language language;
                while (it.hasNext()) {
                    language = (Language) it.next();
                    if (!langueConvert.checkTedCompliance(language)) compliance = false;
                }
            } else {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.language") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " + t.getTitle());
                compliance = false;
            }
            if (t.getTeachers() != null && !t.getTeachers().isEmpty()) {
                Iterator it = t.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    /*teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang,true);   */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    teacherConvert.checkTedCompliance(tcs, message);
                }
            }
            if (t.getInscriptionContacts() != null && !t.getInscriptionContacts().isEmpty()) {
                Iterator it = t.getInscriptionContacts().iterator();
                Contact contact;
                while (it.hasNext()) {
                    contact = (Contact) it.next();
                    /*	contactDB = new ContactDB(contact);
                        contactDB.loadById(lang,true); */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    contactConvert.checkTedCompliance(contact, message);
                }
            }
            if (t.getTrainingContacts() != null && !t.getTrainingContacts().isEmpty()) {
                Iterator it = t.getTrainingContacts().iterator();
                Contact contact;
                while (it.hasNext()) {
                    contact = (Contact) it.next();
                    /*	contactDB = new ContactDB(contact);
                        contactDB.loadById(lang,true);  */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    contactConvert.checkTedCompliance(contact, message);
                }
            }
            if (t.getCatalogues() != null && !t.getCatalogues().isEmpty()) {
                Iterator it = t.getCatalogues().iterator();
                Catalogue cat;
                while (it.hasNext()) {
                    cat = (Catalogue) it.next();
                    /*catalogueDB = new CatalogueDB(cat);
                    catalogueDB.loadById(lang,true); */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    catConvert.checkTedCompliance(cat, message);
                }
            }
            if (t.getLocations() != null && !t.getLocations().isEmpty()) {
                Iterator it = t.getLocations().iterator();
                Location loc;
                while (it.hasNext()) {
                    loc = (Location) it.next();
                    /*	locDB = new LocationDB(loc);
                        locDB.loadById(lang,true);*/
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    locConvert.checkTedCompliance(loc, message);
                }
            }
            if (t.getUnits() != null && !t.getUnits().isEmpty()) {
                Iterator it = t.getUnits().iterator();
                Unit unit;
                while (it.hasNext()) {
                    unit = (Unit) it.next();
                    /*	unitDB = new UnitDB(unit);
                        unitDB.loadById(lang,true);   */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " + t.getTitle());
                    unitConvert.checkTedCompliance(unit, message, lang);
                }
            }

        } else
            compliance = false;
        return compliance;
    }


    /*public boolean checkTedCompliance(TrainingProgramme t,Language lang) {
     	boolean compliance = true;
       	if (t!=null){
	    	if (t.getTitle()==null) compliance = false;
	    	if (t.getModeOfOrganization()!=null){
	    		if (!mooConvert.checkTedCompliance(t.getModeOfOrganization())) {
	    			compliance = false;
	    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.modeOfOrganization") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " +t.getTitle());
	    		}
	    	} else compliance = false;
	    	if (t.getLevel()!=null){
	    		if (!levelConvert.checkTedCompliance(t.getLevel())){
	    			compliance = false;
	    			TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.level") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " +t.getTitle());
	    		}

	    	} else compliance = false;
	    	if (t.getLanguages()!=null && t.getLanguages().size()>0){
	    		Iterator it = t.getLanguages().iterator();
	    		Language language;
	    		while (it.hasNext()){
	    			language = (Language)it.next();
	    			if (!langueConvert.checkTedCompliance(language)) compliance = false;
	    		}
	    	} else compliance = false;
	    	if (t.getBeginValidityDate()==null){
	    		compliance = false;
	    		TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " +t.getTitle());
	    	}
	    	if (t.getEndValidityDate()==null){
	    		compliance = false;
	    		TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate"));
	    	}
	    	if (t.getProgrammeSessions()!= null && !t.getProgrammeSessions().isEmpty()){
	    		Iterator it = t.getProgrammeSessions().iterator();
	    		ProgrammeSession cs;
	    		while (it.hasNext()){
	    			cs = (ProgrammeSession)it.next();
	    			prDB = new ProgrammeSessionDB(cs);
	    			prDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") +" " + t.getTitle());
	    			psConvert.checkTedCompliance(cs,message);
	    		}
	    	}

			if (t.getLanguages()!=null && t.getLanguages().size()>0){
	    		Iterator it = t.getLanguages().iterator();
	    		Language language;
	    		while (it.hasNext()){
	    			language = (Language)it.next();
	    			if (!langueConvert.checkTedCompliance(language)) compliance = false;
	    		}
	    	} else {
	    		TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.language") + " " + labels.get("apostal.toma.tomatoted.trainingProgramme") + " " +t.getTitle());
	    		compliance = false;
	    	}
	    	if (t.getTeachers() != null && !t.getTeachers().isEmpty()){
	    		Iterator it = t.getTeachers().iterator();
	    		Teacher tcs;
	    		while (it.hasNext()){
	    			tcs = (Teacher)it.next();
	    			teacherDB = new TeacherDB(tcs);
	    			teacherDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			teacherConvert.checkTedCompliance(tcs,message);
	    		}
	    	}
	    	if (t.getInscriptionContacts() != null && !t.getInscriptionContacts().isEmpty()){
	    		Iterator it = t.getInscriptionContacts().iterator();
	    		Contact contact;
	    		while (it.hasNext()){
	    			contact = (Contact)it.next();
	    			contactDB = new ContactDB(contact);
	    			contactDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			contactConvert.checkTedCompliance(contact,message);
	    		}
	    	}
	    	if (t.getTrainingContacts() != null && !t.getTrainingContacts().isEmpty()){
	    		Iterator it = t.getTrainingContacts().iterator();
	    		Contact contact;
	    		while (it.hasNext()){
	    			contact = (Contact)it.next();
	    			contactDB = new ContactDB(contact);
	    			contactDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			contactConvert.checkTedCompliance(contact,message);
	    		}
	    	}
	    	if (t.getCatalogues() != null && !t.getCatalogues().isEmpty()){
	    		Iterator it = t.getCatalogues().iterator();
	    		Catalogue cat;
	    		while (it.hasNext()){
	    			cat = (Catalogue)it.next();
	    			catalogueDB = new CatalogueDB(cat);
	    			catalogueDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			catConvert.checkTedCompliance(cat,message);
	    		}
	    	}
	    	if (t.getLocations() != null && !t.getLocations().isEmpty()){
	    		Iterator it = t.getLocations().iterator();
	    		Location loc;
	    		while (it.hasNext()){
	    			loc = (Location)it.next();
	    			locDB = new LocationDB(loc);
	    			locDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			locConvert.checkTedCompliance(loc,message);
	    		}
	    	}
	    	if (t.getUnits() != null && !t.getUnits().isEmpty()){
	    		Iterator it = t.getUnits().iterator();
	    		Unit unit;
	    		while (it.hasNext()){
	    			unit = (Unit)it.next();
	    			unitDB = new UnitDB(unit);
	    			unitDB.loadById(lang,true);
	    			String message = new String(labels.get("apostal.toma.tomatoted.trainingProgramme.programmeSession") + " " +  t.getTitle());
	    			unitConvert.checkTedCompliance(unit,message,lang);
	    		}
	    	}

    	} else compliance = false;
    	return compliance;
    } */

    public TrainingProgrammeXML tomaToTed(TrainingProgramme t, Language lang, boolean publishOrganismDetails, String catalogueFictif, boolean testDate, boolean syrecos, boolean addFirstCat) {

        int id = t.getIdTraining();
        Date toDay = new Date();
        java.sql.Date beginValidityDate = t.getBeginValidityDate();
        java.sql.Date endValidityDate = t.getEndValidityDate();
        String certificatesOrDiplomas = t.getCertificatesOrDiplomas();
        String code = t.getCode();
        String comment = t.getComment();
        String courseMedia = t.getCourseMedia();
        String duration = t.getDuration();
        String evaluation = t.getEvaluation();
        String inscriptionConditions = t.getInscriptionConditions();
        String partnerShip = t.getPartnership();
        String payementFacilities = t.getPaymentFacilities();
        String pedagogicalMethods = t.getPedagogicalMethods();
        String price = t.getPrice();
        String priceComment = t.getPriceComment();
        String title = t.getTitle();
        Level level = t.getLevel();

        ModeOfOrganization moo = t.getModeOfOrganization();
        Vector units = t.getUnits();
        Vector programmeSessions = t.getProgrammeSessions();
        DateXML dateTemp = new DateXML();
        TrainingProgrammeXML training = new TrainingProgrammeXML();

        training.setKey(String.valueOf(id));
        Organism organism = OrganismDB.getOrganism(lang, true);
        if (organism != null) {
            OrganismXML orgXML = orgConvert.tomaToTed(organism, publishOrganismDetails);
            training.setOrganism(orgXML);
        } else {
            organism = new Organism();
            OrganismXML orgXML = orgConvert.tomaToTed(organism, publishOrganismDetails);
            if (orgXML != null)
                training.setOrganism(orgXML);
        }
        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
        } else {
            java.sql.Date toDaySql = new java.sql.Date(toDay.getTime());
            dateTemp = dateConvert.tomaToTed(toDaySql);
            t.setBeginValidityDate(toDaySql);
        }
        training.setBeginValidityDate(new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
        } else {
            Calendar now = Calendar.getInstance();
            now.roll(Calendar.YEAR, 2);
            java.sql.Date endValSql = new java.sql.Date(now.getTime().getTime());
            dateTemp = dateConvert.tomaToTed(endValSql);
            t.setEndValidityDate(endValSql);

        }
        training.setEndValidityDate(new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));
        if (certificatesOrDiplomas != null)
            training.setCertificatesOrDiplomas(certificatesOrDiplomas);
        if (code != null)
            training.setCode(code);
        if (courseMedia != null)
            training.setCourseMedia(courseMedia);
        if (duration != null)
            training.setDuration(duration);
        if (evaluation != null)
            training.setEvaluation(evaluation);
        if (inscriptionConditions != null)
            training.setInscriptionConditions(inscriptionConditions);
        if (partnerShip != null)
            training.setPartnership(partnerShip);
        if (payementFacilities != null)
            training.setPaymentFacilities(payementFacilities);
        if (pedagogicalMethods != null)
            training.setPedagogicalMethods(pedagogicalMethods);
        if (price != null)
            training.setPrice(price);
        if (priceComment != null)
            training.setPriceComment(priceComment);
        if (title != null)
            training.setTitle(title);
        if (comment != null)
            training.setComment(comment);
        //levelConvert.checkTedCompliance(level);
        training.setLevel(levelConvert.tomaToTed(level));
        //mooConvert.checkTedCompliance(moo);
        training.setModeOfOrganization(mooConvert.tomaToTed(moo, lang));

        if (units != null) {
            Iterator it = units.iterator();
            Unit unit;
            while (it.hasNext()) {
                unit = (Unit) it.next();
                	/*UnitDB uDB = new UnitDB(unit);
                    uDB.loadById(lang,true); */
                if ((testDate == false) || (!toDay.before(unit.getBeginValidityDate()) && !toDay.after(unit.getEndValidityDate()))) {
                    //unitConvert.checkTedCompliance(unit,"",lang);
                    training.addUnit(unitConvert.tomaToTed(unit, lang, testDate));
                }
            }
        }

        if (programmeSessions != null) {
            Iterator it = programmeSessions.iterator();
            ProgrammeSession programmeSession;
            while (it.hasNext()) {
                programmeSession = (ProgrammeSession) it.next();
                /*ProgrammeSessionDB psDB = new ProgrammeSessionDB(programmeSession);
                psDB.loadById(lang,true);   */
                if ((testDate == false) || (!toDay.before(programmeSession.getBeginValidityDate()) && !toDay.after(programmeSession.getEndValidityDate()))) {
                    training.addProgrammeSession(psConvert.tomaToTed(programmeSession, t, lang));
                }
            }
        }

        this.setObjectivesTed(training, t);
        this.addPointsDealtWith(training, t);
        this.addKeywords(training, t);
        this.addAudiences(training, t);
        this.addCatalogues(training, t, catalogueFictif, lang, syrecos, addFirstCat);
        this.addContacts(training, t, lang);
        this.addInscriptionContacts(training, t, lang);
        this.addAllPrerequies(training, t);
        this.addSlots(training, t);
        this.addLanguages(training, t, lang);
        this.addLocations(training, t, lang);
        this.setContentDesc(training, t);
        this.addTeachers(training, t, lang);
        this.addDomains(training, t, lang);

        return training;
    }


    /*  public TrainingProgrammeXML tomaToTed(TrainingProgramme t,Language lang,boolean publishOrganismDetails,String catalogueFictif,boolean testDate,boolean syrecos,boolean addFirstCat) {

          int id = t.getIdTraining();
          Date toDay = new Date();
          java.sql.Date beginValidityDate =t.getBeginValidityDate();
          java.sql.Date endValidityDate = t.getEndValidityDate();
          String certificatesOrDiplomas = t.getCertificatesOrDiplomas();
          String code = t.getCode();
          String comment = t.getComment();
          String courseMedia = t.getCourseMedia();
          String duration = t.getDuration();
          String evaluation = t.getEvaluation();
          String inscriptionConditions = t.getInscriptionConditions();
          String partnerShip = t.getPartnership();
          String payementFacilities = t.getPaymentFacilities();
          String pedagogicalMethods = t.getPedagogicalMethods();
          String price = t.getPrice();
          String priceComment = t.getPriceComment();
          String title = t.getTitle();
          Level level = t.getLevel();

          ModeOfOrganization moo = t.getModeOfOrganization();
          Vector units = t.getUnits();
          Vector programmeSessions = t.getProgrammeSessions();
          DateXML dateTemp = new DateXML();
          TrainingProgrammeXML training = new TrainingProgrammeXML();

          training.setKey(String.valueOf(id));
          Organism organism=OrganismDB.getOrganism(lang, true);
          if (organism!=null){
              OrganismXML orgXML = orgConvert.tomaToTed(organism,publishOrganismDetails);
              training.setOrganism(orgXML);
          } else {
              organism = new Organism();
              OrganismXML orgXML = orgConvert.tomaToTed(organism,publishOrganismDetails);
              if(orgXML!=null)
                  training.setOrganism(orgXML);
          }
          if (beginValidityDate!=null){
              dateTemp = dateConvert.tomaToTed(beginValidityDate);
          } else {
              java.sql.Date toDaySql = new java.sql.Date(toDay.getTime());
              dateTemp = dateConvert.tomaToTed(toDaySql);
              t.setBeginValidityDate(toDaySql);
          }
          training.setBeginValidityDate(new BeginValidityDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear()));
          if (endValidityDate!=null){
              dateTemp = dateConvert.tomaToTed(endValidityDate);
          } else {
              Calendar now = Calendar.getInstance();
              now.roll(Calendar.YEAR,2);
              java.sql.Date endValSql = new java.sql.Date(now.getTime().getTime());
              dateTemp = dateConvert.tomaToTed(endValSql);
              t.setEndValidityDate(endValSql);

          }
          training.setEndValidityDate(new EndValidityDateXML(dateTemp.getDay(),dateTemp.getMonth(),dateTemp.getYear()));
          if (certificatesOrDiplomas!=null)
              training.setCertificatesOrDiplomas(certificatesOrDiplomas);
          if (code!=null)
              training.setCode(code);
          if (courseMedia!=null)
              training.setCourseMedia(courseMedia);
          if (duration!=null)
              training.setDuration(duration);
          if (evaluation!=null)
              training.setEvaluation(evaluation);
          if (inscriptionConditions!=null)
              training.setInscriptionConditions(inscriptionConditions);
          if (partnerShip!=null)
              training.setPartnership(partnerShip);
          if (payementFacilities!=null)
              training.setPaymentFacilities(payementFacilities);
          if (pedagogicalMethods!=null)
              training.setPedagogicalMethods(pedagogicalMethods);
          if (price!=null)
              training.setPrice(price);
          if (priceComment!=null)
              training.setPriceComment(priceComment);
          if (title!=null)
              training.setTitle(title);
          if (comment!=null)
              training.setComment(comment);
            //levelConvert.checkTedCompliance(level);
          training.setLevel(levelConvert.tomaToTed(level));
          //mooConvert.checkTedCompliance(moo);
          training.setModeOfOrganization(mooConvert.tomaToTed(moo,lang));

          if (units!=null){
              Iterator it = units.iterator();
              Unit unit;
              while (it.hasNext()){
                  unit = (Unit)it.next();
                  UnitDB uDB = new UnitDB(unit);
                  uDB.loadById(lang,true);
                  if ((testDate==false) || (!toDay.before(unit.getBeginValidityDate()) && !toDay.after(unit.getEndValidityDate()))){
                      //unitConvert.checkTedCompliance(unit,"",lang);
                      training.addUnit(unitConvert.tomaToTed(unit,lang,testDate));
                  }
              }
          }

          if (programmeSessions!=null){
              Iterator it = programmeSessions.iterator();
              ProgrammeSession programmeSession;
              while (it.hasNext()){
                  programmeSession = (ProgrammeSession)it.next();
                  ProgrammeSessionDB psDB = new ProgrammeSessionDB(programmeSession);
                  psDB.loadById(lang,true);
                  if ((testDate==false) || (!toDay.before(programmeSession.getBeginValidityDate()) && !toDay.after(programmeSession.getEndValidityDate()))){
                      training.addProgrammeSession(psConvert.tomaToTed(programmeSession,t,lang));
                  }
              }
          }

          this.setObjectivesTed(training,t);
          this.addPointsDealtWith(training,t);
          this.addKeywords(training,t);
          this.addAudiences(training,t);
          this.addCatalogues(training,t,catalogueFictif,lang,syrecos,addFirstCat);
          this.addContacts(training,t,lang);
          this.addInscriptionContacts(training,t,lang);
          this.addAllPrerequies(training,t);
          this.addSlots(training,t);
          this.addLanguages(training,t,lang);
          this.addLocations(training,t,lang);
          this.setContentDesc(training,t);
          this.addTeachers(training,t,lang);
          this.addDomains(training,t,lang);

          return training;
      }*/


    public TrainingProgramme tedToToma(TrainingProgrammeXML t) {

        DateXML beginValidityDate = t.getBeginValidityDate();
        DateXML endValidityDate = t.getEndValidityDate();
        String certificatesOrDiplomas = t.getCertificatesOrDiplomas();
        String code = t.getCode();
        String comment = t.getComment();
        String courseMedia = t.getCourseMedia();
        String duration = t.getDuration();
        String evaluation = t.getEvaluation();
        String inscriptionConditions = t.getInscriptionConditions();
        String partnerShip = t.getPartnership();
        String payementFacilities = t.getPaymentFacilities();
        String pedagogicalMethods = t.getPedagogicalMethods();
        String price = t.getPrice();
        String priceComment = t.getPriceComment();
        String title = t.getTitle();
        LevelXML level = t.getLevel();
        ModeOfOrganizationXML moo = t.getModeOfOrganization();
        Vector units = t.getUnits();
        Vector programmeSessions = t.getProgrammeSessions();

        TrainingProgramme training = new TrainingProgramme();

        String key = t.getKey();
        if (key != null && !key.equals("")) {
            try {
                int id = Integer.parseInt(key);
                training.setIdTraining(id);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "TrainingProgrammeConversion, key not a number: " + key);
            }
        }

        if (units != null) {
            Iterator it = units.iterator();
            UnitXML unitXML;
            Vector unitsToma = new Vector();
            while (it.hasNext()) {
                unitXML = (UnitXML) it.next();
                unitsToma.add(unitConvert.tedToToma(unitXML));
            }
            training.setUnits(unitsToma);
        }

        if (programmeSessions != null) {
            Iterator it = programmeSessions.iterator();
            ProgrammeSessionXML programmeSessionXML;
            Vector psToma = new Vector();
            while (it.hasNext()) {
                programmeSessionXML = (ProgrammeSessionXML) it.next();
                psToma.add(psConvert.tedToToma(programmeSessionXML));
            }
            training.setProgrammeSessions(psToma);
        }

        if (beginValidityDate != null)
            training.setBeginValidityDate((new DateConversion()).tedToToma(beginValidityDate));
        if (endValidityDate != null)
            training.setEndValidityDate((new DateConversion()).tedToToma(endValidityDate));
        if (certificatesOrDiplomas != null)
            training.setCertificatesOrDiplomas(certificatesOrDiplomas);
        if (code != null)
            training.setCode(code);
        if (courseMedia != null)
            training.setCourseMedia(courseMedia);
        if (duration != null)
            training.setDuration(duration);
        if (evaluation != null)
            training.setEvaluation(evaluation);
        if (inscriptionConditions != null)
            training.setInscriptionConditions(inscriptionConditions);
        if (partnerShip != null)
            training.setPartnership(partnerShip);
        if (payementFacilities != null)
            training.setPaymentFacilities(payementFacilities);
        if (pedagogicalMethods != null)
            training.setPedagogicalMethods(pedagogicalMethods);
        if (price != null)
            training.setPrice(price);
        if (priceComment != null)
            training.setPriceComment(priceComment);
        if (title != null)
            training.setTitle(title);
        if (level != null)
            training.setLevel(levelConvert.tedToToma(level));
        if (moo != null)
            training.setModeOfOrganization(mooConvert.tedToToma(moo));

        this.setObjectivesToma(t, training);
        this.addPointsDealtWithToma(t, training);
        this.addKeywordsToma(t, training);
        this.addAudiencesToma(t, training);
        this.addCataloguesToma(t, training);
        this.addContactsToma(t, training);
        this.addInscriptionContactsToma(t, training);
        this.addAllPrerequiesToma(t, training);
        this.addSlotsToma(t, training);
        this.addLanguagesToma(t, training);
        this.addLocationsToma(t, training);
        this.setContentDescToma(t, training);
        this.addTeachersToma(t, training);
        this.addDomainsToma(t, training);

        return training;
    }
}