// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.TOMA;
import apostal.toma.data.*;
import toolbox.text.ExtendedList;

import java.util.Calendar;
import java.util.Date;
import java.util.Iterator;
import java.util.Vector;

public class UnitConversion {

    TOMALabels labels;
    LevelConversion levelConvert = new LevelConversion();
    DateConversion dateConvert = new DateConversion();
    ModeOfOrganizationConversion mooConvert = new ModeOfOrganizationConversion();
    SlotConversion slotConvert = new SlotConversion();
    TeacherConversion teacherConvert = new TeacherConversion();
    ContactConversion contactConvert = new ContactConversion();
    UnitSessionConversion usc = new UnitSessionConversion();
    LocationConversion lc = new LocationConversion();
    LanguageConversion langConvert = new LanguageConversion();


    public UnitConversion() {
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(Unit u, String mes, Language lang) {
        boolean compliance = true;
        if (u != null) {
            if (u.getBeginValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + u.getTitle() + " " + mes);
            }
            if (u.getEndValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + u.getTitle() + " " + mes);
            }
            if (u.getTitle() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.title") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + mes);
            }
            if (u.getUnitSessions() != null && !u.getUnitSessions().isEmpty()) {
                Iterator it = u.getUnitSessions().iterator();
                UnitSession unit;
                while (it.hasNext()) {
                    unit = (UnitSession) it.next();
                  /*  usDB = new UnitSessionDB(unit);
                    usDB.loadById(lang, true); */
                    String message = new String(labels.get("apostal.toma.tomatoted.unit.unitSession") + " " + u.getTitle() + " " + mes);
                    usc.checkTedCompliance(unit, message, lang);
                }
            }

            if (u.getLanguages() != null && u.getLanguages().size() > 0) {
                Iterator it = u.getLanguages().iterator();
                Language language;
                while (it.hasNext()) {
                    language = (Language) it.next();
                    if (!langConvert.checkTedCompliance(language)) compliance = false;
                }
            } else
                compliance = false;
            if (u.getTeachers() != null && !u.getTeachers().isEmpty()) {
                Iterator it = u.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    /*teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang, true);   */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    teacherConvert.checkTedCompliance(tcs, message);
                }
            }
            if (u.getTrainingContacts() != null && !u.getTrainingContacts().isEmpty()) {
                Iterator it = u.getTrainingContacts().iterator();
                Contact contact;
                while (it.hasNext()) {
                    contact = (Contact) it.next();
                   /* contactDB = new ContactDB(contact);
                    contactDB.loadById(lang, true); */
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    contactConvert.checkTedCompliance(contact, message);
                }
            }
            if (u.getLocations() != null && !u.getLocations().isEmpty()) {
                Iterator it = u.getLocations().iterator();
                Location loc;
                while (it.hasNext()) {
                    loc = (Location) it.next();
                 /*   locDB = new LocationDB(loc);
                    locDB.loadById(lang, true);*/
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    lc.checkTedCompliance(loc, message);
                }
            }
        } else
            compliance = false;
        return compliance;
    }

   /* public boolean checkTedCompliance(Unit u, String mes, Language lang) {
        boolean compliance = true;
        if (u != null) {
            if (u.getBeginValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + u.getTitle() + " " + mes);
            }
            if (u.getEndValidityDate() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + u.getTitle() + " " + mes);
            }
            if (u.getTitle() == null) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.title") + " " + labels.get("apostal.toma.tomatoted.unit") + " " + mes);
            }
            if (u.getUnitSessions() != null && !u.getUnitSessions().isEmpty()) {
                Iterator it = u.getUnitSessions().iterator();
                UnitSession unit;
                while (it.hasNext()) {
                    unit = (UnitSession) it.next();
                    usDB = new UnitSessionDB(unit);
                    usDB.loadById(lang, true);
                    String message = new String(labels.get("apostal.toma.tomatoted.unit.unitSession") + " " + u.getTitle() + " " + mes);
                    usc.checkTedCompliance(unit, message, lang);
                }
            }

            if (u.getLanguages() != null && u.getLanguages().size() > 0) {
                Iterator it = u.getLanguages().iterator();
                Language language;
                while (it.hasNext()) {
                    language = (Language) it.next();
                    if (!langConvert.checkTedCompliance(language)) compliance = false;
                }
            } else
                compliance = false;
            if (u.getTeachers() != null && !u.getTeachers().isEmpty()) {
                Iterator it = u.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang, true);
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    teacherConvert.checkTedCompliance(tcs, message);
                }
            }
            if (u.getTrainingContacts() != null && !u.getTrainingContacts().isEmpty()) {
                Iterator it = u.getTrainingContacts().iterator();
                Contact contact;
                while (it.hasNext()) {
                    contact = (Contact) it.next();
                    contactDB = new ContactDB(contact);
                    contactDB.loadById(lang, true);
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    contactConvert.checkTedCompliance(contact, message);
                }
            }
            if (u.getLocations() != null && !u.getLocations().isEmpty()) {
                Iterator it = u.getLocations().iterator();
                Location loc;
                while (it.hasNext()) {
                    loc = (Location) it.next();
                    locDB = new LocationDB(loc);
                    locDB.loadById(lang, true);
                    String message = new String(labels.get("apostal.toma.tomatoted.trainingCourse.courseSession") + " " + u.getTitle() + " " + mes);
                    lc.checkTedCompliance(loc, message);
                }
            }
        } else
            compliance = false;
        return compliance;
    }*/


    public UnitXML tomaToTed(Unit u, Language lang, boolean testDate) {
        Date toDay = new Date();
        int id = u.getIdTraining();

        java.sql.Date beginValidityDate = u.getBeginValidityDate();
        java.sql.Date endValidityDate = u.getEndValidityDate();
        String code = u.getCode();
        String duration = u.getDuration();
        String courseMedia = u.getCourseMedia();
        String evaluation = u.getEvaluation();
        String partnerShip = u.getPartnership();
        String pedagogicalMethods = u.getPedagogicalMethods();
        String title = u.getTitle();
        Level level = u.getLevel();
        String comment = u.getComment();
        ModeOfOrganization moo = u.getModeOfOrganization();
        String contentDescIntro = u.getContentDescriptionIntroduction();
        String contentDescConclusion = u.getContentDescriptionConclusion();
        Vector contentDescriptions = u.getContentDescription();
        String objectConclusion = u.getObjectivesConclusion();
        String objectIntroduction = u.getObjectivesIntroduction();
        Vector objectives = u.getObjectives();
        Vector locations = u.getLocations();
        Vector languages = u.getLanguages();
        Vector prerequisites = u.getPrerequisites();
        Vector keywords = u.getKeywords();
        Vector teachers = u.getTeachers();
        ExtendedList pointsToDealtWith = u.getPointsDealtWith();
        Vector unitSessions = u.getUnitSessions();
        Vector trainingContacts = u.getTrainingContacts();
        Vector slots = u.getSlots();


        DateXML dateTemp = new DateXML();
        UnitXML unit = new UnitXML();

        // Point Dealt With

        if (pointsToDealtWith != null) {
            String introduction = pointsToDealtWith.getIntroduction();
            String conclusion = pointsToDealtWith.getConclusion();
            Vector listePoints = pointsToDealtWith.getList();
            int taillePDW = 0;
            if (listePoints != null)
                taillePDW = listePoints.size();
            if ((listePoints != null && taillePDW != 0) || introduction != null || conclusion != null) {
                PointsDealtWithXML pointsXML = new PointsDealtWithXML();
                if (conclusion != null)
                    pointsXML.setConclusion(conclusion);
                if (introduction != null)
                    pointsXML.setIntroduction(introduction);
                if (listePoints != null) {
                    Iterator it = listePoints.iterator();
                    ExtendedList exl;
                    PointDealtWithXML pdwXML;
                    Vector subPoints;
                    while (it.hasNext()) {
                        exl = (ExtendedList) it.next();
                        pdwXML = new PointDealtWithXML();
                        if (exl.getConclusion() != null)
                            pdwXML.setConclusion(exl.getConclusion());
                        if (exl.getIntroduction() != null)
                            pdwXML.setIntroduction(exl.getIntroduction());
                        subPoints = exl.getList();
                        if (subPoints != null) {
                            Iterator ite = subPoints.iterator();
                            String subPoint;
                            while (ite.hasNext()) {
                                subPoint = (String) ite.next();
                                pdwXML.addSubPointDealtWith(subPoint);
                            }
                        }
                        pointsXML.addPointDealtWith(pdwXML);
                    }
                }
                unit.setPointsDealtWith(pointsXML);
            }
        }


        // Training Contacts

        if (trainingContacts != null) {
            Iterator it = trainingContacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
               /* ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);   */
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = contactConvert.tomaToTed(contact);
                    unit.addTrainingContact(new TrainingContactXML(contactXML));
                }
            }
        }

        // Slots

        if (slots != null) {
            Iterator it = slots.iterator();
            Slot slot;
            while (it.hasNext()) {
                slot = (Slot) it.next();
                if (slotConvert.checkTedCompliance(slot))
                    unit.addSlot(slotConvert.tomaToTed(slot));
            }
        }

        // Teachers

        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                if (teacherConvert.checkTedCompliance(teacher, ""))
                    unit.addTeacher(teacherConvert.tomaToTed(teacher, u, lang));
            }
        }

        // Content Description

        int tailleCD = 0;
        if (contentDescriptions != null)
            tailleCD = contentDescriptions.size();
        if ((contentDescriptions != null && tailleCD != 0) || contentDescIntro != null || contentDescConclusion != null) {
            ContentDescriptionXML contentDescXML = new ContentDescriptionXML();
            if (contentDescConclusion != null)
                contentDescXML.setConclusion(contentDescConclusion);
            if (contentDescIntro != null)
                contentDescXML.setIntroduction(contentDescIntro);
            if (contentDescriptions != null) {
                Iterator it = contentDescriptions.iterator();
                String subDesc;
                while (it.hasNext()) {
                    subDesc = (String) it.next();
                    contentDescXML.addSubDescription(subDesc);
                }
            }
            unit.setContentDescription(contentDescXML);
        }

        // Objectives

        int tailleObj = 0;
        if (objectives != null)
            tailleObj = objectives.size();
        if ((objectives != null && tailleObj != 0) || objectConclusion != null || objectIntroduction != null) {
            ObjectivesXML objectXML = new ObjectivesXML();
            if (objectConclusion != null)
                objectXML.setConclusion(objectConclusion);
            if (objectIntroduction != null)
                objectXML.setIntroduction(objectIntroduction);
            if (objectives != null) {
                Iterator it = objectives.iterator();
                String objective;
                while (it.hasNext()) {
                    objective = (String) it.next();
                    objectXML.addObjective(objective);
                }
            }
            unit.setObjectives(objectXML);
        }

        // Locations

        if (locations != null) {
            Iterator it = locations.iterator();

            Location location;
            while (it.hasNext()) {
                location = (Location) it.next();
              /*  LocationDB lDB = new LocationDB(location);
                lDB.loadById(lang, true); */
                //if (lc.checkTedCompliance(location)){
                unit.addLocation(lc.tomaToTed(location, lang));
                //	}
            }
        }

        // Languages

        if (languages != null) {
            Iterator it = languages.iterator();

            Language language;
            while (it.hasNext()) {
                language = (Language) it.next();
                if (langConvert.checkTedCompliance(language)) {
                    unit.addLanguage(langConvert.tomaToTed(language));
                }
            }
        }

        // Keywords

        if (keywords != null) {
            Iterator it = keywords.iterator();
            String keyword;
            while (it.hasNext()) {
                keyword = (String) it.next();
                unit.addKeyword(keyword);
            }
        }

        // Prerequisites
        unit.setKey(String.valueOf(id));

        if (prerequisites != null) {
            Iterator it = prerequisites.iterator();
            String prerequisite;
            while (it.hasNext()) {
                prerequisite = (String) it.next();
                unit.addPrerequisites(prerequisite);
            }
        }

        // UnitSession

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
        } else {
            java.sql.Date toDaySql = new java.sql.Date(toDay.getTime());
            dateTemp = dateConvert.tomaToTed(toDaySql);
            u.setBeginValidityDate(toDaySql);
        }
        unit.setBeginValidityDate(new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
        } else {
            Calendar now = Calendar.getInstance();
            now.roll(Calendar.YEAR, 2);
            java.sql.Date nowSql = new java.sql.Date(now.getTime().getTime());
            dateTemp = dateConvert.tomaToTed(nowSql);
            u.setEndValidityDate(nowSql);
        }
        unit.setEndValidityDate(new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));

        if (unitSessions != null) {
            Iterator it = unitSessions.iterator();

            UnitSession unitSession;
            while (it.hasNext()) {
                unitSession = (UnitSession) it.next();
               /* UnitSessionDB uDB = new UnitSessionDB(unitSession);
                uDB.loadById(lang, true);  */
              //  if (usc.checkTedCompliance(unitSession, "", lang)) {
                    if ((testDate == false) || (!toDay.before(unitSession.getBeginValidityDate()) && !toDay.after(unitSession.getEndValidityDate()))) {
                        unit.addUnitSession(usc.tomaToTed(unitSession, u, lang));
                    }
            //    }
            }
        }


        if (courseMedia != null)
            unit.setCourseMedia(courseMedia);
        if (code != null)
            unit.setCode(code);
        if (duration != null)
            unit.setDuration(duration);
        if (evaluation != null)
            unit.setEvaluation(evaluation);
        if (partnerShip != null)
            unit.setPartnership(partnerShip);
        if (pedagogicalMethods != null)
            unit.setPedagogicalMethods(pedagogicalMethods);
        if (title != null)
            unit.setTitle(title);
        if (levelConvert.checkTedCompliance(level)) {
            unit.setLevel(levelConvert.tomaToTed(level));
        }
        if (mooConvert.checkTedCompliance(moo)) {
            unit.setModeOfOrganization(mooConvert.tomaToTed(moo, lang));
        }
        if (comment != null) {
            unit.setComment(comment);
        }
        return unit;
    }

 /*   public UnitXML tomaToTed(Unit u, Language lang, boolean testDate) {
        Date toDay = new Date();
        int id = u.getIdTraining();

        java.sql.Date beginValidityDate = u.getBeginValidityDate();
        java.sql.Date endValidityDate = u.getEndValidityDate();
        String code = u.getCode();
        String duration = u.getDuration();
        String courseMedia = u.getCourseMedia();
        String evaluation = u.getEvaluation();
        String partnerShip = u.getPartnership();
        String pedagogicalMethods = u.getPedagogicalMethods();
        String title = u.getTitle();
        Level level = u.getLevel();
        String comment = u.getComment();
        ModeOfOrganization moo = u.getModeOfOrganization();
        String contentDescIntro = u.getContentDescriptionIntroduction();
        String contentDescConclusion = u.getContentDescriptionConclusion();
        Vector contentDescriptions = u.getContentDescription();
        String objectConclusion = u.getObjectivesConclusion();
        String objectIntroduction = u.getObjectivesIntroduction();
        Vector objectives = u.getObjectives();
        Vector locations = u.getLocations();
        Vector languages = u.getLanguages();
        Vector prerequisites = u.getPrerequisites();
        Vector keywords = u.getKeywords();
        Vector teachers = u.getTeachers();
        ExtendedList pointsToDealtWith = u.getPointsDealtWith();
        Vector unitSessions = u.getUnitSessions();
        Vector trainingContacts = u.getTrainingContacts();
        Vector slots = u.getSlots();


        DateXML dateTemp = new DateXML();
        UnitXML unit = new UnitXML();

        // Point Dealt With

        if (pointsToDealtWith != null) {
            String introduction = pointsToDealtWith.getIntroduction();
            String conclusion = pointsToDealtWith.getConclusion();
            Vector listePoints = pointsToDealtWith.getList();
            int taillePDW = 0;
            if (listePoints != null)
                taillePDW = listePoints.size();
            if ((listePoints != null && taillePDW != 0) || introduction != null || conclusion != null) {
                PointsDealtWithXML pointsXML = new PointsDealtWithXML();
                if (conclusion != null)
                    pointsXML.setConclusion(conclusion);
                if (introduction != null)
                    pointsXML.setIntroduction(introduction);
                if (listePoints != null) {
                    Iterator it = listePoints.iterator();
                    ExtendedList exl;
                    PointDealtWithXML pdwXML;
                    Vector subPoints;
                    while (it.hasNext()) {
                        exl = (ExtendedList) it.next();
                        pdwXML = new PointDealtWithXML();
                        if (exl.getConclusion() != null)
                            pdwXML.setConclusion(exl.getConclusion());
                        if (exl.getIntroduction() != null)
                            pdwXML.setIntroduction(exl.getIntroduction());
                        subPoints = exl.getList();
                        if (subPoints != null) {
                            Iterator ite = subPoints.iterator();
                            String subPoint;
                            while (ite.hasNext()) {
                                subPoint = (String) ite.next();
                                pdwXML.addSubPointDealtWith(subPoint);
                            }
                        }
                        pointsXML.addPointDealtWith(pdwXML);
                    }
                }
                unit.setPointsDealtWith(pointsXML);
            }
        }


        // Training Contacts

        if (trainingContacts != null) {
            Iterator it = trainingContacts.iterator();
            Contact contact;
            ContactXML contactXML;
            while (it.hasNext()) {
                contact = (Contact) it.next();
                ContactDB cDB = new ContactDB(contact);
                cDB.loadById(lang, true);
                if (contactConvert.checkTedCompliance(contact, "")) {
                    contactXML = contactConvert.tomaToTed(contact);
                    unit.addTrainingContact(new TrainingContactXML(contactXML));
                }
            }
        }

        // Slots

        if (slots != null) {
            Iterator it = slots.iterator();
            Slot slot;
            while (it.hasNext()) {
                slot = (Slot) it.next();
                if (slotConvert.checkTedCompliance(slot))
                    unit.addSlot(slotConvert.tomaToTed(slot));
            }
        }

        // Teachers

        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                if (teacherConvert.checkTedCompliance(teacher, ""))
                    unit.addTeacher(teacherConvert.tomaToTed(teacher, u, lang));
            }
        }

        // Content Description

        int tailleCD = 0;
        if (contentDescriptions != null)
            tailleCD = contentDescriptions.size();
        if ((contentDescriptions != null && tailleCD != 0) || contentDescIntro != null || contentDescConclusion != null) {
            ContentDescriptionXML contentDescXML = new ContentDescriptionXML();
            if (contentDescConclusion != null)
                contentDescXML.setConclusion(contentDescConclusion);
            if (contentDescIntro != null)
                contentDescXML.setIntroduction(contentDescIntro);
            if (contentDescriptions != null) {
                Iterator it = contentDescriptions.iterator();
                String subDesc;
                while (it.hasNext()) {
                    subDesc = (String) it.next();
                    contentDescXML.addSubDescription(subDesc);
                }
            }
            unit.setContentDescription(contentDescXML);
        }

        // Objectives

        int tailleObj = 0;
        if (objectives != null)
            tailleObj = objectives.size();
        if ((objectives != null && tailleObj != 0) || objectConclusion != null || objectIntroduction != null) {
            ObjectivesXML objectXML = new ObjectivesXML();
            if (objectConclusion != null)
                objectXML.setConclusion(objectConclusion);
            if (objectIntroduction != null)
                objectXML.setIntroduction(objectIntroduction);
            if (objectives != null) {
                Iterator it = objectives.iterator();
                String objective;
                while (it.hasNext()) {
                    objective = (String) it.next();
                    objectXML.addObjective(objective);
                }
            }
            unit.setObjectives(objectXML);
        }

        // Locations

        if (locations != null) {
            Iterator it = locations.iterator();

            Location location;
            while (it.hasNext()) {
                location = (Location) it.next();
                LocationDB lDB = new LocationDB(location);
                lDB.loadById(lang, true);
                //if (lc.checkTedCompliance(location)){
                unit.addLocation(lc.tomaToTed(location, lang));
                //	}
            }
        }

        // Languages

        if (languages != null) {
            Iterator it = languages.iterator();

            Language language;
            while (it.hasNext()) {
                language = (Language) it.next();
                if (langConvert.checkTedCompliance(language)) {
                    unit.addLanguage(langConvert.tomaToTed(language));
                }
            }
        }

        // Keywords

        if (keywords != null) {
            Iterator it = keywords.iterator();
            String keyword;
            while (it.hasNext()) {
                keyword = (String) it.next();
                unit.addKeyword(keyword);
            }
        }

        // Prerequisites
        unit.setKey(String.valueOf(id));

        if (prerequisites != null) {
            Iterator it = prerequisites.iterator();
            String prerequisite;
            while (it.hasNext()) {
                prerequisite = (String) it.next();
                unit.addPrerequisites(prerequisite);
            }
        }

        // UnitSession

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
        } else {
            java.sql.Date toDaySql = new java.sql.Date(toDay.getTime());
            dateTemp = dateConvert.tomaToTed(toDaySql);
            u.setBeginValidityDate(toDaySql);
        }
        unit.setBeginValidityDate(new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
        } else {
            Calendar now = Calendar.getInstance();
            now.roll(Calendar.YEAR, 2);
            java.sql.Date nowSql = new java.sql.Date(now.getTime().getTime());
            dateTemp = dateConvert.tomaToTed(nowSql);
            u.setEndValidityDate(nowSql);
        }
        unit.setEndValidityDate(new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear()));

        if (unitSessions != null) {
            Iterator it = unitSessions.iterator();

            UnitSession unitSession;
            while (it.hasNext()) {
                unitSession = (UnitSession) it.next();
                UnitSessionDB uDB = new UnitSessionDB(unitSession);
                uDB.loadById(lang, true);
                if (usc.checkTedCompliance(unitSession, "", lang)) {
                    if ((testDate == false) || (!toDay.before(unitSession.getBeginValidityDate()) && !toDay.after(unitSession.getEndValidityDate()))) {
                        unit.addUnitSession(usc.tomaToTed(unitSession, u, lang));
                    }
                }
            }
        }


        if (courseMedia != null)
            unit.setCourseMedia(courseMedia);
        if (code != null)
            unit.setCode(code);
        if (duration != null)
            unit.setDuration(duration);
        if (evaluation != null)
            unit.setEvaluation(evaluation);
        if (partnerShip != null)
            unit.setPartnership(partnerShip);
        if (pedagogicalMethods != null)
            unit.setPedagogicalMethods(pedagogicalMethods);
        if (title != null)
            unit.setTitle(title);
        if (levelConvert.checkTedCompliance(level)) {
            unit.setLevel(levelConvert.tomaToTed(level));
        }
        if (mooConvert.checkTedCompliance(moo)) {
            unit.setModeOfOrganization(mooConvert.tomaToTed(moo, lang));
        }
        if (comment != null) {
            unit.setComment(comment);
        }
        return unit;
    }*/



    public Unit tedToToma(UnitXML u) {

        DateXML beginValidityDate = u.getBeginValidityDate();
        DateXML endValidityDate = u.getEndValidityDate();
        String code = u.getCode();
        String courseMedia = u.getCourseMedia();
        String duration = u.getDuration();
        String evaluation = u.getEvaluation();
        String partnerShip = u.getPartnership();
        String pedagogicalMethods = u.getPedagogicalMethods();
        Vector prerequisitess = u.getPrerequisitess();
        String title = u.getTitle();
        LevelXML level = u.getLevel();
        Vector languages = u.getLanguages();
        Vector locations = u.getLocations();
        Vector keywords = u.getKeywords();
        Vector trainingContacts = u.getTrainingContacts();
        Vector teachers = u.getTeachers();
        Vector slots = u.getSlots();
        ModeOfOrganizationXML moo = u.getModeOfOrganization();
        PointsDealtWithXML points = u.getPointsDealtWith();
        ContentDescriptionXML contentDescXML = u.getContentDescription();
        ObjectivesXML objectivesXML = u.getObjectives();
        String comment = u.getComment();

        Unit unit = new Unit();

        String key = u.getKey();
        if (key != null && !key.equals("")) {
            try {
                int id = Integer.parseInt(key);
                unit.setIdTraining(id);
            } catch (java.lang.NumberFormatException ex) {
                TOMA.log(TOMA.SEVERE, "UnitConversion, key not a number: " + key);
            }
        }

        if (contentDescXML != null) {
            String conclusion = contentDescXML.getConclusion();
            String intro = contentDescXML.getIntroduction();
            if (conclusion != null)
                unit.setContentDescriptionConclusion(conclusion);
            if (intro != null)
                unit.setContentDescriptionIntroduction(intro);
            Vector subDesc = contentDescXML.getSubDescriptions();
            if (subDesc != null) {
                Vector desc = new Vector();
                Iterator it = subDesc.iterator();
                while (it.hasNext()) {
                    desc.add((String) it.next());
                }
                unit.setContentDescription(desc);
            }
        }

        if (objectivesXML != null) {
            String intro = objectivesXML.getIntroduction();
            String conclusion = objectivesXML.getConclusion();
            Vector objectives = objectivesXML.getObjectives();
            if (conclusion != null)
                unit.setObjectivesConclusion(conclusion);
            if (intro != null)
                unit.setObjectivesIntroduction(intro);
            if (objectives != null) {
                unit.setObjectives(objectives);
            }
        }

        if (languages != null) {
            Iterator it = languages.iterator();
            LanguageConversion lc = new LanguageConversion();
            LanguageXML language;
            Vector languageToma = new Vector();
            while (it.hasNext()) {
                language = (LanguageXML) it.next();
                languageToma.add(lc.tedToToma(language));
            }
            unit.setLanguages(languageToma);
        }

        if (locations != null) {
            Iterator it = locations.iterator();
            LocationConversion lc = new LocationConversion();
            LocationXML location;
            Vector locationsToma = new Vector();
            while (it.hasNext()) {
                location = (LocationXML) it.next();
                locationsToma.add(lc.tedToToma(location));
            }
            unit.setLocations(locationsToma);
        }

        if (keywords != null) {
            Iterator it = keywords.iterator();
            Vector keywordsToma = new Vector();
            while (it.hasNext()) {
                keywordsToma.add((String) it.next());
            }
            unit.setKeywords(keywordsToma);
        }
        if (prerequisitess != null) {
            Vector pres = new Vector();
            Iterator iter_pre = prerequisitess.iterator();
            while (iter_pre.hasNext()) {
                String pre = (String) iter_pre.next();
                pres.add(pre);
            }
            unit.setPrerequisites(pres);
        }

        //trainingContacts
        if (trainingContacts != null) {
            Iterator it = trainingContacts.iterator();
            Contact contact;
            ContactXML contactXML;
            Vector contactsToma = new Vector();
            ContactConversion contactConvert = new ContactConversion();
            while (it.hasNext()) {
                contactXML = (ContactXML) it.next();
                contact = contactConvert.tedToToma(contactXML);
                contactsToma.add(contact);
            }
            unit.setTrainingContacts(contactsToma);
        }
        //teachers
        if (teachers != null) {
            Iterator it = teachers.iterator();
            Vector teachersToma = new Vector();
            Vector compToma = new Vector();
            TeacherXML teacher;
            TeacherConversion teacherConvert = new TeacherConversion();
            while (it.hasNext()) {
                teacher = (TeacherXML) it.next();
                teachersToma.add(teacherConvert.tedToToma(teacher));
                compToma.add(teacherConvert.getCompetence());
            }
            unit.setTeachers(teachersToma);
            unit.setCompetences(compToma);
        }

        //slots
        if (slots != null) {
            Iterator it = slots.iterator();
            SlotXML slotXML;
            Vector slotsToma = new Vector();
            SlotConversion slotConvert = new SlotConversion();
            while (it.hasNext()) {
                slotXML = (SlotXML) it.next();
                slotsToma.add(slotConvert.tedToToma(slotXML));
            }
            unit.setSlots(slotsToma);
        }

        if (points != null) {
            String intro = points.getIntroduction();
            String conclusion = points.getConclusion();
            PointDealtWithXML point;
            Vector pointDealtWithVector = points.getPointDealtWiths();
            ExtendedList extList = new ExtendedList();
            extList.setConclusion(conclusion);
            extList.setIntroduction(intro);
            String subIntro;
            String subConclusion;
            Vector subPoints = new Vector();
            if (pointDealtWithVector != null) {
                Iterator it = pointDealtWithVector.iterator();
                ExtendedList subExtList;
                while (it.hasNext()) {
                    point = (PointDealtWithXML) it.next();
                    subExtList = new ExtendedList();
                    subConclusion = point.getConclusion();
                    subIntro = point.getIntroduction();
                    subPoints = point.getSubPointDealtWiths();
                    if (subPoints != null) {
                        Iterator ite = subPoints.iterator();
                        while (ite.hasNext()) {
                            subExtList.addElement((String) ite.next());
                        }
                    }
                    subExtList.setConclusion(subConclusion);
                    subExtList.setIntroduction(subIntro);
                    extList.addElement(subExtList);
                }

            }
            unit.setPointsDealtWith(extList);
        }

        Vector sessions = new Vector();
        if (u.getUnitSessions() != null) {
            UnitSessionConversion sessconv = new UnitSessionConversion();
            Iterator iter_sess = u.getUnitSessions().iterator();
            while (iter_sess.hasNext()) {
                UnitSessionXML sess = (UnitSessionXML) iter_sess.next();
                UnitSession session = sessconv.tedToToma(sess);
                if (session != null)
                    sessions.add(session);
            }
        }
        unit.setUnitSessions(sessions);

        ModeOfOrganizationConversion mooc = new ModeOfOrganizationConversion();
        LevelConversion lc = new LevelConversion();
        DateConversion dc = new DateConversion();
        if (moo != null)
            unit.setModeOfOrganization(mooc.tedToToma(moo));
        if (beginValidityDate != null)
            unit.setBeginValidityDate(dc.tedToToma(beginValidityDate));
        if (endValidityDate != null)
            unit.setEndValidityDate(dc.tedToToma(endValidityDate));
        if (code != null)
            unit.setCode(code);
        if (duration != null)
            unit.setDuration(duration);
        if (evaluation != null)
            unit.setEvaluation(evaluation);
        if (partnerShip != null)
            unit.setPartnership(partnerShip);
        if (pedagogicalMethods != null)
            unit.setPedagogicalMethods(pedagogicalMethods);
        if (courseMedia != null)
            unit.setCourseMedia(courseMedia);
        if (title != null)
            unit.setTitle(title);
        if (level != null)
            unit.setLevel(lc.tedToToma(level));
        if (comment != null)
            unit.setComment(comment);

        return unit;
    }
}
