// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.external.tedtoma;

import apostal.ted.*;
import apostal.toma.data.*;
import apostal.toma.database.*;

import java.util.Iterator;
import java.util.Vector;

public class UnitSessionConversion {

    private SlotConversion slotConvert;
    private LocationConversion locConvert;
    private LanguageConversion langueConvert;
    private TeacherConversion teacherConvert;
    private SeanceConversion seanceConvert;
    private DateConversion dateConvert;
    TOMALabels labels;
    private LocationDB locDB;
    private TeacherDB teacherDB;
    private ContactDB contactDB;
    private CatalogueDB catalogueDB;

    public UnitSessionConversion() {
        slotConvert = new SlotConversion();
        locConvert = new LocationConversion();
        langueConvert = new LanguageConversion();
        teacherConvert = new TeacherConversion();
        seanceConvert = new SeanceConversion();
        dateConvert = new DateConversion();
        labels = new TOMALabels();
    }

    public boolean checkTedCompliance(UnitSession u, String message, Language lang) {
        boolean compliance = true;
        if (u != null) {
            if (u.getBeginValidityDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getEndValidityDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getBeginDate() == null || u.getEndDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getSlot() == null || !slotConvert.checkTedCompliance(u.getSlot())) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.slot") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getIdProgrammeSession() < 0) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.programmeSessionName") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getTeachers() != null && !u.getTeachers().isEmpty()) {
                Iterator it = u.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    /*teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang, true);      */
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                    teacherConvert.checkTedCompliance(tcs, newMessage);
                }
            }
            if (u.getLocation() != null) {
                Location loc = u.getLocation();
              /*  locDB = new LocationDB(loc);
                locDB.loadById(lang, true);  */
                String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                locConvert.checkTedCompliance(loc, newMessage);
            }
            if (u.getSeances() != null && !u.getSeances().isEmpty()) {
                Iterator it = u.getSeances().iterator();
                Seance seance;
                while (it.hasNext()) {
                    seance = (Seance) it.next();
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                    seanceConvert.checkTedCompliance(seance, newMessage);
                }
            }

        } else {
            compliance = false;
        }
        return compliance;
    }

    /*public boolean checkTedCompliance(UnitSession u, String message, Language lang) {
        boolean compliance = true;
        if (u != null) {
            if (u.getBeginValidityDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.beginValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getEndValidityDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.endValidityDate") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getBeginDate() == null || u.getEndDate() == null) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.dateInterval") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getSlot() == null || !slotConvert.checkTedCompliance(u.getSlot())) {
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.slot") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getIdProgrammeSession() < 0) {
                compliance = false;
                TedTomaConversion.addError(labels.get("apostal.toma.tomatoted.session.programmeSessionName") + " " + labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
            }
            if (u.getTeachers() != null && !u.getTeachers().isEmpty()) {
                Iterator it = u.getTeachers().iterator();
                Teacher tcs;
                while (it.hasNext()) {
                    tcs = (Teacher) it.next();
                    teacherDB = new TeacherDB(tcs);
                    teacherDB.loadById(lang, true);
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                    teacherConvert.checkTedCompliance(tcs, newMessage);
                }
            }
            if (u.getLocation() != null) {
                Location loc = u.getLocation();
                locDB = new LocationDB(loc);
                locDB.loadById(lang, true);
                String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                locConvert.checkTedCompliance(loc, newMessage);
            }
            if (u.getSeances() != null && !u.getSeances().isEmpty()) {
                Iterator it = u.getSeances().iterator();
                Seance seance;
                while (it.hasNext()) {
                    seance = (Seance) it.next();
                    String newMessage = new String(labels.get("apostal.toma.tomatoted.trainingCourse.session") + " " + u.getSessionName() + " " + message);
                    seanceConvert.checkTedCompliance(seance, newMessage);
                }
            }

        } else {
            compliance = false;
        }
        return compliance;
    }*/

  /*  public UnitSessionXML tomaToTed(UnitSession u, Unit unit, Language lang) {

        String comment = u.getComment();
        String price = u.getPrice();
        String priceComment = u.getPriceComment();
        String sessionName = u.getSessionName();
        String textualCalendar = u.getTextualCalendar();
        Language language = u.getLanguage();
        Location location = u.getLocation();
        Vector teachers = u.getTeachers();
        Vector seances = u.getSeances();
        Slot slot = u.getSlot();
        java.sql.Date beginDate = u.getBeginDate();
        java.sql.Date endDate = u.getEndDate();
        java.sql.Date beginValidityDate = u.getBeginValidityDate();
        java.sql.Date endValidityDate = u.getEndValidityDate();
        DateXML dateTemp = new DateXML();
        int idPS = u.getIdProgrammeSession();

        UnitSessionXML unitSession = new UnitSessionXML();


        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
                TeacherDB tDB = new TeacherDB(teacher);
                tDB.loadById(lang, true);
                if (teacherConvert.checkTedCompliance(teacher, ""))
                    unitSession.addTeacher(teacherConvert.tomaToTed(teacher, unit, lang));

            }
        }

        if (idPS != -1) {
            ProgrammeSession ps = new ProgrammeSession(idPS);
            ProgrammeSessionDB psDB = new ProgrammeSessionDB(ps);
            psDB.loadById(lang, true);
            String pSessionName = ps.toString();
            unitSession.setProgrammeSessionName(pSessionName);
        }


        BeginValidityDateXML validityDateXML;
        EndValidityDateXML endValidityDateXML;

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(unit.getBeginValidityDate());
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            u.setBeginValidityDate(unit.getBeginValidityDate());
        }
        unitSession.setBeginValidityDate(validityDateXML);
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(unit.getEndValidityDate());
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            u.setEndValidityDate(unit.getEndValidityDate());
        }
        unitSession.setEndValidityDate(endValidityDateXML);


        BeginDateXML beginDateXML = new BeginDateXML();
        ;
        EndDateXML endDateXML = new EndDateXML();
        if (beginDate != null && endDate != null) {
            dateTemp = dateConvert.tomaToTed(beginDate);
            beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            dateTemp = dateConvert.tomaToTed(endDate);
            endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());

        } else {
            if (beginDate == null) {
                dateTemp = dateConvert.tomaToTed(u.getBeginValidityDate());
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(beginDate);
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
            if (endDate == null) {
                dateTemp = dateConvert.tomaToTed(u.getEndValidityDate());
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(endDate);
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
        }
        DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML, endDateXML);
        unitSession.setDateInterval(intervalXML);


        if (seances != null) {
            Iterator it = seances.iterator();
            Seance seance;
            while (it.hasNext()) {
                seance = (Seance) it.next();
                unitSession.addSeance(seanceConvert.tomaToTed(seance, u));
            }
        }

        unitSession.setSlot(slotConvert.tomaToTed(slot));
        if (langueConvert.checkTedCompliance(language))
            unitSession.setLanguage(langueConvert.tomaToTed(language));
        if (location != null) {
            LocationDB lDB = new LocationDB(location);
            lDB.loadById(lang, true);
            unitSession.setLocation(locConvert.tomaToTed(location, lang));
        }
        if (comment != null)
            unitSession.setComment(comment);
        if (price != null)
            unitSession.setPrice(price);
        if (priceComment != null)
            unitSession.setPriceComment(priceComment);
        if (sessionName != null)
            unitSession.setSessionName(sessionName);
        if (textualCalendar != null)
            unitSession.setTextualCalendar(textualCalendar);


        return unitSession;
    }
     */

    public UnitSessionXML tomaToTed(UnitSession u, Unit unit, Language lang) {

        String comment = u.getComment();
        String price = u.getPrice();
        String priceComment = u.getPriceComment();
        String sessionName = u.getSessionName();
        String textualCalendar = u.getTextualCalendar();
        Language language = u.getLanguage();
        Location location = u.getLocation();
        Vector teachers = u.getTeachers();
        Vector seances = u.getSeances();
        Slot slot = u.getSlot();
        java.sql.Date beginDate = u.getBeginDate();
        java.sql.Date endDate = u.getEndDate();
        java.sql.Date beginValidityDate = u.getBeginValidityDate();
        java.sql.Date endValidityDate = u.getEndValidityDate();
        DateXML dateTemp = new DateXML();
        int idPS = u.getIdProgrammeSession();

        UnitSessionXML unitSession = new UnitSessionXML();


        if (teachers != null) {
            Iterator it = teachers.iterator();
            Teacher teacher;
            while (it.hasNext()) {
                teacher = (Teacher) it.next();
              /*  TeacherDB tDB = new TeacherDB(teacher);
                tDB.loadById(lang, true);      */
                if (teacherConvert.checkTedCompliance(teacher, ""))
                    unitSession.addTeacher(teacherConvert.tomaToTed(teacher, unit, lang));

            }
        }

        if (idPS != -1) {
            ProgrammeSession ps = new ProgrammeSession(idPS);
            ProgrammeSessionDB psDB = new ProgrammeSessionDB(ps);
            psDB.loadById(lang, true);
            String pSessionName = ps.toString();
            unitSession.setProgrammeSessionName(pSessionName);
        }


        BeginValidityDateXML validityDateXML;
        EndValidityDateXML endValidityDateXML;

        if (beginValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(beginValidityDate);
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(unit.getBeginValidityDate());
            validityDateXML = new BeginValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            u.setBeginValidityDate(unit.getBeginValidityDate());
        }
        unitSession.setBeginValidityDate(validityDateXML);
        if (endValidityDate != null) {
            dateTemp = dateConvert.tomaToTed(endValidityDate);
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
        } else {
            dateTemp = dateConvert.tomaToTed(unit.getEndValidityDate());
            endValidityDateXML = new EndValidityDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            u.setEndValidityDate(unit.getEndValidityDate());
        }
        unitSession.setEndValidityDate(endValidityDateXML);


        BeginDateXML beginDateXML = new BeginDateXML();

        EndDateXML endDateXML = new EndDateXML();
        if (beginDate != null && endDate != null) {
            dateTemp = dateConvert.tomaToTed(beginDate);
            beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            dateTemp = dateConvert.tomaToTed(endDate);
            endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());

        } else {
            if (beginDate == null) {
                dateTemp = dateConvert.tomaToTed(u.getBeginValidityDate());
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(beginDate);
                beginDateXML = new BeginDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
            if (endDate == null) {
                dateTemp = dateConvert.tomaToTed(u.getEndValidityDate());
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            } else {
                dateTemp = dateConvert.tomaToTed(endDate);
                endDateXML = new EndDateXML(dateTemp.getDay(), dateTemp.getMonth(), dateTemp.getYear());
            }
        }
        DateIntervalXML intervalXML = new DateIntervalXML(beginDateXML, endDateXML);
        unitSession.setDateInterval(intervalXML);


        if (seances != null) {
            Iterator it = seances.iterator();
            Seance seance;
            while (it.hasNext()) {
                seance = (Seance) it.next();
                unitSession.addSeance(seanceConvert.tomaToTed(seance, u));
            }
        }

        unitSession.setSlot(slotConvert.tomaToTed(slot));
        if (langueConvert.checkTedCompliance(language))
            unitSession.setLanguage(langueConvert.tomaToTed(language));
        if (location != null) {
            /*LocationDB lDB = new LocationDB(location);
            lDB.loadById(lang, true);     */
            unitSession.setLocation(locConvert.tomaToTed(location, lang));
        }
        if (comment != null)
            unitSession.setComment(comment);
        if (price != null)
            unitSession.setPrice(price);
        if (priceComment != null)
            unitSession.setPriceComment(priceComment);
        if (sessionName != null)
            unitSession.setSessionName(sessionName);
        if (textualCalendar != null)
            unitSession.setTextualCalendar(textualCalendar);


        return unitSession;
    }

    public UnitSession tedToToma(UnitSessionXML u) {

        String comment = u.getComment();
        String price = u.getPrice();
        String priceComment = u.getPriceComment();
        String sessionName = u.getSessionName();
        String textualCalendar = u.getTextualCalendar();
        Vector teachers = u.getTeachers();
        Vector seances = u.getSeances();
        LanguageXML languageXML = u.getLanguage();
        LocationXML locationXML = u.getLocation();
        SlotXML slotXML = u.getSlot();
        BeginValidityDateXML validityDate = u.getBeginValidityDate();
        EndValidityDateXML endValidityDate = u.getEndValidityDate();
        DateIntervalXML interval = u.getDateInterval();
        BeginDateXML beginDate = interval.getBeginDate();
        EndDateXML endDate = interval.getEndDate();

        UnitSession unitSession = new UnitSession();

        if (beginDate != null)
            unitSession.setBeginDate((new DateConversion()).tedToToma(beginDate));
        if (endDate != null)
            unitSession.setEndDate((new DateConversion()).tedToToma(endDate));
        if (validityDate != null)
            unitSession.setBeginValidityDate((new DateConversion()).tedToToma(validityDate));
        if (endValidityDate != null)
            unitSession.setEndValidityDate((new DateConversion()).tedToToma(endValidityDate));
        if (textualCalendar != null)
            unitSession.setTextualCalendar(textualCalendar);
        if (comment != null)
            unitSession.setComment(comment);
        if (price != null)
            unitSession.setPrice(price);
        if (priceComment != null)
            unitSession.setPriceComment(priceComment);
        if (sessionName != null)
            unitSession.setSessionName(sessionName);
        if (slotXML != null)
            unitSession.setSlot(slotConvert.tedToToma(slotXML));
        if (locationXML != null)
            unitSession.setLocation(locConvert.tedToToma(locationXML));
        if (languageXML != null)
            unitSession.setLanguage(langueConvert.tedToToma(languageXML));
        if (teachers != null) {
            Iterator it = teachers.iterator();
            Vector teachersToma = new Vector();
            TeacherXML teacher;
            while (it.hasNext()) {
                teacher = (TeacherXML) it.next();
                teachersToma.add(teacherConvert.tedToToma(teacher));
            }
            unitSession.setTeachers(teachersToma);
        }

        if (seances != null) {
            Iterator it = seances.iterator();
            Vector seancesToma = new Vector();
            SeanceXML seance;
            while (it.hasNext()) {
                seance = (SeanceXML) it.next();
                seancesToma.add(seanceConvert.tedToToma(seance));
            }
            unitSession.setSeances(seancesToma);
        }


        return unitSession;
    }
}