// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreeNode;
import java.util.Enumeration;
import java.util.Vector;

public class CatalogueTreeNode extends DefaultMutableTreeNode {
    private CatalogueTreeNode parent;

    // 0->nbCatalogues-1: catalogues
    // nbCatalogues-fin : trainings
    private Vector data;
    private int nbCatalogues;

    private boolean seeCourses;
    private boolean seeProgrammes;

    private String title;
    private int idCatalogue;

    public CatalogueTreeNode() {
    }

    public CatalogueTreeNode(int idCatalogue, String title, Vector data, int nbCatalogues, boolean seeCourses, boolean seeProgrammes) {
        this.title = title;
        this.idCatalogue = idCatalogue;

        this.seeCourses = seeCourses;
        this.seeProgrammes = seeProgrammes;

        this.data = data;
        this.nbCatalogues = nbCatalogues;
    }

    public CatalogueTreeNode(CatalogueTreeNode parent, int idCatalogue, String title, Vector data, int nbCatalogues, boolean seeCourses, boolean seeProgrammes) {
        this(idCatalogue, title, data, nbCatalogues, seeCourses, seeProgrammes);
        this.parent = parent;
    }

    public CatalogueTreeNode(int idCatalogue, String title, boolean seeCourses, boolean seeProgrammes) {
        this.title = title;
        this.idCatalogue = idCatalogue;

        this.seeCourses = seeCourses;
        this.seeProgrammes = seeProgrammes;
    }

    public CatalogueTreeNode(CatalogueTreeNode parent, int idCatalogue, String title, boolean seeCourses, boolean seeProgrammes) {
        this(idCatalogue, title, seeCourses, seeProgrammes);
        this.parent = parent;
    }

    public void setData(Vector data, int nbCatalogues) {
        this.data = data;
        this.nbCatalogues = nbCatalogues;
    }

    public Enumeration children() {
        return data.elements();
    }

    public boolean getAllowsChildren() {
        return true;
    }

    public TreeNode getChildAt(int index) {
        TreeNode node = (TreeNode) data.elementAt(index);

        return node;
    }

    public int getChildCount() {
        if (data != null) {
            return data.size();
        } else
            return 0;
    }

    public int getIndex(TreeNode node) {
        int index = -1;

        Class cl = node.getClass();
        if (cl.getName().equals("apostal.toma.view.CatalogueTreeNode")) {
            CatalogueTreeNode n = (CatalogueTreeNode) node;

            int i = 0;
            while (i < nbCatalogues && index == -1) {
                CatalogueTreeNode n2 = (CatalogueTreeNode) data.elementAt(i);
                if (n2.getIdCatalogue() == n.getIdCatalogue())
                    index = i;

                i++;
            }
        } else if (cl.getName().equals("apostal.toma.view.TrainingTreeNode")) {
            TrainingTreeNode n = (TrainingTreeNode) node;

            int i = nbCatalogues;
            int size = data.size();
            while (i < size && index == -1) {
                TrainingTreeNode n2 = (TrainingTreeNode) data.elementAt(i);
                if (n2.getIdTraining() == n.getIdTraining())
                    index = i;

                i++;
            }
        }

        return index;
    }

    public boolean isLeaf() {
        boolean leaf = false;
        if (data != null) {
            if (data.size() == 0)
                leaf = true;
        }

        return leaf;
    }

    public String toString() {
        return title;
    }

    public TreeNode getParent() {
        return parent;
    }

    public int getIdCatalogue() {
        return idCatalogue;
    }

    public String getTitle() {
        return title;
    }

    public boolean equals(CatalogueTreeNode node) {
        boolean equals = false;
        if (node != null) {
            if (node.idCatalogue == this.idCatalogue)
                equals = true;
        }
        return equals;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public void addTrainingTreeNode(TrainingTreeNode node) {
        data.add(node);
        TOMA.getInstance().getTomaView().getTree().updateModel();
    }

    public void addCatalogueTreeNode(CatalogueTreeNode node) {
        data.add(nbCatalogues, node);
        nbCatalogues++;
        //remettre le model
        //TOMA.getInstance().getTomaView().getTree().getTree().getModel().
        TOMA.getInstance().getTomaView().getTree().updateModel();
    }

    public void removeNode(Object o) {
        if (o != null) {
            int index = data.indexOf(o);
            if (index < nbCatalogues) {
                //c'est un catalogue
                nbCatalogues--;
            }

            data.remove(o);
            TOMA.getInstance().getTomaView().getTree().updateModel();
        }

    }
}
