// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.Catalogue;
import apostal.toma.data.TOMAConstants;
import apostal.toma.data.TOMALabels;
import apostal.toma.viewcontrol.CatalogueEventHandler;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.border.TitledBorder;
import java.awt.*;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

public class CatalogueView extends JPanel {

    TitledBorder titledBorder1;
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    //CatalogueEventHandler handler = new CatalogueEventHandler(this);
    CatalogueEventHandler handler;
    protected TOMALabels labels;
    private Catalogue data;
    TOMAButton jButton1 = new TOMAButton(false);
    TOMAButton jButton2 = new TOMAButton(false);
    TOMAButton jButton3 = new TOMAButton();
    TOMAButton jButton4 = new TOMAButton();
    TOMAButton jButton5 = new TOMAButton();
    TOMAButton jButton6 = new TOMAButton();
    TOMAButton jButton7 = new TOMAButton();

    TOMALabel jLtitle = new TOMALabel();
    TOMATextField jTFtitle = new TOMATextField();
    TOMALabel jLdescription = new TOMALabel();
    TOMATextArea jTAdescription = new TOMATextArea();
    TOMALabel jLcreated = new TOMALabel();
    TOMATextField jTFcreated = new TOMATextField();
    TOMALabel jLmodified = new TOMALabel();
    TOMATextField jTFmodified = new TOMATextField();
    JScrollPane jScrollPane1 = new JScrollPane();
    JScrollPane jScrollPane2 = new JScrollPane();
    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout2 = new GridBagLayout();
    JPanel jPanel2 = new JPanel();
    GridBagLayout gridBagLayout3 = new GridBagLayout();

    /**Construct the frame*/
    public CatalogueView(CatalogueEventHandler handler) {
        this.handler = handler;
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            TOMA.log(TOMA.SEVERE, "Exception in Init");
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);

        this.setLayout(gridBagLayout1);
        titledBorder1 = new TitledBorder(BorderFactory.createEtchedBorder(Color.white, new Color(134, 134, 134)), labels.get("apostal.toma.catalogue.catalogue"));
        ImageIcon iSave = new ImageIcon(TOMAConstants.saveImagePath);
        ImageIcon iSavePressed = new ImageIcon(TOMAConstants.savePressedImagePath);
        jButton1.setIcon(iSave);
        jButton1.setBackground(TOMAColors.toolbarColor);
        jButton1.setBorder(border);
        jButton1.setPressedIcon(iSavePressed);
        jButton1.addActionListener(handler);
        jButton1.setActionCommand(".save");
        ImageIcon iDelete = new ImageIcon(TOMAConstants.deleteImagePath);
        ImageIcon iDeletePressed = new ImageIcon(TOMAConstants.deletePressedImagePath);
        jButton2.setIcon(iDelete);
        jButton2.setPressedIcon(iDeletePressed);
        jButton2.setBackground(TOMAColors.toolbarColor);
        jButton2.setBorder(border);
        jButton2.addActionListener(handler);
        jButton2.setActionCommand(".delete");
        jButton3.setText(labels.get("apostal.toma.catalogue.new_sub"));
        jButton3.addActionListener(handler);
        jButton3.setActionCommand(".new");
        jButton4.setText(labels.get("apostal.toma.catalogue.new_course"));
        jButton4.addActionListener(handler);
        jButton4.setActionCommand(".course");
        jButton5.setText(labels.get("apostal.toma.catalogue.new_programme"));
        jButton5.addActionListener(handler);
        jButton5.setActionCommand(".prog");
        jButton6.setText(labels.get("apostal.toma.catalogue.add"));
        jButton6.addActionListener(handler);
        jButton6.setActionCommand(".add");
        jButton7.setText(labels.get("apostal.toma.catalogue.remove"));
        jButton7.addActionListener(handler);
        jButton7.setActionCommand(".remove");
        jLtitle.setText(labels.get("apostal.toma.catalogue.title"));

        jTFtitle.setColumns(60);

        jLdescription.setText(labels.get("apostal.toma.catalogue.description"));
        jTAdescription.setColumns(60);
        jTAdescription.setRows(9);

        jLcreated.setTextWithLowerCase(labels.get("apostal.toma.catalogue.created"));
        jTFcreated.setBackground(TOMAColors.catalogueColor);
        jTFcreated.setEditable(false);
        jTFcreated.setColumns(10);
        jTFcreated.setBorder(border);
        jLmodified.setTextWithLowerCase(labels.get("apostal.toma.catalogue.modified"));
        jTFmodified.setBackground(TOMAColors.catalogueColor);
        jTFmodified.setEditable(false);
        jTFmodified.setColumns(10);
        jTFmodified.setBorder(border);

        jPanel1.setLayout(gridBagLayout2);
        jPanel1.setBackground(TOMAColors.toolbarColor);

        jPanel1.add(jButton1, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 3, 3, 0), 0, 0));
        jPanel1.add(jButton3, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 20, 3, 0), 0, 0));
        jPanel1.add(jButton4, new GridBagConstraints(3, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 20, 3, 0), 0, 0));
        jPanel1.add(jButton5, new GridBagConstraints(4, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 3, 3, 0), 0, 0));
        jPanel1.add(jButton6, new GridBagConstraints(5, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 20, 3, 0), 0, 0));
        jPanel1.add(jButton7, new GridBagConstraints(6, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 3, 3, 0), 0, 0));

        //coller les boutons  gauche
        jPanel1.add(Box.createGlue(), new GridBagConstraints(7, 0, 1, 1, 1.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 0, 3, 0), 0, 0));

        jPanel1.add(jButton2, new GridBagConstraints(8, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(3, 20, 3, 20), 0, 0));

        this.add(jPanel1, new GridBagConstraints(0, 0, 7, 1, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));

        jPanel2.setLayout(gridBagLayout3);
        jPanel2.setBackground(TOMAColors.catalogueColor);
        jPanel2.add(jLtitle, new GridBagConstraints(1, 4, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel2.add(jTFtitle, new GridBagConstraints(2, 4, 6, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel2.add(jLdescription, new GridBagConstraints(1, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel2.add(jLcreated, new GridBagConstraints(1, 6, 1, 1, 0.0, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(10, 5, 0, 0), 0, 0));
        jPanel2.add(jTFcreated, new GridBagConstraints(2, 6, 6, 1, 0.0, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel2.add(jLmodified, new GridBagConstraints(1, 7, 1, 1, 0.0, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel2.add(jTFmodified, new GridBagConstraints(2, 7, 6, 1, 0.0, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel2.add(jScrollPane2, new GridBagConstraints(2, 5, 6, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jScrollPane2.getViewport().add(jTAdescription, null);

        this.add(jPanel2, new GridBagConstraints(0, 1, 7, 1, 1.0, 1.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(10, 0, 0, 0), 0, 0));

        TOMA.log(TOMA.WARNING, "end init CatalogueView");

    }

    // Donnes de la fentre d'affichage vers  l'object contacts
    public Catalogue getData() {
        data.setTitle(jTFtitle.getText());
        data.setDescription(jTAdescription.getText());
        //sauver la date de la modification actuelle
        Calendar calendar = new GregorianCalendar();
        Date trialtime = new Date();
        calendar.setTime(trialtime);
        java.sql.Date date = new java.sql.Date(calendar.getTime().getTime());
        data.setDateMaj(date);
        return data;
    }

    public int getId() {
        return data.getIdCatalogue();
    }


    // donnes de l'object vers le formulaire
    public void setData(Catalogue data) {
        TOMA.log(TOMA.WARNING, "setData");
        this.data = data;
        String title = data.getTitle();
        jTFtitle.setText(title);
        String description = data.getDescription();
        jTAdescription.setText(description);
        String created = data.getDateCreation().toString();
        jTFcreated.setText(created);
        String modified = data.getDateMaj().toString();
        jTFmodified.setText(modified);
    }


    //Sauvegarde les donnes du formulaire dans un object, affichage dans la liste
    public Catalogue save() {
        Catalogue catalogue = getData();
        return catalogue;
    }

    // affichage des donnes de la base de donnes
    public void empty() {
        Catalogue data = new Catalogue();
        jTFtitle.setText("");
        jTAdescription.setText("");
        jTFcreated.setText("");
        jTFmodified.setText("");
    }

    // affichage des donnes de la base de donnes
    public void refresh() {
    }

}


