// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import java.util.*;

import apostal.toma.data.*;
import apostal.toma.viewcontrol.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.datacontrol.ContactsControl;
import apostal.toma.TOMA;

public class ContactsView extends AuxiliarElementsView implements ListSelectionListener {

    private static int multipleElementsLength = 30;

    private Vector vlist = new Vector();
    private Vector vcontacts = new Vector();
    private Contact data;
    private ContactsControl control = new ContactsControl();

    JScrollPane jScrollPane1 = new JScrollPane();
    JList jList1 = new JList();
    TOMAButton button_new = new TOMAButton();
    JPanel jPanel1 = new JPanel();
    TitledBorder titledBorder1;
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    GridBagLayout gridBagLayout2 = new GridBagLayout();    
    ContactsEventHandler handler = new ContactsEventHandler(this);
    
    TOMAButton button_delete = new TOMAButton();    
    TOMAButton button_save = new TOMAButton();    
    
    protected TOMALabels labels;    
    TOMALabel labelAddress = new TOMALabel();
    TOMALabel label_title = new TOMALabel();
    TOMALabel label_firstname = new TOMALabel();
    TOMALabel label_lastname = new TOMALabel();
    TOMALabel label_function = new TOMALabel();
    TOMALabel label_tel = new TOMALabel();
    TOMALabel label_fax = new TOMALabel();
    TOMALabel label_email = new TOMALabel();
    TOMALabel label_postcode = new TOMALabel();
    TOMALabel label_city = new TOMALabel();
    TOMALabel label_country = new TOMALabel();
    TOMALabel label_created = new TOMALabel();
    TOMALabel label_modified = new TOMALabel();
    
    TOMATextField jTFtitle = new TOMATextField();
    TOMATextField jTFfirstname = new TOMATextField();
    TOMATextField jTFlastname = new TOMATextField();
    TOMATextField jTFfunction = new TOMATextField();
    TOMATextField jTFtel = new TOMATextField();
    TOMATextField jTFpostcode = new TOMATextField();
    TOMAMultipleElements jAddressLines;
    TOMATextField jTFcreated = new TOMATextField();
    TOMATextField jTFmodified = new TOMATextField();
    TOMATextField jTFcity = new TOMATextField();
    TOMAComboBox jCBcountry = new TOMAComboBox();    
    TOMATextField jTFemail = new TOMATextField();
    TOMATextField jTFfax = new TOMATextField();

    //templates
    JComponent titleComponent;
    JComponent firstnameComponent;
    JComponent functionComponent;
    JComponent telComponent;
    JComponent faxComponent;
    JComponent emailComponent;
    int type=TOMATemplateView.CONTACTSVIEW;
    
    //pour les lments locks
    private TOMALocked panelLocked = new TOMALocked(null);
    private boolean screenIsLocked = false;
    private boolean notSelect = true;
    private boolean alreadyWarned;
    private int selectedIndex;
    
    /**Construct the frame*/
    public ContactsView() {
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }

        this.addWindowListener(handler);
    }

    private void jbInit() throws Exception {
        String denomination = "";
        JPanel contentPane = (JPanel) this.getContentPane();
        contentPane.setLayout(gridBagLayout1);
        titledBorder1 = new TitledBorder(BorderFactory.createEtchedBorder(Color.white, new Color(134, 134, 134)), labels.get("apostal.toma.contact.contact"));

        button_new.setText(labels.get("apostal.toma.contact.new"));
        button_new.addActionListener(handler);
        button_new.setActionCommand(".new");
        jPanel1.setBorder(titledBorder1);
        jPanel1.setLayout(gridBagLayout2);
        jPanel1.setBackground(TOMAColors.auxBackgroundColor2);

        button_delete.setText(labels.get("apostal.toma.contact.delete"));
        button_delete.addActionListener(handler);

        button_delete.setActionCommand(".delete");
        button_delete.setEnabled(false);

        labelAddress.setText(labels.get("apostal.toma.contact.addressLines"));
        label_title.setText(labels.get("apostal.toma.contact.title"));
        label_firstname.setText(labels.get("apostal.toma.contact.firstname"));
        label_lastname.setText(labels.get("apostal.toma.contact.lastname"));
        label_function.setText(labels.get("apostal.toma.contact.function"));
        label_tel.setText(labels.get("apostal.toma.contact.tel"));
        label_fax.setText(labels.get("apostal.toma.contact.fax"));
        label_email.setText(labels.get("apostal.toma.contact.email"));
        label_postcode.setText(labels.get("apostal.toma.contact.postcode"));
        label_city.setText(labels.get("apostal.toma.contact.city"));
        label_country.setText(labels.get("apostal.toma.contact.country"));
        label_created.setTextWithLowerCase(labels.get("apostal.toma.contact.created"));
        label_modified.setTextWithLowerCase(labels.get("apostal.toma.contact.modified"));
        button_save.setText(labels.get("apostal.toma.contact.save"));
        button_save.addActionListener(handler);
        button_save.setActionCommand(".save");
        button_save.setEnabled(false);

        // Countries
        TOMA t = TOMA.getInstance();
        Vector countries = t.getCountries();
        for (int i = 0; i < countries.size(); i++) {
            jCBcountry.addItem(countries.elementAt(i));
        }
        jList1.setBackground(TOMAColors.editingFieldColor);
        jList1.addListSelectionListener(this);
        jList1.setVisibleRowCount(5);
        jList1.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        jList1.setFixedCellWidth(200);
        jList1.setFont(TOMAFonts.listsFont);

        //jTFtitle.setPreferredSize(new Dimension(4, 20));
        jTFtitle.setColumns(20);
        jTFtitle.setDisabledTextColor(Color.white);
        jTFcreated.setBackground(TOMAColors.auxBackgroundColor2);
        jTFcreated.setEditable(false);
        jTFcreated.setBorder(new EmptyBorder(0, 0, 0, 0));
        jTFmodified.setBackground(TOMAColors.auxBackgroundColor2);
        jTFmodified.setEditable(false);
        jTFmodified.setBorder(new EmptyBorder(0, 0, 0, 0));

        // Initialistation de la liste des contacts  partir des donnes de la
        // base de donnes
        vlist = loadContacts();
        jList1.setListData(vlist);

        this.addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                this_windowClosing(e);
            }
        });
        jTFfirstname.setColumns(20);
        jTFlastname.setColumns(20);
        jTFfunction.setColumns(20);
        jTFtel.setColumns(20);
        jTFfax.setColumns(20);
        jTFemail.setColumns(20);
        jTFcity.setColumns(20);
        jTFpostcode.setColumns(20);
        jScrollPane1.getViewport().add(jList1);
        
        //////// pour templates ////////
        //title
        JScrollPane titlePane = new JScrollPane();
        titlePane.getViewport().add(jTFtitle);
        TOMATemplateResult titleResult = TOMATemplateView.getTemplateResult(type, "title");                
        if (titleResult.isForbidden())
            jTFtitle.setEnabled(false);
        if (titleResult.isMandatory())
            label_title.setText(label_title.getText() + " (*)");
        if (titleResult.getMaximum() > -1)
            label_title.setText(label_title.getText() + " (" + new Integer(titleResult.getMaximum()) + ")");
        if (titleResult.getValues() != null && !titleResult.getValues().isEmpty()) {
            Vector v = titleResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox titleCombo = new TOMAComboBox(v);
            titleComponent = titleCombo;
        } else
            titleComponent = titlePane;   
        
        //firstname
        JScrollPane firstnamePane = new JScrollPane();
        firstnamePane.getViewport().add(jTFfirstname);
        TOMATemplateResult firstnameResult = TOMATemplateView.getTemplateResult(type, "firstname");                
        if (firstnameResult.isForbidden())
            jTFfirstname.setEnabled(false);
        if (firstnameResult.isMandatory())
            label_firstname.setText(label_firstname.getText() + " (*)");
        if (firstnameResult.getMaximum() > -1)
            label_firstname.setText(label_firstname.getText() + " (" + new Integer(firstnameResult.getMaximum()) + ")");
        if (firstnameResult.getValues() != null && !firstnameResult.getValues().isEmpty()) {
            Vector v = firstnameResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox firstnameCombo = new TOMAComboBox(v);
            firstnameComponent = firstnameCombo;
        } else
            firstnameComponent = firstnamePane;           
        
        //lastname
        TOMATemplateResult lastnameResult = TOMATemplateView.getTemplateResult(type, "lastname");                
        if (lastnameResult.getMaximum() > -1)
            label_lastname.setText(label_lastname.getText() + " (" + new Integer(lastnameResult.getMaximum()) + ")");
        
        //function
        JScrollPane functionPane = new JScrollPane();
        functionPane.getViewport().add(jTFfunction);
        TOMATemplateResult functionResult = TOMATemplateView.getTemplateResult(type, "function");                
        if (functionResult.isForbidden())
            jTFfunction.setEnabled(false);
        if (functionResult.isMandatory())
            label_function.setText(label_function.getText() + " (*)");
        if (functionResult.getMaximum() > -1)
            label_function.setText(label_function.getText() + " (" + new Integer(functionResult.getMaximum()) + ")");
        if (functionResult.getValues() != null && !functionResult.getValues().isEmpty()) {
            Vector v = functionResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox functionCombo = new TOMAComboBox(v);
            functionComponent = functionCombo;
        } else
            functionComponent = functionPane;           
        
        //tel
        JScrollPane telPane = new JScrollPane();
        telPane.getViewport().add(jTFtel);
        TOMATemplateResult telResult = TOMATemplateView.getTemplateResult(type, "tel");
        if (telResult.isForbidden())
            jTFtel.setEnabled(false);
        if (telResult.isMandatory())
            label_tel.setText(label_tel.getText() + " (*)");
        if (telResult.getMaximum() > -1)
            label_tel.setText(label_tel.getText() + " (" + new Integer(telResult.getMaximum()) + ")");
        if (telResult.getValues() != null && !telResult.getValues().isEmpty()) {
            Vector v = telResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox telCombo = new TOMAComboBox(v);
            telComponent = telCombo;
        } else
            telComponent = telPane;          
        
        //fax
        JScrollPane faxPane = new JScrollPane();
        faxPane.getViewport().add(jTFfax);
        TOMATemplateResult faxResult = TOMATemplateView.getTemplateResult(type, "fax");
        if (faxResult.isForbidden())
            jTFfax.setEnabled(false);
        if (faxResult.isMandatory())
            label_fax.setText(label_fax.getText() + " (*)");
        if (faxResult.getMaximum() > -1)
            label_fax.setText(label_fax.getText() + " (" + new Integer(faxResult.getMaximum()) + ")");
        if (faxResult.getValues() != null && !faxResult.getValues().isEmpty()) {
            Vector v = faxResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox faxCombo = new TOMAComboBox(v);
            faxComponent = faxCombo;
        } else
            faxComponent = faxPane;          
        
        //email
        JScrollPane emailPane = new JScrollPane();
        emailPane.getViewport().add(jTFemail);
        TOMATemplateResult emailResult = TOMATemplateView.getTemplateResult(type, "email");
        if (emailResult.isForbidden())
            jTFemail.setEnabled(false);
        if (emailResult.isMandatory())
            label_email.setText(label_email.getText() + " (*)");
        if (emailResult.getMaximum() > -1)
            label_email.setText(label_email.getText() + " (" + new Integer(emailResult.getMaximum()) + ")");
        if (emailResult.getValues() != null && !emailResult.getValues().isEmpty()) {
            Vector v = emailResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox emailCombo = new TOMAComboBox(v);
            emailComponent = emailCombo;
        } else
            emailComponent = emailPane;            
        
        //address
        Integer columNb = new Integer(ContactsView.multipleElementsLength);
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        values[0] = columNb;
        jAddressLines = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 3, "", labels.get("apostal.toma.contact.add_addressline"), labels.get("apostal.toma.contact.remove"), TOMAColors.multipleElementsColor, 350, 120);        
        
        TOMATemplateResult addressResult = TOMATemplateView.getTemplateResult(type, "address");                
        if (addressResult.isMandatory())
            labelAddress.setText(labelAddress.getText() + " (*)");
        if (addressResult.isForbidden()){            
            jTFcity.setEnabled(false);
            jTFpostcode.setEnabled(false);
            jCBcountry.setEnabled(false);
            jAddressLines.setEnabled(false);
        }        
        
        ////////////////////////////////
        
        contentPane.add(jPanel1, new GridBagConstraints(0, 2, 2, 1, 1.0, 1.0
                , GridBagConstraints.NORTH, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        jPanel1.add(label_title, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_firstname, new GridBagConstraints(0, 1, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_lastname, new GridBagConstraints(0, 2, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_function, new GridBagConstraints(0, 3, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        
        jPanel1.add(firstnameComponent, new GridBagConstraints(2, 1, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFlastname, new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(functionComponent, new GridBagConstraints(2, 3, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(titleComponent, new GridBagConstraints(2, 0, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(labelAddress, new GridBagConstraints(3, 0, 2, 1, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jAddressLines, new GridBagConstraints(3, 1, 2, 6, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(telComponent, new GridBagConstraints(2, 4, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_tel, new GridBagConstraints(0, 4, 2, 3, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(jScrollPane1, new GridBagConstraints(0, 0, 1, 2, 1.1, 0.0
                , GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(button_new, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(button_delete, new GridBagConstraints(1, 1, 1, 1, 1.0, 0.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jScrollPane1.getViewport().add(jList1, null);
        jPanel1.add(label_email, new GridBagConstraints(0, 6, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_fax, new GridBagConstraints(0, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_postcode, new GridBagConstraints(3, 7, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_city, new GridBagConstraints(3, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_country, new GridBagConstraints(3, 9, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_created, new GridBagConstraints(0, 9, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_modified, new GridBagConstraints(0, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(button_save, new GridBagConstraints(2, 11, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFcity, new GridBagConstraints(4, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFpostcode, new GridBagConstraints(4, 7, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jCBcountry, new GridBagConstraints(4, 9, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(faxComponent, new GridBagConstraints(2, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(emailComponent, new GridBagConstraints(2, 6, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFcreated, new GridBagConstraints(2, 9, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFmodified, new GridBagConstraints(2, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));


        panelLocked.setVisible(false);
        contentPane.add(panelLocked, new GridBagConstraints(0, 3, 2, 1, 1.0, 1.0
                , GridBagConstraints.NORTH, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        jCBcountry.setSelectedIndex(11);
        this.setTitle(labels.get("apostal.toma.contact.contacts"));

        //this.setSize(new Dimension(707, 494));
        //centerFrame();
        this.getContentPane().setBackground(TOMAColors.auxBackgroundColor);
        this.pack();
        this.setVisible(true);

        this.refresh();
    }

    /**Overridden so we can exit when window is closed*/
    protected void processWindowEvent(WindowEvent e) {
        super.processWindowEvent(e);
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            //System.exit(0);
        }
    }

    // Donnes de la fentre d'affichage vers  l'object contacts
    public Contact getData() {
        if (screenIsLocked || notSelect) {
            return null;
        } else {
            Address address = getAddress();
            if (address != null)
                data.setAddress(address);
            
            if(titleComponent instanceof TOMAComboBox){
                try {
                    data.setTitle((String) ((TOMAComboBox) titleComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setTitle(null);
                }              
            }
            else            
                data.setTitle(jTFtitle.getText());
            
            if(firstnameComponent instanceof TOMAComboBox){
                try {
                    data.setFirstname((String) ((TOMAComboBox) firstnameComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setFirstname(null);
                }              
            }
            else
                data.setFirstname(jTFfirstname.getText());
            
            data.setLastname(jTFlastname.getText());
            
            if(functionComponent instanceof TOMAComboBox){
                try {
                    data.setFunction((String) ((TOMAComboBox) functionComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setFunction(null);
                }              
            }
            else            
                data.setFunction(jTFfunction.getText());
            
            if(telComponent instanceof TOMAComboBox){
                try {
                    data.setTel((String) ((TOMAComboBox) telComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setTel(null);
                }              
            }
            else             
                data.setTel(jTFtel.getText());
            
            if(faxComponent instanceof TOMAComboBox){
                try {
                    data.setFax((String) ((TOMAComboBox) faxComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setFax(null);
                }              
            }
            else                
                data.setFax(jTFfax.getText());
            
            if(emailComponent instanceof TOMAComboBox){
                try {
                    data.setEmail((String) ((TOMAComboBox) emailComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setEmail(null);
                }              
            }
            else                
                data.setEmail(jTFemail.getText());
        
            //sauver la date de la modification actuelle
        /*
       	Date de mise  jour modifie automatiquement

       	Calendar calendar = new GregorianCalendar();
        Date trialtime = new Date();
        calendar.setTime(trialtime);
        java.sql.Date date = new java.sql.Date(calendar.getTime().getTime());
        data.setDateMaj(date);*/
            return data;
        }
    }

    //Address des champs du formulaire vers l'object Address
    private Address getAddress() {
        Vector vaddresslines = new Vector();
        JComponent[] components = jAddressLines.getElements();
        for (int i = 0; i < components.length; i++) {
            vaddresslines.addElement(((TOMATextField) components[i]).getText());
        }
        String city = jTFcity.getText();
        String postCode = jTFpostcode.getText();
        Country country = (Country) jCBcountry.getSelectedItem();
        Address addressdata = new Address(vaddresslines, city, postCode, country);
        return addressdata;
    }


    // donnes de l'object vers le formulaire
    public void setData(Contact data) {
        this.clearData();
        button_save.setEnabled(true);
        this.data = data;
        Address address = data.getAddress();
        setAddress(address);
        String title = data.getTitle();
        String firstname = data.getFirstname();
        String lastname = data.getLastname();
        String function = data.getFunction();
        String tel = data.getTel();
        String fax = data.getFax();
        String email = data.getEmail();
        String datacreated = data.getDateCreation().toString();
        String datamodif = data.getDateMaj().toString();

        if(titleComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(title, (JComboBox) titleComponent);
        else        
            jTFtitle.setText(title);
        
        if(firstnameComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(firstname, (JComboBox) firstnameComponent);
        else          
            jTFfirstname.setText(firstname);
                
        jTFlastname.setText(lastname);
        
        if(functionComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(function, (JComboBox) functionComponent);
        else            
            jTFfunction.setText(function);
        
        if(telComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(tel, (JComboBox) telComponent);
        else            
            jTFtel.setText(tel);
        
        if(faxComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(fax, (JComboBox) faxComponent);
        else                    
            jTFfax.setText(fax);
        
        if(emailComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(email, (JComboBox) emailComponent);
        else         
            jTFemail.setText(email);
        
        jTFcreated.setText(datacreated);
        jTFmodified.setText(datamodif);

    }


    //Mettre les donnes de l'object address dans la fentre d'affichage
    public void setAddress(Address address) {
        Vector vstringlines = new Vector();
        Vector vcomponentlines = new Vector();
        
        //address lines
        try {
            vstringlines = address.getAddressLines();
            for (int i = 0; i < vstringlines.size(); i++) {
                vcomponentlines.addElement(new TOMATextField(ContactsView.multipleElementsLength, (String) vstringlines.elementAt(i)));
            }
        } catch (NullPointerException np) {
        }
        jAddressLines.setElements(vcomponentlines);
        TOMATemplateResult addressResult = TOMATemplateView.getTemplateResult(type, "address");
        if (addressResult.isForbidden())
            jAddressLines.setEnabled(false);          
        
        //city
        try {
            jTFcity.setText(address.getCity());
        } catch (NullPointerException np) {
            jTFcity.setText("");
        }
        //postcode
        try {
            jTFpostcode.setText(address.getPostCode());
        } catch (NullPointerException np) {
            jTFpostcode.setText("");
        }
        //country
        try {
            for (int i = 0; i < jCBcountry.getItemCount(); i++) {
                if (jCBcountry.getItemAt(i).toString().compareTo(address.getCountry().toString()) == 0) {
                    jCBcountry.setSelectedIndex(i);
                }
            }
        } catch (NullPointerException np) {
        }
                
    }       

    public int getIndex(Object object) {
        int index = -1;
        for (int i = 0; i < vlist.size(); i++) {
            if (vlist.elementAt(i).toString().compareTo(object.toString()) == 0) {
                index = i;
            }
        }
        return index;
    }

    public Vector loadContacts() {
        vcontacts = control.loadContacts(true);
        return vcontacts;
    }

    //Sauvegarde les donnes du formulaire dans un object, affichage dans la liste
    public Contact save() {
        Contact contact = getData();
        int index = getIndex(contact);
        vlist.removeElementAt(index);
        vlist.insertElementAt(contact.getTitle(), index);
        vcontacts.removeElementAt(index);
        vcontacts.insertElementAt(contact, index);
        return contact;
    }

    // affichage des donnes de la base de donnes
    public void refresh() {
        this.clearData();

        // Initialistation de la liste des contacts  partir des donnes de la
        // base de donnes
        vlist = loadContacts();
        jList1.setListData(vlist);

        jList1.clearSelection();
        button_delete.setEnabled(false);
        button_save.setEnabled(false);

        this.pack();
    }

    public void clearData() {
        //vider les champs
        jTFtitle.setText("");
        jTFfirstname.setText("");
        jTFlastname.setText("");
        jTFfunction.setText("");
        jTFtel.setText("");
        jTFfax.setText("");
        jTFemail.setText("");
        jTFcity.setText("");
        jTFpostcode.setText("");
        jAddressLines.setElements(new Vector());

        this.setEnabled(false);
        this.pack();
    }

    public void setEnabled(boolean enabled) {
        if (!enabled) {
            jTFtitle.setEnabled(false);
            if(titleComponent!=null)
                titleComponent.setEnabled(false);
            jTFfirstname.setEnabled(false);
            if(firstnameComponent!=null)
                firstnameComponent.setEnabled(false);
            jTFlastname.setEnabled(false);
            jTFfunction.setEnabled(false);
            if(functionComponent!=null)
                functionComponent.setEnabled(false);
            jTFtel.setEnabled(false);
            if(telComponent!=null)
                telComponent.setEnabled(false);
            jTFfax.setEnabled(false);
            if(faxComponent!=null)
                faxComponent.setEnabled(false);
            jTFemail.setEnabled(false);
            if(emailComponent!=null)
                emailComponent.setEnabled(false);
            
            jTFcity.setEnabled(false);
            jTFpostcode.setEnabled(false);
            jAddressLines.setEnabled(false);
            jCBcountry.setEnabled(false);
        }else{
            TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "title");
            if (!result.isForbidden()) {            
                jTFtitle.setEnabled(true);
                if(titleComponent!=null)
                    titleComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "firstname");
            if (!result.isForbidden()) {             
                jTFfirstname.setEnabled(true);
                if(firstnameComponent!=null)
                    firstnameComponent.setEnabled(true);
                }            
            jTFlastname.setEnabled(true);
            result = TOMATemplateView.getTemplateResult(type, "function");
            if (!result.isForbidden()) {             
                jTFfunction.setEnabled(true);
                if(functionComponent!=null)
                    functionComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "tel");
            if (!result.isForbidden()) {             
                jTFtel.setEnabled(true);
                if(telComponent!=null)
                    telComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "fax");
            if (!result.isForbidden()) {             
                jTFfax.setEnabled(true);
                if(faxComponent!=null)
                    faxComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "email");
            if (!result.isForbidden()) {             
                jTFemail.setEnabled(true);
                if(emailComponent!=null)
                    emailComponent.setEnabled(true);
            }
            
            result = TOMATemplateView.getTemplateResult(type, "address");
            if (!result.isForbidden()) {             
                jTFcity.setEnabled(true);
                jTFpostcode.setEnabled(true);
                jCBcountry.setEnabled(true); 
                jAddressLines.setEnabled(true);                
            }
        }
    }

    public void selectContact(int id) {
        alreadyWarned = true;
        if (vlist != null) {
            Iterator it = vlist.iterator();
            boolean found = false;
            while (it.hasNext() && !found) {
                Contact c = (Contact) it.next();
                if (c.getIdContact() == id) {
                    found = true;
                    jList1.setSelectedValue(c, true);
                    this.changeSelection();
                }
            }
        }
    }

    public boolean contactSelected() {
        return !notSelect && !screenIsLocked && !jList1.isSelectionEmpty();
    }

    private void changeSelection() {
        int index = jList1.getSelectedIndex();
        selectedIndex = index;
        if (index > -1) {

            try {
                //unlock contacts locked
                if (data != null)
                    control.unlockContact(data);
                //test lock from new contact
                Contact contact = (Contact) vcontacts.elementAt(index);
                boolean idtest = control.getLock(contact);
                if (!idtest) {
//activer les champs
                    button_delete.setEnabled(true);
                    notSelect = false;

                    //lock new contact
                    control.lockContact(contact);

//si l'cran d'avant tait "locked":
                    if (screenIsLocked) {
                        screenIsLocked = false;
                        jPanel1.setVisible(true);
                        panelLocked.setVisible(false);
                    }

                    //get new contact
                    setData(contact);

                    this.setEnabled(true);
                    this.pack();
                } else {
                    button_delete.setEnabled(false);
                    //Show Message
                    panelLocked.changeElement(contact);

                    if (!screenIsLocked) //on n'tait pas dj lock
                    {
                        data = null;
                        jPanel1.setVisible(false);
                        panelLocked.setVisible(true);
                        screenIsLocked = true;
                        notSelect = true;
                    } else {
                        panelLocked.setVisible(false);
                        panelLocked.setVisible(true);
                        notSelect = true;
                    }
                }
            } catch (NullPointerException np) {
            }
        }
    }

    public void valueChanged(ListSelectionEvent e) {
        int result = 0;

        if (!alreadyWarned) {
            if (selectedIndex > -1 && this.contactSelected() && TOMA.getInstance().getTomaParameters().getOpenWarningWindow()) {
                TOMAQuestion tq = new TOMAQuestion(TOMAFonts.htmlBegin + labels.get("apostal.toma.changeSelection.contact.confirm") + TOMAFonts.htmlEnd, labels.get("apostal.toma.changeSelection.contact.confirm.title"));
                result = tq.getResult();
                alreadyWarned = true;
            }

            if (result == 0) {
                this.changeSelection();
                //alreadyWarned = false;
                alreadyWarned = true;
            } else {
                alreadyWarned = true;
//jList1.setSelectedIndex(e.getLastIndex());
                jList1.setSelectedIndex(selectedIndex);
            }
        } else {
            alreadyWarned = false;
        }
    }

    void this_windowClosing(WindowEvent e) {
        //UnLock contact
        if (data != null) {
            control.unlockContact(data);
        }
    }

    public String testTemplateElements() {
        Contact c=this.getData();
        String msg = "";
                           
        String msg_title=TOMATemplateView.testTemplateElement(type, "title", c.getTitle(), labels.get("apostal.toma.contact.title"));
        if(msg_title!=null)
            msg =msg +"\n" + msg_title;
        
        String msg_firstname=TOMATemplateView.testTemplateElement(type, "firstname", c.getFirstname(), labels.get("apostal.toma.contact.firstname"));
        if(msg_firstname!=null)
            msg =msg +"\n" + msg_firstname;
        
        String msg_lastname=TOMATemplateView.testTemplateElement(type, "lastname", c.getLastname(), labels.get("apostal.toma.contact.lastname"));
        if(msg_lastname!=null)
            msg =msg +"\n" + msg_lastname;
        
        String msg_function=TOMATemplateView.testTemplateElement(type, "function", c.getFunction(), labels.get("apostal.toma.contact.function"));
        if(msg_function!=null)
            msg =msg +"\n" + msg_function;        
        
        String msg_tel=TOMATemplateView.testTemplateElement(type, "tel", c.getTel(), labels.get("apostal.toma.contact.tel"));
        if(msg_tel!=null)
            msg =msg +"\n" + msg_tel;   
        
        String msg_fax=TOMATemplateView.testTemplateElement(type, "fax",c.getFax(), labels.get("apostal.toma.contact.fax"));
        if(msg_fax!=null)
            msg =msg +"\n" + msg_fax;
                
        String msg_email=TOMATemplateView.testTemplateElement(type, "email", c.getEmail(), labels.get("apostal.toma.contact.email"));
        if(msg_email!=null)
            msg =msg +"\n" + msg_email;
        
        String msg_address=TOMATemplateView.testTemplateElement(type, "address", c.getAddress(), labels.get("apostal.toma.contact.address"));
        if(msg_address!=null)
            msg =msg +"\n" + msg_address;        
        
        if (msg.equals(""))
            return null;
        else
            return msg;
    }        
    
}


