// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;


import toolbox.swing.LimitedNumericDocument;
import apostal.toma.data.PublicationUnit;
import apostal.toma.data.Seance;

import javax.swing.*;
import javax.swing.border.LineBorder;
import java.awt.*;
import java.awt.event.*;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.SyrecosLogin;

import java.util.Vector;
import java.util.GregorianCalendar;
import java.util.Calendar;
import java.util.Date;


import javax.swing.JFrame;


public class CreateConsecSessionsView extends JDialog implements ActionListener {


    private TOMALabel label_days;
    private TOMALabel label_horaire;
    private TOMALabel labelDateBegin;
    private TOMALabel labelDateEnd;
    private TOMALabel labelSlotBegin;
    private TOMALabel labelSlotEnd;
    private TOMALabel labelOpenableDays;
    private TOMAButton ok;
    private TOMAButton cancel;
    private TOMATextField beginDateDay;
    private TOMATextField beginDateMonth;
    private TOMATextField beginDateYear;
    private TOMATextField endDateDay;
    private TOMATextField endDateMonth;
    private TOMATextField endDateYear;
    private TOMATextField beginSlotHour;
    private TOMATextField beginSlotMinute;
    private TOMATextField endSlotHour;
    private TOMATextField endSlotMinute;
    private JCheckBox cbOpenableDays;
    private TOMAFrame parent;
    protected TOMALabels labels = new TOMALabels();

    private JPanel panel;
    private JPanel panelInfo;
    private JPanel panelButton;


    public CreateConsecSessionsView(ActionListener listener, TOMAFrame parent) {
        super(apostal.toma.TOMA.getInstance().getTomaView(), "", true);
        this.parent = parent;
        this.setTitle(labels.get("apostal.toma.session.seancesConsec.title"));

        label_days = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.day"));
        label_horaire = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.slot"));
        labelDateBegin = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.dateBegin"));
        labelDateEnd = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.dateEnd"));
        labelSlotBegin = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.slotBegin"));
        labelSlotEnd = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.slotEnd"));
        labelOpenableDays = new TOMALabel(labels.get("apostal.toma.session.seancesConsec.openableDays"));

        beginDateDay = new TOMATextField(2);
        beginDateDay.setDocument(new LimitedNumericDocument(2));
        beginDateMonth = new TOMATextField(2);
        beginDateMonth.setDocument(new LimitedNumericDocument(2));
        beginDateYear = new TOMATextField(4);
        beginDateYear.setDocument(new LimitedNumericDocument(4));
        endDateDay = new TOMATextField(2);
        endDateDay.setDocument(new LimitedNumericDocument(2));
        endDateMonth = new TOMATextField(2);
        endDateMonth.setDocument(new LimitedNumericDocument(2));
        endDateYear = new TOMATextField(4);
        endDateYear.setDocument(new LimitedNumericDocument(4));
        beginSlotHour = new TOMATextField(2);
        beginSlotHour.setDocument(new LimitedNumericDocument(2));
        beginSlotMinute = new TOMATextField(2);
        beginSlotMinute.setDocument(new LimitedNumericDocument(2));
        endSlotHour = new TOMATextField(2);
        endSlotHour.setDocument(new LimitedNumericDocument(2));
        endSlotMinute = new TOMATextField(2);
        endSlotMinute.setDocument(new LimitedNumericDocument(2));

        cbOpenableDays = new JCheckBox(labelOpenableDays.getText());
        cbOpenableDays.setBackground(TOMAColors.tomaBackgroundColor);
        cbOpenableDays.setBorder(new LineBorder(TOMAColors.buttonsBorderColor, 1));
        cbOpenableDays.setForeground(Color.black);
        cbOpenableDays.setFont(TOMAFonts.labelsFont);

        cancel = new TOMAButton(labels.get("apostal.toma.session.seancesConsec.cancel"));
        cancel.setActionCommand("cancel");
        cancel.addActionListener(this);


        ok = new TOMAButton(labels.get("apostal.toma.session.seancesConsec.ok"));
        ok.setActionCommand("session_ok");
        ok.addActionListener(listener);

        panel = new JPanel(new GridBagLayout());

        panelInfo = new JPanel(new GridBagLayout());
        panelInfo.add(label_days, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(labelDateBegin, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(beginDateDay, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(beginDateMonth, new GridBagConstraints(2, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(beginDateYear, new GridBagConstraints(3, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(labelDateEnd, new GridBagConstraints(4, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(endDateDay, new GridBagConstraints(5, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(endDateMonth, new GridBagConstraints(6, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(endDateYear, new GridBagConstraints(7, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(label_horaire, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(labelSlotBegin, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(beginSlotHour, new GridBagConstraints(1, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(beginSlotMinute, new GridBagConstraints(2, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(labelSlotEnd, new GridBagConstraints(4, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(endSlotHour, new GridBagConstraints(5, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(endSlotMinute, new GridBagConstraints(6, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelInfo.add(cbOpenableDays, new GridBagConstraints(0, 4, 7, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        panelButton = new JPanel(new GridBagLayout());
        panelButton.add(cancel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panelButton.add(ok, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));


        panel.add(panelInfo, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        panel.add(panelButton, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        endDateYear.addFocusListener(new MyTextListener());

        panel.setBackground(TOMAColors.tomaBackgroundColor);
        panelInfo.setBackground(TOMAColors.tomaBackgroundColor);
        panelButton.setBackground(TOMAColors.tomaBackgroundColor);
        this.addWindowListener(new MyWindowAdapter());
        this.setBackground(TOMAColors.tomaBackgroundColor);
        this.getContentPane().add(panel);


    }

    public Vector getData() {
        boolean ouvrables = cbOpenableDays.isSelected();
        Vector seances = new Vector();
        int debutJour = 0;
        int debutMois = 0;
        int debutAnnee = 0;
        int finJour = 0;
        int finMois = 0;
        int finAnnee = 0;
        int slotBeginHour = 8;
        int slotBeginMinute = 0;
        int slotEndHour = 17;
        int slotEndMinute = 0;
        if (beginDateDay.getText() != null && !beginDateDay.getText().equals(""))
            debutJour = Integer.parseInt(beginDateDay.getText());
        if (beginDateMonth.getText() != null && !beginDateMonth.getText().equals(""))
            debutMois = Integer.parseInt(beginDateMonth.getText());
        if (beginDateYear.getText() != null && !beginDateYear.getText().equals(""))
            debutAnnee = Integer.parseInt(beginDateYear.getText());
        if (endDateDay.getText() != null && !endDateDay.getText().equals(""))
            finJour = Integer.parseInt(endDateDay.getText());
        if (endDateMonth.getText() != null && !endDateMonth.getText().equals(""))
            finMois = Integer.parseInt(endDateMonth.getText());
        if (endDateYear.getText() != null && !endDateYear.getText().equals(""))
            finAnnee = Integer.parseInt(endDateYear.getText());
        if (beginSlotHour.getText() != null && !beginSlotHour.getText().equals(""))
            slotBeginHour = Integer.parseInt(beginSlotHour.getText());
        if (beginSlotMinute.getText() != null && !beginSlotMinute.getText().equals(""))
            slotBeginMinute = Integer.parseInt(beginSlotMinute.getText());
        if (endSlotHour.getText() != null && !endSlotHour.getText().equals(""))
            slotEndHour = Integer.parseInt(endSlotHour.getText());
        if (endSlotMinute.getText() != null && !endSlotMinute.getText().equals(""))
            slotEndMinute = Integer.parseInt(endSlotMinute.getText());
        GregorianCalendar lastDayOfYear = new GregorianCalendar(debutAnnee, 11, 31);
        GregorianCalendar debut = new GregorianCalendar(debutAnnee, debutMois - 1, debutJour);
        Date dateDebut = debut.getTime();
        GregorianCalendar fin = new GregorianCalendar(finAnnee, finMois - 1, finJour);
        Date dateFin = fin.getTime();
        if (dateDebut.before(dateFin)) {
            debut.setTime(dateDebut);
            fin.setTime(dateFin);
            Date dateTemp;
            java.sql.Date date;
            Seance tempSeance;
            if (!ouvrables || ((debut.get(Calendar.DAY_OF_WEEK) != Calendar.SATURDAY) && (debut.get(Calendar.DAY_OF_WEEK) != Calendar.SUNDAY))) {
                dateTemp = debut.getTime();
                date = new java.sql.Date(dateTemp.getTime());
                tempSeance = new Seance();
                tempSeance.setBeginHour(slotBeginHour);
                tempSeance.setBeginMinute(slotBeginMinute);
                tempSeance.setEndHour(slotEndHour);
                tempSeance.setEndMinute(slotEndMinute);
                tempSeance.setSeanceDate(date);
                seances.add(tempSeance);
            }
            do {
                if (!debut.equals(lastDayOfYear)) {
                    debut.roll(GregorianCalendar.DAY_OF_YEAR, true);
                } else {
                    debut.roll(GregorianCalendar.YEAR, true);
                    debut.roll(GregorianCalendar.DAY_OF_YEAR, true);
                    lastDayOfYear.roll(GregorianCalendar.YEAR, true);
                }


                if (!ouvrables || ((debut.get(Calendar.DAY_OF_WEEK) != Calendar.SATURDAY) && (debut.get(Calendar.DAY_OF_WEEK) != Calendar.SUNDAY))) {
                    dateTemp = debut.getTime();
                    date = new java.sql.Date(dateTemp.getTime());
                    tempSeance = new Seance();
                    tempSeance.setBeginHour(slotBeginHour);
                    tempSeance.setBeginMinute(slotBeginMinute);
                    tempSeance.setEndHour(slotEndHour);
                    tempSeance.setEndMinute(slotEndMinute);
                    tempSeance.setSeanceDate(date);
                    seances.add(tempSeance);
                }
            } while (!debut.equals(fin));
        }
        return seances;
    }

    public void center() {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension frameSize = this.getSize();
        this.setLocation((screenSize.width - frameSize.width) / 2, (screenSize.height - frameSize.height) / 2);
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("cancel")) {
            this.dispose();
            parent.show();

        }
    }


    class MyTextListener implements FocusListener {
        public void focusGained(FocusEvent e) {
            if (endDateYear.getText().equals("")) {
                if (!beginDateYear.getText().equals("")) {
                    String s = beginDateYear.getText();
                    endDateYear.setText(s);
                }
            }
        }

        public void focusLost(FocusEvent e) {
            String text = endDateYear.getText();
            if (beginDateYear.getText().equals(""))
                beginDateYear.setText(text);
        }
    }

    class MyWindowAdapter extends WindowAdapter {
        public void windowClosing(WindowEvent e) {
            parent.show();
        }
    }

}

