// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.data.Language;
import apostal.toma.data.Domain;
import apostal.toma.database.DomainDB;
import apostal.toma.TOMA;
import apostal.toma.data.TOMAParameters;

public class DomainsComboBoxes extends JPanel implements ActionListener {
    private static Vector domains;
    private static Language ln;

    static {
        TOMA toma = TOMA.getInstance();
        ln = toma.getTomaParameters().getLanguage();
        domains = toma.getDomains();
    }

    private GridBagLayout layout;
    private Vector boxes;

    public DomainsComboBoxes() {
        super();
        layout = new GridBagLayout();
        this.setLayout(layout);

        boxes = new Vector();

        TOMAComboBox box = new TOMAComboBox(domains);
        box.addActionListener(this);
        box.setActionCommand("0");
        boxes.add(box);
        this.add(box, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        this.setBackground(TOMAColors.multipleElementsColor);
    }

    public Vector getBoxes() {
        return boxes;
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        int i = 0;
        try {
            i = Integer.parseInt(cmd);
            this.listSelected(i);
        } catch (java.lang.NumberFormatException ex) {
            TOMA.log(TOMA.SEVERE, "the command " + cmd + " is not an int");
        }
    }

    public void listSelected(int i) {
        //enlever tous les combo box aprs
        int taille = boxes.size();
        Vector newboxes = new Vector(boxes);
        for (int j = i + 1; j < taille; j++) {
            TOMAComboBox abox = (TOMAComboBox) boxes.elementAt(j);
            this.remove(abox);
            newboxes.remove(abox);
        }
        boxes = newboxes;

        //rajouter le nouveau combo box
        //charger les sous domains
        TOMAComboBox box = (TOMAComboBox) boxes.elementAt(i);
        Domain d = (Domain) box.getSelectedItem();

        if (d.getDomains() == null) {
            DomainDB ddb = new DomainDB(d);
            ddb.loadById(ln);
            ddb.loadSubLevel(ln);
        }

        Vector subdomains = d.getDomains();
        //crer le combo box si non vide
        if (subdomains != null && !subdomains.isEmpty()) {
            TOMAComboBox subbox = new TOMAComboBox(subdomains);
            subbox.addActionListener(this);
            subbox.setActionCommand((new Integer(i + 1)).toString());
            boxes.add(subbox);
            this.add(subbox, new GridBagConstraints(0, i + 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, (i + 1) * 20, 0, 0), 0, 0));
        }

        this.doLayout();
        this.revalidate();
        this.repaint();
    }

    public void addSelectedDomainPath(Vector path) {
        if (path.size() > 1) {
            Vector parentPath = (Vector) path.clone();
            parentPath.remove(path.lastElement());

            this.addSelectedDomainPath(parentPath);

            //rajouter  la fin
            //dernier lment
            int i = boxes.size() - 1;

            TOMAComboBox box = (TOMAComboBox) boxes.elementAt(i);
            Domain domain = this.getDomainInComboBox(box, (Domain) path.lastElement());
            if (domain != null) {
                box.setSelectedItem(domain);
                this.listSelected(i);
            }
        } else if (path.size() == 1) {
            TOMAComboBox box = (TOMAComboBox) boxes.elementAt(0);
            Domain domain = this.getDomainInComboBox(box, (Domain) path.elementAt(0));
            if (domain != null) {
                box.setSelectedItem(domain);
                this.listSelected(0);
            }
        }
    }

    /**
     * selectionne le domaine ou sous domaine
     */
    public void addSelectedDomain(Domain d) {
        Language ln = TOMA.getInstance().getTomaParameters().getLanguage();
        DomainDB ddb = new DomainDB(d);
        ddb.loadById(ln);

        if (d.getIdSuperDomain() < 0) {
            TOMAComboBox box = (TOMAComboBox) boxes.elementAt(0);
            Domain domain = this.getDomainInComboBox(box, d);
            if (domain != null) {
                box.setSelectedItem(domain);
                this.listSelected(0);
            }
        }
        //pas encore le cas terminal
        else {
            Domain pere = new Domain(d.getIdSuperDomain());
            this.addSelectedDomain(pere);

            //rajouter  la fin
            //dernier lment
            int i = boxes.size() - 1;

            TOMAComboBox box = (TOMAComboBox) boxes.elementAt(i);
            Domain domain = this.getDomainInComboBox(box, d);
            if (domain != null) {
                box.setSelectedItem(domain);
                this.listSelected(i);
            }
        }
    }

    public Domain getDomainInComboBox(TOMAComboBox box, Domain domain) {
        int id = domain.getIdDomain();
        int nb = box.getItemCount();
        Domain found = null;
        for (int i = 0; i < nb; i++) {
            Domain d = (Domain) box.getItemAt(i);
            if (d.getIdDomain() == id) {
                found = d;
                break;
            }
        }
        return found;
    }

    public void setEnabled(boolean enabled) {
        if (boxes != null) {
            Iterator iter = boxes.iterator();
            while (iter.hasNext()) {
                TOMAComboBox box = (TOMAComboBox) iter.next();
                box.setEnabled(enabled);
            }
        }
    }

}