// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;
import java.util.*;

import apostal.toma.data.*;
import apostal.toma.viewcontrol.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.datacontrol.LocationsControl;
import apostal.toma.TOMA;
import apostal.toma.database.AreaDB;

public class LocationsView extends AuxiliarElementsView implements ActionListener, ListSelectionListener {

    private static int multipleElementsLength = 30;

    private Vector vlist = new Vector();
    private Vector vlocations = new Vector();
    private Location data;
    private LocationsControl control = new LocationsControl();
    private int oldIndex = -1;
    public String oldLocation = null;
    private int cpt = 0;
    JScrollPane jScrollPane1 = new JScrollPane();
    JList jList1 = new JList();
    TOMAButton button_new = new TOMAButton();
    JPanel jPanel1 = new JPanel();
    TitledBorder titledBorder1;
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMAButton button_delete = new TOMAButton();
    TOMALabel labelAddress = new TOMALabel();
    TOMALabel labelImages = new TOMALabel();
    TOMALabel label_denomination = new TOMALabel();
    TOMALabel label_completeName = new TOMALabel();
    TOMALabel label_tel = new TOMALabel();
    TOMALabel label_fax = new TOMALabel();
    TOMALabel label_email = new TOMALabel();
    TOMALabel label_postcode = new TOMALabel();
    TOMALabel label_country = new TOMALabel();
    TOMALabel label_accessDesc = new TOMALabel();
    TOMALabel label_accessComment = new TOMALabel();
    TOMALabel label_accessFac = new TOMALabel();
    TOMALabel label_lastModified = new TOMALabel();
    TOMALabel label_created = new TOMALabel();
    TOMATextField jTFdenomination = new TOMATextField();
    TOMATextField jTFcompletename = new TOMATextField();
    TOMATextField jTFtelephone = new TOMATextField();
    TOMATextField jTFfax = new TOMATextField();
    TOMATextField jTFemail = new TOMATextField();
    TOMATextField jTFpostcode = new TOMATextField();
    TOMATextField jTAaccesscom = new TOMATextField();
    TOMATextField jTAaccessfac = new TOMATextField();
    //JScrollPane jScrollPane2 = new JScrollPane();
    //JScrollPane jScrollPane3 = new JScrollPane();
    //JScrollPane jScrollPane4 = new JScrollPane();
    TOMAButton button_save = new TOMAButton();
    TOMAMultipleElements jAddressLines;
    TOMAMultipleElements jImages;
    GridBagLayout gridBagLayout2 = new GridBagLayout();
    TOMATextField jTFcreated = new TOMATextField();
    TOMATextField jTFmodified = new TOMATextField();
    TOMATextField jTAaccessdesc = new TOMATextField();

    LocationsEventHandler handler = new LocationsEventHandler(this);
    TOMALabel label_city = new TOMALabel();
    TOMATextField jTFcity = new TOMATextField();
    TOMALabel label_area = new TOMALabel();
    TOMAComboBox jCBarea = new TOMAComboBox();
    TOMALabel label_subarea = new TOMALabel();
    TOMAComboBox jCBsubarea = new TOMAComboBox();
    TOMAComboBox jCBcountry = new TOMAComboBox();
    protected TOMALabels labels;

    JPanel contentPane;

    //pour les lments locks
    private TOMALocked panelLocked = new TOMALocked(null);
    private boolean screenIsLocked = false;
    private boolean notSelect = true;
    public boolean alreadyWarned;
    private int selectedIndex;
    private int type;
    
    //components for templates
    JComponent completeNameComponent;
    JComponent telComponent;
    JComponent faxComponent;
    JComponent emailComponent;
    JComponent accessDescriptionComponent;
    JComponent accessCommentComponent;
    JComponent accessFacilitiesComponent;
    
    private Vector allowed_images;    

    /**Construct the frame*/
    public LocationsView() {
        type=TOMATemplateView.LOCATIONSVIEW;
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try {
            labels = new TOMALabels();
            jbInit();
            pack();
        } catch (Exception e) {
            e.printStackTrace();
        }

        this.addWindowListener(handler);
    }

    private void jbInit() throws Exception {
        String denomination = "";
        contentPane = (JPanel) this.getContentPane();
        contentPane.setLayout(gridBagLayout1);
        titledBorder1 = new TitledBorder(BorderFactory.createEtchedBorder(Color.white, new Color(134, 134, 134)), labels.get("apostal.toma.location.location"));

        button_new.setText(labels.get("apostal.toma.location.new"));
        button_new.addActionListener(handler);
        button_new.setActionCommand(".new");
        jPanel1.setBackground(TOMAColors.auxBackgroundColor2);
        jPanel1.setBorder(titledBorder1);
        jPanel1.setLayout(gridBagLayout2);

        button_delete.setText(labels.get("apostal.toma.location.delete"));
        button_delete.addActionListener(handler);
        button_delete.setActionCommand(".delete");
        button_delete.setEnabled(false);

        labelAddress.setText(labels.get("apostal.toma.location.addressLines"));
        labelImages.setText(labels.get("apostal.toma.location.images"));
        label_denomination.setText(labels.get("apostal.toma.location.denomination"));
        label_completeName.setText(labels.get("apostal.toma.location.completename"));
        label_tel.setText(labels.get("apostal.toma.location.telephone"));
        label_fax.setText(labels.get("apostal.toma.location.fax"));
        label_email.setText(labels.get("apostal.toma.location.email"));
        label_postcode.setText(labels.get("apostal.toma.location.postcode"));
        label_country.setText(labels.get("apostal.toma.location.country"));
        label_accessDesc.setText(labels.get("apostal.toma.location.access_description"));
        label_accessComment.setText(labels.get("apostal.toma.location.acccess_comment"));
        label_accessFac.setText(labels.get("apostal.toma.location.access_facilities"));
        label_lastModified.setTextWithLowerCase(labels.get("apostal.toma.location.lastmodified"));
        label_created.setTextWithLowerCase(labels.get("apostal.toma.location.created"));
        jTAaccesscom.setBorder(BorderFactory.createEtchedBorder());
        jTAaccesscom.setColumns(20);
        jTAaccessfac.setBorder(BorderFactory.createEtchedBorder());
        button_save.setText(labels.get("apostal.toma.location.save"));
        button_save.addActionListener(handler);
        button_save.setActionCommand(".save");
        button_save.setEnabled(false);

        jTAaccessdesc.setBorder(BorderFactory.createEtchedBorder());
        jTAaccessdesc.setColumns(20);
        label_city.setText(labels.get("apostal.toma.location.city"));
        label_area.setText(labels.get("apostal.toma.location.area"));
        label_subarea.setText(labels.get("apostal.toma.location.subarea"));

        //liste de lieux
        jList1.setBackground(TOMAColors.editingFieldColor);
        jList1.addListSelectionListener(this);
        /*jList1.addMouseListener(new java.awt.event.MouseAdapter()
        {
          public void mouseClicked(MouseEvent e)
          {
            jList1_mouseClicked(e);
          }
        });*/
        jList1.setVisibleRowCount(5);
        jList1.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        jList1.setFixedCellWidth(200);
        jList1.setFont(TOMAFonts.listsFont);

        jTFdenomination.setColumns(20);
        jTFcreated.setEditable(false);
        jTFcreated.setBackground(TOMAColors.auxBackgroundColor2);
        jTFcreated.setBorder(new EmptyBorder(0, 0, 0, 0));
        jTFmodified.setEditable(false);
        jTFmodified.setBackground(TOMAColors.auxBackgroundColor2);
        jTFmodified.setBorder(new EmptyBorder(0, 0, 0, 0));

        // Initialistation de la liste des locations  partir des donnes de la
        // base de donnes
        vlist = loadLocations();

        // Countries
        TOMA t = TOMA.getInstance();
        Vector countries = t.getCountries();
        for (int i = 0; i < countries.size(); i++) {
            jCBcountry.addItem(countries.elementAt(i));
        }
        jCBcountry.addActionListener(this);
        jCBcountry.setActionCommand("country");

        //Area
        jCBarea.addActionListener(this);
        jCBarea.setActionCommand("area");

        //Subarea
        //Vector areas = SubAreaDB.load(TOMA.getInstance().getTomaParameters().getLanguage());

        jList1.setListData(vlist);

        jTFcompletename.setColumns(20);
        jTFtelephone.setColumns(20);
        jTFfax.setColumns(20);
        jTFemail.setColumns(20);
        jTFcity.setColumns(20);
        jTFpostcode.setColumns(20);

        contentPane.setBackground(TOMAColors.auxBackgroundColor);
        jScrollPane1.getViewport().add(jList1);

        //address
        Integer columNb = new Integer(LocationsView.multipleElementsLength);
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        values[0] = columNb;
        jAddressLines = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 3, "", labels.get("apostal.toma.location.add_address_lines"), labels.get("apostal.toma.location.remove"), TOMAColors.multipleElementsColor, 350, 120);        
        
        // images
        TOMATemplateResult imageResult = TOMATemplateView.getTemplateResult(type, "image");
        if (imageResult.isMandatory())
            labelImages.setText(labelImages.getText() + " (*)");                
        if (imageResult.getValues() != null && !imageResult.getValues().isEmpty()) {
            allowed_images = imageResult.getValues();            
            Class[] classes2 = new Class[1];
            classes2[0] = Class.forName("java.util.Vector");
            Object[] values2 = new Object[1];
            values2[0] = allowed_images;
            jImages = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes2, values2, 1, "", labels.get("apostal.toma.location.add_image"), labels.get("apostal.toma.location.remove"), TOMAColors.multipleElementsColor, 330, 120);        
        } else {
            Class[] classes2 = new Class[1];
            classes2[0] = Class.forName("java.lang.Integer");
            Object[] values2 = new Object[1];
            values2[0] = new Integer(25);
            jImages = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes2, values2, 1, "", labels.get("apostal.toma.location.add_image"), labels.get("apostal.toma.location.remove"), TOMAColors.multipleElementsColor, 330, 120);        
        }                
        if (imageResult.isForbidden())
            jImages.setEnabled(false);        
        
        //////////////// for templates ////////////
        
        //denomination
        TOMATemplateResult denominationResult = TOMATemplateView.getTemplateResult(type, "denomination");
        if (denominationResult.getMaximum() > -1)
            label_denomination.setText(label_denomination.getText() + " (" + new Integer(denominationResult.getMaximum()) + ")");                
        
        //completeName
        JScrollPane completeNamePane = new JScrollPane();
        completeNamePane.getViewport().add(jTFcompletename);
        TOMATemplateResult completeNameResult = TOMATemplateView.getTemplateResult(type, "completeName");                
        if (completeNameResult.isForbidden())
            jTFcompletename.setEnabled(false);
        if (completeNameResult.isMandatory())
            label_completeName.setText(label_completeName.getText() + " (*)");
        if (completeNameResult.getMaximum() > -1)
            label_completeName.setText(label_completeName.getText() + " (" + new Integer(completeNameResult.getMaximum()) + ")");
        if (completeNameResult.getValues() != null && !completeNameResult.getValues().isEmpty()) {
            Vector v = completeNameResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox completeNameCombo = new TOMAComboBox(v);
            completeNameComponent = completeNameCombo;
        } else
            completeNameComponent = completeNamePane;        

        //tel
        JScrollPane telPane = new JScrollPane();
        telPane.getViewport().add(jTFtelephone);
        TOMATemplateResult telResult = TOMATemplateView.getTemplateResult(type, "tel");
        if (telResult.isForbidden())
            jTFtelephone.setEnabled(false);
        if (telResult.isMandatory())
            label_tel.setText(label_tel.getText() + " (*)");
        if (telResult.getMaximum() > -1)
            label_tel.setText(label_tel.getText() + " (" + new Integer(telResult.getMaximum()) + ")");
        if (telResult.getValues() != null && !telResult.getValues().isEmpty()) {
            Vector v = telResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox telCombo = new TOMAComboBox(v);
            telComponent = telCombo;
        } else
            telComponent = telPane;          
        
        //fax
        JScrollPane faxPane = new JScrollPane();
        faxPane.getViewport().add(jTFfax);
        TOMATemplateResult faxResult = TOMATemplateView.getTemplateResult(type, "fax");
        if (faxResult.isForbidden())
            jTFfax.setEnabled(false);
        if (faxResult.isMandatory())
            label_fax.setText(label_fax.getText() + " (*)");
        if (faxResult.getMaximum() > -1)
            label_fax.setText(label_fax.getText() + " (" + new Integer(faxResult.getMaximum()) + ")");
        if (faxResult.getValues() != null && !faxResult.getValues().isEmpty()) {
            Vector v = faxResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox faxCombo = new TOMAComboBox(v);
            faxComponent = faxCombo;
        } else
            faxComponent = faxPane;          
        
        //email
        JScrollPane emailPane = new JScrollPane();
        emailPane.getViewport().add(jTFemail);
        TOMATemplateResult emailResult = TOMATemplateView.getTemplateResult(type, "email");
        if (emailResult.isForbidden())
            jTFemail.setEnabled(false);
        if (emailResult.isMandatory())
            label_email.setText(label_email.getText() + " (*)");
        if (emailResult.getMaximum() > -1)
            label_email.setText(label_email.getText() + " (" + new Integer(emailResult.getMaximum()) + ")");
        if (emailResult.getValues() != null && !emailResult.getValues().isEmpty()) {
            Vector v = emailResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox emailCombo = new TOMAComboBox(v);
            emailComponent = emailCombo;
        } else
            emailComponent = emailPane;    
        
        //area
        TOMATemplateResult areaResult = TOMATemplateView.getTemplateResult(type, "area");
        if (areaResult.isForbidden()){
            jCBarea.setEnabled(false);
            jCBsubarea.setEnabled(false);
        }
        //if (areaResult.isMandatory())
        //    label_area.setText(label_area.getText() + " (*)");
        
        //accessDescription
        JScrollPane accessDescriptionPane = new JScrollPane();
        accessDescriptionPane.getViewport().add(jTAaccessdesc);
        TOMATemplateResult accessDescriptionResult = TOMATemplateView.getTemplateResult(type, "accessDescription");
        if (accessDescriptionResult.isForbidden())
            jTAaccessdesc.setEnabled(false);
        if (accessDescriptionResult.isMandatory())
            label_accessDesc.setText(label_accessDesc.getText() + " (*)");
        if (accessDescriptionResult.getMaximum() > -1)
            label_accessDesc.setText(label_accessDesc.getText() + " (" + new Integer(accessDescriptionResult.getMaximum()) + ")");
        if (accessDescriptionResult.getValues() != null && !accessDescriptionResult.getValues().isEmpty()) {
            Vector v = accessDescriptionResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox accessDescriptionCombo = new TOMAComboBox(v);
            accessDescriptionComponent = accessDescriptionCombo;
        } else
            accessDescriptionComponent = accessDescriptionPane;   
        
        //accessComment
        JScrollPane accessCommentPane = new JScrollPane();
        accessCommentPane.getViewport().add(jTAaccesscom);
        TOMATemplateResult accessCommentResult = TOMATemplateView.getTemplateResult(type, "accessComment");
        if (accessCommentResult.isForbidden())
            jTAaccesscom.setEnabled(false);
        if (accessCommentResult.isMandatory())
            label_accessComment.setText(label_accessComment.getText() + " (*)");
        if (accessCommentResult.getMaximum() > -1)
            label_accessComment.setText(label_accessComment.getText() + " (" + new Integer(accessCommentResult.getMaximum()) + ")");
        if (accessCommentResult.getValues() != null && !accessCommentResult.getValues().isEmpty()) {
            Vector v = accessCommentResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox accessCommentCombo = new TOMAComboBox(v);
            accessCommentComponent = accessCommentCombo;
        } else
            accessCommentComponent = accessCommentPane; 
        
        //accessFacilities
        JScrollPane accessFacilitiesPane = new JScrollPane();
        accessFacilitiesPane.getViewport().add(jTAaccessfac);
        TOMATemplateResult accessFacilitiesResult = TOMATemplateView.getTemplateResult(type, "accessFacilities");
        if (accessFacilitiesResult.isForbidden())
            jTAaccessfac.setEnabled(false);
        if (accessFacilitiesResult.isMandatory())
            label_accessFac.setText(label_accessFac.getText() + " (*)");
        if (accessFacilitiesResult.getMaximum() > -1)
            label_accessFac.setText(label_accessFac.getText() + " (" + new Integer(accessFacilitiesResult.getMaximum()) + ")");
        if (accessFacilitiesResult.getValues() != null && !accessFacilitiesResult.getValues().isEmpty()) {
            Vector v = accessFacilitiesResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox accessFacilitiesCombo = new TOMAComboBox(v);
            accessFacilitiesComponent = accessFacilitiesCombo;
        } else
            accessFacilitiesComponent = accessFacilitiesPane;          
                      
        //////////////////////////////////////////
        
        contentPane.add(jScrollPane1, new GridBagConstraints(0, 0, 1, 2, 0.1, 0.0
                , GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(5, 0, 0, 0), 0, 0));

        contentPane.add(button_new, new GridBagConstraints(1, 0, 1, 1, 0.1, 0.1
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 0, 0), 0, 0));
        contentPane.add(button_delete, new GridBagConstraints(1, 1, 1, 1, 0.1, 0.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 0, 0), 0, 0));
        jScrollPane1.getViewport().add(jList1, null);

        contentPane.add(jPanel1, new GridBagConstraints(0, 2, 2, 1, 1.0, 1.0
                , GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
        jPanel1.add(label_denomination, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_completeName, new GridBagConstraints(0, 1, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_tel, new GridBagConstraints(0, 2, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_fax, new GridBagConstraints(0, 3, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_email, new GridBagConstraints(0, 4, 2, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel1.add(jTFdenomination, new GridBagConstraints(2, 0, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(completeNameComponent, new GridBagConstraints(2, 1, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(telComponent, new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(faxComponent, new GridBagConstraints(2, 3, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jAddressLines, new GridBagConstraints(0, 6, 3, 4, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(emailComponent, new GridBagConstraints(2, 4, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel1.add(labelAddress, new GridBagConstraints(0, 5, 2, 1, 0.0, 0.0
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(labelImages, new GridBagConstraints(3, 0, 3, 1, 0.0, 0.0
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel1.add(jImages, new GridBagConstraints(3, 1, 3, 5, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));


        jPanel1.add(jTFcity, new GridBagConstraints(2, 10, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel1.add(jTFpostcode, new GridBagConstraints(2, 11, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        jPanel1.add(label_subarea, new GridBagConstraints(0, 14, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_area, new GridBagConstraints(0, 13, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_country, new GridBagConstraints(0, 12, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_postcode, new GridBagConstraints(0, 11, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_city, new GridBagConstraints(0, 10, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jCBsubarea, new GridBagConstraints(2, 14, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jCBarea, new GridBagConstraints(2, 13, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jCBcountry, new GridBagConstraints(2, 12, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_accessDesc, new GridBagConstraints(3, 6, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_accessComment, new GridBagConstraints(3, 7, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(accessDescriptionComponent, new GridBagConstraints(4, 6, 2, 1, 0.0, 1.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_accessFac, new GridBagConstraints(3, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(accessCommentComponent, new GridBagConstraints(4, 7, 2, 1, 1.0, 1.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(accessFacilitiesComponent, new GridBagConstraints(4, 8, 2, 1, 1.0, 1.1
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_lastModified, new GridBagConstraints(3, 15, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_created, new GridBagConstraints(3, 14, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFmodified, new GridBagConstraints(4, 15, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFcreated, new GridBagConstraints(4, 14, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(button_save, new GridBagConstraints(2, 16, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        panelLocked.setVisible(false);
        contentPane.add(panelLocked, new GridBagConstraints(0, 3, 2, 1, 1.0, 1.0
                , GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        //jScrollPane4.getViewport().add(jTAaccessfac);
        //jScrollPane3.getViewport().add(jTAaccessdesc);
        //jScrollPane2.getViewport().add(jTAaccesscom);

        //jCBcountry.setSelectedIndex(11);
        this.setTitle(labels.get("apostal.toma.location.locations"));

        this.pack();
        //centerFrame();
        this.setVisible(true);

        this.refresh();
    }

    /**Overridden so we can exit when window is closed*/
    protected void processWindowEvent(WindowEvent e) {
        super.processWindowEvent(e);
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            //System.exit(0);
        }
    }

    // Donnes de la fentre d'affichage vers  l'object locations
    public Location getData() {
        if (screenIsLocked || notSelect) {
            return null;
        } else {

            data.setDenomination(jTFdenomination.getText());

            Address address = getAddress();
            data.setAddress(address);

            if(accessCommentComponent instanceof TOMAComboBox){
                try {
                    data.setAccessComment((String) ((TOMAComboBox) accessCommentComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setAccessComment(null);
                }              
            }
            else
                data.setAccessComment(jTAaccesscom.getText());
            
            if(accessDescriptionComponent instanceof TOMAComboBox){
                try {
                    data.setAccessDescription((String) ((TOMAComboBox) accessDescriptionComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setAccessDescription(null);
                }              
            }
            else            
                data.setAccessDescription(jTAaccessdesc.getText());
            
            if(accessFacilitiesComponent instanceof TOMAComboBox){
                try {
                    data.setAccessFacilities((String) ((TOMAComboBox) accessFacilitiesComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setAccessFacilities(null);
                }              
            }
            else               
                data.setAccessFacilities(jTAaccessfac.getText());

            if(completeNameComponent instanceof TOMAComboBox){
                try {
                    data.setCompleteName((String) ((TOMAComboBox) completeNameComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setCompleteName(null);
                }              
            }
            else                
                data.setCompleteName(jTFcompletename.getText());

            //sauver la date de modification actuelle
            Calendar calendar = new GregorianCalendar();
            Date trialtime = new Date();
            calendar.setTime(trialtime);
            java.sql.Date date = new java.sql.Date(calendar.getTime().getTime());
            data.setDateMaj(date);

            data.setDenomination(jTFdenomination.getText());
            
            if(emailComponent instanceof TOMAComboBox){
                try {
                    data.setEmail((String) ((TOMAComboBox) emailComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setEmail(null);
                }              
            }
            else                  
                data.setEmail(jTFemail.getText());
            
            if(faxComponent instanceof TOMAComboBox){
                try {
                    data.setFax((String) ((TOMAComboBox) faxComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setFax(null);
                }              
            }
            else              
                data.setFax(jTFfax.getText());
                        
            if(telComponent instanceof TOMAComboBox){
                try {
                    data.setTel((String) ((TOMAComboBox) telComponent).getSelectedItem());
                } catch (java.lang.ClassCastException ex) {
                    data.setTel(null);
                }              
            }
            else             
                data.setTel(jTFtelephone.getText());
                     
            Area area = (Area) jCBarea.getSelectedItem();
            if (area != null) {
                Area subarea = (Area) jCBsubarea.getSelectedItem();
                if (subarea != null)
                    data.setArea(subarea);
                else
                    data.setArea(area);
            } else {
                //remove the area?
                data.setArea(null);
            }

            //images
            Vector vimages = getImages();
            //data.setImages(vimages);              
            Vector images = new Vector();
            JComponent[] ims = jImages.getElements();
            int size = ims.length;
            for (int i = 0; i < size; i++) {
                try {
                    JTextField field = (JTextField) ims[i];
                    String text=field.getText();
                    if (!images.contains(text))
                        images.add(text);
                } catch (java.lang.ClassCastException ex) {
                    TOMAComboBox box = (TOMAComboBox) ims[i];
                    String txt = (String) box.getSelectedItem();

                    if (!images.contains(txt))
                        images.add(txt);
                }
            }
            data.setImages(images);              
            
            return data;
        }
    }

    //Mettre les donnes du formulaire dans l'object
    public Vector getImages() {
        Vector vimages = new Vector();
        JComponent[] components = jImages.getElements();
        for (int i = 0; i < components.length; i++) {
            JComponent component=components[i];
            if(component instanceof TOMATextField){
                TOMATextField field=(TOMATextField) component;
                vimages.addElement(field.getText());
            }
            else if(component instanceof TOMAComboBox){
                TOMAComboBox box=(TOMAComboBox) component;
                Object o=box.getSelectedItem();
                if(o instanceof TOMATextField){
                    TOMATextField field=(TOMATextField) o;
                    vimages.addElement(field.getText());
                }
            }
            //vimages.addElement(((TOMATextField) components[i]).getText());
        }
        return vimages;
    }

    //Address des champs du formulaire vers l'object Address
    public Address getAddress() {
        Vector vaddresslines = new Vector();
        JComponent[] components = jAddressLines.getElements();
        for (int i = 0; i < components.length; i++) {
            vaddresslines.addElement(((TOMATextField) components[i]).getText());
        }
        String city = jTFcity.getText();
        String postCode = jTFpostcode.getText();
        Country country = (Country) jCBcountry.getSelectedItem();
        Address addressdata = new Address(vaddresslines, city, postCode, country);
        return addressdata;
    }


    // donnes de l'object vers le formulaire
    public void setData(Location data) {
        this.clearData();
        button_save.setEnabled(true);

        this.data = data;
        Address address = data.getAddress();
        setAddress(address);

        String denomination = data.getDenomination();
        jTFdenomination.setText(denomination);        
        
        String completename = data.getCompleteName();
        if(completeNameComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(completename, (JComboBox) completeNameComponent);
        else
            jTFcompletename.setText(completename);         
        
        String telephone = data.getTel();
        if(telComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(telephone, (JComboBox) telComponent);
        else        
            jTFtelephone.setText(telephone);        
        String fax = data.getFax();
        if(faxComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(fax, (JComboBox) faxComponent);
        else                
            jTFfax.setText(fax);
        String email = data.getEmail();
        if(emailComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(email, (JComboBox) emailComponent);
        else          
            jTFemail.setText(email);                
        String accessdesc = data.getAccessDescription();
        if(accessDescriptionComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(accessdesc, (JComboBox) accessDescriptionComponent);
        else           
        jTAaccessdesc.setText(accessdesc);        
        String accesscom = data.getAccessComment();
        if(accessCommentComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(accesscom, (JComboBox) accessCommentComponent);
        else            
            jTAaccesscom.setText(accesscom);
        String accessfacilities = data.getAccessFacilities();                
        if(accessFacilitiesComponent instanceof JComboBox)
            TOMATemplateView.setTextCombo(accessfacilities, (JComboBox) accessFacilitiesComponent);
        else         
            jTAaccessfac.setText(accessfacilities);
        
        //area
        Area area = data.getArea();        
        if (address != null && address.getCountry() != null)
            this.setAreaList(address.getCountry());
        this.setArea(area);
        TOMATemplateResult areaResult = TOMATemplateView.getTemplateResult(type, "area");
        if (areaResult.isForbidden())
            jCBarea.setEnabled(false);        
        
        //images
        Vector vimages = data.getImages();
        //setImages(vimages);    
        if (vimages != null) {
            Vector images = new Vector();

            Iterator iter = vimages.iterator();
            while (iter.hasNext()) {
                String image = (String) iter.next();
                if (image != null) {
                    if (allowed_images == null || allowed_images.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(30));
                        field.setText(image);
                        images.add(field);
                    } else {
                        //combo boxes et pas text fields
                        if(!allowed_images.contains(image)){
                            allowed_images.add(image);
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_images);
                        box.setSelectedItem(image);
                        images.add(box);
                    }
                }
            }
            jImages.setElements(images);
        }
        TOMATemplateResult imagesResult = TOMATemplateView.getTemplateResult(type, "image");
        if (imagesResult.isForbidden())
            jImages.setEnabled(false);        
        
        //dates
        String datacreated = data.getDateCreation().toString();
        String datamodif = data.getDateMaj().toString();
        jTFcreated.setText(datacreated);
        jTFmodified.setText(datamodif);
    }

    public void setAreaList(Country c) {
        jCBarea.removeAllItems();
        Vector areas = control.getAreasByCountry(c);
        if (areas != null) {
            int size = areas.size();
            for (int i = 0; i < size; i++) {
                Area a = (Area) areas.elementAt(i);
                if (a != null)
                    jCBarea.addItem(a);
            }
        }
        jCBarea.addActionListener(this);
        jCBarea.setActionCommand("area");
    }

    public void setSubAreaList(Area first) {
        jCBsubarea.removeAllItems();
        Vector subs = control.getSubAreas(first);
        if (subs != null) {
            int subs_size = subs.size();
            for (int j = 0; j < subs_size; j++) {
                Area a = (Area) subs.elementAt(j);
                if (a != null)
                    jCBsubarea.addItem(a);
            }
        }
    }

    public void setArea(Area a) {
        Area[] areas = control.getFirstAndSecondArea(a);

        Area first = areas[0];
        Area second = areas[1];
        if (first != null) {
            //choisir le 1er area
            boolean found = false;
            int i = 0;
            int max = jCBarea.getItemCount();
            while (i < max && !found) {
                Area test = (Area) jCBarea.getItemAt(i);
                if (test != null && test.toString().compareTo(first.toString()) == 0) {
                    jCBarea.setSelectedIndex(i);
                    found = true;
                }

                i++;
            }

            if (found) {
                Area selected = (Area) jCBarea.getSelectedItem();

                //maj de la liste des subarea
                this.setSubAreaList(selected);

                //choisir le subarea
                this.setSubArea(second);
            }
        }
    }

    public void setSubArea(Area second) {
        if (second != null) {
            int i = 0;
            boolean found = false;
            int subs_size = jCBsubarea.getItemCount();
            while (i < subs_size && !found) {
                Area test = (Area) jCBsubarea.getItemAt(i);
                if (test != null && test.toString().compareTo(second.toString()) == 0) {
                    jCBsubarea.setSelectedIndex(i);
                    found = true;
                }
                i++;
            }
        }
    }

    // affichage des donnes de la base de donnes
    public void refresh() {
        this.clearData();

        // Initialistation de la liste des contacts  partir des donnes de la
        // base de donnes
        vlist = loadLocations();
        jList1.setListData(vlist);

        jList1.clearSelection();
        button_delete.setEnabled(false);
        button_save.setEnabled(false);

        this.pack();
    }

    public void clearData() {
        jTFdenomination.setText("");
        jTFcompletename.setText("");
        jTFtelephone.setText("");
        jTFfax.setText("");
        jTFemail.setText("");
        jTFcity.setText("");
        jTFpostcode.setText("");
        jTAaccesscom.setText("");
        jTAaccessfac.setText("");
        jTAaccessdesc.setText("");

        jImages.setElements(new Vector());
        jAddressLines.setElements(new Vector());

        //this.setEnabled(false);
        //this.pack();
    }

    public void setEnabled(boolean enabled) {
        if (!enabled) {
            jTFdenomination.setEnabled(false);
            jTFcompletename.setEnabled(false);
            if (completeNameComponent != null)
                completeNameComponent.setEnabled(false);
            jTFtelephone.setEnabled(false);
            if(telComponent!=null)
                telComponent.setEnabled(false);
            jTFfax.setEnabled(false);
            if(faxComponent!=null)
                faxComponent.setEnabled(false);
            jTFemail.setEnabled(false);
            if(emailComponent!=null)
                emailComponent.setEnabled(false);
            jTFcity.setEnabled(false);
            jTFpostcode.setEnabled(false);
            jTAaccesscom.setEnabled(false);
            if(accessCommentComponent!=null)
                accessCommentComponent.setEnabled(false);
            jTAaccessfac.setEnabled(false);
            if(accessFacilitiesComponent!=null)
                accessFacilitiesComponent.setEnabled(false);
            jTAaccessdesc.setEnabled(false);
            if(accessDescriptionComponent!=null)
                accessDescriptionComponent.setEnabled(false);
            jImages.setEnabled(false);
            jAddressLines.setEnabled(false);
            jCBcountry.setEnabled(false);
            jCBarea.setEnabled(false);
            if (jCBsubarea != null)
                jCBsubarea.setEnabled(false);
        }else{
            jTFdenomination.setEnabled(true);
            TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "completeName");
            if (!result.isForbidden()) {
                jTFcompletename.setEnabled(true);
                if (completeNameComponent != null)
                    completeNameComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "tel");
            if (!result.isForbidden()) {            
                jTFtelephone.setEnabled(true);
                if(telComponent!=null)
                    telComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "fax");
            if (!result.isForbidden()) {            
                jTFfax.setEnabled(true);
                if(faxComponent!=null)
                    faxComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "email");
            if (!result.isForbidden()) {
                jTFemail.setEnabled(true);
                if(emailComponent!=null)
                    emailComponent.setEnabled(true);
            }
            jTFcity.setEnabled(true);
            jTFpostcode.setEnabled(true);
            result = TOMATemplateView.getTemplateResult(type, "accessComment");
            if (!result.isForbidden()) {            
                jTAaccesscom.setEnabled(true);
                if(accessCommentComponent!=null)
                    accessCommentComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "accessFacilities");
            if (!result.isForbidden()) {            
                jTAaccessfac.setEnabled(true);
                if(accessFacilitiesComponent!=null)
                    accessFacilitiesComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "accessDescription");
            if (!result.isForbidden()) {            
                jTAaccessdesc.setEnabled(true);
                if(accessDescriptionComponent!=null)
                    accessDescriptionComponent.setEnabled(true);
            }
            result = TOMATemplateView.getTemplateResult(type, "image");
            if (!result.isForbidden()) {            
                jImages.setEnabled(true);
            }
            jAddressLines.setEnabled(true);
            jCBcountry.setEnabled(true);
            jCBarea.setEnabled(true);
            if (jCBsubarea != null)
                jCBsubarea.setEnabled(true);        
        }
    }

    //Mettre les donnes de l'objet images dans le formulaire
    public void setImages(Vector vimages) {
        Vector vcomponentlines = new Vector();
        for (int i = 0; i < vimages.size(); i++) {
                String image=(String) vimages.elementAt(i);            
                TOMATextField field=new TOMATextField(LocationsView.multipleElementsLength, image);
                vcomponentlines.addElement(field);
        }
        jImages.setElements(vcomponentlines);

    }

    //Mettre les donnes de l'object address dans la fentre d'affichage
    public void setAddress(Address address) {
        Vector vstringlines = new Vector();

        Vector vcomponentlines = new Vector();
        try {
            //Vecteur avec les donnes des lignes en string
            vstringlines = address.getAddressLines();
            for (int i = 0; i < vstringlines.size(); i++) {
                vcomponentlines.addElement(new TOMATextField(LocationsView.multipleElementsLength, (String) vstringlines.elementAt(i)));
            }
        } catch (NullPointerException np) {
        }
        jAddressLines.setElements(vcomponentlines);
        try {
            jTFcity.setText(address.getCity());
        } catch (NullPointerException np) {
            jTFcity.setText("");
        }
        try {
            jTFpostcode.setText(address.getPostCode());
        } catch (NullPointerException np) {
            jTFpostcode.setText("");
        }

        try {
            for (int i = 0; i < jCBcountry.getItemCount(); i++) {
                if (jCBcountry.getItemAt(i).toString().compareTo(address.getCountry().toString()) == 0) {
                    jCBcountry.setSelectedIndex(i);
                }
            }
        } catch (NullPointerException np) {
        }

    }

    public int getIndex(String denomination) {
        int index = -1;
        for (int i = 0; i < vlist.size(); i++) {
            if (vlist.elementAt(i).toString().compareTo(denomination) == 0) {
                index = i;
            }
        }
        return index;
    }

    //Sauvegarde les donnes du formulaire dans un object, affichage dans la liste
    public Location save() {
        Location location = getData();
        int index = getIndex(location.getDenomination());
        vlist.removeElementAt(index);
        vlist.insertElementAt(location.getDenomination(), index);
        vlocations.removeElementAt(index);
        vlocations.insertElementAt(location, index);
        return location;
    }

    public Vector loadLocations() {
        vlocations = control.loadLocations(true);
        return vlocations;
    }


    public void counterToZero() {
        cpt = 0;
    }

    /**
     *  @return true if a location is selected, false otherwise
     **/
    public boolean locationSelected() {
        return !notSelect && !screenIsLocked && !jList1.isSelectionEmpty();
    }

    public void selectLocation(int id) {
        alreadyWarned = true;
        if (vlist != null) {
            Iterator it = vlist.iterator();
            boolean found = false;
            while (it.hasNext() && !found) {
                Location l = (Location) it.next();
                if (l.getIdLocation() == id) {
                    found = true;
                    jList1.setSelectedValue(l, true);
                    this.changeSelection();
                }
            }
        }
    }

    public void changeSelection() {
        int index = jList1.getSelectedIndex();
        selectedIndex = index;
        if (index > -1) {

            try {
                //unlock location locked
                //data=donnes prcdentes, ou null si l'cran tait lock
                //donc on ne dlocke que si on est responsable du lock
                if (data != null) {
                    oldLocation = data.getDenomination();
                    control.unlockLocation(data);
                }
                //test lock from new location
                Location location = (Location) vlocations.elementAt(index);
                boolean idtest = control.getLock(location);
                if (!idtest) {
                    button_delete.setEnabled(true);
                    notSelect = false;
                    //lock new location
                    control.lockLocation(location);
                    //si l'cran d'avant tait "locked":
                    if (screenIsLocked) {
                        screenIsLocked = false;
                        jPanel1.setVisible(true);
                        panelLocked.setVisible(false);
                    }
                    //get new location
                    setData(location);
                    oldLocation = data.getDenomination();
                    this.setEnabled(true);
                    this.pack();
                } else {
                    //Show Message
                    panelLocked.changeElement(location);
                    if (!screenIsLocked) //on n'tait pas dj lock
                    {
                        button_delete.setEnabled(false);
                        data = null;
                        jPanel1.setVisible(false);
                        panelLocked.setVisible(true);
                        screenIsLocked = true;
                        notSelect = true;
                    } else {
                        panelLocked.setVisible(false);
                        panelLocked.setVisible(true);
                    }
                    oldLocation = null;
                }
            } catch (NullPointerException np) {
            }
        }
    }

    public void valueChanged(ListSelectionEvent e)
            //public void jList1_mouseClicked(MouseEvent e)
    {

        int result = 0;
        cpt++;

        if (!alreadyWarned && !handler.newLocation) {
            //if (oldLocation!=null && TOMA.getInstance().getTomaParameters().getOpenWarningWindow() && cpt>2){
            if (this.locationSelected() && TOMA.getInstance().getTomaParameters().getOpenWarningWindow() && selectedIndex > -1) {
                TOMAQuestion tq = new TOMAQuestion(TOMAFonts.htmlBegin + labels.get("apostal.toma.changeSelection.location.confirm") + TOMAFonts.htmlEnd, labels.get("apostal.toma.changeSelection.location.confirm.title"));
                result = tq.getResult();
                alreadyWarned = true;
            }
            if (result == 0) {
                this.changeSelection();
                //alreadyWarned = false;
                alreadyWarned = true;
            } else {
                alreadyWarned = true;
                //jList1.setSelectedIndex(this.getIndex(oldLocation));
                jList1.setSelectedIndex(selectedIndex);
            }

        } else {
            alreadyWarned = false;
            handler.newLocation = false;
        }

    }

    void this_windowClosing(WindowEvent e) {
        //UnLock location
        if (data != null) {
            control.unlockLocation(data);
        }
    }

    public void actionPerformed(java.awt.event.ActionEvent actionEvent) {
        String cmd = actionEvent.getActionCommand();
        if (cmd != null) {
            if (cmd.equals("country")) {
                Country c = (Country) jCBcountry.getSelectedItem();
                this.setAreaList(c);
            } else if (cmd.equals("area")) {
                Area a = (Area) jCBarea.getSelectedItem();
                this.setSubAreaList(a);
            }
        }
    }

    public String testTemplateElements() {
        Location l=this.getData();
        String msg = "";

        String msg_denomination = TOMATemplateView.testTemplateElement(type, "denomination", l.getDenomination(), labels.get("apostal.toma.location.denomination"));
        if (msg_denomination != null)
            msg = msg + "\n" + msg_denomination;            
        String msg_completeName=TOMATemplateView.testTemplateElement(type, "completeName", l.getCompleteName(), labels.get("apostal.toma.location.completename"));
        if(msg_completeName!=null)
            msg =msg +"\n" + msg_completeName;                     
        String msg_tel=TOMATemplateView.testTemplateElement(type, "tel", l.getTel(), labels.get("apostal.toma.location.telephone"));
        if(msg_tel!=null)
            msg =msg +"\n" + msg_tel;   
        String msg_fax=TOMATemplateView.testTemplateElement(type, "fax", l.getFax(), labels.get("apostal.toma.location.fax"));
        if(msg_fax!=null)
            msg =msg +"\n" + msg_fax;
        String msg_email=TOMATemplateView.testTemplateElement(type, "email", l.getEmail(), labels.get("apostal.toma.location.email"));
        if(msg_email!=null)
            msg =msg +"\n" + msg_email;
        String msg_area=TOMATemplateView.testTemplateElement(type, "area", l.getArea(), labels.get("apostal.toma.location.area"));
        if(msg_area!=null)
            msg =msg +"\n" + msg_area;
        String msg_accessdesc=TOMATemplateView.testTemplateElement(type, "accessDescription", l.getAccessDescription(), labels.get("apostal.toma.location.access_description"));
        if(msg_accessdesc!=null)
            msg =msg +"\n" + msg_accessdesc;
        String msg_accesscomment=TOMATemplateView.testTemplateElement(type, "accessComment", l.getAccessComment(), labels.get("apostal.toma.location.accsess_comment"));
        if(msg_accesscomment!=null)
            msg =msg +"\n" + msg_accesscomment;
        String msg_accessfac=TOMATemplateView.testTemplateElement(type, "accessFacilities", l.getAccessFacilities(), labels.get("apostal.toma.location.access_facilities"));
        if(msg_accessfac!=null)
            msg =msg +"\n" + msg_accessfac;
        String msg_image=TOMATemplateView.testTemplateElement(type, "image", l.getImages(), labels.get("apostal.toma.location.images"));
        if(msg_image!=null)
            msg =msg +"\n" + msg_image;        
        
        if (msg.equals(""))
            return null;
        else
            return msg;
    }    
    
}

