// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.*;
import apostal.toma.viewcontrol.*;
import apostal.toma.database.CountryDB;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.util.*;

import apostal.toma.data.TOMALabels;
import apostal.toma.datacontrol.OrganismControl;

public class OrganismView extends TOMAFrame {
    private static int multipleElementsLength = 30;

    private static Vector languages;
    private static Vector country;

    private BorderLayout borderLayout1 = new BorderLayout();
    private OrganismControl control = new OrganismControl();
    private Organism data;
    private Vector vaddress = new Vector();
    protected TOMALabels labels;

    Vector vlist = new Vector();
    TOMALabel label_denomination = new TOMALabel();
    TOMALabel label_completeName = new TOMALabel();
    TOMALabel label_presentation = new TOMALabel();
    TOMALabel label_url = new TOMALabel();
    TOMALabel label_addresses = new TOMALabel();
    TOMATextField jTFname = new TOMATextField();
    TOMATextField jTFurl = new TOMATextField();
    JList jLaddresses = new JList();
    TOMAButton button_remove = new TOMAButton();
    JPanel jPanel1 = new JPanel();
    JPopupMenu jPopupMenu1 = new JPopupMenu();
    TitledBorder titledBorder1;
    TOMALabel label_postcode = new TOMALabel();
    TOMALabel label_city = new TOMALabel();
    TOMALabel label_country = new TOMALabel();
    TOMAButton button_saveAddress = new TOMAButton();
    TOMAComboBox jCBcountry = new TOMAComboBox();
    TOMATextField jTFcity = new TOMATextField();
    TOMATextField jTFpostcode = new TOMATextField();
    TOMAButton button_new = new TOMAButton();
    TOMAButton button_save = new TOMAButton();
    Border border1;
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    GridBagLayout gridBagLayout2 = new GridBagLayout();

    TOMAMultipleElements jAddressLines;

    OrganismEventHandler handler = new OrganismEventHandler(this);
    TOMATextArea jTApresentation = new TOMATextArea();
    TOMATextField jTFdenomination = new TOMATextField();

    //components / templates
    JComponent denominationComponent;
    JComponent completeNameComponent;
    JComponent presentationComponent;
    JComponent urlComponent;
    
    private int type;
    
    /**Construct the frame*/
    public OrganismView() {
        type=TOMATemplateView.ORGANISMVIEW;
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }

        this.addWindowListener(handler);
    }

    /**Component initialization*/
    private void jbInit() throws Exception {

        JPanel contentPane = (JPanel) this.getContentPane();        
        titledBorder1 = new TitledBorder(BorderFactory.createEtchedBorder(Color.white, new Color(134, 134, 134)), labels.get("apostal.toma.organism.address"));
        border1 = BorderFactory.createBevelBorder(BevelBorder.LOWERED, Color.white, Color.white, new Color(178, 178, 178), new Color(124, 124, 124));
        contentPane.setLayout(gridBagLayout1);        
        
        //boutons
        button_remove.setText(labels.get("apostal.toma.organism.remove"));
        button_remove.addActionListener(handler);
        button_remove.setActionCommand(".removeList");
        jPanel1.setBackground(TOMAColors.auxBackgroundColor2);
        jPanel1.setBorder(titledBorder1);
        jPanel1.setLayout(gridBagLayout2);        
        button_saveAddress.setText(labels.get("apostal.toma.organism.save_address"));
        button_saveAddress.addActionListener(handler);
        button_saveAddress.setActionCommand(".validate");
        button_new.setText(labels.get("apostal.toma.organism.new"));
        button_new.addActionListener(handler);
        button_new.setActionCommand(".new");
        button_save.setText(labels.get("apostal.toma.organism.save"));
        button_save.addActionListener(handler);
        button_save.setActionCommand(".save");        
        
        //labels        
        label_denomination.setText(labels.get("apostal.toma.organism.denomination"));
        label_completeName.setText(labels.get("apostal.toma.organism.completename"));
        label_presentation.setText(labels.get("apostal.toma.organism.presentation"));
        label_url.setText(labels.get("apostal.toma.organism.url"));
        label_addresses.setText(labels.get("apostal.toma.organism.addresses"));
        label_postcode.setText(labels.get("apostal.toma.organism.postcode"));
        label_city.setText(labels.get("apostal.toma.organism.city"));
        label_country.setText(labels.get("apostal.toma.organism.country"));
        
        //addresses
        Integer columNb = new Integer(OrganismView.multipleElementsLength);
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        values[0] = columNb;
        jAddressLines = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 3, "", labels.get("apostal.toma.organism.add_address_lines"), labels.get("apostal.toma.organism.remove"), TOMAColors.multipleElementsColor, 400, 120);
        
        JScrollPane scrollList = new JScrollPane();
        jLaddresses.setBackground(TOMAColors.editingFieldColor);
        jLaddresses.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                jLaddresses_mouseClicked(e);
            }
        });
        jLaddresses.setVisibleRowCount(5);
        jLaddresses.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        jLaddresses.setFixedCellWidth(200);
        jLaddresses.setFont(TOMAFonts.listsFont);

        // Countries
        TOMA t = TOMA.getInstance();
        Vector countries = t.getCountries();
        TOMA.log(TOMA.WARNING, "Countries " + countries);
        for (int i = 0; i < countries.size(); i++) {
            jCBcountry.addItem(countries.elementAt(i));
        }
        jCBcountry.setSelectedIndex(11);
        scrollList.getViewport().add(jLaddresses);
        
        //fields
        jTFdenomination.setColumns(20);
        jTFname.setColumns(20);
        jTFurl.setColumns(20);
        jTFpostcode.setColumns(20);
        jTFcity.setColumns(20);
        jTApresentation.setColumns(20);
        jTApresentation.setRows(4);
        
        //denomination
        JScrollPane denominationPane = new JScrollPane();
        denominationPane.getViewport().add(jTFdenomination);
        TOMATemplateResult denominationResult = TOMATemplateView.getTemplateResult(type, "denomination");
        if (denominationResult.getMaximum() > -1)
            label_denomination.setText(label_denomination.getText() + " (" + new Integer(denominationResult.getMaximum()) + ")");                
        denominationComponent = denominationPane;     
        
        //completeName
        JScrollPane completeNamePane = new JScrollPane();
        completeNamePane.getViewport().add(jTFname);
        TOMATemplateResult completeNameResult = TOMATemplateView.getTemplateResult(type, "completeName");
        if (completeNameResult.isForbidden())
            jTFname.setEnabled(false);
        if (completeNameResult.isMandatory())
            label_completeName.setText(label_completeName.getText() + " (*)");
        if (completeNameResult.getMaximum() > -1)
            label_completeName.setText(label_completeName.getText() + " (" + new Integer(completeNameResult.getMaximum()) + ")");
        if (completeNameResult.getValues() != null && !completeNameResult.getValues().isEmpty()) {
            Vector v = completeNameResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox completeNameCombo = new TOMAComboBox(v);
            completeNameComponent = completeNameCombo;
        } else
            completeNameComponent = completeNamePane;
        
        //presentation
        JScrollPane presentationPane = new JScrollPane();
        presentationPane.getViewport().add(jTApresentation);
        TOMATemplateResult presentationResult = TOMATemplateView.getTemplateResult(type, "presentation");
        if (presentationResult.isForbidden())
            jTApresentation.setEnabled(false);
        if (presentationResult.isMandatory())
            label_presentation.setText(label_presentation.getText() + " (*)");
        if (presentationResult.getMaximum() > -1)
            label_presentation.setText(label_presentation.getText() + " (" + new Integer(presentationResult.getMaximum()) + ")");
        if (presentationResult.getValues() != null && !presentationResult.getValues().isEmpty()) {
            Vector v = presentationResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox presentationCombo = new TOMAComboBox(v);
            presentationComponent = presentationCombo;
        } else
            presentationComponent = presentationPane;        
        
        //url
        JScrollPane urlPane = new JScrollPane();
        urlPane.getViewport().add(jTFurl);
        TOMATemplateResult urlResult = TOMATemplateView.getTemplateResult(type, "url");
        if (urlResult.isForbidden())
            jTFurl.setEnabled(false);
        if (urlResult.isMandatory())
            label_url.setText(label_url.getText() + " (*)");
        if (urlResult.getValues() != null && !urlResult.getValues().isEmpty()) {
            Vector v = urlResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox urlCombo = new TOMAComboBox(v);
            urlComponent = urlCombo;
        } else
            urlComponent = urlPane;
        
        //address
        TOMATemplateResult addressResult = TOMATemplateView.getTemplateResult(type, "address");
        if (addressResult.isForbidden()){
            button_new.setEnabled(false);
            button_remove.setEnabled(false);
            button_saveAddress.setEnabled(false);
            jAddressLines.setEnabled(false);
            jLaddresses.setEnabled(false);
            
        }
        if (addressResult.isMandatory())
            label_addresses.setText(label_addresses.getText() + " (*)");        
        
        //adding elements to the panels
        jPanel1.add(jAddressLines, new GridBagConstraints(0, 0, 1, 4, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_postcode, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_city, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFpostcode, new GridBagConstraints(2, 0, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jTFcity, new GridBagConstraints(2, 1, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(jCBcountry, new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(label_country, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        jPanel1.add(button_saveAddress, new GridBagConstraints(2, 4, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        contentPane.add(jPanel1, new GridBagConstraints(0, 7, 3, 1, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(label_url, new GridBagConstraints(0, 4, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(completeNameComponent, new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(label_presentation, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        //contentPane.add(jScrollPane2, new GridBagConstraints(2, 3, 1, 1, 0.0, 0.0
         //       , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(presentationComponent, new GridBagConstraints(2, 3, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));        
        contentPane.add(button_save, new GridBagConstraints(2, 8, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTH, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(urlComponent, new GridBagConstraints(2, 4, 1, 1, 1.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(scrollList, new GridBagConstraints(2, 5, 1, 2, 1.0, 1.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(denominationComponent, new GridBagConstraints(2, 0, 1, 2, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(label_completeName, new GridBagConstraints(0, 1, 1, 2, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(label_denomination, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(button_remove, new GridBagConstraints(1, 6, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(label_addresses, new GridBagConstraints(0, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));
        contentPane.add(button_new, new GridBagConstraints(1, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 0, 0), 0, 0));

        // Charger donnes de la base de donnes, comme seulement un organisme possible
        data = control.loadOrganism();
        setData(data);

        this.setTitle(labels.get("apostal.toma.organism.organism"));
        this.getContentPane().setBackground(TOMAColors.auxBackgroundColor);
        this.pack();
        this.setVisible(true);
    }

    
    /**Overridden so we can exit when window is closed*/
    protected void processWindowEvent(WindowEvent e) {
        super.processWindowEvent(e);
        if (e.getID() == WindowEvent.WINDOW_CLOSING) {
            //System.exit(0);
        }
    }

    //Prendre les donnes du formulaire et les mettre dans l'object organisme
    public Organism getData() {
        Organism data = new Organism();

        data.setDenomination(jTFdenomination.getText());
                
        if(completeNameComponent instanceof TOMAComboBox){
            try {
                data.setCompleteName((String) ((TOMAComboBox) completeNameComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                data.setCompleteName(null);
            }              
        }
        else
            data.setCompleteName(jTFname.getText());
        
        if(presentationComponent instanceof TOMAComboBox){
            try {
                data.setPresentation((String) ((TOMAComboBox) presentationComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                data.setPresentation(null);
            }              
        }
        else        
        data.setPresentation(jTApresentation.getText());
        
        if(urlComponent instanceof TOMAComboBox){
            try {
                data.setUrl((String) ((TOMAComboBox) urlComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                data.setUrl(null);
            }              
        }
        else          
            data.setUrl(jTFurl.getText());
                
        data.setAddresses(vaddress);
        return data;
    }

    //Address des champs du formulaire vers l'object Address
    private Address getAddress() {
        Vector vaddresslines = new Vector();
        JComponent[] components = jAddressLines.getElements();
        for (int i = 0; i < components.length; i++) {
            vaddresslines.addElement(((JTextField) components[i]).getText());
        }
        String city = jTFcity.getText();
        String postCode = jTFpostcode.getText();
        Country country = (Country) jCBcountry.getSelectedItem();
        TOMA.log(TOMA.WARNING, "Country saved " + country);
        Address addressdata = new Address(vaddresslines, city, postCode, country);
        return addressdata;
    }

    // donnes de l'object vers le formulaire
    public void setData(Organism data) {
        
        TOMA.log(TOMA.WARNING, "setData");
        
        //addresses
        Vector vaddresslines = new Vector();
        this.data = data;
        try {
            vaddress = data.getAddresses();

            TOMA.log(TOMA.WARNING, "addresses");

            vlist.removeAllElements();
            for (int i = 0; i < vaddress.size(); i++) {
                Address address = (Address) vaddress.elementAt(i);
                String line1 = (String) address.getAddressLines().elementAt(0);
                vlist.addElement(line1);
            }
            jLaddresses.setListData(vlist);
        } catch (NullPointerException np) {
        }
        TOMATemplateResult addressResult = TOMATemplateView.getTemplateResult(type, "address");
        if (addressResult.isForbidden()){
            jAddressLines.setEnabled(false);        
        }
        
        //denomination
        try {
            String denomination = data.getDenomination();
            jTFdenomination.setText(denomination);
            
        } catch (NullPointerException np) {
        }
        
        //url
        try {
            String url = data.getUrl();
            //jTFurl.setText(url);            
            if(urlComponent instanceof JComboBox)
                TOMATemplateView.setTextCombo(url, (JComboBox) urlComponent);
            else
                jTFurl.setText(url);            
            
        } catch (NullPointerException np) {
        }
        
        //presentation
        try {
            String presentation = data.getPresentation();
            //jTApresentation.setText(presentation);
            if(presentationComponent instanceof JComboBox)
                TOMATemplateView.setTextCombo(presentation, (JComboBox) presentationComponent);
            else
                jTApresentation.setText(presentation);
        } catch (NullPointerException np) {
        }
        
        //completeName
        try {
            String completename = data.getCompleteName();
            //jTFname.setText(completename);
            if(completeNameComponent instanceof JComboBox)
                TOMATemplateView.setTextCombo(completename, (JComboBox) completeNameComponent);
            else
                jTFname.setText(completename);         
            
        } catch (NullPointerException np) {
        }
    }

    public void setAddress(Address address) {
        Vector vstringlines = new Vector();
        //Vecteur avec les donnes des lignes en string
        vstringlines = address.getAddressLines();

        Vector vcomponentlines = new Vector();
        for (int i = 0; i < vstringlines.size(); i++) {
            vcomponentlines.addElement(new TOMATextField(OrganismView.multipleElementsLength, (String) vstringlines.elementAt(i)));
        }

        jAddressLines.setElements(vcomponentlines);
        jTFcity.setText(address.getCity());
        jTFpostcode.setText(address.getPostCode());

        //retrouver le pays dans la liste
        String code = null;
        if (address != null && address.getCountry() != null)
            code = address.getCountry().getCode();

        //mettre l'adresse
        int count = jCBcountry.getItemCount();
        int cpt = 0;
        boolean found = false;
        while (cpt < count && !found) {
            Country c = (Country) jCBcountry.getItemAt(cpt);
            if (c != null && c.getCode().equals(code)) {
                jCBcountry.setSelectedIndex(cpt);
                found = true;
            }
            cpt++;
        }
    }

    public void emptyAddress() {
        Vector v = new Vector();
        jAddressLines.setElements(v);
        jTFcity.setText("");
        jTFpostcode.setText("");
    }


    //mettre la premire ligne de l'address dans la list  cot
    public void putAddress() {
        Address address;
        //Tester si l'address existe dj dans le vecteur des addresses
        TOMATextField tomatextfield = (TOMATextField) jAddressLines.getElementAt(0);
        String addressText = tomatextfield.getText();
        int index = testAddress(addressText);
        System.out.println("Index: " + index);
        if (index == -1) {
            //Mettre addresse dans la liste des addresses
            if (addressText.compareTo("") != 0) {
                vlist.addElement(addressText);
                jLaddresses.setListData(vlist);
                //Sauvegarder l'address dans un Vecteur d'addresses
                address = getAddress();
                Vector lines = address.getAddressLines();
                vaddress.addElement(address);
            } else {
                System.out.println("Message Line 1 empty");
            }
        } else {
            //Modifier addresse dans la liste des addresses
            vlist.removeElementAt(index);
            vlist.insertElementAt(addressText, index);
            //Modifier l'address dans un Vecteur d'addresses
            address = getAddress();
            vaddress.removeElementAt(index);
            vaddress.insertElementAt(address, index);
        }
        //vider l'ancien emplacement
        emptyAddress();
    }

    //Test si la premiere ligne se trouve dj dans la liste des addresses
    //retou index si vrai, -1 si pas dans la liste
    public int testAddress(String firstline) {
        int index = -1;
        for (int i = 0; i < vaddress.size(); i++) {
            Address address = (Address) vaddress.elementAt(i);
            String line = (String) address.getAddressLines().elementAt(0);
            if (line.compareTo(firstline) == 0) {
                index = i;
            }
        }
        System.out.println("Fin testaddress");
        return index;
    }

    //retirer la ligne de l'address de la liste
    public void removeList() {
        int index = jLaddresses.getSelectedIndex();
        try {
            vlist.removeElementAt(index);
            jLaddresses.setListData(vlist);
            //retirer l'addresse du vecteur des addresses
            vaddress.removeElementAt(index);
        } catch (ArrayIndexOutOfBoundsException ar) {
        }
    }


    void jLaddresses_mouseClicked(MouseEvent e) {
        int index = jLaddresses.getSelectedIndex();
        System.out.println("Index" + index);
        if (index > -1) {
            try {
                Address address = (Address) vaddress.elementAt(index);
                setAddress(address);
            } catch (NullPointerException np) {
            }
        }
    }

    //Debug imprimer une addresse
    public void printAddress(Address address) {
        Vector lines = address.getAddressLines();
        for (int i = 0; i < lines.size(); i++) {
            System.out.println("Line: " + lines.elementAt(i));
        }
        System.out.println("Country: " + address.getCountry().getName());
        System.out.println("City: " + address.getCity());
        System.out.println("Postcode" + address.getPostCode());
    }
    
    public String testTemplateElements() {
        Organism o=this.getData();
        String msg = "";

        String msg_denomination = TOMATemplateView.testTemplateElement(type, "denomination", o.getDenomination(), labels.get("apostal.toma.organism.denomination"));
        if (msg_denomination != null)
            msg = msg + "\n" + msg_denomination;    
        
        String msg_completeName=TOMATemplateView.testTemplateElement(type, "completeName", o.getCompleteName(), labels.get("apostal.toma.organism.completename"));
        if(msg_completeName!=null)
            msg =msg +"\n" + msg_completeName;
        
        String msg_presentation=TOMATemplateView.testTemplateElement(type, "presentation", o.getPresentation(), labels.get("apostal.toma.organism.presentation"));
        if(msg_presentation!=null)
            msg =msg +"\n" + msg_presentation;
        
        String msg_url=TOMATemplateView.testTemplateElement(type, "url", o.getUrl(), labels.get("apostal.toma.organism.url"));
        if(msg_url!=null)
            msg =msg +"\n" + msg_url;        
        
        String msg_address=TOMATemplateView.testTemplateElement(type, "address", o.getAddresses(), labels.get("apostal.toma.organism.addresses"));
        if(msg_address!=null)
            msg =msg +"\n" + msg_address;                
        
        if (msg.equals(""))
            return null;
        else
            return msg;
    }
}
