// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import java.awt.*;
import java.lang.Class;
import java.lang.Integer;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.view.SubPointDealtWithPanel;
import toolbox.text.ExtendedList;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class PointDealtWithsComboBoxes extends JScrollPane {
    private static int pointIntroLength = 60;
    private static int pointIntroHeight = 3;
    private static int pointPointLength = 50;
    private static int pointPointFrameLength = 483;
    private static int pointPointFrameHeight = 105;

    JPanel jPanel1 = new JPanel();
    TOMALabel label_introduction = new TOMALabel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMATextArea introduction = new TOMATextArea(PointDealtWithsComboBoxes.pointIntroHeight, PointDealtWithsComboBoxes.pointIntroLength);
    TOMALabel label_conclusion = new TOMALabel();
    TOMATextArea conclusion = new TOMATextArea(PointDealtWithsComboBoxes.pointIntroHeight, PointDealtWithsComboBoxes.pointIntroLength);
    TOMALabel label_point = new TOMALabel();

    TOMAMultipleElements points = null;

    private TOMALabels labels;

    private int _type;
    public PointDealtWithsComboBoxes(Integer type) {
        try {
            labels = new TOMALabels();
            if (type != null){
                _type=type.intValue();
                jbInit();
            }
            else {
                TOMA.log(TOMA.SEVERE, "PointDealtWithsComboBox: type is null");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        //introduction
        label_introduction.setText(labels.get("apostal.toma.trainingview.pointsDealtWith.point.introduction"));
        TOMATemplateResult introResult = TOMATemplateView.getTemplateResult(_type, "subPwdIntroduction");
        if (introResult.getMaximum() > -1)
            label_introduction.setText(label_introduction.getText() + " (" + new Integer(introResult.getMaximum()) + ")");
        if (introResult.isForbidden())
            introduction.setEnabled(false); 
        jPanel1.setLayout(gridBagLayout1);
        JScrollPane pane_introduction = new JScrollPane(introduction);

        //conclusion
        label_conclusion.setText(labels.get("apostal.toma.trainingview.pointsDealtWith.point.conclusion"));
        TOMATemplateResult cclResult = TOMATemplateView.getTemplateResult(_type, "subPwdConclusion");
        if (cclResult.getMaximum() > -1)
            label_conclusion.setText(label_conclusion.getText() + " (" + new Integer(cclResult.getMaximum()) + ")");
        if (cclResult.isForbidden())
            conclusion.setEnabled(false);     
        JScrollPane pane_conclusion = new JScrollPane(conclusion);

        ImageIcon icon = new ImageIcon("Images/point.gif");
        label_point.setIcon(icon);

        //points
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        values[0] = new Integer(PointDealtWithsComboBoxes.pointPointLength);

        TOMATemplateResult pointResult = TOMATemplateView.getTemplateResult(_type, "subPwdPoint");
        if (pointResult != null && pointResult.getMaximum() > -1) {
            String forEachPoint = "(" + pointResult.getMaximum() + " " + labels.get("apostal.toma.trainingview.pointsDealtWith.point.forEachPoint") + ")";
            points = new TOMAMultipleElements("apostal.toma.view.SubPointDealtWithPanel", classes, values, 0, null, labels.get("apostal.toma.trainingview.pointsDealtWith.point.addPoint"), labels.get("apostal.toma.trainingview.pointsDealtWith.point.removePoint"), TOMAColors.multipleElementsColor, PointDealtWithsComboBoxes.pointPointFrameLength, PointDealtWithsComboBoxes.pointPointFrameHeight, forEachPoint);
        } else {
            points = new TOMAMultipleElements("apostal.toma.view.SubPointDealtWithPanel", classes, values, 0, null, labels.get("apostal.toma.trainingview.pointsDealtWith.point.addPoint"), labels.get("apostal.toma.trainingview.pointsDealtWith.point.removePoint"), TOMAColors.multipleElementsColor, PointDealtWithsComboBoxes.pointPointFrameLength, PointDealtWithsComboBoxes.pointPointFrameHeight);
        }
        if(pointResult.isForbidden())
            points.setEnabled(false);

        jPanel1.add(label_point, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 10), 0, 0));
        jPanel1.add(label_introduction, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 20), 0, 0));
        jPanel1.add(pane_introduction, new GridBagConstraints(2, 1, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        jPanel1.add(points, new GridBagConstraints(2, 2, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        jPanel1.add(label_conclusion, new GridBagConstraints(2, 3, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(pane_conclusion, new GridBagConstraints(2, 4, 1, 1, 0.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        jPanel1.setBackground(TOMAColors.multipleElementsColor);
        this.setBackground(TOMAColors.multipleElementsColor);
        this.getViewport().add(jPanel1, null);
        this.setBorder(new javax.swing.border.EmptyBorder(0, 0, 20, 0));
    }

    public ExtendedList getData() {
        ExtendedList ex = new ExtendedList();

        ex.setIntroduction(introduction.getText());

        JComponent[] elements = points.getElements();
        int size = elements.length;
        for (int i = 0; i < size; i++) {
            SubPointDealtWithPanel sub = (SubPointDealtWithPanel) elements[i];
            ex.addElement(sub.getData());
        }
        ex.setConclusion(conclusion.getText());

        return ex;
    }

    public void setData(ExtendedList ex) {
        if (ex != null) {
            introduction.setText(ex.getIntroduction());
            Vector list = ex.getList();
            if (list != null) {
                Vector elements = new Vector();
                Iterator iter = list.iterator();
                while (iter.hasNext()) {
                    String point = (String) iter.next();
                    if (point != null) {
                        SubPointDealtWithPanel sub = new SubPointDealtWithPanel(new Integer(PointDealtWithsComboBoxes.pointPointLength));
                        sub.setData(point);
                        elements.add(sub);
                    }
                }
                points.setElements(elements);
                
                if(TOMATemplateView.getTemplateResult(_type, "subPwdPoint").isForbidden())
                    points.setEnabled(false);
            }

            conclusion.setText(ex.getConclusion());
        }
    }

    public void setEnabled(boolean enabled) {
        introduction.setEnabled(enabled);
        conclusion.setEnabled(enabled);
        points.setEnabled(enabled);
    }
}