// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import toolbox.swing.LimitedNumericDocument;

import apostal.toma.data.Seance;
import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;

import javax.swing.*;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import java.util.GregorianCalendar;
import java.util.Calendar;

import java.sql.Date;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class SeancePanel extends JPanel {
    private TOMALabels labels;

    private TOMATextField day = new TOMATextField(2);
    private TOMATextField month = new TOMATextField(2);
    private TOMATextField year = new TOMATextField(4);

    private TOMATextField beginHour = new TOMATextField(2);
    private TOMATextField beginMinute = new TOMATextField(2);

    private TOMATextField endHour = new TOMATextField(2);
    private TOMATextField endMinute = new TOMATextField(2);

    /*private TOMAComboBox beginHour;
    private TOMAComboBox beginMinute;

    private TOMAComboBox endHour;
    private TOMAComboBox endMinute;*/

    private TOMALabel label_date;
    private TOMALabel label_begin;
    private TOMALabel label_end;

    public SeancePanel() {
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void jbInit() throws Exception {
        this.setLayout(new GridBagLayout());
        this.setBackground(TOMAColors.multipleElementsColor);

        //inits
        day.setDocument(new LimitedNumericDocument(2));
        month.setDocument(new LimitedNumericDocument(2));
        year.setDocument(new LimitedNumericDocument(4));
        /*beginHour=new TOMAComboBox();
        beginMinute=new TOMAComboBox();
        endHour=new TOMAComboBox();
        endMinute=new TOMAComboBox();
        this.addLists();*/
        beginHour.setDocument(new LimitedNumericDocument(2));
        beginMinute.setDocument(new LimitedNumericDocument(2));
        endHour.setDocument(new LimitedNumericDocument(2));
        endMinute.setDocument(new LimitedNumericDocument(2));

        label_date = new TOMALabel(labels.get("apostal.toma.sessionview.seance.date"));
        label_begin = new TOMALabel(labels.get("apostal.toma.sessionview.seance.beginTime"));
        label_end = new TOMALabel(labels.get("apostal.toma.sessionview.seance.endTime"));

        //adds
        this.add(label_date, new GridBagConstraints(0, 0, 3, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(day, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(month, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(year, new GridBagConstraints(2, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
        this.add(label_begin, new GridBagConstraints(3, 0, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 10, 0, 0), 0, 0));
        this.add(beginHour, new GridBagConstraints(3, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 10, 0, 0), 0, 0));
        this.add(beginMinute, new GridBagConstraints(4, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
        this.add(label_end, new GridBagConstraints(5, 0, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 10, 0, 0), 0, 0));
        this.add(endHour, new GridBagConstraints(5, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 10, 0, 0), 0, 0));
        this.add(endMinute, new GridBagConstraints(6, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
    }

    /*public void addLists()
    {
      //hours
      for(int i=0;i<24;i++)
      {
        Integer val=new Integer(i);
        beginHour.addItem(val);
        endHour.addItem(val);
      }

      //minutes
      for(int i=0;i<60;i++)
      {
        Integer val=new Integer(i);
        beginMinute.addItem(val);
        endMinute.addItem(val);
      }
    }*/

    public void setData(Seance s) {
        //date
        Date seanceDate = s.getSeanceDate();
        GregorianCalendar cal = new GregorianCalendar();
        cal.setTime(seanceDate);
        int d = cal.get(Calendar.DAY_OF_MONTH);
        int m = cal.get(Calendar.MONTH) + 1;
        int y = cal.get(Calendar.YEAR);

        day.setText((new Integer(d)).toString());
        month.setText((new Integer(m)).toString());
        year.setText((new Integer(y)).toString());

        int bh = s.getBeginHour();
        //beginHour.setSelectedIndex(bh);
        beginHour.setText((new Integer(bh)).toString());
        int bm = s.getBeginMinute();
        //beginMinute.setSelectedIndex(bm);
        beginMinute.setText((new Integer(bm)).toString());
        int eh = s.getEndHour();
        //endHour.setSelectedIndex(eh);
        endHour.setText((new Integer(eh)).toString());
        int em = s.getEndMinute();
        //endMinute.setSelectedIndex(em);
        endMinute.setText((new Integer(em)).toString());
    }

    public Seance getData() {
        Seance s = new Seance();

        //date
        try {
            int d = Integer.parseInt(day.getText());
            int m = Integer.parseInt(month.getText());
            int y = Integer.parseInt(year.getText());

            GregorianCalendar cal = new GregorianCalendar();
            cal.set(Calendar.DAY_OF_MONTH, d);
            cal.set(Calendar.MONTH, m - 1);
            cal.set(Calendar.YEAR, y);

            Date date = new Date(cal.getTime().getTime());
            s.setSeanceDate(date);

        } catch (java.lang.NumberFormatException ex) {
            TOMA.log(TOMA.SEVERE, "this seance date is not numeric");
        }

        //mettre des horaires par dfaut?
        s.setBeginHour(0);
        s.setBeginMinute(0);
        s.setEndHour(0);
        s.setEndMinute(0);

        //begin time
        /*Integer bh=(Integer) beginHour.getSelectedItem();
        if(bh!=null)
          s.setBeginHour(bh.intValue());*/
        String bh = beginHour.getText();
        try {
            Integer i = new Integer(bh);
            if (i != null && i.intValue() < 24)
                s.setBeginHour(i.intValue());
            else
                TOMA.log(TOMA.SEVERE, "seance's beginHour incorrect, =" + i);
        } catch (java.lang.NumberFormatException ex) {
        }
        /*Integer bm=(Integer) beginMinute.getSelectedItem();
        if(bm!=null)
          s.setBeginMinute(bm.intValue());*/
        String bm = beginMinute.getText();
        try {
            Integer i = new Integer(bm);
            if (i != null && i.intValue() < 60)
                s.setBeginMinute(i.intValue());
            else
                TOMA.log(TOMA.SEVERE, "seance's beginMinute incorrect, =" + i);
        } catch (java.lang.NumberFormatException ex) {
        }

        //end time
        /*Integer eh=(Integer) endHour.getSelectedItem();
        if(eh!=null)
          s.setEndHour(eh.intValue());*/
        String eh = endHour.getText();
        try {
            Integer i = new Integer(eh);
            if (i != null && i.intValue() < 24)
                s.setEndHour(i.intValue());
            else
                TOMA.log(TOMA.SEVERE, "seance's endHour incorrect, =" + i);
        } catch (java.lang.NumberFormatException ex) {
        }
        /*Integer em=(Integer) endMinute.getSelectedItem();
        if(em!=null)
          s.setEndMinute(em.intValue());*/
        String em = endMinute.getText();
        try {
            Integer i = new Integer(em);
            if (i != null && i.intValue() < 60)
                s.setEndMinute(i.intValue());
            else
                TOMA.log(TOMA.SEVERE, "seance's endMinute incorrect, =" + i);
        } catch (java.lang.NumberFormatException ex) {
        }

        return s;
    }

    public void setEnabled(boolean enabled) {
        day.setEnabled(enabled);
        month.setEnabled(enabled);
        year.setEnabled(enabled);
        beginHour.setEnabled(enabled);
        beginMinute.setEnabled(enabled);
        endHour.setEnabled(enabled);
        endMinute.setEnabled(enabled);
    }
}