// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.view;

import apostal.toma.TOMA;

import java.lang.String;
import java.io.File;
import javax.swing.*;

/**
 * TOMA file chooser.
 * Its role is to make the chooser choose a file for:
 * - the TED file to import (Import TED: choose file)
 * - the destination of publications in html, xml or pdf (Publication Unit: destination)
 * - the properties file of publications (Publication Unit: properties)
 * - the destination of XML export (Training: export destination)*/

public class TOMAFileChooser {
    public static final int APPROVE = JFileChooser.APPROVE_OPTION;
    public static final int CANCEL = JFileChooser.CANCEL_OPTION;

    private File data;
    private JFileChooser fileChooser;
    private JFrame frame;

    public TOMAFileChooser(JFrame frame, String title, String accept, String cancel) {
        String path = TOMA.getInstance().getTomaParameters().getTomaPath();
        File tomaDirectory = null;
        try {
            tomaDirectory = new File(path);
        } catch (java.lang.NullPointerException ex) {
            TOMA.log(TOMA.INFO, "the toma path is null");
        }

        if (tomaDirectory != null)
            fileChooser = new JFileChooser(tomaDirectory);
        else
            fileChooser = new JFileChooser();

        fileChooser.setApproveButtonText(accept);
        //todo: tenir compte de cancel!!!
        fileChooser.setDialogTitle(title);

        fileChooser.setBackground(TOMAColors.tomaBackgroundColor);
        fileChooser.setFont(TOMAFonts.labelsFont);
        fileChooser.setForeground(TOMAColors.unclickableTextColor);
        this.frame = frame;
    }

    public java.io.File getData() {
        return data;
    }

    public void setData(java.io.File data) {
        this.data = data;
    }

    public void setSelectionMode(int mode) {
        fileChooser.setFileSelectionMode(mode);
    }

    public void addTOMAFileFilter(TOMAFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public void addFOFileFilter(FOFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public void addPDFFileFilter(PDFFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public void addRTFFileFilter(RTFFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public void addXSLFileFilter(XSLFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public void addDirectoryFileFilter(DirectoryFileFilter filter) {
        fileChooser.addChoosableFileFilter(filter);
    }

    public int showOpenDialog() {
        return fileChooser.showOpenDialog(frame);
    }

    public int showSaveDialog() {
        return fileChooser.showSaveDialog(frame);
    }

    public File getSelectedFile() {
        return fileChooser.getSelectedFile();
    }

    public String getSelectedPath() {
        return fileChooser.getSelectedFile().getPath();
    }
}
