// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/*
 * TOMAFirstRun.java
 *
 * Created on February 25, 2002, 2:44 PM
 */

package apostal.toma.view;

import apostal.toma.data.TOMAConstants;
import apostal.toma.data.Language;
import apostal.toma.data.Organism;
import apostal.toma.database.LanguageDB;
import apostal.toma.database.OrganismDB;
import apostal.toma.viewcontrol.TOMAFirstRunEventHandler;
import apostal.toma.TOMA;

import javax.swing.*;
import javax.swing.border.*;

import java.util.Properties;
import java.util.Vector;
import java.io.FileInputStream;
import java.io.FileOutputStream;

import java.awt.*;


/**
 *
 * @author  ramel
 */
public class TOMAFirstRun extends TOMAFrame {

    //public static String syrecosLoginPanelName="Syrecos Login";
    public static String organismPanelName = "Organism";
    public static String soapLoginPanelName = "SOAP Server Login";

    public static int SINGLESTATION = 0;
    public static int CLIENT = 1;
    public static int SERVER = 2;

    private int type;

    private JPanel panel;

    private TOMALabel label_top;
    //langues
    private TOMALabel label_langue;
    private TOMAComboBox box_langues;

    //server
    private TOMALabel label_server;
    private TOMATextField tf_server;

    //layout
    private CardLayout cardLayout;

    //Organism
    private JPanel panel_organism;
    private TOMALabel label_organism;
    private TOMATextField tf_organism;

    //choice
    private TOMALabel label_choice;
    private TOMALabel label_choice_syrecos;
    private TOMALabel label_choice_soap;
    private TOMALabel label_choice_organism;
    private JRadioButton choice_syrecos;
    private JRadioButton choice_soap;
    private JRadioButton choice_organism;

    //syrecos
    private ButtonGroup syrecos_group;
    private TOMALabel label_syrecos_warning;
    private JPanel panel_syrecos;
    private JPanel panel_syrecosLogin;
    private TOMALabel label_login;
    private TOMALabel label_password;
    private TOMATextField tf_login;
    private JPasswordField tf_password;

    //SOAP
    private ButtonGroup soap_group;
    private TOMALabel label_soap_warning;
    private JPanel panel_soap;
    private JPanel panel_soapLogin;
    private TOMALabel label_soap_login;
    private TOMALabel label_soap_password;
    private TOMATextField tf_soap_login;
    private JPasswordField tf_soap_password;


    private TOMAButton button;

    private TOMAFirstRunEventHandler handler;

    /** Creates a new instance of TOMAFirstRun */
    public TOMAFirstRun() {
        type = TOMAFirstRun.SINGLESTATION;
        Properties props = new Properties();
        try {
            FileInputStream fin = new FileInputStream(TOMAConstants.parametersFile);
            props.load(fin);

            String myType = (String) props.get("firstRunType");
            if (myType != null) {
                if (myType.equals("singlestation"))
                    type = TOMAFirstRun.SINGLESTATION;
                else if (myType.equals("client"))
                    type = TOMAFirstRun.CLIENT;
                else if (myType.equals("server"))
                    type = TOMAFirstRun.SERVER;
            }

            fin.close();
        } catch (Exception ex) {
        }

        handler = new TOMAFirstRunEventHandler(this);

        this.init();
    }

    public void init() {
        panel = new JPanel();
        panel.setBackground(TOMAColors.auxBackgroundColor);
        panel.setLayout(new GridBagLayout());

        GridBagConstraints c = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0);

        label_top = new TOMALabel();
        label_top.setTextWithLowerCase(TOMAFonts.htmlBegin + "<P>This is the first time you run TOMA.</P><P>Before beginning to use TOMA, some additional information is needed.</P><P>Please fill this screen carefully, because it will only be shown once.</P>" + TOMAFonts.htmlEnd);
        c.gridwidth = 2;
        panel.add(label_top, c);
        c.gridwidth = 1;
        c.gridy++;

        if (type == TOMAFirstRun.CLIENT || type == TOMAFirstRun.SINGLESTATION) {
            //demander la langue par dfaut
            label_langue = new TOMALabel("Choose TOMA's default language: ");
            panel.add(label_langue, c);

            Language eng = new Language("eng", "English", true, true, true);
            Language fra = new Language("fra", "French", true, true, true);
            Language deu = new Language("deu", "German", true, true, true);
            Vector languages = new Vector();
            languages.add(eng);
            languages.add(fra);
            languages.add(deu);
            box_langues = new TOMAComboBox(languages);
            box_langues.setEditable(false);
            box_langues.setSelectedIndex(0);
            c.gridx = 1;
            panel.add(box_langues, c);

            c.gridx = 0;
            c.gridy++;
        }

        if (type == TOMAFirstRun.CLIENT) {
            //demander le chemin du serveur
            label_server = new TOMALabel("Enter TOMA's server complete name: ");
            panel.add(label_server, c);

            tf_server = new TOMATextField();
            c.gridx = 1;
            panel.add(tf_server, c);

            c.gridx = 0;
            c.gridy++;
        }

        if (type == TOMAFirstRun.SERVER || type == TOMAFirstRun.SINGLESTATION) {
            //extraction de Syrecos demande
            //label_choice=new TOMALabel("Do you want to extract your data from Syrecos, from SOAP or not at all?");
            label_choice = new TOMALabel("Do you want to extract your data from a server or not?");
            panel.add(label_choice, c);

            c.gridx = 1;
            JPanel panel_radio = new JPanel();
            panel_radio.setLayout(new FlowLayout());

            /*choice_syrecos=new JRadioButton("Syrecos");
            choice_syrecos.setSelected(true);
            choice_syrecos.addActionListener(handler);
            choice_syrecos.setActionCommand("syrecos");
            choice_syrecos.setBackground(TOMAColors.auxBackgroundColor);
            panel_radio.add(choice_syrecos);*/

            choice_soap = new JRadioButton("extract");
            choice_soap.setSelected(true);
            choice_soap.addActionListener(handler);
            choice_soap.setActionCommand("soap");
            choice_soap.setBackground(TOMAColors.auxBackgroundColor);
            panel_radio.add(choice_soap);

            choice_organism = new JRadioButton("Do not extract");
            choice_organism.setSelected(false);
            choice_organism.addActionListener(handler);
            choice_organism.setActionCommand("no");
            choice_organism.setBackground(TOMAColors.auxBackgroundColor);
            panel_radio.add(choice_organism);

            panel.add(panel_radio, c);

            syrecos_group = new ButtonGroup();
            //syrecos_group.add(choice_syrecos);
            syrecos_group.add(choice_soap);
            syrecos_group.add(choice_organism);

            c.gridx = 0;
            c.gridy++;
            c.gridwidth = 2;
            panel_syrecos = new JPanel();
            cardLayout = new CardLayout();
            panel_syrecos.setLayout(cardLayout);
            panel.add(panel_syrecos, c);

            //panel_syrecosLogin
            /*panel_syrecosLogin=new JPanel();
            panel_syrecosLogin.setBackground(TOMAColors.auxBackgroundColor2);
            panel_syrecosLogin.setLayout(new GridBagLayout());
            GridBagConstraints c2=new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0);
            label_login=new TOMALabel("login: ");
            panel_syrecosLogin.add(label_login, c2);
            c2.gridx=1;
            tf_login=new TOMATextField();
            panel_syrecosLogin.add(tf_login, c2);
            c2.gridx=0;
            c2.gridy=1;
            label_password=new TOMALabel("password: ");
            panel_syrecosLogin.add(label_password, c2);
            c2.gridx=1;
            tf_password=new JPasswordField();
            tf_password.setBackground(TOMAColors.editingFieldColor);
            panel_syrecosLogin.add(tf_password, c2);

            label_syrecos_warning=new TOMALabel();
            label_syrecos_warning.setTextWithLowerCase(TOMAFonts.htmlBegin+"Warning: you are about to extract your data from Syrecos.<BR>The extraction will begin when you click on the \"OK\" button, and may take some time <BR>(depending on the amount of data you have in Syrecos, but it can be up to 1/2 hour). <BR>Make sure you used the correct login & password before continuing."+TOMAFonts.htmlEnd);
            c2.gridx=0;
            c2.gridy=2;
            c2.gridwidth=2;
            panel_syrecosLogin.add(label_syrecos_warning, c2);

            TitledBorder border=new TitledBorder("Your Syrecos login");
            panel_syrecosLogin.setBorder(border); */

            //panel_soapLogin
            panel_soapLogin = new JPanel();
            panel_soapLogin.setBackground(TOMAColors.auxBackgroundColor2);
            panel_soapLogin.setLayout(new GridBagLayout());
            GridBagConstraints c3 = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0);
            label_soap_login = new TOMALabel("login: ");
            panel_soapLogin.add(label_soap_login, c3);
            c3.gridx = 1;
            tf_soap_login = new TOMATextField();
            panel_soapLogin.add(tf_soap_login, c3);
            c3.gridx = 0;
            c3.gridy = 1;
            label_soap_password = new TOMALabel("password: ");
            panel_soapLogin.add(label_soap_password, c3);
            c3.gridx = 1;
            tf_soap_password = new JPasswordField();
            tf_soap_password.setBackground(TOMAColors.editingFieldColor);
            panel_soapLogin.add(tf_soap_password, c3);

            label_soap_warning = new TOMALabel();

            String warning = "The SOAP server configuration is read in the file '" + TOMAConstants.propertiesFileSOAP + "': please check if it is correct before continuing.";
            warning = warning + "<BR><P>Warning: you are about to extract your data from a SOAP server.<BR>The extraction will begin when you click on the \"OK\" button, and may take some time <BR>(depending on the amount of data you have in the server). <BR>Make sure you used the correct login & password before continuing.</P>";
            label_soap_warning.setTextWithLowerCase(TOMAFonts.htmlBegin + warning + TOMAFonts.htmlEnd);
            c3.gridx = 0;
            c3.gridy = 2;
            c3.gridwidth = 2;
            panel_soapLogin.add(label_soap_warning, c3);

            TitledBorder border = new TitledBorder("Your SOAP server login");
            panel_soapLogin.setBorder(border);

            //panel_organism
            panel_organism = new JPanel();
            panel_organism.setBackground(TOMAColors.auxBackgroundColor2);
            panel_organism.setLayout(new GridBagLayout());
            GridBagConstraints c4 = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH, new Insets(5, 5, 5, 5), 0, 0);
            label_organism = new TOMALabel("organism's denomination: ");
            panel_organism.add(label_organism, c4);
            c4.gridx = 1;
            c4.fill = GridBagConstraints.NONE;
            tf_organism = new TOMATextField();
            panel_organism.add(tf_organism, c4);
            border = new TitledBorder("Your organism's data");
            panel_organism.setBorder(border);

            //panel_syrecos.add(panel_syrecosLogin, TOMAFirstRun.syrecosLoginPanelName);
            panel_syrecos.add(panel_soapLogin, TOMAFirstRun.soapLoginPanelName);
            panel_syrecos.add(panel_organism, TOMAFirstRun.organismPanelName);

            c.gridx = 0;
            c.gridy++;
        }

        //bouton ok
        c.gridwidth = 2;
        c.anchor = GridBagConstraints.CENTER;
        c.fill = GridBagConstraints.NONE;
        button = new TOMAButton("OK");
        button.addActionListener(handler);
        button.setActionCommand("ok");
        panel.add(button, c);

        this.setTitle("TOMA First Run");

        JScrollPane scrollPane = new JScrollPane(panel);
        this.setContentPane(scrollPane);
        this.pack();
        this.setVisible(true);
    }

    /*public void showSyrecosLoginPanel()
    {
         cardLayout.show(panel_syrecos, TOMAFirstRun.syrecosLoginPanelName);
    }*/
    public void showOrganismPanel() {
        cardLayout.show(panel_syrecos, TOMAFirstRun.organismPanelName);
    }

    public void showSOAPLoginPanel() {
        cardLayout.show(panel_syrecos, TOMAFirstRun.soapLoginPanelName);
    }

    public Language getLanguageSelected() {
        return (Language) box_langues.getSelectedItem();
    }

    public String getServer() {
        return tf_server.getText();
    }

    public boolean isSyrecosSelected() {
        return choice_syrecos.isSelected();
    }

    public boolean isSOAPSelected() {
        return choice_soap.isSelected();
    }

    public String getOrganismDenomination() {
        return tf_organism.getText();
    }

    public String getSyrecosLogin() {
        return tf_login.getText();
    }

    public char[] getSyrecosPassword() {
        return tf_password.getPassword();
    }

    public String getSOAPLogin() {
        return tf_soap_login.getText();
    }

    public char[] getSOAPPassword() {
        return tf_soap_password.getPassword();
    }

    public int getType() {
        return type;
    }
}
