// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import apostal.toma.TOMA;
import apostal.toma.data.TOMAConstants;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.border.TitledBorder;
import javax.swing.border.LineBorder;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import java.lang.Class;
import java.lang.reflect.Constructor;
import java.util.Vector;

public class TOMAMultipleElements extends JScrollPane implements ActionListener {
    private static ImageIcon addIcon;
    private static ImageIcon addPressedIcon;
    private static ImageIcon removeIcon;
    private static ImageIcon removePressedIcon;
    private static Insets insets;
    private static EmptyBorder border;

    static {
        addIcon = new ImageIcon(TOMAConstants.addPointIconPath);
        addPressedIcon = new ImageIcon(TOMAConstants.addPointPressedIconPath);
        removeIcon = new ImageIcon(TOMAConstants.removePointIconPath);
        removePressedIcon = new ImageIcon(TOMAConstants.removePointPressedIconPath);
        insets = new Insets(0, 0, 0, 0);
        border = new EmptyBorder(0, 0, 0, 0);
    }

    private int nb;
    private JComponent[] elements;
    private JButton[] removes;
    private GridBagLayout layout;
    private TitledBorder titledBorder;
    private JButton add;
    private JPanel panel;

    private Class[] paramsClasses;
    private Object[] paramsValues;
    private String removeLabel;
    private Class elementClass;

    private String addLabel;
    private int width;
    private int height;

    private int removeButtonAnchor;

    //paneaux pour contenir les elemnts & les boutons
    private Vector subPanels = new Vector();

    //additional label
    private String _additionalLabel;

    public TOMAMultipleElements(String className, Class[] paramsClasses, Object[] paramsValues, int nb, String title, String addLabel, String removeLabel, Color color, int width, int height, String additionalLabel) {
        this(className, paramsClasses, paramsValues, nb, title, addLabel, removeLabel, color, width, height);

        this._additionalLabel = additionalLabel;
        panel.remove(add);
        this.addAddButton();
    }

    public TOMAMultipleElements(String className, Class[] paramsClasses, Object[] paramsValues, int nb, String title, String addLabel, String removeLabel, Color color, int width, int height) {
        this.paramsClasses = paramsClasses;
        this.paramsValues = paramsValues;
        this.removeLabel = removeLabel;
        this.addLabel = addLabel;
        this.width = width;
        this.height = height;

        removeButtonAnchor = GridBagConstraints.NORTH;

        //chargement
        try {
            elementClass = Class.forName(className);
        } catch (Exception ex) {
            TOMA.log(TOMA.SEVERE, "exception loading the class " + className);
        }

        panel = new JPanel();
        layout = new GridBagLayout();
        panel.setLayout(layout);
        this.addAddButton();

        Dimension d = new Dimension(width, height);
        this.setPreferredSize(d);

        //bordure ou couleur?
        if (color != null) {
            panel.setBackground(TOMAColors.trainingTabBackgroundColor);
            LineBorder border = new LineBorder(color, 1);
            panel.setBorder(border);
        }

        this.createLines(nb);
        this.setViewportView(panel);
    }

    public void setRemoveButtonAnchor(int anchor) {
        this.removeButtonAnchor = anchor;
    }

    //rcuprer un constructeur pour les lments de type elementClass
    private Constructor getElementConstructor() {
        Constructor cons = null;
        try {
            cons = elementClass.getConstructor(paramsClasses);
        } catch (java.lang.NoSuchMethodException ex) {
            TOMA.log(TOMA.SEVERE, "the constructor of the class " + elementClass.getName() + " was not found");
        } catch (java.lang.SecurityException ex) {
            TOMA.log(TOMA.SEVERE, "you do not have the rights to call this constructor of the class " + elementClass.getName());
        }

        return cons;
    }

    private JComponent getElementInstance(Constructor cons) {

        JComponent element = null;
        try {
            element = (JComponent) cons.newInstance(paramsValues);
        } catch (Exception ex) {
            TOMA.log(TOMA.SEVERE, "an instance of " + elementClass.getName() + " could not be obtained");
        }

        return element;
    }

    public void createLines(int nbLines) {
        nb = 0;
        elements = new JComponent[0];
        removes = new JButton[0];
        for (int i = 0; i < nbLines; i++) {
            this.addLine();
        }
    }

    /**
     * adds a new line to elements, removes and nb
     */
    public void addLine() {
        nb++;
        JComponent[] newelements = new JComponent[nb];
        JButton[] newremoves = new JButton[nb];
        for (int i = 0; i < nb - 1; i++) {
            newelements[i] = elements[i];
            newremoves[i] = removes[i];
        }

        elements = newelements;
        removes = newremoves;

        //element
        Constructor cons = this.getElementConstructor();
        if (cons != null) {
            JComponent element = this.getElementInstance(cons);
            elements[nb - 1] = element;
            this.addElement(element, 0, nb);
        }

        //bouton
        JButton remove = this.getRemoveButton("remove_" + new Integer(nb - 1));
        removes[nb - 1] = remove;

        this.addRemoveButton(remove, 1, nb);

        panel.doLayout();
        panel.revalidate();
    }

    private JButton getRemoveButton(String actionCommand) {
        JButton remove = new JButton(removeIcon);
        remove.setPressedIcon(removePressedIcon);
        remove.setBackground(TOMAColors.multipleElementsColor);
        remove.setMargin(insets);
        remove.setBorder(border);
        remove.setActionCommand(actionCommand);
        remove.addActionListener(this);

        return remove;
    }

    // Ajouter des lments sur les paneaux, avec les bonnes contraintes
    private void addAddButton() {
        add = new JButton(addIcon);
        add.setPressedIcon(addPressedIcon);
        add.setMargin(insets);
        add.setBorder(border);
        add.setBackground(TOMAColors.multipleElementsColor);
        add.setActionCommand("add");
        add.addActionListener(this);
        panel.add(add, new GridBagConstraints(0, 0, 1, 1, 0.1, 0.1, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 0), 0, 0));

        //additional label
        if (_additionalLabel != null && !_additionalLabel.equals("")) {
            TOMALabel newlabel = new TOMALabel(_additionalLabel);
            panel.add(newlabel, new GridBagConstraints(1, 0, 1, 1, 0.1, 0.1, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 0), 0, 0));
        }
    }

    private void addElement(JComponent element, int x, int y) {
        //panel.add(element, new GridBagConstraints(x, y, 1, 1, 0.0, 1.0,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 5, 0), 0, 0));

        JPanel subPanel = new JPanel();
        subPanel.setBackground(TOMAColors.multipleElementsColor);
        subPanel.add(element, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        panel.add(subPanel, new GridBagConstraints(x, y, 2, 1, 0.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 5, 0), 0, 0));
        subPanels.add(subPanel);
    }

    private void addRemoveButton(JButton remove, int x, int y) {
        int nb = subPanels.size();
        JPanel subPanel=null;
        if(nb>0)
            subPanel = (JPanel) subPanels.elementAt(nb - 1);
        if (subPanel != null) {
            subPanel.add(remove, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0, removeButtonAnchor, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        }
    }

    public void removeLine(int no) {
        //rcuprer le layout
        GridBagLayout layout = (GridBagLayout) panel.getLayout();

        //enlever des tableaux
        // + mettre  jour les action command
        JComponent[] newelements = new JComponent[nb - 1];
        JButton[] newremoves = new JButton[nb - 1];
        for (int i = 0; i < nb; i++) {
            if (i < no) {
                newelements[i] = elements[i];
                newremoves[i] = removes[i];
            } else if (i > no) {
                newelements[i - 1] = elements[i];
                newremoves[i - 1] = removes[i];

                //maj actionCommand des boutons remove
                JButton button = removes[i];
                button.setActionCommand("remove_" + new Integer(i - 1));

                //maj des contraintes des lments dj ajouts:
                //faire remonter d'un cran ce qui tait aprs
                //pour les elements
                GridBagConstraints cons = layout.getConstraints(elements[i]);
                int y = cons.gridy;
                cons.gridy = y - 1;
                layout.setConstraints(elements[i], cons);
                //pour les boutons
                cons = layout.getConstraints(removes[i]);
                y = cons.gridy;
                cons.gridy = y - 1;
                layout.setConstraints(removes[i], cons);
            }
        }

        //enlever du panel
        JPanel sub = (JPanel) subPanels.elementAt(no);
        subPanels.removeElementAt(no);
        panel.remove(sub);
        /*panel.remove(elements[no]);
        panel.remove(removes[no]);*/

        elements = newelements;
        removes = newremoves;
        nb--;

        panel.doLayout();
        panel.revalidate();
        panel.repaint();
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();

        if (cmd != null) {
            if (cmd.equals("add")) {
                this.addLine();
            } else if (cmd.startsWith("remove_")) {
                String index = cmd.substring(7);
                int no = 0;
                try {
                    no = Integer.parseInt(index);
                    this.removeLine(no);
                } catch (java.lang.NumberFormatException ex) {
                    TOMA.log(TOMA.SEVERE, "the cmd " + cmd + " is incorrect");
                }
            }
        }

    }

    public JComponent getElementAt(int index) {
        if (index < nb)
            return elements[index];
        else
            return null;
    }

    public JComponent[] getElements() {
        return elements;
    }

    public void setElements(Vector elems) {
        this.nb = elems.size();

        JComponent[] array = new JComponent[nb];
        this.elements = (JComponent[]) elems.toArray(array);

        this.setLines();
    }

    //like createLines but without creating new elements but using the existing
    public void setLines() {
        //enlever tout ce qu'il y avait sur le panel
        panel.removeAll();
        subPanels.removeAllElements();

        this.addAddButton();

        removes = new JButton[nb];

        for (int i = 0; i < nb; i++) {
            //lment
            JComponent element = elements[i];
            //panel.add(element, new GridBagConstraints(0, i+1, 1, 1, 0.0, 0.0,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 5, 5, 0), 0, 0));
            this.addElement(element, 0, i + 1);

            //bouton remove
            JButton remove = this.getRemoveButton("remove_" + new Integer(i));
            /*JButton remove=new JButton(removeLabel);
            remove.setActionCommand("remove_"+new Integer(i));
            remove.addActionListener(this);*/
            removes[i] = remove;
            //panel.add(remove, new GridBagConstraints(1, i+1, 1, 1, 0.0, 0.0,removeButtonAnchor, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
            this.addRemoveButton(remove, 1, i + 1);
        }

        this.doLayout();
        this.revalidate();
        this.repaint();
    }

    public void setEnabled(boolean enabled) {
        add.setEnabled(enabled);

        int size = elements.length;
        for (int i = 0; i < nb; i++) {
            JComponent el = elements[i];
            if(el!=null){
                el.setEnabled(enabled);
                JButton rem = removes[i];
                rem.setEnabled(enabled);
            }
        }
        
        TOMA.log(TOMA.INFO, "TOMAMultipleElements.setEnabled with enabled="+enabled);
    }

}
