// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.data.TOMAConstants;

import javax.swing.*;
import javax.swing.border.LineBorder;
import javax.swing.border.EmptyBorder;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TOMAMultipleElementsList extends JPanel implements ActionListener {
    private static ImageIcon addIcon;
    private static ImageIcon addPressedIcon;
    private static ImageIcon removeIcon;
    private static ImageIcon removePressedIcon;

    static {
        addIcon = new ImageIcon(TOMAConstants.addIconPath);
        addPressedIcon = new ImageIcon(TOMAConstants.addPressedIconPath);
        removeIcon = new ImageIcon(TOMAConstants.removeIconPath);
        removePressedIcon = new ImageIcon(TOMAConstants.removePressedIconPath);
    }


    private Vector existing;
    private Vector chosen;
    private JButton add;
    private JButton remove;
    private JList existingList;
    private JList chosenList;
    private TOMALabel existingLabel;
    private TOMALabel chosenLabel;

    public TOMAMultipleElementsList(Vector existing, String addLabel, String removeLabel, String existingTitle, String chosenTitle, Color color, int rows) {
        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);
        Insets insets = new Insets(0, 0, 0, 0);

        this.existing = existing;
        //add=new TOMAButton(addLabel);
        add = new JButton();
        add.setIcon(addIcon);
        add.setPressedIcon(addPressedIcon);
        add.setBorder(border);
        add.setMargin(insets);
        add.setBackground(TOMAColors.trainingTabBackgroundColor);
        add.setActionCommand("add");
        add.addActionListener(this);

        //remove=new TOMAButton(removeLabel);
        remove = new JButton();
        remove.setIcon(removeIcon);
        remove.setPressedIcon(removePressedIcon);
        remove.setBorder(border);
        remove.setMargin(insets);
        remove.setBackground(TOMAColors.trainingTabBackgroundColor);
        remove.setActionCommand("remove");
        remove.addActionListener(this);

        if (color != null) {
            this.setBackground(TOMAColors.multipleElementsColor);
        } else {
            this.setBorder(new LineBorder(Color.black));
        }

        existingList = new JList();
        existingList.setListData(existing);
        existingList.setVisibleRowCount(rows);
        existingList.setFixedCellWidth(200);
        JScrollPane existingPane = new JScrollPane();
        existingPane.getViewport().add(existingList);

        chosen = new Vector();
        chosenList = new JList();
        chosenList.setVisibleRowCount(rows);
        chosenList.setFixedCellWidth(200);
        JScrollPane chosenPane = new JScrollPane();
        chosenPane.getViewport().add(chosenList);

        existingLabel = new TOMALabel(existingTitle);
        chosenLabel = new TOMALabel(chosenTitle);

        this.setLayout(new GridBagLayout());
        this.add(add, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        this.add(remove, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        this.add(existingLabel, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(existingPane, new GridBagConstraints(0, 1, 1, 2, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(chosenLabel, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(chosenPane, new GridBagConstraints(2, 1, 1, 2, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        existingList.setBackground(TOMAColors.editingFieldColor);
        chosenList.setBackground(TOMAColors.editingFieldColor);
        existingLabel.setForeground(TOMAColors.unclickableTextColor);
        chosenLabel.setForeground(TOMAColors.unclickableTextColor);
    }

    public void setExistingData(Vector existing) {
        this.existing = existing;
        existingList.setListData(existing);
    }

    public void setChosenData(Vector chosen) {
        this.chosen = chosen;
        chosenList.setListData(chosen);
    }

    public Vector getChosenData() {
        return chosen;
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("add")) {
            Object o = existingList.getSelectedValue();
            if (o != null && !chosen.contains(o)) {
                chosen.add(o);
                chosenList.setListData(chosen);
            }
        } else if (cmd.equals("remove")) {
            Object o = chosenList.getSelectedValue();
            if (o != null) {
                chosen.remove(o);
                chosenList.setListData(chosen);
            }
        }
    }

    public void setEnabled(boolean enabled) {
        add.setEnabled(enabled);
        remove.setEnabled(enabled);
        existingList.setEnabled(enabled);
        chosenList.setEnabled(enabled);
    }
}
