// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.TOMAParameters;
import apostal.toma.data.Language;
import apostal.toma.viewcontrol.TOMAParametersEventHandler;
import apostal.toma.datacontrol.TOMAParametersControl;
import apostal.toma.data.TOMALabels;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.UIManager;
import javax.swing.border.LineBorder;
import java.util.Vector;
import java.util.Iterator;

public class TOMAParametersView extends JFrame {
    TOMALabels labels;

    JPanel panel;
    GridBagLayout layout;
    GridBagConstraints c;
    TOMALabel label_interfaceLanguage = new TOMALabel();
    Vector radio_interfaceLanguages = new Vector();
    ButtonGroup group_interfaceLanguage = new ButtonGroup();
    TOMALabel label_exportLanguage = new TOMALabel();
    Vector radio_exportLanguages = new Vector();
    TOMALabel label_exportLanguageComment = new TOMALabel();
    ButtonGroup group_exportLanguage = new ButtonGroup();

    TOMALabel label_template = new TOMALabel();
    TOMALabel label_restart = new TOMALabel();
    TOMAButton ok = new TOMAButton();
    TOMATextField template = new TOMATextField(30);
    TOMAButton browseTemplate = new TOMAButton();

    TOMALabel label_browser = new TOMALabel();
    TOMATextField browser = new TOMATextField(30);
    TOMAButton browseBrowser = new TOMAButton();

    TOMALabel label_server = new TOMALabel();
    TOMATextField server = new TOMATextField();

    JCheckBox cbWarningWindow;
    //data list
    private Vector interfaceLanguages;
    private Vector exportLanguages;
    //private Vector lookAndFeels;
    private boolean usingProxy;
    private String proxyHost;
    private String proxyPort;

    public TOMAParameters getData() {

        TOMAParameters data = new TOMAParameters();

        //interface Language
        ButtonModel interfaceSelected = group_interfaceLanguage.getSelection();
        if (interfaceSelected != null) {
            String interfaceCode = interfaceSelected.getActionCommand();
            Language interfaceLanguage = TOMAParametersControl.getLanguageByCode(interfaceCode);
            data.setLanguage(interfaceLanguage);
        }

        //export Language
        ButtonModel exportSelected = group_exportLanguage.getSelection();
        if (exportSelected != null) {
            String exportCode = exportSelected.getActionCommand();
            Language exportLanguage = TOMAParametersControl.getLanguageByCode(exportCode);
            data.setExportationLanguage(exportLanguage);
        }

        //template
        String templateSelected = template.getText();
        data.setTemplateFile(templateSelected);

        //tomaPath: inchang
        String path = TOMA.getInstance().getTomaParameters().getTomaPath();
        data.setTomaPath(path);

        //browser
        String browserValue = browser.getText();
        data.setBrowser(browserValue);

        //server
        String serverValue = server.getText();
        if (serverValue != null && !serverValue.equals(""))
            data.setServer(serverValue);
        boolean openWarningWindow = cbWarningWindow.isSelected();
        data.setOpenWarningWindow(openWarningWindow);
        data.setUsingProxy(usingProxy);
        data.setProxyHost(proxyHost);
        data.setProxyPort(proxyPort);
        return data;
    }

    public void setData(TOMAParameters data) {
        //interfaceLanguage
        String il_code = data.getLanguage().getCode();
        Iterator iter_il = radio_interfaceLanguages.iterator();
        while (iter_il.hasNext()) {
            JRadioButton radio = (JRadioButton) iter_il.next();
            String cmd = radio.getActionCommand();
            if (il_code.equals(cmd))
                radio.setSelected(true);
            else
                radio.setSelected(false);
        }

        //exportLanguage
        String el_code = data.getExportationLanguage().getCode();
        Iterator iter_el = radio_exportLanguages.iterator();
        while (iter_el.hasNext()) {
            JRadioButton radio = (JRadioButton) iter_el.next();
            String cmd = radio.getActionCommand();
            if (el_code.equals(cmd))
                radio.setSelected(true);
            else
                radio.setSelected(false);
        }

        //template
        template.setText(data.getTemplateFile());

        //browser
        browser.setText(data.getBrowser());

        //server
        String serverValue = data.getServer();
        if (serverValue != null && !serverValue.equals("")) {
            label_server.setVisible(true);
            server.setVisible(true);
            server.setText(serverValue);
        }
        cbWarningWindow.setSelected(data.getOpenWarningWindow());
        usingProxy = data.isUsingProxy();
        proxyHost = data.getProxyHost();
        proxyPort = data.getProxyPort();
    }

    public void getInterfaceLanguages() {
        interfaceLanguages = TOMAParametersControl.getInterfaceLanguages();
    }

    public void getExportLanguages() {
        exportLanguages = TOMAParametersControl.getExportLanguages();
    }

    public TOMAParametersView() {
        this.getInterfaceLanguages();
        this.getExportLanguages();

        labels = new TOMALabels();
        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setTitle(labels.get("apostal.toma.parameters.title"));
        panel = new JPanel();
        this.getContentPane().add(panel);
        layout = new GridBagLayout();
        c = new GridBagConstraints();
        c.fill = GridBagConstraints.BOTH;
        c.ipadx = 5;
        c.ipady = 5;
        //this.getContentPane().setLayout(layout);

        panel.setLayout(layout);

        //interface language
        label_interfaceLanguage.setText(labels.get("apostal.toma.parameters.interfacelanguage"));
        c.gridx = 0;
        c.gridy = 0;
        Insets in = new Insets(10, 10, 2, 20);
        c.insets = in;
        layout.setConstraints(label_interfaceLanguage, c);
        //this.getContentPane().add(label_interfaceLanguage, null);
        panel.add(label_interfaceLanguage, null);
        int il_size = interfaceLanguages.size();
        for (int i = 0; i < il_size; i++) {
            Language l = (Language) interfaceLanguages.elementAt(i);
            JRadioButton b = new JRadioButton();
            b.setForeground(TOMAColors.clickableTextColor);
            b.setBackground(TOMAColors.tomaBackgroundColor);
            b.setText(l.getName());
            b.setActionCommand(l.getCode());
            c.gridx = 1;
            c.gridy = i;
            if (i == 0)
                in = new Insets(10, 2, 2, 10);
            else
                in = new Insets(2, 2, 2, 10);
            c.insets = in;

            layout.setConstraints(b, c);
            group_interfaceLanguage.add(b);
            //this.getContentPane().add(b, null);
            panel.add(b, null);
            radio_interfaceLanguages.add(b);
        }

        //export language
        label_exportLanguage.setText(labels.get("apostal.toma.parameters.exportlanguage"));
        c.gridx = 0;
        c.gridy = il_size;
        in = new Insets(10, 10, 2, 20);
        c.insets = in;
        layout.setConstraints(label_exportLanguage, c);
        //this.getContentPane().add(label_exportLanguage, null);
        panel.add(label_exportLanguage, null);
        int el_size = exportLanguages.size();
        for (int i = 0; i < el_size; i++) {
            Language l = (Language) exportLanguages.elementAt(i);
            JRadioButton b = new JRadioButton();
            b.setForeground(TOMAColors.clickableTextColor);
            b.setBackground(TOMAColors.tomaBackgroundColor);
            b.setText(l.getName());
            b.setActionCommand(l.getCode());
            c.gridx = 1;
            c.gridy = il_size + i;
            if (i == 0)
                in = new Insets(10, 2, 2, 10);
            else
                in = new Insets(2, 2, 2, 10);
            c.insets = in;
            layout.setConstraints(b, c);
            group_exportLanguage.add(b);
            //this.getContentPane().add(b, null);
            panel.add(b, null);
            radio_exportLanguages.add(b);
        }

        label_exportLanguageComment.setTextWithLowerCase(TOMAFonts.htmlBegin + labels.get("apostal.toma.parameters.exportlanguagecomment") + TOMAFonts.htmlEnd);
        Dimension d = new Dimension(130, 100);
        label_exportLanguageComment.setPreferredSize(d);
        label_exportLanguageComment.setVerticalAlignment(JLabel.TOP);
        c.gridx = 0;
        c.gridy = il_size + 1;
        c.gridheight = el_size;
        c.gridwidth = 1;
        in = new Insets(2, 15, 0, 20);
        c.insets = in;
        layout.setConstraints(label_exportLanguageComment, c);
        //this.getContentPane().add(label_exportLanguageComment, null);
        panel.add(label_exportLanguageComment, null);
        c.gridheight = 1;

        int y = il_size + el_size + 1;
        //template
        label_template.setText(labels.get("apostal.toma.parameters.template"));
        c.gridx = 0;
        c.gridy = y;
        in = new Insets(10, 10, 10, 10);
        c.insets = in;
        layout.setConstraints(label_template, c);
        //this.getContentPane().add(label_template, null);
        panel.add(label_template, null);
        c.gridx = 1;
        c.gridy = y;
        in = new Insets(10, 2, 2, 10);
        c.insets = in;
        layout.setConstraints(template, c);
        //this.getContentPane().add(template, null);
        panel.add(template, null);
        browseTemplate.setText(labels.get("apostal.toma.parameters.templatebrowse"));
        browseTemplate.addActionListener(new TOMAParametersEventHandler(this));
        browseTemplate.setActionCommand("browse");
        c.gridx = 1;
        c.gridy = y + 1;
        c.anchor = GridBagConstraints.WEST;
        c.fill = GridBagConstraints.NONE;
        in = new Insets(10, 2, 10, 10);
        c.insets = in;
        layout.setConstraints(browseTemplate, c);
        //this.getContentPane().add(browseTemplate, null);
        panel.add(browseTemplate, null);
        c.fill = GridBagConstraints.BOTH;

        //browser
        label_browser.setText(labels.get("apostal.toma.parameters.browser"));
        c.gridx = 0;
        c.gridy = y + 2;
        c.insets = new Insets(10, 10, 10, 10);
        panel.add(label_browser, c);

        c.gridx = 1;
        c.gridy = y + 2;
        c.insets = new Insets(10, 2, 2, 10);
        panel.add(browser, c);

        browseBrowser.setText(labels.get("apostal.toma.parameters.browserBrowse"));
        browseBrowser.addActionListener(new TOMAParametersEventHandler(this));
        browseBrowser.setActionCommand("browseBrowser");
        c.anchor = GridBagConstraints.WEST;
        c.fill = GridBagConstraints.NONE;
        c.gridx = 1;
        c.gridy = y + 3;
        c.insets = new Insets(10, 2, 2, 10);
        panel.add(browseBrowser, c);

        //server
        label_server.setVisible(false);
        server.setVisible(false);
        label_server.setText(labels.get("apostal.toma.parameters.server"));
        c.gridx = 0;
        c.gridy = y + 4;
        c.insets = new Insets(10, 10, 10, 10);
        panel.add(label_server, c);

        c.gridx = 1;
        c.gridy = y + 4;
        c.insets = new Insets(10, 2, 2, 10);
        panel.add(server, c);

        // warning window
        cbWarningWindow = new JCheckBox(labels.get("apostal.toma.parameters.warningWindow"));
        cbWarningWindow.setBackground(TOMAColors.tomaBackgroundColor);
        cbWarningWindow.setBorder(new LineBorder(TOMAColors.buttonsBorderColor, 1));
        cbWarningWindow.setForeground(Color.black);
        cbWarningWindow.setFont(TOMAFonts.listsFont);
        c.gridx = 0;
        c.gridy = y + 5;
        c.insets = new Insets(10, 10, 10, 10);
        panel.add(cbWarningWindow, c);
        //restart
        label_restart.setTextWithLowerCase(TOMAFonts.htmlBegin + labels.get("apostal.toma.parameters.comment") + TOMAFonts.htmlEnd);
        d = new Dimension(100, 100);
        label_exportLanguageComment.setPreferredSize(d);
        c.gridx = 0;
        c.gridy = y + 6;
        in = new Insets(20, 10, 10, 10);
        c.insets = in;
        c.gridwidth = 2;
        layout.setConstraints(label_restart, c);
        //this.getContentPane().add(label_restart, null);
        panel.add(label_restart, null);

        //ok
        ok.setText(labels.get("apostal.toma.parameters.ok"));
        ok.addActionListener(new TOMAParametersEventHandler(this));
        ok.setActionCommand("ok");
        c.gridx = 0;
        c.gridy = y + 7;
        c.anchor = GridBagConstraints.CENTER;
        c.fill = GridBagConstraints.NONE;
        in = new Insets(0, 10, 10, 10);
        c.insets = in;
        layout.setConstraints(ok, c);
        //this.getContentPane().add(ok, null);

        panel.add(ok, null);
        panel.setBackground(TOMAColors.auxBackgroundColor);
        JScrollPane scrollPane = new JScrollPane(panel);
        this.getContentPane().add(scrollPane);
        this.pack();
        this.setVisible(true);
    }
}

