// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import java.util.Vector;
import java.util.Iterator;
import javax.swing.JComboBox;

import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMATemplate;

public class TOMATemplateView {

    public static final int TRAININGCOURSEVIEW = 0;
    public static final int TRAININGPROGRAMMEVIEW = 1;
    public static final int UNITVIEW = 2;
    public static final int COURSESESSIONVIEW = 3;
    public static final int PROGRAMMESESSIONVIEW = 4;
    public static final int UNITSESSIONVIEW = 5;
    public static final int ORGANISMVIEW = 6;
    public static final int LOCATIONSVIEW = 7;
    public static final int CONTACTSVIEW = 8;
    public static final int TEACHERSVIEW = 9;

    private static TOMATemplate template;

    static {
        template = TOMA.getInstance().getTomaTemplate();
    }

    /** Creates a new instance of TOMATemplateView */
    public TOMATemplateView() {
    }


    /**
     * selects the correct value in the combo box.
     * If the value isn't in the combo box, it adds it.
     */
    public static void setTextCombo(String text, JComboBox box) {
        if (text != null && !text.equals("")) {
            int nb = box.getItemCount();
            //on commence  1 car on ne prend pas l'lment "nodata"
            int i = 1;
            boolean found = false;
            while (i < nb && !found) {
                try {
                    String s = (String) box.getItemAt(i);
                    if (s != null && s.equals(text)) {
                        box.setSelectedIndex(i);
                        found = true;
                    }
                } catch (java.lang.ClassCastException ex) {
                }
                i++;
            }
            if (!found) {
                box.addItem(text);
                box.setSelectedItem(text);
            }
        }

        if ((text == null || text.equals("")) && box.getItemCount() > 0) {
            box.setSelectedIndex(0);
        }
    }

    /**
     * Tests the result of the template
     */
    public static String testTemplateElement(int type, String name, Object field, String label) {
        TOMALabels tomaLabels = new TOMALabels();

        TOMATemplateResult templateResult = TOMATemplateView.getTemplateResult(type, name);

        String msg = null;

        if (field != null) {
            String s = TOMATemplateView.getTestedValueForObject(name, field);
            int result = templateResult.testCorrectness(s);

            String debut = label + " : ";
            if (result == TOMATemplateResult.MAXIMUM_PROBLEM)
                msg = debut + tomaLabels.get("apostal.toma.trainingview.templateMaximumProblem");
            else if (result == TOMATemplateResult.MANDATORY_PROBLEM)
                msg = debut + tomaLabels.get("apostal.toma.trainingview.templateMandatoryProblem");
        }

        return msg;
    }

    public static String testTemplateElement(int type, String name, Vector field, String label) {
        TOMALabels tomaLabels = new TOMALabels();

        TOMATemplateResult templateResult = TOMATemplateView.getTemplateResult(type, name);

        String msg = null;

        if (field != null && !field.isEmpty()) {
            int cpt = 0;

            Iterator iter = field.iterator();
            while (iter.hasNext()) {
                Object item = iter.next();

                String s = TOMATemplateView.getTestedValueForObject(name, item);

                int result = templateResult.testCorrectness(s);

                String debut = label + " (" + new Integer(cpt) + "): ";
                if (result == TOMATemplateResult.MAXIMUM_PROBLEM)
                    msg = debut + tomaLabels.get("apostal.toma.trainingview.templateMaximumProblem");

                cpt++;
            }
        } else {
            if (templateResult.isMandatory()) {
                String debut = label + " : ";
                msg = debut + tomaLabels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }
        return msg;
    }

    /**
     * additional methods *
     */

    public static TOMATemplateResult getTemplateResult(int type, String name) {
        TOMATemplateResult result = null;
        if (type == TOMATemplateView.TRAININGCOURSEVIEW)
            result = template.getTrainingCourseResult(name);
        else if (type == TOMATemplateView.TRAININGPROGRAMMEVIEW)
            result = template.getTrainingProgrammeResult(name);
        else if (type == TOMATemplateView.UNITVIEW)
            result = template.getUnitResult(name);
        else if (type == TOMATemplateView.COURSESESSIONVIEW)
            result = template.getCourseSessionResult(name);
        else if (type == TOMATemplateView.PROGRAMMESESSIONVIEW)
            result = template.getProgrammeSessionResult(name);
        else if (type == TOMATemplateView.UNITSESSIONVIEW)
            result = template.getUnitSessionResult(name);
        else if (type == TOMATemplateView.ORGANISMVIEW)
            result = template.getOrganismResult(name);
        else if (type == TOMATemplateView.LOCATIONSVIEW)
            result = template.getLocationResult(name);
        else if (type == TOMATemplateView.CONTACTSVIEW)
            result = template.getContactResult(name);
        else if (type == TOMATemplateView.TEACHERSVIEW)
            result = template.getTeacherResult(name);

        return result;
    }

    public static String getTestedValueForObject(String name, Object value) {
        String s = null;
        if (name.equals("slot"))
            s = ((apostal.toma.data.Slot) value).getValue();
        else if (name.equals("language"))
            s = ((apostal.toma.data.Language) value).getCode();
        else if (name.equals("domain"))
            s = (new Integer(((apostal.toma.data.Domain) value).getIdDomain())).toString();
        else if (name.equals("location"))
            s = ((apostal.toma.data.Location) value).getDenomination();
        else if (name.equals("seance"))
            s = ((apostal.toma.data.Seance) value).getSeanceDate().toString();
        else if (name.equals("teacher"))
            s = ((apostal.toma.data.Teacher) value).getLastname();
        else if (name.equals("address")) {
            apostal.toma.data.Address a = (apostal.toma.data.Address) value;
            if (a.getAddressLines() != null && !a.getAddressLines().isEmpty())
                s = (String) a.getAddressLines().elementAt(0);
            else
                s = null;
        } else if (name.equals("area")) {
            apostal.toma.data.Area a = (apostal.toma.data.Area) value;
            if (a != null)
                s = a.getName();
            else
                s = null;
        } else
            s = (String) value;

        return s;
    }

}