// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.tree.*;
import javax.swing.JTree;
import javax.swing.ImageIcon;
import java.awt.Component;
import javax.swing.event.TreeSelectionListener;
import javax.swing.event.TreeModelListener;
import javax.swing.event.TreeModelEvent;
import java.lang.Class;
import java.util.Iterator;
import java.util.Vector;


import apostal.toma.TOMA;
import apostal.toma.data.*;


public class TOMATree implements Cloneable {

    private TOMAJTree tree;

    private boolean selectCatalogues;
    private boolean selectCourses;
    private boolean selectProgrammes;

    private CatalogueTreeNode root;
    private DefaultTreeModel model;

    public TOMATree(boolean selectCatalogues, boolean selectCourses, boolean selectProgrammes, CatalogueTreeNode node) {
        super();
        this.selectCatalogues = selectCatalogues;
        this.selectCourses = selectCourses;
        this.selectProgrammes = selectProgrammes;

        model = new DefaultTreeModel(node);
        model.addTreeModelListener(new MyTreeModelListener());
        tree = new TOMAJTree(model);
        tree.setEditable(false);
        tree.setRootVisible(true);
        tree.setScrollsOnExpand(true);
        tree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);

        TOMATreeCellRenderer renderer = new TOMATreeCellRenderer();
        tree.setCellRenderer(renderer);

        this.root = node;

        //colors
        tree.setBackground(TOMAColors.treeBackgroundColor);
        tree.setForeground(TOMAColors.treeTextColor);
        tree.setFont(TOMAFonts.treeFont);

        String openPath = TOMAConstants.treeOpenedIconPath;
        ImageIcon open = new ImageIcon(openPath);
        //this.setOpenIcon(open);

        String closedPath = TOMAConstants.treeClosedIconPath;
        ImageIcon closed = new ImageIcon(closedPath);
        //this.setClosedIcon(closed);

    }

    //mthode permettant de simuler la touche "CTRL"
    public void addTOMAControlKeySimulator(TOMAFrame frame) {
        if (tree != null)
            tree.addMouseListener(new TOMAControlKeySimulator(frame));
    }

    public CatalogueTreeNode getRoot() {
        return root;
    }

    public TOMAJTree getTree() {
        return tree;
    }

    public void addTreeSelectionListener(TreeSelectionListener listener) {
        tree.addTreeSelectionListener(listener);
    }

    public void updateModel() {
        model = new DefaultTreeModel(root);
        tree.setModel(model);
    }

    public TOMATree getClone() {
        TOMATree tree = null;
        try {
            tree = (TOMATree) clone();
        } catch (Exception e) {
        }
        return tree;
    }

    /**
     * Debugging classes *
     */

    public void printTree() {
        String s = this.printNode(root, 0);
        TOMA.log(TOMA.WARNING, "Printing TOMATree:\n" + s);
    }

    private String printNode(TreeNode node, int depth) {
        String s = "";
        for (int i = 0; i < depth; i++)
            s = s + "   ";

        s = s + node + "\n";

        String name = node.getClass().getName();
        if (name.equals("apostal.toma.view.CatalogueTreeNode")) {
            CatalogueTreeNode c = (CatalogueTreeNode) node;
            int cpt = c.getChildCount();
            for (int i = 0; i < cpt; i++) {
                TreeNode node2 = c.getChildAt(i);
                s = s + this.printNode(node2, depth + 1);
            }
        }
        return s;
    }





}
