// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.data.TOMALabels;
import apostal.toma.TOMA;

import java.awt.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.awt.event.WindowListener;

import javax.swing.*;
import javax.swing.border.LineBorder;

public class TOMAView extends TOMAFrame {

    private ImportTrainingView importTrainingView;
    private TOMAParametersView parametersView;
    private OrganismView organismView;
    private PublicationUnitsView publicationUnitsView;
    private LocationsView locationsView;
    private ContactsView contactsView;
    private TeachersView teachersView;
    private JComponent contextualView;
    //vrai contextual view, meme si le contextualView est un panel contenant le vrai contextual view
    private JComponent realContextualView;
    private CatalogueView catalogue;

    private JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
    private GridBagLayout layout = new GridBagLayout();
    private GridBagLayout layout2 = new GridBagLayout();

    private JScrollPane panelTree = new JScrollPane();
    private JScrollPane panelContextual = new JScrollPane();
    private JMenuBar menuBar = new JMenuBar();
    private JMenu tomaMenu = new JMenu();
    private JMenu auxMenu = new JMenu();
    private JMenu helpMenu = new JMenu();

    private TOMATree tree;


    private JMenuItem importItem = new JMenuItem();
    private JMenuItem parametersItem = new JMenuItem();
    private JMenuItem quitItem = new JMenuItem();

    private JMenuItem organismItem = new JMenuItem();
    private JMenuItem teachersItem = new JMenuItem();
    private JMenuItem locationsItem = new JMenuItem();
    private JMenuItem contactsItem = new JMenuItem();
    private JMenuItem publicationUnitsItem = new JMenuItem();
    private JMenuItem viewItem = new JMenuItem();

    private JMenuItem helpItem = new JMenuItem();
    private JMenuItem aboutItem = new JMenuItem();


    private TOMALabels labels;

    /**Construct the frame*/
    public TOMAView(ActionListener listener, WindowListener wlistener) {
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);
        try {
            labels = new TOMALabels();
            jbInit(listener, wlistener);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**Component initialization*/
    private void jbInit(ActionListener listener, WindowListener wlistener) throws Exception {

        this.addWindowListener(wlistener);

        this.setTitle(labels.get("apostal.toma.title"));
        this.setBackground(TOMAColors.tomaBackgroundColor);

        //tree
        splitPane.setLeftComponent(panelTree);
        TrainingCourseView tpview = new TrainingCourseView();


        JPanel panel_tmp = new JPanel();
        panel_tmp.setBackground(TOMAColors.tomaBackgroundColor);
        panelContextual.setViewportView(panel_tmp);

        //split pane
        splitPane.setRightComponent(panelContextual);
        splitPane.setDividerLocation(160);
        splitPane.setDividerSize(2);

        //menu
        menuBar.setBackground(TOMAColors.menuBackgroundColor);
        this.setJMenuBar(menuBar);

        //menu TOMA
        tomaMenu.setText(labels.get("apostal.toma.menu.toma").toUpperCase());
        tomaMenu.setBackground(TOMAColors.menuBackgroundColor);
        tomaMenu.setForeground(TOMAColors.unclickableTextColor);
        tomaMenu.setFont(TOMAFonts.buttonsFont);

        menuBar.add(tomaMenu);
        importItem.setText(labels.get("apostal.toma.menu.toma.import"));
        importItem.setActionCommand("import");
        importItem.addActionListener(listener);
        this.setMenuItemDesign(importItem);
        tomaMenu.add(importItem);
        parametersItem.setText(labels.get("apostal.toma.menu.toma.parameters"));
        parametersItem.setActionCommand("parameters");
        parametersItem.addActionListener(listener);
        this.setMenuItemDesign(parametersItem);
        tomaMenu.add(parametersItem);
        quitItem.setText(labels.get("apostal.toma.menu.toma.quit"));
        quitItem.setActionCommand("quit");
        quitItem.addActionListener(listener);
        this.setMenuItemDesign(quitItem);
        tomaMenu.add(quitItem);

        //menu aux
        auxMenu.setText(labels.get("apostal.toma.menu.aux").toUpperCase());
        auxMenu.setBackground(TOMAColors.menuBackgroundColor);
        auxMenu.setForeground(TOMAColors.unclickableTextColor);
        auxMenu.setFont(TOMAFonts.buttonsFont);
        menuBar.add(auxMenu);
        organismItem.setText(labels.get("apostal.toma.menu.aux.organism"));
        organismItem.setActionCommand("organism");
        organismItem.addActionListener(listener);
        this.setMenuItemDesign(organismItem);
        auxMenu.add(organismItem);
        teachersItem.setText(labels.get("apostal.toma.menu.aux.teachers"));
        teachersItem.setActionCommand("teachers");
        teachersItem.addActionListener(listener);
        this.setMenuItemDesign(teachersItem);
        auxMenu.add(teachersItem);
        locationsItem.setText(labels.get("apostal.toma.menu.aux.locations"));
        locationsItem.setActionCommand("locations");
        locationsItem.addActionListener(listener);
        this.setMenuItemDesign(locationsItem);
        auxMenu.add(locationsItem);
        contactsItem.setText(labels.get("apostal.toma.menu.aux.contacts"));
        contactsItem.setActionCommand("contacts");
        contactsItem.addActionListener(listener);
        this.setMenuItemDesign(contactsItem);
        auxMenu.add(contactsItem);
        publicationUnitsItem.setText(labels.get("apostal.toma.menu.aux.publicationUnits"));
        publicationUnitsItem.setActionCommand("publicationUnits");
        publicationUnitsItem.addActionListener(listener);
        this.setMenuItemDesign(publicationUnitsItem);
        auxMenu.add(publicationUnitsItem);
        viewItem.setText(labels.get("apostal.toma.menu.aux.view"));
        viewItem.setActionCommand("view");
        viewItem.addActionListener(listener);
        this.setMenuItemDesign(viewItem);
        auxMenu.add(viewItem);


        //help
        String helpText = labels.get("apostal.toma.menu.help");
        if (helpText != null)
            helpMenu.setText(helpText.toUpperCase());
        else
            TOMA.log(TOMA.SEVERE, "TOMAView, trying to set null text to help menu");
        helpMenu.setBackground(TOMAColors.menuBackgroundColor);
        helpMenu.setForeground(TOMAColors.unclickableTextColor);
        helpMenu.setFont(TOMAFonts.buttonsFont);
        helpItem.setText(labels.get("apostal.toma.menu.help.help"));
        helpItem.setActionCommand("help");
        helpItem.addActionListener(listener);
        this.setMenuItemDesign(helpItem);
        helpMenu.add(helpItem);
        aboutItem.setText(labels.get("apostal.toma.menu.help.about"));
        aboutItem.setActionCommand("about");
        aboutItem.addActionListener(listener);
        this.setMenuItemDesign(aboutItem);
        helpMenu.add(aboutItem);
        menuBar.add(Box.createHorizontalGlue());
        menuBar.add(helpMenu);


        //panel tree
        panelTree.setBackground(TOMAColors.treeBackgroundColor);
        panelTree.setBorder(new LineBorder(TOMAColors.tomaBackgroundColor, 5));

        /*int x=950;
        int y=715;
        Dimension screenSize=Toolkit.getDefaultToolkit().getScreenSize();
        if(screenSize!=null && (screenSize.width<x || screenSize.hashCode()<y))
          splitPane.setPreferredSize(screenSize);
        else
          splitPane.setPreferredSize(new Dimension(x, y));
         **/

        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Double dx = new Double(screenSize.getWidth());
        int ix = dx.intValue();
        Double dy = new Double(screenSize.getHeight() - 40);
        int iy = dy.intValue();
        if (screenSize != null)
            this.setSize(ix, iy);

        this.setContentPane(splitPane);
        //this.pack();
        this.setVisible(true);

        this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
    }


    public ImportTrainingView getImportTrainingView() {
        return importTrainingView;
    }

    public TOMAParametersView getParametersView() {
        return parametersView;
    }

    public OrganismView getOrganismView() {
        return organismView;
    }

    public PublicationUnitsView getPublicationUnitsView() {
        return publicationUnitsView;
    }

    public LocationsView getLocationsView() {
        return locationsView;
    }

    public ContactsView getContactsView() {
        return contactsView;
    }

    public TeachersView getTeachersView() {
        return teachersView;
    }

    public JComponent getContextualView() {
        return realContextualView;
    }

    public TOMATree getTree() {
        return tree;
    }

    public void setImportTrainingView(ImportTrainingView importTrainingView) {
        this.importTrainingView = importTrainingView;
    }

    public void setParametersView(TOMAParametersView parametersView) {
        this.parametersView = parametersView;
    }

    public void setOrganismView(OrganismView organismView) {
        this.organismView = organismView;
    }

    public void setPublicationUnitsView(PublicationUnitsView publicationUnitsView) {
        this.publicationUnitsView = publicationUnitsView;
    }

    public void setLocationsView(LocationsView locationsView) {
        this.locationsView = locationsView;
    }

    public void setContactsView(ContactsView contactsView) {
        this.contactsView = contactsView;
    }

    public void setTeachersView(TeachersView teachersView) {
        this.teachersView = teachersView;
    }

    public void setContextualView(JComponent component) {
        this.realContextualView = component;
        if (component.getClass().getName().equals("apostal.toma.view.TrainingProgrammeAndUnitsView")) {
            JPanel panel_tmp = new JPanel();
            panel_tmp.setBackground(TOMAColors.tomaBackgroundColor);
            panel_tmp.setLayout(new BoxLayout(panel_tmp, BoxLayout.X_AXIS));
            panel_tmp.add(component);
            this.contextualView = panel_tmp;

            panelContextual.setViewportView(panel_tmp);
        } else {
            this.contextualView = component;
            panelContextual.setViewportView(component);
        }
        //this.pack();
    }

    public void setTree(TOMATree tree) {
        this.tree = tree;
        tree.getTree().setVisibleRowCount(30);

        panelTree.setViewportView(tree.getTree());
    }

    private void setMenuItemDesign(JMenuItem item) {
        String s = item.getText();
        if (s != null)
            item.setText(s.toUpperCase());
        else
            TOMA.log(TOMA.SEVERE, "TOMAView, trying to set null text to MenuItem");

        item.setBackground(TOMAColors.menuBackgroundColor);
        item.setForeground(TOMAColors.unclickableTextColor);
        item.setFont(TOMAFonts.buttonsFont);
    }
}
