// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.view;

import apostal.toma.data.Training;
import apostal.toma.data.Language;
import apostal.toma.database.TrainingCourseDB;
import apostal.toma.database.TrainingProgrammeDB;
import apostal.toma.database.UnitDB;
import apostal.toma.TOMA;

import toolbox.swing.MultipleLinesLabel;

import javax.swing.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;

/**
 * choose a training in the tree of catalogue.
 * Used in:
 * Catalogue: add training
 * Training Programme: create unit with training course
 * View Training: choose
 */
public class TrainingChooser extends JDialog implements ActionListener {
    private Training data;

    private TOMAMultipleLinesLabel label;
    private JPanel panel;
    private JList list;
    private JScrollPane listPane;
    private TOMAButton ok;
    private TOMAButton cancel;

    public TrainingChooser(String msg, String title, String label_ok, String label_cancel, boolean courses, boolean programmes, boolean units, ActionListener listener) {
        super(TOMA.getInstance().getTomaView(), title, true);

        panel = new JPanel();
        panel.setLayout(new GridBagLayout());

        label = new TOMAMultipleLinesLabel(50);
        label.setTextWithLowerCase(msg);
        panel.add(label, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        //vecteur de formations
        Language lng = TOMA.getInstance().getTomaParameters().getLanguage();
        Vector trainings = new Vector();
        if (programmes)
            trainings.addAll(TrainingProgrammeDB.load(lng, false));
        if (units)
            trainings.addAll(UnitDB.load(lng, false));
        if (courses)
            trainings.addAll(TrainingCourseDB.load(lng, false));

        list = new JList(trainings);
        listPane = new JScrollPane();
        listPane.getViewport().add(list);
        panel.add(listPane, new GridBagConstraints(0, 1, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));

        cancel = new TOMAButton(label_cancel);
        cancel.setActionCommand("choose_cancel");
        cancel.addActionListener(this);
        panel.add(cancel, new GridBagConstraints(0, 2, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        ok = new TOMAButton(label_ok);
        ok.setActionCommand("choose_ok");
        ok.addActionListener(listener);
        panel.add(ok, new GridBagConstraints(1, 2, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        this.setBackground(TOMAColors.tomaBackgroundColor);
        panel.setBackground(TOMAColors.tomaBackgroundColor);

        this.setContentPane(panel);
    }

    public apostal.toma.data.Training getData() {
        Training t = (Training) list.getSelectedValue();
        return t;
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("choose_cancel"))
            this.dispose();
    }

}
