// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.view;

import apostal.toma.viewcontrol.TOMATreeControl;
import apostal.toma.data.Training;
import apostal.toma.data.Catalogue;
import apostal.toma.view.TOMATree;
import apostal.toma.TOMA;

import toolbox.swing.MultipleLinesLabel;

import javax.swing.*;
import javax.swing.tree.*;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * allow to choose a training in a given catalogue.
 * used for:
 * Catalogue: remove training
 */
public class TrainingInCatalogueChooser extends JDialog implements ActionListener {
    private boolean inCatalogue;
    private Catalogue catalogue;
    private Training data;

    private TOMAMultipleLinesLabel label;
    private JPanel panel;
    private TOMATree tree;
    private JScrollPane treePane;
    private TOMAButton ok;
    private TOMAButton cancel;

    public TrainingInCatalogueChooser(String msg, String title, String label_ok, String label_cancel, boolean seeCourses, boolean seeProgrammes, boolean selectCourses, boolean selectProgrammes, ActionListener listener) {
        super(TOMA.getInstance().getTomaView(), title, true);

        panel = new JPanel();
        panel.setLayout(new GridBagLayout());

        label = new TOMAMultipleLinesLabel(50);
        label.setTextWithLowerCase(msg);
        panel.add(label, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        TOMATreeControl control = new TOMATreeControl();
        tree = control.createRootTree(seeCourses, seeProgrammes, false, selectCourses, selectProgrammes, TOMA.getInstance().getTomaParameters().getLanguage());
        treePane = new JScrollPane();
        TOMAJTree jtree = tree.getTree();
        jtree.setVisibleRowCount(20);
        treePane.getViewport().add(jtree);
        panel.add(treePane, new GridBagConstraints(0, 1, 2, 1, 0.1, 0.1, GridBagConstraints.NORTH, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));

        cancel = new TOMAButton(label_cancel);
        cancel.setActionCommand("choose_cancel");
        cancel.addActionListener(this);
        panel.add(cancel, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHEAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        ok = new TOMAButton(label_ok);
        ok.setActionCommand("choose_ok");
        ok.addActionListener(listener);
        panel.add(ok, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        this.setBackground(TOMAColors.tomaBackgroundColor);
        panel.setBackground(TOMAColors.tomaBackgroundColor);
        label.setBackground(TOMAColors.tomaBackgroundColor);

        this.setContentPane(panel);
    }

    public void changeActionCommand(String cmd) {
        ok.setActionCommand(cmd);
    }

    /**
     * return the id of the training selected, if the training is selected
     * (does not give the path to this training)
     */
    public int getIdTraining() {
        TreePath path = tree.getTree().getSelectionPath();

        if (path != null) {
            Object o = path.getLastPathComponent();
            if (o != null && o.getClass().getName().equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode node = (TrainingTreeNode) o;
                return node.getIdTraining();
            } else
                return -1;
        } else
            return -1;
    }

    public int getTypeTraining() {
        TreePath path = tree.getTree().getSelectionPath();

        if (path != null) {
            Object o = path.getLastPathComponent();
            if (o != null && o.getClass().getName().equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode node = (TrainingTreeNode) o;
                return node.getType();
            } else
                return -1;
        } else
            return -1;
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("choose_cancel"))
            this.dispose();
    }
}
