// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import java.awt.Component;
import java.awt.Dimension;
import java.util.Vector;
import java.util.Iterator;

import javax.swing.JTabbedPane;
import javax.swing.border.LineBorder;

import apostal.toma.data.TOMALabels;

import apostal.toma.data.TrainingProgramme;
import apostal.toma.viewcontrol.TrainingProgrammeEventHandler;
import apostal.toma.data.Unit;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingProgrammeAndUnitsView extends JTabbedPane {
    private TrainingProgrammeView trainingProgrammeView;
    private Vector unitViews;
    protected TrainingProgrammeEventHandler handler;

    public void updateTeachers() {
        if (trainingProgrammeView != null)
            trainingProgrammeView.updateTeachers();
        if (unitViews != null) {
            Iterator it = unitViews.iterator();
            while (it.hasNext()) {
                UnitView unitView = (UnitView) it.next();
                unitView.updateTeachers();
            }
        }
    }

    public void updateContacts() {
        if (trainingProgrammeView != null)
            trainingProgrammeView.updateContacts();
        if (unitViews != null) {
            Iterator it = unitViews.iterator();
            while (it.hasNext()) {
                UnitView unitView = (UnitView) it.next();
                unitView.updateContacts();
            }
        }
    }

    public void updateLocations() {
        if (trainingProgrammeView != null)
            trainingProgrammeView.updateLocations();
        if (unitViews != null) {
            Iterator it = unitViews.iterator();
            while (it.hasNext()) {
                UnitView unitView = (UnitView) it.next();
                unitView.updateLocations();
            }
        }
    }

    public TrainingProgrammeAndUnitsView(TrainingProgrammeEventHandler handler) {
        this.setFont(TOMAFonts.buttonsFont);

        TOMALabels labels = new TOMALabels();

        this.handler = handler;

        trainingProgrammeView = new TrainingProgrammeView(handler);
        //this.addTab(labels.get("apostal.toma.trainingprogramme"), trainingProgrammeView);
        this.addTOMATab(labels.get("apostal.toma.trainingprogramme"), trainingProgrammeView);

        this.setSelectedComponent(trainingProgrammeView);

        unitViews = new Vector();

        //ne fait rien?
        //this.setBackground(TOMAColors.tomaBackgroundColor);
    }

    public TrainingProgrammeEventHandler getHandler() {
        return handler;
    }

    public TrainingProgrammeView getTrainingProgrammeView() {
        return trainingProgrammeView;
    }

    public Vector getUnitViews() {
        return unitViews;
    }

    public void setData(TrainingProgramme t) {
        //data
        trainingProgrammeView.setData(t);

        //units
        Vector units = t.getUnits();
        if (units != null) {
            Iterator iter = units.iterator();
            while (iter.hasNext()) {
                Unit u = (Unit) iter.next();
                UnitView view = new UnitView(this);
                view.setData(u);

                unitViews.add(view);
                //this.addTab(u.getTitle(), view);
                this.addTOMATab(u.getTitle(), view);
            }
        }
    }

    public void removeUnit(UnitView view) {
        int taborder = unitViews.indexOf(view);
        unitViews.remove(view);
        this.removeTabAt(taborder + 1);
    }

    public void addUnit(Unit u) {
        UnitView unitview = new UnitView(this);
        unitview.setData(u);
        unitViews.add(unitview);
        //this.addTab(u.getTitle(), unitview);
        this.addTOMATab(u.getTitle(), unitview);

        this.setSelectedComponent(unitview);
    }

    private void addTOMATab(String s, Component c) {
        String maj = s.toUpperCase();
        this.addTab(maj, c);

        int i = this.getTabCount();
        //this.setForegroundAt(i-1, TOMAColors.clickableTextColor);
        this.setForegroundAt(i - 1, TOMAColors.trainingTabTitleForegroundColor);
        //if(i>1) //units
        this.setBackgroundAt(i - 1, TOMAColors.tomaBackgroundColor);
        //else //trainingProgramme
        //this.setBackgroundAt(0, TOMAColors.buttonsBackgroundColor);
    }
}