// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.data.Unit;
import apostal.toma.data.TrainingProgramme;
import apostal.toma.viewcontrol.TrainingEventHandler;

import javax.swing.JTextField;
import javax.swing.JLabel;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

public class TrainingProgrammeDuplication extends TrainingDuplication {
    private TrainingProgramme tp;

    private Vector unitsTitles = new Vector();
    private Vector unitsCodes = new Vector();

    public TrainingProgrammeDuplication(TrainingEventHandler handler, TrainingProgramme tp, TOMAFrame parent) {
        super(handler, parent);
        this.tp = tp;
        title.setText(tp.getTitle());

        this.setMessage(labels.get("apostal.toma.trainingview.duplicate.message.trainingProgramme"));

        //units
        if (tp.getUnits() != null) {
            Iterator iter = tp.getUnits().iterator();
            int cpt = 3;
            while (iter.hasNext()) {
                Unit unit = (Unit) iter.next();

                //label
                JLabel label = new JLabel(labels.get("apostal.toma.trainingview.duplicate.duplicateUnit") + " \"" + unit.getTitle() + "\" (" + unit.getCode() + "):");
                questions.add(label, new GridBagConstraints(0, cpt, 2, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

                //label	code
                JLabel label_code = new JLabel(labels.get("apostal.toma.trainingview.duplicate.unitCode"));
                questions.add(label_code, new GridBagConstraints(0, cpt + 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 20, 5, 5), 0, 0));

                //code
                JTextField code = new JTextField();
                code.setColumns(20);
                unitsCodes.add(code);
                questions.add(code, new GridBagConstraints(1, cpt + 1, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

                //label	title
                JLabel label_title = new JLabel(labels.get("apostal.toma.trainingview.duplicate.unitTitle"));
                questions.add(label_title, new GridBagConstraints(0, cpt + 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 20, 5, 5), 0, 0));

                //title
                JTextField title = new JTextField();
                title.setColumns(20);
                title.setText(unit.getTitle());
                unitsTitles.add(title);
                questions.add(title, new GridBagConstraints(1, cpt + 2, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

                cpt = cpt + 3;
            }
        }
    }

    public Object getData() {
        Vector datas = new Vector();
        TrainingProgramme t = (TrainingProgramme) tp.duplicate();
        t.setTitle(title.getText());
        t.setCode(code.getText());

        Vector units = new Vector();
        if (tp.getUnits() != null) {
            Iterator iter = tp.getUnits().iterator();
            int cpt = 0;
            int nbTitles = unitsTitles.size();
            while (iter.hasNext()) {
                Unit unit = (Unit) iter.next();
                if (nbTitles > cpt) {
                    Unit newU = (Unit) unit.duplicate();
                    newU.setTitle(((JTextField) unitsTitles.elementAt(cpt)).getText());
                    newU.setCode(((JTextField) unitsCodes.elementAt(cpt)).getText());
                    units.add(newU);
                }

                cpt++;
            }
        }
        t.setUnits(units);
        datas.add(t);
        Boolean withSession = new Boolean(cbWithSession.isSelected());
        datas.add(withSession);

        return datas;
    }
}
