// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;

import apostal.toma.viewcontrol.TOMATreeControl;
import apostal.toma.data.Training;
import apostal.toma.data.Catalogue;
import apostal.toma.view.TOMATree;


import toolbox.swing.MultipleLinesLabel;


import javax.swing.*;
import javax.swing.tree.*;

import java.util.Enumeration;

import java.awt.Toolkit;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class TrainingToPublishView extends JDialog implements ActionListener {
    private boolean inCatalogue;
    private Catalogue catalogue;
    private Training data;

    private TOMAMultipleLinesLabel label;
    private JPanel panel;
    private TOMATree tree;
    private JScrollPane treePane;
    private TOMAButton ok;
    private String label_ok;

    public TrainingToPublishView(TOMATree tomaTree, String title) {
        super(TOMA.getInstance().getTomaView(), title, true);
        tree = tomaTree;
        label_ok = new String("ok");

        panel = new JPanel();
        panel.setLayout(new GridBagLayout());
        treePane = new JScrollPane();
        CatalogueTreeNode node = tomaTree.getRoot();
        Enumeration enum = node.breadthFirstEnumeration();
        while (enum.hasMoreElements()) {
            Object o = enum.nextElement();
            String className = o.getClass().getName();
            if (className.equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode tnode = (TrainingTreeNode) o;
                DefaultTreeModel model = (DefaultTreeModel) tree.getTree().getModel();
                TreePath path = new TreePath(model.getPathToRoot(tnode));
                tomaTree.getTree().makeVisible(path);
            }
            if (className.equals("apostal.toma.view.CatalogueTreeNode")) {
                CatalogueTreeNode tnode = (CatalogueTreeNode) o;
                DefaultTreeModel model = (DefaultTreeModel) tree.getTree().getModel();
                TreePath path = new TreePath(model.getPathToRoot(tnode));
                tomaTree.getTree().makeVisible(path);
            }
        }

        tree.getTree().setSelectionModel(null);
        treePane.setViewportView(tomaTree.getTree());

        panel.add(treePane, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        ok = new TOMAButton(label_ok);
        ok.setActionCommand("choose_ok");
        ok.addActionListener(this);

        panel.add(ok, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));

        this.setBackground(TOMAColors.tomaBackgroundColor);
        panel.setBackground(TOMAColors.tomaBackgroundColor);

        this.getContentPane().add(panel);

        //this.setContentPane(panel);
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("choose_ok"))
            this.dispose();
    }


    public void center() {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension frameSize = this.getSize();
        this.setLocation((screenSize.width - frameSize.width) / 2, (screenSize.height - frameSize.height) / 2);
    }
}