// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.data.*;

//import javax.swing.JTree;
import javax.swing.tree.*;

import java.util.Vector;
import java.util.Enumeration;

public class TrainingTreeNode extends DefaultMutableTreeNode {
    public final static int TRAININGCOURSE = 0;
    public final static int TRAININGPROGRAMME = 1;
    public final static int UNIT = 2;

    private CatalogueTreeNode parent;
    private int idCatalogue;
    private int idTraining;
    private String title;
    private String code;

    private int type;

    public TrainingTreeNode() {
    }

    public TrainingTreeNode(int idTraining,int idCatalogue) {
        this.idCatalogue = idCatalogue;
        this.idTraining = idTraining;
    }

    public TrainingTreeNode(int idTraining, String title, String code, int idCatalogue, int type) {
        this.idTraining = idTraining;
        this.title = title;
        this.code = code;
        this.idCatalogue = idCatalogue;
        this.type = type;
    }

    public TrainingTreeNode(CatalogueTreeNode parent, int idTraining, String title, String code, int idCatalogue, int type) {
        this(idTraining, title, code, idCatalogue, type);
        this.parent = parent;
        this.type = type;
    }

    public Enumeration children() {
        return (new Vector()).elements();
    }

    public boolean getAllowsChildren() {
        return false;
    }

    public TreeNode getChildAt(int index) {
        return null;
    }

    public int getChildCount() {
        return 0;
    }

    public int getIndex(TreeNode node) {
        return -1;
    }

    public TreeNode getParent() {
        return parent;
    }

    public boolean isLeaf() {
        return true;
    }

    public int getIdTraining() {
        return idTraining;
    }

    public String getTitle() {
        return title;
    }

    public int getType() {
        return type;
    }

    public String toString() {
        return title + " (" + code + ")";
    }

    public boolean equals(TrainingTreeNode node) {
        boolean equals = false;
        if (node != null) {
            if (node.idTraining == this.idTraining && node.idCatalogue == this.idCatalogue)
                equals = true;
        }
        return equals;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public void setCode(String code) {
        this.code = code;
    }
}
