// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.border.EmptyBorder;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import apostal.toma.datacontrol.ContactsControl;
import apostal.toma.data.*;
import apostal.toma.TOMA;
import apostal.toma.database.ContactDB;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewContacts extends JScrollPane implements ActionListener {
    public static Vector contacts;
    private static ImageIcon addIcon;
    private static ImageIcon addPressedIcon;
    private static ImageIcon removeIcon;
    private static ImageIcon removePressedIcon;

    static {
        ContactsControl control = new ContactsControl();
        contacts = control.loadContacts(false);

        addIcon = new ImageIcon(TOMAConstants.addIconPath);
        addPressedIcon = new ImageIcon(TOMAConstants.addPressedIconPath);
        removeIcon = new ImageIcon(TOMAConstants.removeIconPath);
        removePressedIcon = new ImageIcon(TOMAConstants.removePressedIconPath);
    }

    public static Vector refreshLists() {
        ContactsControl control = new ContactsControl();
        contacts = control.loadContacts(false);
        return contacts;
    }

    public void updateContacts() {
        //mettre  jour la liste des contacts existants
        existingContacts.setListData(contacts);

        //mettre  jour les contacts chargs
        TrainingCourse tc = new TrainingCourse();
        this.getData(tc);
        if (tc != null) {
            //mettre  jour les contacts d'inscription chargs
            Vector tcInscriptionContacts = tc.getInscriptionContacts();
            Vector newInscriptionContacts = new Vector();
            if (tcInscriptionContacts != null) {
                Iterator it = tcInscriptionContacts.iterator();
                while (it.hasNext()) {
                    Contact c = (Contact) it.next();
                    boolean found = false;
                    Iterator it2 = contacts.iterator();
                    while (it2.hasNext() && !found) {
                        Contact c2 = (Contact) it2.next();
                        if (c2 != null && c != null && c2.getIdContact() == c.getIdContact()) {
                            newInscriptionContacts.add(c2);
                            found = true;
                        }
                    }
                }
            }
            tc.setInscriptionContacts(newInscriptionContacts);

            //mettre  jour les contacts de training chargs
            Vector tcTrainingContacts = tc.getTrainingContacts();
            Vector newTrainingContacts = new Vector();
            if (tcTrainingContacts != null) {
                Iterator it = tcTrainingContacts.iterator();
                while (it.hasNext()) {
                    Contact c = (Contact) it.next();
                    boolean found = false;
                    Iterator it2 = contacts.iterator();
                    while (it2.hasNext() && !found) {
                        Contact c2 = (Contact) it2.next();
                        if (c2 != null && c != null && c2.getIdContact() == c.getIdContact()) {
                            newTrainingContacts.add(c2);
                            found = true;
                        }
                    }
                }
            }
            tc.setTrainingContacts(newTrainingContacts);

            this.setData(tc);
        }
    }

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMALabel label_existingContacts = new TOMALabel();
    JList existingContacts = new JList(contacts);
    JScrollPane contactsPane = new JScrollPane();
    JButton addTrainingContact = new JButton();
    JButton addInscriptionContact = new JButton();
    TOMALabel label_trainingContacts = new TOMALabel();
    TOMALabel label_inscriptionContacts = new TOMALabel();

    Vector trainingContacts = new Vector();
    JList trainingContactsList = new JList(trainingContacts);
    JScrollPane trainingContactsPane = new JScrollPane();
    Vector inscriptionContacts = new Vector();
    JList inscriptionContactsList = new JList(inscriptionContacts);
    JScrollPane inscriptionContactsPane = new JScrollPane();

    JButton removeTraining = new JButton();
    JButton removeInscription = new JButton();

    private TOMALabels labels;

    /*****************contactsData*****************/
    private JScrollPane trainingContactsDataScrollPane;
    private JPanel trainingContactsDataPane;
    private TOMALabel trainingContactsName;
    private TOMALabel trainingContactsFunction;
    private TOMALabel trainingContactsTel;
    private TOMALabel trainingContactsFax;
    private TOMALabel trainingContactsEmail;
    private TOMALabel trainingContactsAddress;

    private JScrollPane inscriptionContactsDataScrollPane;
    private JPanel inscriptionContactsDataPane;
    private TOMALabel inscriptionContactsName;
    private TOMALabel inscriptionContactsFunction;
    private TOMALabel inscriptionContactsTel;
    private TOMALabel inscriptionContactsFax;
    private TOMALabel inscriptionContactsEmail;
    private TOMALabel inscriptionContactsAddress;

    public TrainingViewContacts(int type) {
        try {
            labels = new TOMALabels();
            jbInit(type);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit(int type) throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        label_existingContacts.setText(labels.get("apostal.toma.trainingview.contacts.existingContacts"));
        existingContacts.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        existingContacts.setListData(contacts);
        existingContacts.setVisibleRowCount(10);
        existingContacts.setFixedCellWidth(200);
        existingContacts.setBackground(TOMAColors.editingFieldColor);
        trainingContactsList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        trainingContactsList.setVisibleRowCount(10);
        trainingContactsList.setFixedCellWidth(200);
        trainingContactsList.setBackground(TOMAColors.editingFieldColor);
        trainingContactsList.addListSelectionListener(new ContactsListSelectionListener(this, true));

        inscriptionContactsList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        inscriptionContactsList.setVisibleRowCount(10);
        inscriptionContactsList.setFixedCellWidth(200);
        inscriptionContactsList.setBackground(TOMAColors.editingFieldColor);
        inscriptionContactsList.addListSelectionListener(new ContactsListSelectionListener(this, false));

        //addTrainingContact.setText(labels.get("apostal.toma.trainingview.contacts.addTrainingContact"));
        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);
        Insets insets = new Insets(0, 0, 0, 0);
        addTrainingContact.setIcon(addIcon);
        addTrainingContact.setPressedIcon(addPressedIcon);
        addTrainingContact.setBorder(border);
        addTrainingContact.setMargin(insets);
        addTrainingContact.setBackground(TOMAColors.trainingTabBackgroundColor);
        addTrainingContact.setActionCommand("addTraining");
        addTrainingContact.addActionListener(this);

        addInscriptionContact.setIcon(addIcon);
        addInscriptionContact.setPressedIcon(addPressedIcon);
        addInscriptionContact.setBorder(border);
        addInscriptionContact.setMargin(insets);
        addInscriptionContact.setBackground(TOMAColors.trainingTabBackgroundColor);
        addInscriptionContact.setActionCommand("addInscription");
        addInscriptionContact.addActionListener(this);

        label_trainingContacts.setText(labels.get("apostal.toma.trainingview.contacts.trainingContacts"));
        label_inscriptionContacts.setText(labels.get("apostal.toma.trainingview.contacts.inscriptionContacts"));

        removeTraining.setIcon(removeIcon);
        removeTraining.setPressedIcon(removePressedIcon);
        removeTraining.setBorder(border);
        removeTraining.setMargin(insets);
        removeTraining.setBackground(TOMAColors.trainingTabBackgroundColor);
        removeTraining.setActionCommand("removeTraining");
        removeTraining.addActionListener(this);

        removeInscription.setIcon(removeIcon);
        removeInscription.setPressedIcon(removePressedIcon);
        removeInscription.setBorder(border);
        removeInscription.setMargin(insets);
        removeInscription.setBackground(TOMAColors.trainingTabBackgroundColor);
        removeInscription.setActionCommand("removeInscription");
        removeInscription.addActionListener(this);

        TOMATemplateResult trainingResult = TOMATemplateView.getTemplateResult(type, "trainingContact");
        if (trainingResult.isForbidden()) {
            addTrainingContact.setEnabled(false);
            removeTraining.setEnabled(false);
            trainingContactsList.setEnabled(false);
        }
        if (trainingResult.isMandatory()) {
            label_trainingContacts.setText(label_trainingContacts.getText() + " (*)");
        }
        TOMATemplateResult inscriptionResult = TOMATemplateView.getTemplateResult(type, "inscriptionContact");
        if (inscriptionResult.isForbidden()) {
            addInscriptionContact.setEnabled(false);
            removeInscription.setEnabled(false);
            inscriptionContactsList.setEnabled(false);
        }
        if (inscriptionResult.isMandatory()) {
            label_inscriptionContacts.setText(label_inscriptionContacts.getText() + " (*)");
        }

        contactsPane.getViewport().add(existingContacts);
        trainingContactsPane.getViewport().add(trainingContactsList);
        inscriptionContactsPane.getViewport().add(inscriptionContactsList);

        this.getViewport().add(jPanel1, null);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;

        jPanel1.add(label_existingContacts, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(contactsPane, new GridBagConstraints(0, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(addTrainingContact, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTH, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(removeTraining, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTH, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));


        jPanel1.add(label_trainingContacts, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(trainingContactsPane, new GridBagConstraints(2, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));


        jPanel1.add(label_inscriptionContacts, new GridBagConstraints(2, 3, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(inscriptionContactsPane, new GridBagConstraints(2, 4, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(addInscriptionContact, new GridBagConstraints(1, 4, 1, 1, 0.0, 0.0
                , GridBagConstraints.SOUTH, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(removeInscription, new GridBagConstraints(1, 5, 1, 1, 0.0, 0.0
                , GridBagConstraints.NORTH, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));

        //fill
        jPanel1.add(Box.createGlue(), new GridBagConstraints(0, 6, 1, 1, 0.0, 1.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(Box.createGlue(), new GridBagConstraints(3, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));

        /*****************trainingContactData*****************/
        trainingContactsDataScrollPane = new JScrollPane();
        trainingContactsDataPane = new JPanel();
        trainingContactsDataPane.setLayout(new BoxLayout(trainingContactsDataPane, BoxLayout.Y_AXIS));
        trainingContactsDataPane.setBackground(TOMAColors.auxBackgroundColor2);
        trainingContactsName = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsName);
        trainingContactsFunction = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsFunction);
        trainingContactsTel = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsTel);
        trainingContactsFax = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsFax);
        trainingContactsEmail = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsEmail);
        trainingContactsAddress = new TOMALabel();
        trainingContactsDataPane.add(trainingContactsAddress);
        trainingContactsDataScrollPane.setViewportView(trainingContactsDataPane);
        trainingContactsDataScrollPane.setPreferredSize(new Dimension(200, 200));
        jPanel1.add(trainingContactsDataScrollPane, new GridBagConstraints(3, 0, 1, 3, 0.0, 0.0, anchor, fill, new Insets(5, 5, 5, 5), 0, 0));

        /*****************inscriptionContactData*****************/
        inscriptionContactsDataScrollPane = new JScrollPane();
        inscriptionContactsDataPane = new JPanel();
        inscriptionContactsDataPane.setLayout(new BoxLayout(inscriptionContactsDataPane, BoxLayout.Y_AXIS));
        inscriptionContactsDataPane.setBackground(TOMAColors.auxBackgroundColor2);
        inscriptionContactsName = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsName);
        inscriptionContactsFunction = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsFunction);
        inscriptionContactsTel = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsTel);
        inscriptionContactsFax = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsFax);
        inscriptionContactsEmail = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsEmail);
        inscriptionContactsAddress = new TOMALabel();
        inscriptionContactsDataPane.add(inscriptionContactsAddress);
        inscriptionContactsDataScrollPane.setViewportView(inscriptionContactsDataPane);
        inscriptionContactsDataScrollPane.setPreferredSize(new Dimension(200, 200));
        jPanel1.add(inscriptionContactsDataScrollPane, new GridBagConstraints(3, 3, 1, 3, 0.0, 0.0, anchor, fill, new Insets(5, 5, 5, 5), 0, 0));
    }

    public void setTrainingContactsData(Contact contact) {
        String title = (contact.getTitle() == null) ? "" : contact.getTitle();
        String firstname = (contact.getFirstname() == null) ? "" : contact.getFirstname();
        String lastname = (contact.getLastname() == null) ? "" : contact.getLastname();
        trainingContactsName.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-weight: bold\">" + title + " " + firstname + " " + lastname + "</font>" + TOMAFonts.htmlEnd);

        String function = (contact.getFunction() == null) ? "" : contact.getFunction();
        trainingContactsFunction.setTextWithLowerCase(labels.get("apostal.toma.contact.function") + ": " + function);

        String tel = (contact.getTel() == null) ? "" : contact.getTel();
        trainingContactsTel.setTextWithLowerCase(labels.get("apostal.toma.contact.tel") + ": " + tel);

        String fax = (contact.getFax() == null) ? "" : contact.getFax();
        trainingContactsFax.setTextWithLowerCase(labels.get("apostal.toma.contact.fax") + ": " + fax);

        String email = (contact.getEmail() == null) ? "" : contact.getEmail();
        trainingContactsEmail.setTextWithLowerCase(labels.get("apostal.toma.contact.email") + ": " + email);

        if (contact.getAddress() != null)
            trainingContactsAddress.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-size: 10pt;\">" + labels.get("apostal.toma.contact.address") + ": " + "<table><tr><td style=\"font-size: 10pt;\">" + contact.getAddress().toHTMLString() + "</td></tr></table></font>" + TOMAFonts.htmlEnd);
    }

    public void setInscriptionContactsData(Contact contact) {
        String title = (contact.getTitle() == null) ? "" : contact.getTitle();
        String firstname = (contact.getFirstname() == null) ? "" : contact.getFirstname();
        String lastname = (contact.getLastname() == null) ? "" : contact.getLastname();
        inscriptionContactsName.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-weight: bold\">" + title + " " + firstname + " " + lastname + "</font>" + TOMAFonts.htmlEnd);

        String function = (contact.getFunction() == null) ? "" : contact.getFunction();
        inscriptionContactsFunction.setTextWithLowerCase(labels.get("apostal.toma.contact.function") + ": " + function);

        String tel = (contact.getTel() == null) ? "" : contact.getTel();
        inscriptionContactsTel.setTextWithLowerCase(labels.get("apostal.toma.contact.tel") + ": " + tel);

        String fax = (contact.getFax() == null) ? "" : contact.getFax();
        inscriptionContactsFax.setTextWithLowerCase(labels.get("apostal.toma.contact.fax") + ": " + fax);

        String email = (contact.getEmail() == null) ? "" : contact.getEmail();
        inscriptionContactsEmail.setTextWithLowerCase(labels.get("apostal.toma.contact.email") + ": " + email);

        if (contact.getAddress() != null)
            inscriptionContactsAddress.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-size: 10pt;\">" + labels.get("apostal.toma.contact.address") + ": " + "<table><tr><td style=\"font-size: 10pt;\">" + contact.getAddress().toHTMLString() + "</td></tr></table></font>" + TOMAFonts.htmlEnd);
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();

        if (cmd != null) {
            if (cmd.equals("addTraining")) {
                //rcuprer le contact slectionn
                Contact t = (Contact) existingContacts.getSelectedValue();
                if (t != null && !trainingContacts.contains(t)) {
                    trainingContacts.add(t);
                    trainingContactsList.setListData(trainingContacts);
                }
            }
            if (cmd.equals("addInscription")) {
                //rcuprer le contact slectionn
                Contact t = (Contact) existingContacts.getSelectedValue();
                if (t != null && !inscriptionContacts.contains(t)) {
                    inscriptionContacts.add(t);
                    inscriptionContactsList.setListData(inscriptionContacts);
                }
            } else if (cmd.equals("removeTraining")) {
                Contact t = (Contact) trainingContactsList.getSelectedValue();
                if (t != null) {
                    trainingContacts.remove(t);
                    trainingContactsList.setListData(trainingContacts);
                }
            } else if (cmd.equals("removeInscription")) {
                Contact t = (Contact) inscriptionContactsList.getSelectedValue();
                if (t != null) {
                    inscriptionContacts.remove(t);
                    inscriptionContactsList.setListData(inscriptionContacts);
                }
            }
        }
    }

    public void getData(StandaloneTraining t) {
        t.setTrainingContacts(trainingContacts);
        t.setInscriptionContacts(inscriptionContacts);
    }

    public void setData(StandaloneTraining t) {
        //training Contacts
        Vector ts = t.getTrainingContacts();
        if (ts != null) {
            trainingContacts = new Vector();
            int size = ts.size();
            for (int i = 0; i < size; i++) {
                //retrouver le contact dans "contacts";
                Contact c = (Contact) ts.elementAt(i);
                if (c != null) {
                    int id = c.getIdContact();
                    //Iterator iter = trainingContacts.iterator();
                    Iterator iter = contacts.iterator();
                    boolean found = false;
                    while (iter.hasNext() && !found) {
                        Contact c2 = (Contact) iter.next();
                        if (c2 != null && c2.getIdContact() == id) {
                            trainingContacts.add(c2);
                            found = true;
                        }
                    }
                }
            }
            trainingContactsList.setListData(trainingContacts);
        }

        //inscription Contacts
        Vector ins = t.getInscriptionContacts();
        if (ins != null) {
            inscriptionContacts = new Vector();
            int ins_size = ins.size();
            for (int i = 0; i < ins_size; i++) {
                //retrouver le contact dans "contacts";
                Contact c = (Contact) ins.elementAt(i);
                if (c != null) {
                    int id = c.getIdContact();
                    //Iterator iter = inscriptionContacts.iterator();
                    Iterator iter = contacts.iterator();
                    boolean found = false;
                    while (iter.hasNext() && !found) {
                        Contact c2 = (Contact) iter.next();
                        if (c2 != null && c2.getIdContact() == id) {
                            inscriptionContacts.add(c2);
                            found = true;
                        }
                    }
                }
            }
            inscriptionContactsList.setListData(inscriptionContacts);
        }
    }

    public String testTemplateElements(int type) {
        String msg = "";
        TrainingCourse tc = new TrainingCourse();
        this.getData(tc);

        TOMATemplateResult tr_result = TOMATemplateView.getTemplateResult(type, "trainingContact");
        if (tr_result.isMandatory()) {
            if (tc.getTrainingContacts() == null || tc.getTrainingContacts().isEmpty()) {
                msg = "\n" + labels.get("apostal.toma.trainingview.contacts.trainingContacts") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        TOMATemplateResult ins_result = TOMATemplateView.getTemplateResult(type, "inscriptionContact");
        if (ins_result.isMandatory()) {
            if (tc.getInscriptionContacts() == null || tc.getInscriptionContacts().isEmpty()) {
                msg = msg + "\n" + labels.get("apostal.toma.trainingview.contacts.inscriptionContacts") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        if (msg.equals(""))
            return null;
        else
            return msg;
    }

    public JList getTrainingContactsList() {
        return trainingContactsList;
    }

    public JList getInscriptionContactsList() {
        return inscriptionContactsList;
    }
}

class ContactsListSelectionListener implements ListSelectionListener {
    private TrainingViewContacts view;
    private boolean trainingContact;
    private ContactsControl control;

    public ContactsListSelectionListener(TrainingViewContacts view, boolean trainingContact) {
        this.view = view;
        this.trainingContact = trainingContact;
        control = new ContactsControl();
    }

    public void valueChanged(ListSelectionEvent e) {
        Contact c = null;
        if (trainingContact)
            c = (Contact) view.getTrainingContactsList().getSelectedValue();
        else
            c = (Contact) view.getInscriptionContactsList().getSelectedValue();
        if (c != null) {
            control.loadContact(c, true);
            if (trainingContact)
                view.setTrainingContactsData(c);
            else
                view.setInscriptionContactsData(c);
        }
    }
}