// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import java.awt.*;
import java.lang.Class;

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.data.Training;
import toolbox.text.ExtendedList;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewContent extends JScrollPane {
    private static int introLength = 60;
    private static int introHeight = 4;
    private static int pointLength = 53;
    private static int pointFrameLength = 600;
    private static int pointFrameHeight = 250;

    JPanel jPanel1 = new JPanel();
    TOMALabel label_introduction = new TOMALabel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMATextArea introduction = new TOMATextArea(TrainingViewContent.introHeight, TrainingViewContent.introLength);
    TOMALabel label_conclusion = new TOMALabel();
    TOMATextArea conclusion = new TOMATextArea(TrainingViewContent.introHeight, TrainingViewContent.introLength);

    TOMAMultipleElements points;

    private TOMALabels labels;
    private TOMATemplateResult result;

    private int _type;
    
    public TrainingViewContent(int type) {
        try {
            labels = new TOMALabels();
            this._type=type;
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);
        
        //introduction
        label_introduction.setText(labels.get("apostal.toma.trainingview.content.introduction"));
        TOMATemplateResult introResult = TOMATemplateView.getTemplateResult(_type, "contentIntroduction");
        if (introResult.getMaximum() > -1)
            label_introduction.setText(label_introduction.getText() + " (" + new Integer(introResult.getMaximum()) + ")");
        if (introResult.isForbidden())
            introduction.setEnabled(false);            
        JScrollPane pane_introduction = new JScrollPane(introduction);

        //conclusion
        label_conclusion.setText(labels.get("apostal.toma.trainingview.content.conclusion"));
        TOMATemplateResult cclResult = TOMATemplateView.getTemplateResult(_type, "contentConclusion");
        if (cclResult.getMaximum() > -1)
            label_conclusion.setText(label_conclusion.getText() + " (" + new Integer(cclResult.getMaximum()) + ")");
        if (cclResult.isForbidden())
            conclusion.setEnabled(false);                    
        JScrollPane pane_conclusion = new JScrollPane(conclusion);

        //points
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        values[0] = new Integer(TrainingViewContent.pointLength);
        TOMATemplateResult pointResult = TOMATemplateView.getTemplateResult(_type, "contentPoint");
        if (pointResult != null && pointResult.getMaximum() > -1) {
            String forEachPoint = "(" + pointResult.getMaximum() + " " + labels.get("apostal.toma.trainingview.content.forEachPoint") + ")";
            points = new TOMAMultipleElements("apostal.toma.view.SubPointDealtWithPanel", classes, values, 0, null, labels.get("apostal.toma.trainingview.content.addPoint"), labels.get("apostal.toma.trainingview.content.removePoint"), TOMAColors.multipleElementsColor, TrainingViewContent.pointFrameLength, TrainingViewContent.pointFrameHeight, forEachPoint);
        } else
            points = new TOMAMultipleElements("apostal.toma.view.SubPointDealtWithPanel", classes, values, 0, null, labels.get("apostal.toma.trainingview.content.addPoint"), labels.get("apostal.toma.trainingview.content.removePoint"), TOMAColors.multipleElementsColor, TrainingViewContent.pointFrameLength, TrainingViewContent.pointFrameHeight);
        if(pointResult.isForbidden())
            points.setEnabled(false);

        //global
        result = TOMATemplateView.getTemplateResult(_type, "contentDescription");
        if (result.isForbidden()) {
            introduction.setEnabled(false);
            conclusion.setEnabled(false);
            points.setEnabled(false);
        }

        this.getViewport().add(jPanel1, null);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;

        jPanel1.add(label_introduction, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(pane_introduction, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 5, 0), 0, 0));
        jPanel1.add(points, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(label_conclusion, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(5, 10, 0, 0), 0, 0));
        jPanel1.add(pane_conclusion, new GridBagConstraints(0, 4, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));

        //fill
        jPanel1.add(Box.createGlue(), new GridBagConstraints(0, 5, 1, 1, 0.0, 1.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(Box.createGlue(), new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
    }

    public void getData(Training t) {
        t.setContentDescriptionIntroduction(introduction.getText());

        JComponent[] elements = points.getElements();
        int size = elements.length;
        Vector objectives = new Vector();
        for (int i = 0; i < size; i++) {
            SubPointDealtWithPanel sub = (SubPointDealtWithPanel) elements[i];
            objectives.addElement(sub.getData());
        }
        t.setContentDescription(objectives);
        t.setContentDescriptionConclusion(conclusion.getText());
    }

    public void setData(Training t) {
        introduction.setText(t.getContentDescriptionIntroduction());

        Vector objectives = t.getContentDescription();
        if (objectives != null) {
            Vector elements = new Vector();
            Iterator iter = objectives.iterator();
            while (iter.hasNext()) {
                String point = (String) iter.next();
                if (point != null) {
                    SubPointDealtWithPanel sub = new SubPointDealtWithPanel(new Integer(TrainingViewContent.pointLength));
                    sub.setData(point);
                    elements.add(sub);
                }
            }
            points.setElements(elements);
            if (result.isForbidden()
            || TOMATemplateView.getTemplateResult(_type, "contentPoint").isForbidden())
                points.setEnabled(false);
        }

        conclusion.setText(t.getContentDescriptionConclusion());
    }

    public String testTemplateElements(int type) {
        String msg = "";
        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "contentDescription");
        if (result.isMandatory()) {
            TrainingCourse tc = new TrainingCourse();
            this.getData(tc);

            if (
                    (tc.getContentDescriptionIntroduction() == null || tc.getContentDescriptionIntroduction().equals(""))
                    &&
                    (tc.getContentDescriptionConclusion() == null || tc.getContentDescriptionConclusion().equals(""))
                    &&
                    (tc.getContentDescription() == null || tc.getContentDescription().isEmpty())
            ) {
                msg = "\n" + labels.get("apostal.toma.trainingview.content") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        //size of the elements
        //introduction
        String intro = introduction.getText();
        TOMATemplateResult introResult = TOMATemplateView.getTemplateResult(type, "contentIntroduction");
        if (intro != null && introResult.getMaximum() > -1 && intro.length() > introResult.getMaximum()) {
            msg = msg + "\n" + labels.get("apostal.toma.trainingview.content.contentIntroduction") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
        }
        //points
        JComponent[] elements = points.getElements();
        int nbPoints = elements.length;
        TOMATemplateResult pointResult = TOMATemplateView.getTemplateResult(type, "contentPoint");
        for (int j = 0; j < nbPoints; j++) {
            SubPointDealtWithPanel pointPanel = (SubPointDealtWithPanel) elements[j];
            String point = pointPanel.getData();
            if (point != null && pointResult.getMaximum() > -1 && point.length() > pointResult.getMaximum())
                msg = msg + "\n" + labels.get("apostal.toma.trainingview.content.contentPoint") + " " + j + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
        }
        //conclusion
        String ccl = conclusion.getText();
        TOMATemplateResult cclResult = TOMATemplateView.getTemplateResult(type, "contentConclusion");
        if (ccl != null && cclResult.getMaximum() > -1 && ccl.length() > cclResult.getMaximum()) {
            msg = msg + "\n" + labels.get("apostal.toma.trainingview.content.contentConclusion") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
        }

        if (msg.equals(""))
            msg = null;

        return msg;
    }
}