// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.border.LineBorder;
import java.awt.*;

import apostal.toma.data.ElementNotSpecified;
import apostal.toma.database.LanguageDB;
import apostal.toma.data.Catalogue;
import apostal.toma.database.CatalogueDB;
import apostal.toma.data.Language;
import apostal.toma.data.Domain;
import apostal.toma.database.DomainDB;
import apostal.toma.database.TrainingCourseDB;
import apostal.toma.database.TrainingProgrammeDB;
import apostal.toma.database.StandaloneTrainingDB;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TrainingProgramme;
import apostal.toma.data.Unit;
import apostal.toma.database.UnitDB;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMAParameters;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.data.StandaloneTraining;
import apostal.toma.view.TOMATextField;
import apostal.toma.view.TOMAColors;

import apostal.toma.datacontrol.UnitControl;

import apostal.toma.TOMA;

import toolbox.swing.MultipleLinesLabel;

import java.lang.Class;
import java.lang.Integer;
import java.util.Vector;
import java.util.Iterator;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewDetails extends JScrollPane {
    private static int multipleElementsLength = 30;

    private Vector allowed_keywords;

    private static Vector languages;
    private Vector allowed_languages;

    static {
        languages = TOMA.getInstance().getLanguages();
    }

    private int type;

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMAMultipleLinesLabel label_partnership = new TOMAMultipleLinesLabel(10);
    TOMATextArea partnership = new TOMATextArea(3, 30);
    JComponent partnershipComponent;
    TOMAMultipleLinesLabel label_pedagogicalMethods = new TOMAMultipleLinesLabel(10);
    TOMATextArea pedagogicalMethods = new TOMATextArea(3, 30);
    JComponent pedagogicalMethodsComponent;
    TOMAMultipleLinesLabel label_courseMedia = new TOMAMultipleLinesLabel(10);
    TOMATextArea courseMedia = new TOMATextArea(3, 30);
    JComponent courseMediaComponent;
    TOMAMultipleLinesLabel label_certificates = new TOMAMultipleLinesLabel(10);
    TOMATextArea certificates = new TOMATextArea(3, 30);
    JComponent certificatesComponent;
    TOMAMultipleLinesLabel label_evaluation = new TOMAMultipleLinesLabel(10);
    TOMATextArea evaluation = new TOMATextArea(3, 30);
    JComponent evaluationComponent;
    TOMAMultipleLinesLabel label_commentNotPublished = new TOMAMultipleLinesLabel(10);
    TOMATextArea commentNotPublished = new TOMATextArea(3, 30);
    TOMAMultipleLinesLabel label_comment = new TOMAMultipleLinesLabel(10);
    TOMATextArea comment = new TOMATextArea(3, 30);
    JComponent commentComponent;
    TOMAMultipleElements keywords;
    TOMALabel label_keywords = new TOMALabel();

    TOMALabel label_languages = new TOMALabel();
    TOMAMultipleElements languagesCombo;

    TOMALabel label_domains = new TOMALabel();
    TOMAMultipleElements domainsCombo;

    TOMALabel catalogues = new TOMALabel();
    TOMALabel units = new TOMALabel();

    private TOMALabels labels;

    public TrainingViewDetails(int type) {
        try {
            labels = new TOMALabels();

            this.type = type;
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        //language
        label_languages.setText(labels.get("apostal.toma.trainingview.languages"));
        TOMATemplateResult languageResult = TOMATemplateView.getTemplateResult(type, "language");
        if (languageResult.isMandatory())
            label_languages.setText(label_languages.getText() + " (*)");
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.util.Vector");
        Object[] values = new Object[1];
        values[0] = this.languages;
        if (languageResult.getValues() != null && !languageResult.getValues().isEmpty()) {
            allowed_languages = new Vector();
            Iterator iter = languageResult.getValues().iterator();
            while (iter.hasNext()) {
                String ln_code = (String) iter.next();
                //trouver le language associ dans languages
                Iterator iter2 = languages.iterator();
                Language ln = null;
                while (iter2.hasNext() & ln == null) {
                    Language language = (Language) iter2.next();
                    if (language != null && language.getCode().equals(ln_code))
                        ln = language;
                }
                allowed_languages.add(ln);
            }
            values[0] = allowed_languages;
        } else
            allowed_languages = languages;

        languagesCombo = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes, values, 1, null, labels.get("apostal.toma.trainingview.addLanguage"), labels.get("apostal.toma.trainingview.removeLanguage"), TOMAColors.multipleElementsColor, 265, 80);
        if (languageResult.isForbidden())
            languagesCombo.setEnabled(false);

        /*label_languages.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_languages.setForeground(TOMAColors.unclickableTextColor);*/

        //domains
        Class[] classes_dom = new Class[0];
        Object[] values_dom = new Object[0];
        TOMATemplateResult domainResult = TOMATemplateView.getTemplateResult(type, "domain");
        domainsCombo = new TOMAMultipleElements("apostal.toma.view.DomainsComboBoxes", classes_dom, values_dom, 0, null, labels.get("apostal.toma.trainingview.addDomain"), labels.get("apostal.toma.trainingview.removeDomain"), TOMAColors.multipleElementsColor, 600, 80);
        if (domainResult.isForbidden())
            domainsCombo.setEnabled(false);

        label_domains.setText(labels.get("apostal.toma.trainingview.domains"));
        if (domainResult.isMandatory())
            label_domains.setText(label_domains.getText() + " (*)");

        //keywords
        label_keywords.setText(labels.get("apostal.toma.trainingview.keywords"));
        TOMATemplateResult keywordsResult = TOMATemplateView.getTemplateResult(type, "keyword");
        if (keywordsResult.isMandatory())
            label_keywords.setText(label_keywords.getText() + " (*)");
        if (keywordsResult.getMaximum() > -1)
            label_keywords.setText(label_keywords.getText() + " (" + new Integer(keywordsResult.getMaximum()) + ")");
        if (keywordsResult.getValues() != null && !keywordsResult.getValues().isEmpty()) {
            allowed_keywords = keywordsResult.getValues();
            Class[] classes2 = new Class[1];
            classes2[0] = Class.forName("java.util.Vector");
            Object[] values2 = new Object[1];
            values2[0] = allowed_keywords;
            keywords = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes2, values2, 0, null, labels.get("apostal.toma.trainingview.addKeyword"), labels.get("apostal.toma.trainingview.removeKeyword"), TOMAColors.multipleElementsColor, 360, 80);
        } else {
            Class[] classes2 = new Class[1];
            classes2[0] = Class.forName("java.lang.Integer");
            Object[] values2 = new Object[1];
            values2[0] = new Integer(TrainingViewDetails.multipleElementsLength);
            keywords = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes2, values2, 0, null, labels.get("apostal.toma.trainingview.addKeyword"), labels.get("apostal.toma.trainingview.removeKeyword"), TOMAColors.multipleElementsColor, 360, 80);
        }
        if (keywordsResult.isForbidden())
            keywords.setEnabled(false);

        //partnership
        label_partnership.setText(labels.get("apostal.toma.trainingview.partnership"));

        JScrollPane pane_partnership = new JScrollPane(partnership);
        TOMATemplateResult partnershipResult = TOMATemplateView.getTemplateResult(type, "partnership");
        if (partnershipResult.isForbidden())
            partnership.setEnabled(false);
        if (partnershipResult.isMandatory())
            label_partnership.setText(label_partnership.getText() + " (*)");
        if (partnershipResult.getMaximum() > -1)
            label_partnership.setText(label_partnership.getText() + " (" + new Integer(partnershipResult.getMaximum()) + ")");
        if (partnershipResult.getValues() != null && !partnershipResult.getValues().isEmpty()) {
            Vector v = partnershipResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox partnershipCombo = new TOMAComboBox(v);
            partnershipComponent = partnershipCombo;
        } else
            partnershipComponent = pane_partnership;

        //pedagogical Methods
        label_pedagogicalMethods.setText(labels.get("apostal.toma.trainingview.pedagogicalMethods"));

        JScrollPane pane_pedagogicalMethods = new JScrollPane(pedagogicalMethods);
        TOMATemplateResult pedagogicalMethodsResult = TOMATemplateView.getTemplateResult(type, "pedagogicalMethods");
        if (pedagogicalMethodsResult.isForbidden())
            pedagogicalMethods.setEnabled(false);
        if (pedagogicalMethodsResult.isMandatory())
            label_pedagogicalMethods.setText(label_pedagogicalMethods.getText() + " (*)");
        if (pedagogicalMethodsResult.getMaximum() > -1)
            label_pedagogicalMethods.setText(label_pedagogicalMethods.getText() + " (" + new Integer(pedagogicalMethodsResult.getMaximum()) + ")");
        if (pedagogicalMethodsResult.getValues() != null && !pedagogicalMethodsResult.getValues().isEmpty()) {
            Vector v = pedagogicalMethodsResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox pedagogicalMethodsCombo = new TOMAComboBox(v);
            pedagogicalMethodsComponent = pedagogicalMethodsCombo;
        } else
            pedagogicalMethodsComponent = pane_pedagogicalMethods;

        //course media
        label_courseMedia.setText(labels.get("apostal.toma.trainingview.courseMedia"));

        JScrollPane pane_courseMedia = new JScrollPane(courseMedia);
        TOMATemplateResult courseMediaResult = TOMATemplateView.getTemplateResult(type, "courseMedia");
        if (courseMediaResult.isForbidden())
            courseMedia.setEnabled(false);
        if (courseMediaResult.isMandatory())
            label_courseMedia.setText(label_courseMedia.getText() + " (*)");
        if (courseMediaResult.getMaximum() > -1)
            label_courseMedia.setText(label_courseMedia.getText() + " (" + new Integer(courseMediaResult.getMaximum()) + ")");
        if (courseMediaResult.getValues() != null && !courseMediaResult.getValues().isEmpty()) {
            Vector v = courseMediaResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox courseMediaCombo = new TOMAComboBox(v);
            courseMediaComponent = courseMediaCombo;
        } else
            courseMediaComponent = pane_courseMedia;

        //evaluation
        label_evaluation.setText(labels.get("apostal.toma.trainingview.evaluation"));

        JScrollPane pane_evaluation = new JScrollPane(evaluation);
        TOMATemplateResult evaluationResult = TOMATemplateView.getTemplateResult(type, "evaluation");
        if (evaluationResult.isForbidden())
            evaluation.setEnabled(false);
        if (evaluationResult.isMandatory())
            label_evaluation.setText(label_evaluation.getText() + " (*)");
        if (evaluationResult.getMaximum() > -1)
            label_evaluation.setText(label_evaluation.getText() + " (" + new Integer(evaluationResult.getMaximum()) + ")");
        if (evaluationResult.getValues() != null && !evaluationResult.getValues().isEmpty()) {
            Vector v = evaluationResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox evaluationCombo = new TOMAComboBox(v);
            evaluationComponent = evaluationCombo;
        } else
            evaluationComponent = pane_evaluation;

        //certificates
        label_certificates.setText(labels.get("apostal.toma.trainingview.certificatesOrDiplomas"));

        JScrollPane pane_certificates = new JScrollPane(certificates);
        TOMATemplateResult certificatesResult = TOMATemplateView.getTemplateResult(type, "certificatesOrDiplomas");
        if (certificatesResult.isForbidden())
            certificates.setEnabled(false);
        if (certificatesResult.isMandatory())
            label_certificates.setText(label_certificates.getText() + " (*)");
        if (certificatesResult.getMaximum() > -1)
            label_certificates.setText(label_certificates.getText() + " (" + new Integer(certificatesResult.getMaximum()) + ")");
        if (certificatesResult.getValues() != null && !certificatesResult.getValues().isEmpty()) {
            Vector v = certificatesResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox certificatesCombo = new TOMAComboBox(v);
            certificatesComponent = certificatesCombo;
        } else
            certificatesComponent = pane_certificates;

        //comment not published
        label_commentNotPublished.setText(labels.get("apostal.toma.trainingview.commentNotPublished"));

        JScrollPane pane_commentNotPublished = new JScrollPane(commentNotPublished);

        //comment
        label_comment.setText(labels.get("apostal.toma.trainingview.comment"));

        JScrollPane pane_comment = new JScrollPane(comment);
        TOMATemplateResult commentResult = TOMATemplateView.getTemplateResult(type, "comment");
        if (commentResult.isForbidden())
            comment.setEnabled(false);
        if (commentResult.isMandatory())
            label_comment.setText(label_comment.getText() + " (*)");
        if (commentResult.getMaximum() > -1)
            label_comment.setText(label_comment.getText() + " (" + new Integer(commentResult.getMaximum()) + ")");
        if (commentResult.getValues() != null && !commentResult.getValues().isEmpty()) {
            Vector v = commentResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox commentCombo = new TOMAComboBox(v);
            commentComponent = commentCombo;
        } else
            commentComponent = pane_comment;

        catalogues.setText("");
        units.setText("");

        this.getViewport().add(jPanel1);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;
        Insets insets = new Insets(5, 10, 0, 0);

        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, insets, 0, 0);

        jPanel1.add(label_partnership, cons);
        cons.gridx = 1;
        jPanel1.add(partnershipComponent, cons);
        cons.gridx = 0;
        cons.gridy = 1;
        jPanel1.add(label_pedagogicalMethods, cons);
        cons.gridx = 1;
        jPanel1.add(pedagogicalMethodsComponent, cons);
        cons.gridx = 0;
        cons.gridy = 2;
        jPanel1.add(label_courseMedia, cons);
        cons.gridx = 1;
        jPanel1.add(courseMediaComponent, cons);
        cons.gridx = 0;
        cons.gridy = 3;
        jPanel1.add(label_commentNotPublished, cons);
        cons.gridx = 1;
        jPanel1.add(pane_commentNotPublished, cons);
        cons.gridx = 2;
        cons.gridy = 2;
        jPanel1.add(label_comment, cons);
        cons.gridx = 3;
        jPanel1.add(commentComponent, cons);

        cons.gridx = 0;
        cons.gridy = 4;
        cons.gridwidth = 2;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(label_keywords, cons);
        cons.gridy = 5;
        cons.fill = fill;
        jPanel1.add(keywords, cons);

        cons.gridx = 2;
        cons.gridy = 4;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(label_languages, cons);
        cons.gridy = 5;
        cons.fill = fill;
        jPanel1.add(languagesCombo, cons);

        cons.gridx = 0;
        cons.gridy = 6;
        cons.gridwidth = 4;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(label_domains, cons);
        cons.gridy = 7;
        cons.fill = fill;
        jPanel1.add(domainsCombo, cons);
        cons.gridx = 2;
        cons.gridy = 1;
        cons.gridwidth = 1;
        jPanel1.add(label_certificates, cons);
        cons.gridx = 3;
        jPanel1.add(certificatesComponent, cons);
        cons.gridx = 2;
        cons.gridy = 0;
        jPanel1.add(label_evaluation, cons);
        cons.gridx = 3;
        jPanel1.add(evaluationComponent, cons);
        cons.gridx = 0;
        cons.gridy = 9;
        cons.gridwidth = 4;
        cons.insets = new Insets(3, 10, 3, 0);
        jPanel1.add(catalogues, cons);
        cons.gridy = 10;
        cons.insets = new Insets(0, 10, 3, 0);
        jPanel1.add(units, cons);

        //fill
        cons.gridy = 11;
        cons.gridwidth = 1;
        cons.weighty = 1.0;
        cons.insets = new Insets(0, 0, 0, 0);
        jPanel1.add(Box.createGlue(), cons);
        cons.gridx = 4;
        cons.gridy = 0;
        cons.weightx = 1.0;
        cons.weighty = 0.0;
        jPanel1.add(Box.createGlue(), cons);

    }

    /**
     * agit directement sur le tc pass en paramtre
     */
    public void getData(StandaloneTraining t) {
        //TrainingCourse tc=new TrainingCourse();

        if (!partnershipComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPartnership(partnership.getText());
        else {
            try {
                t.setPartnership((String) ((TOMAComboBox) partnershipComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setPartnership(null);
            }
        }

        if (!pedagogicalMethodsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPedagogicalMethods(pedagogicalMethods.getText());
        else {
            try {
                t.setPedagogicalMethods((String) ((TOMAComboBox) pedagogicalMethodsComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setPedagogicalMethods(null);
            }
        }

        if (!courseMediaComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setCourseMedia(courseMedia.getText());
        else {
            try {
                t.setCourseMedia((String) ((TOMAComboBox) courseMediaComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setCourseMedia(null);
            }
        }

        if (!evaluationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setEvaluation(evaluation.getText());
        else {
            try {
                t.setEvaluation((String) ((TOMAComboBox) evaluationComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setEvaluation(null);
            }
        }

        if (!certificatesComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setCertificatesOrDiplomas(certificates.getText());
        else {
            try {
                t.setCertificatesOrDiplomas((String) ((TOMAComboBox) certificatesComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setCertificatesOrDiplomas(null);
            }
        }

        if (!commentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setComment(comment.getText());
        else {
            try {
                t.setComment((String) ((TOMAComboBox) commentComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setComment(null);
            }
        }

        t.setCommentNotPublished(commentNotPublished.getText());

        //keywords
        Vector words = new Vector();
        JComponent[] kws = keywords.getElements();
        int size = kws.length;
        for (int i = 0; i < size; i++) {
            try {
                JTextField field = (JTextField) kws[i];

                if (!words.contains(field.getText()))
                    words.add(field.getText());
            } catch (java.lang.ClassCastException ex) {
                TOMAComboBox box = (TOMAComboBox) kws[i];
                String txt = (String) box.getSelectedItem();

                if (!words.contains(txt))
                    words.add(txt);
            }
        }
        t.setKeywords(words);

        //languages
        Vector lngs = new Vector();
        JComponent[] languagesComponents = languagesCombo.getElements();
        int components_size = languagesComponents.length;
        for (int i = 0; i < components_size; i++) {
            TOMAComboBox combo = (TOMAComboBox) languagesComponents[i];
            Language l = (Language) combo.getSelectedItem();
            if (!lngs.contains(l))
                lngs.add(l);
        }
        t.setLanguages(lngs);

        //domains
        Vector dmns = new Vector();
        JComponent[] domainsComponents = domainsCombo.getElements();
        int dom_components_size = domainsComponents.length;
        for (int i = 0; i < dom_components_size; i++) {
            DomainsComboBoxes combo = (DomainsComboBoxes) domainsComponents[i];
            Vector boxes = combo.getBoxes();
            if (boxes != null) {
                Iterator dom_iter = boxes.iterator();
                while (dom_iter.hasNext()) {
                    TOMAComboBox box = (TOMAComboBox) dom_iter.next();
                    try {
                        Domain d = (Domain) box.getSelectedItem();
                        if (!dmns.contains(d))
                            dmns.add(d);
                    } catch (java.lang.ClassCastException exception) {
                    }
                }
            }
        }
        t.setDomains(dmns);
    }

    public void setData(StandaloneTraining t) {
        Language toma_lng = TOMA.getInstance().getTomaParameters().getLanguage();

        if (!partnershipComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            partnership.setText(t.getPartnership());
        else
            TOMATemplateView.setTextCombo(t.getPartnership(), (TOMAComboBox) partnershipComponent);

        if (!pedagogicalMethodsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            pedagogicalMethods.setText(t.getPedagogicalMethods());
        else
            TOMATemplateView.setTextCombo(t.getPedagogicalMethods(), (TOMAComboBox) pedagogicalMethodsComponent);

        if (!courseMediaComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            courseMedia.setText(t.getCourseMedia());
        else
            TOMATemplateView.setTextCombo(t.getCourseMedia(), (TOMAComboBox) courseMediaComponent);

        if (!evaluationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            evaluation.setText(t.getEvaluation());
        else
            TOMATemplateView.setTextCombo(t.getEvaluation(), (TOMAComboBox) evaluationComponent);

        if (!certificatesComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            certificates.setText(t.getCertificatesOrDiplomas());
        else
            TOMATemplateView.setTextCombo(t.getCertificatesOrDiplomas(), (TOMAComboBox) certificatesComponent);

        if (!commentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            comment.setText(t.getComment());
        else
            TOMATemplateView.setTextCombo(t.getComment(), (TOMAComboBox) commentComponent);

        commentNotPublished.setText(t.getCommentNotPublished());

        //keywords
        Vector k = t.getKeywords();
        if (k != null) {
            Vector words = new Vector();

            Iterator iter = k.iterator();
            while (iter.hasNext()) {
                String keyword = (String) iter.next();
                if (keyword != null) {
                    if (allowed_keywords == null || allowed_keywords.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(TrainingViewDetails.multipleElementsLength));
                        field.setText(keyword);
                        words.add(field);
                    } else {
                        //combo boxes et pas text fields
                        Iterator iter2 = allowed_keywords.iterator();
                        String found = null;
                        while (iter2.hasNext() && found == null) {
                            try {
                                String kw = (String) iter2.next();
                                if (keyword.equals(kw))
                                    found = kw;
                            } catch (java.lang.ClassCastException exception) {
                            }
                        }
                        if (found == null) {
                            allowed_keywords.add(keyword);
                            found = keyword;
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_keywords);
                        box.setSelectedItem(found);
                        words.add(box);
                    }
                }
            }
            keywords.setElements(words);
        }
        TOMATemplateResult keywordsResult = TOMATemplateView.getTemplateResult(type, "keyword");
        if (keywordsResult.isForbidden())
            keywords.setEnabled(false);

        //languages
        Vector lng_combo = new Vector();
        Vector t_languages = t.getLanguages();
        if (t_languages != null) {
            Iterator t_languages_iter = t_languages.iterator();
            while (t_languages_iter.hasNext()) {
                Language lng = (Language) t_languages_iter.next();
                if (lng != null) {
                    String code = lng.getCode();

                    //trouver le language  slectionner dans languages
                    Language selectedLanguage = null;
                    Iterator languages_iter = languages.iterator();
                    while (languages_iter.hasNext() && selectedLanguage == null) {
                        Language l_found = (Language) languages_iter.next();
                        if (l_found != null && l_found.getCode().equals(code))
                            selectedLanguage = l_found;
                    }

                    if (selectedLanguage != null) {
                        TOMAComboBox combo = new TOMAComboBox(allowed_languages);
                        combo.setSelectedItem(selectedLanguage);
                        lng_combo.add(combo);
                    } else
                        TOMA.log(TOMA.SEVERE, "language " + code + " not found in the list");
                }
            }
            languagesCombo.setElements(lng_combo);
        }
        TOMATemplateResult languageResult = TOMATemplateView.getTemplateResult(type, "language");
        if (languageResult.isForbidden())
            languagesCombo.setEnabled(false);


        //apostal.toma.TOMA.printTime("details.setData: before domains");
        //domains
        Vector domainsComboBoxes = new Vector();
        Vector t_domains = t.getDomains();

        //Obtenir le vecteur ou on a enlev les info redondantes,
        //c-a-d qu'il n'y a que les chemins les plus complets:
        Vector domains_used = Domain.getLastLevelDomainsPaths(t_domains);
        Iterator itdom = domains_used.iterator();
        while (itdom.hasNext()) {
            Vector domainPath = (Vector) itdom.next();

            DomainsComboBoxes boxes = new DomainsComboBoxes();
            boxes.addSelectedDomainPath(domainPath);

            domainsComboBoxes.add(boxes);
        }

        //Obtenir le vecteur avec seulement les domaines de dernier niveau
        /*TOMA.printTime("avant reduceToLastLevelsDomains:");
        Vector domains_fils=DomainDB.reduceToLastLevelsDomains(toma_lng, t_domains);
      //vrifier si les domains renvoys, ainsi que leurs pres, sont bien tous chargs
        TOMA.printTime("aprs reduceToLastLevelsDomains:");

        Iterator itdom=domains_fils.iterator();
        while(itdom.hasNext())
        {
      Domain domain = (Domain) itdom.next();

      DomainsComboBoxes boxes=new DomainsComboBoxes();
      boxes.addSelectedDomain(domain);

      domainsComboBoxes.add(boxes);
        }
        */
        domainsCombo.setElements(domainsComboBoxes);

        TOMATemplateResult domainResult = TOMATemplateView.getTemplateResult(type, "domain");
        if (domainResult.isForbidden())
            domainsCombo.setEnabled(false);

        //apostal.toma.TOMA.printTime("details.setData: after domains, before cats");

        //catalogues
        String cat_text = "";
        Vector cats = t.getCatalogues();
        if (cats != null && !cats.isEmpty()) {
            cat_text = TOMAFonts.htmlBegin + "<font size=-1>" + labels.get("apostal.toma.trainingview.cataloguesLabel") + ":<UL>";

            Iterator iter = cats.iterator();
            while (iter.hasNext()) {
                Catalogue cat = (Catalogue) iter.next();
                CatalogueDB catdb = new CatalogueDB(cat);
                //charger tout mais pas les listes
                catdb.loadById(toma_lng, true, false);

                //liste des catalogues
                String list_cats = cat.getTitle();
                int idSuperCatalogue = cat.getIdSuperCatalogue();
                while (idSuperCatalogue > -1) {
                    Catalogue c = new Catalogue(idSuperCatalogue);
                    CatalogueDB cdb = new CatalogueDB(c);
                    //charger tout mais pas les listes
                    cdb.loadById(toma_lng, true, false);
                    list_cats = c.getTitle() + " / " + list_cats;

                    idSuperCatalogue = c.getIdSuperCatalogue();
                }
                cat_text = cat_text + "<LI>" + list_cats + "</LI>";
            }
        }
        //cat_text=cat_text+TOMAFonts.htmlEnd;
        catalogues.setTextWithLowerCase(cat_text);

        //apostal.toma.TOMA.printTime("details.setData: after cats, before units");

        //units
        String unit_text = "";

        String name = t.getClass().getName();
        StandaloneTrainingDB tdb = null;
        if (name.equals("apostal.toma.data.TrainingCourse"))
            tdb = new TrainingCourseDB((TrainingCourse) t);
        else if (name.equals("apostal.toma.data.TrainingProgramme"))
            tdb = new TrainingProgrammeDB((TrainingProgramme) t);
        else {
            TOMA.log(TOMA.SEVERE, "not a trainingCourse nor a training Programme is used in TrainingViewDetails.setData: " + name);
        }

        if (tdb != null) {
            Vector txt_units = tdb.getUnitsCreatedByCopy(toma_lng);
            if (units != null && !txt_units.isEmpty()) {
                unit_text = TOMAFonts.htmlBegin + "<font size=-1>" + labels.get("apostal.toma.trainingview.unitsLabel") + ":<UL>";

                Iterator iter = txt_units.iterator();
                UnitControl unitControl = new UnitControl();
                String labelInTP = " " + labels.get("apostal.toma.trainingview.unitsInTrainingProgramme") + " ";
                while (iter.hasNext()) {
                    Unit u = (Unit) iter.next();
                    UnitDB udb = new UnitDB(u);
                    udb.loadById(toma_lng, true);

                    TrainingProgramme tp = unitControl.getTrainingProgramme(u, false);

                    //unit_text=unit_text+"<LI>"+u.getTitle()+" ("+u.getCode()+")";
                    unit_text = unit_text + "<LI>" + u + labelInTP + tp;
                }
            }
        }
        //unit_text=unit_text+TOMAFonts.htmlEnd;
        units.setTextWithLowerCase(unit_text);
        //apostal.toma.TOMA.printTime("details.setData: after units");
    }

    public String testTemplateElements(int type) {
        //formation pour les tests de template uniquement
        apostal.toma.data.TrainingCourse t = new apostal.toma.data.TrainingCourse();
        this.getData(t);

        String msg = "";

        String msg_partnership = TOMATemplateView.testTemplateElement(type, "partnership", t.getPartnership(), labels.get("apostal.toma.trainingview.partnership"));
        if (msg_partnership != null)
            msg = msg + "\n" + msg_partnership;

        String msg_ped = TOMATemplateView.testTemplateElement(type, "pedagogicalMethods", t.getPedagogicalMethods(), labels.get("apostal.toma.trainingview.pedagogicalMethods"));
        if (msg_ped != null)
            msg = msg + "\n" + msg_ped;

        String msg_courseMedia = TOMATemplateView.testTemplateElement(type, "courseMedia", t.getCourseMedia(), labels.get("apostal.toma.trainingview.courseMedia"));
        if (msg_courseMedia != null)
            msg = msg + "\n" + msg_courseMedia;

        String msg_eval = TOMATemplateView.testTemplateElement(type, "evaluation", t.getEvaluation(), labels.get("apostal.toma.trainingview.evaluation"));
        if (msg_eval != null)
            msg = msg + "\n" + msg_eval;

        String msg_cert = TOMATemplateView.testTemplateElement(type, "certificatesOrDiplomas", t.getCertificatesOrDiplomas(), labels.get("apostal.toma.trainingview.certificatesOrDiplomas"));
        if (msg_cert != null)
            msg = msg + "\n" + msg_cert;

        String msg_comment = TOMATemplateView.testTemplateElement(type, "comment", t.getComment(), labels.get("apostal.toma.trainingview.comment"));
        if (msg_comment != null)
            msg = msg + "\n" + msg_comment;

        String msg_kw = TOMATemplateView.testTemplateElement(type, "keyword", t.getKeywords(), labels.get("apostal.toma.trainingview.keywords"));
        if (msg_kw != null)
            msg = msg + "\n" + msg_kw;

        String msg_lng = TOMATemplateView.testTemplateElement(type, "language", t.getLanguages(), labels.get("apostal.toma.trainingview.languages"));
        if (msg_lng != null)
            msg = msg + "\n" + msg_lng;

        String msg_dom = TOMATemplateView.testTemplateElement(type, "domain", t.getDomains(), labels.get("apostal.toma.trainingview.domains"));
        if (msg_dom != null)
            msg = msg + "\n" + msg_dom;

        if (msg.equals(""))
            return null;
        else
            return msg;
    }


}
