// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import java.awt.*;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.data.ElementNotSpecified;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.view.TOMATextField;
import apostal.toma.view.TrainingView;
import apostal.toma.view.TOMAColors;
import apostal.toma.data.StandaloneTraining;
import apostal.toma.TOMA;

import toolbox.swing.MultipleLinesLabel;

import java.lang.Class;
import java.lang.Integer;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewInscriptionDetails extends JScrollPane {
    private static int multipleElementsLength = 30;

    private Vector allowed_audiences;
    private Vector allowed_prerequisites;

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMAMultipleLinesLabel label_duration = new TOMAMultipleLinesLabel(10);
    TOMATextArea duration = new TOMATextArea(3, 30);
    JComponent durationComponent;

    TOMAMultipleLinesLabel label_price = new TOMAMultipleLinesLabel(10);
    TOMATextArea price = new TOMATextArea(3, 30);
    JComponent priceComponent;

    TOMAMultipleLinesLabel label_priceComment = new TOMAMultipleLinesLabel(10);
    TOMATextArea priceComment = new TOMATextArea(3, 30);
    JComponent priceCommentComponent;

    TOMAMultipleLinesLabel label_paymentFacilities = new TOMAMultipleLinesLabel(10);
    TOMATextArea paymentFacilities = new TOMATextArea(3, 30);
    JComponent paymentFacilitiesComponent;

    TOMAMultipleLinesLabel label_inscriptionConditions = new TOMAMultipleLinesLabel(10);
    TOMATextArea inscriptionConditions = new TOMATextArea(3, 30);
    JComponent inscriptionConditionsComponent;

    TOMALabel label_audiences = new TOMALabel();
    TOMALabel label_prerequisites = new TOMALabel();
    TOMAMultipleElements audiences;
    TOMAMultipleElements prerequisites;

    private TOMALabels labels;
    private int type;

    public TrainingViewInscriptionDetails(int type) {
        try {
            labels = new TOMALabels();
            this.type = type;
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        //audiences
        JPanel panelLabelAudiences = new JPanel();
        panelLabelAudiences.setLayout(new FlowLayout(FlowLayout.LEFT));
        panelLabelAudiences.setBackground(TOMAColors.listsLabelBackgroundColor);
        panelLabelAudiences.add(label_audiences);
        label_audiences.setText(labels.get("apostal.toma.trainingview.audiences"));
        TOMATemplateResult audiencesResult = TOMATemplateView.getTemplateResult(type, "audience");
        if (audiencesResult.isMandatory())
            label_audiences.setText(label_audiences.getText() + " (*)");
        if (audiencesResult.getMaximum() > -1)
            label_audiences.setText(label_audiences.getText() + " (" + new Integer(audiencesResult.getMaximum()) + ")");
        if (audiencesResult.getValues() != null && !audiencesResult.getValues().isEmpty()) {
            allowed_audiences = audiencesResult.getValues();
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.util.Vector");
            Object[] values = new Object[1];
            values[0] = allowed_audiences;
            audiences = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes, values, 0, null, labels.get("apostal.toma.trainingview.addAudience"), labels.get("apostal.toma.trainingview.removeAudience"), TOMAColors.multipleElementsColor, 360, 80);
        } else {
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.lang.Integer");
            Object[] values = new Object[1];
            values[0] = new Integer(TrainingViewInscriptionDetails.multipleElementsLength);
            audiences = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 0, null, labels.get("apostal.toma.trainingview.addAudience"), labels.get("apostal.toma.trainingview.removeAudience"), TOMAColors.multipleElementsColor, 360, 80);
        }
        if (audiencesResult.isForbidden())
            audiences.setEnabled(false);

        /*label_audiences.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_audiences.setForeground(TOMAColors.unclickableTextColor);*/

        //prerequisites
        JPanel panelLabelPrerequisites = new JPanel();
        panelLabelPrerequisites.setLayout(new FlowLayout(FlowLayout.LEFT));
        panelLabelPrerequisites.setBackground(TOMAColors.listsLabelBackgroundColor);
        panelLabelPrerequisites.add(label_prerequisites);
        label_prerequisites.setText(labels.get("apostal.toma.trainingview.prerequisites"));
        TOMATemplateResult prerequisitesResult = TOMATemplateView.getTemplateResult(type, "prerequisites");

        if (prerequisitesResult.isMandatory())
            label_prerequisites.setText(label_prerequisites.getText() + " (*)");
        if (prerequisitesResult.getMaximum() > -1)
            label_prerequisites.setText(label_prerequisites.getText() + " (" + new Integer(prerequisitesResult.getMaximum()) + ")");
        if (prerequisitesResult.getValues() != null && !prerequisitesResult.getValues().isEmpty()) {
            allowed_prerequisites = prerequisitesResult.getValues();
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.util.Vector");
            Object[] values = new Object[1];
            values[0] = allowed_prerequisites;
            prerequisites = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes, values, 0, null, labels.get("apostal.toma.trainingview.addPrerequisite"), labels.get("apostal.toma.trainingview.removePrerequisite"), TOMAColors.multipleElementsColor, 360, 80);
        } else {
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.lang.Integer");
            Object[] values = new Object[1];
            values[0] = new Integer(TrainingViewInscriptionDetails.multipleElementsLength);
            prerequisites = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 0, null, labels.get("apostal.toma.trainingview.addPrerequisite"), labels.get("apostal.toma.trainingview.removePrerequisite"), TOMAColors.multipleElementsColor, 360, 80);
        }
        if (prerequisitesResult.isForbidden())
            prerequisites.setEnabled(false);

        /*label_prerequisites.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_prerequisites.setForeground(TOMAColors.unclickableTextColor);*/

        //duration
        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        label_duration.setText(labels.get("apostal.toma.trainingview.duration"));

        JScrollPane pane_duration = new JScrollPane(duration);
        TOMATemplateResult durationResult = TOMATemplateView.getTemplateResult(type, "duration");
        if (durationResult.isForbidden())
            duration.setEnabled(false);
        if (durationResult.isMandatory())
            label_duration.setText(label_duration.getText() + " (*)");
        if (durationResult.getMaximum() > -1)
            label_duration.setText(label_duration.getText() + " (" + new Integer(durationResult.getMaximum()) + ")");
        if (durationResult.getValues() != null && !durationResult.getValues().isEmpty()) {
            Vector v = durationResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox durationCombo = new TOMAComboBox(v);
            durationComponent = durationCombo;
        } else
            durationComponent = pane_duration;

        //price
        label_price.setText(labels.get("apostal.toma.trainingview.price"));

        JScrollPane pane_price = new JScrollPane(price);
        TOMATemplateResult priceResult = TOMATemplateView.getTemplateResult(type, "price");
        if (priceResult.isForbidden())
            price.setEnabled(false);
        if (priceResult.isMandatory())
            label_price.setText(label_price.getText() + " (*)");
        if (priceResult.getMaximum() > -1)
            label_price.setText(label_price.getText() + " (" + new Integer(priceResult.getMaximum()) + ")");
        if (priceResult.getValues() != null && !priceResult.getValues().isEmpty()) {
            Vector v = priceResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox priceCombo = new TOMAComboBox(v);
            priceComponent = priceCombo;
        } else
            priceComponent = pane_price;

        //price comment
        label_priceComment.setText(labels.get("apostal.toma.trainingview.priceComment"));

        JScrollPane pane_priceComment = new JScrollPane(priceComment);
        TOMATemplateResult priceCommentResult = TOMATemplateView.getTemplateResult(type, "priceComment");
        if (priceCommentResult.isForbidden())
            priceComment.setEnabled(false);
        if (priceCommentResult.isMandatory())
            label_priceComment.setText(label_priceComment.getText() + " (*)");
        if (priceCommentResult.getMaximum() > -1)
            label_priceComment.setText(label_priceComment.getText() + " (" + new Integer(priceCommentResult.getMaximum()) + ")");
        if (priceCommentResult.getValues() != null && !priceCommentResult.getValues().isEmpty()) {
            Vector v = priceCommentResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox priceCommentCombo = new TOMAComboBox(v);
            priceCommentComponent = priceCommentCombo;
        } else
            priceCommentComponent = pane_priceComment;

        //paymentFacilities
        label_paymentFacilities.setText(labels.get("apostal.toma.trainingview.paymentFacilities"));

        JScrollPane pane_paymentFacilities = new JScrollPane(paymentFacilities);
        TOMATemplateResult paymentFacilitiesResult = TOMATemplateView.getTemplateResult(type, "paymentFacilities");
        if (paymentFacilitiesResult.isForbidden())
            paymentFacilities.setEnabled(false);
        if (paymentFacilitiesResult.isMandatory())
            label_paymentFacilities.setText(label_paymentFacilities.getText() + " (*)");
        if (paymentFacilitiesResult.getMaximum() > -1)
            label_paymentFacilities.setText(label_paymentFacilities.getText() + " (" + new Integer(paymentFacilitiesResult.getMaximum()) + ")");
        if (paymentFacilitiesResult.getValues() != null && !paymentFacilitiesResult.getValues().isEmpty()) {
            Vector v = paymentFacilitiesResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox paymentFacilitiesCombo = new TOMAComboBox(v);
            paymentFacilitiesComponent = paymentFacilitiesCombo;
        } else
            paymentFacilitiesComponent = pane_paymentFacilities;

        //inscriptionConditions
        label_inscriptionConditions.setText(labels.get("apostal.toma.trainingview.inscriptionConditions"));

        JScrollPane pane_inscriptionConditions = new JScrollPane(inscriptionConditions);
        TOMATemplateResult inscriptionConditionsResult = TOMATemplateView.getTemplateResult(type, "inscriptionConditions");
        if (inscriptionConditionsResult.isForbidden())
            inscriptionConditions.setEnabled(false);
        if (inscriptionConditionsResult.isMandatory())
            label_inscriptionConditions.setText(label_inscriptionConditions.getText() + " (*)");
        if (inscriptionConditionsResult.getMaximum() > -1)
            label_inscriptionConditions.setText(label_inscriptionConditions.getText() + " (" + new Integer(inscriptionConditionsResult.getMaximum()) + ")");
        if (inscriptionConditionsResult.getValues() != null && !inscriptionConditionsResult.getValues().isEmpty()) {
            Vector v = inscriptionConditionsResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox inscriptionConditionsCombo = new TOMAComboBox(v);
            inscriptionConditionsComponent = inscriptionConditionsCombo;
        } else
            inscriptionConditionsComponent = pane_inscriptionConditions;

        this.setViewportView(jPanel1);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;
        Insets insets = new Insets(0, 10, 5, 0);
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, insets, 0, 0);

        jPanel1.add(label_duration, cons);
        cons.gridx = 1;
        jPanel1.add(durationComponent, cons);
        cons.gridx = 0;
        cons.gridy = 1;
        jPanel1.add(label_price, cons);
        cons.gridx = 1;
        jPanel1.add(priceComponent, cons);
        cons.gridx = 0;
        cons.gridy = 2;
        jPanel1.add(label_priceComment, cons);
        cons.gridx = 1;
        jPanel1.add(priceCommentComponent, cons);
        cons.gridx = 2;
        cons.gridy = 0;
        jPanel1.add(label_paymentFacilities, cons);
        cons.gridx = 3;
        jPanel1.add(paymentFacilitiesComponent, cons);
        cons.gridx = 2;
        cons.gridy = 1;
        jPanel1.add(label_inscriptionConditions, cons);
        cons.gridx = 3;
        jPanel1.add(inscriptionConditionsComponent, cons);
        cons.gridx = 0;
        cons.gridy = 3;
        cons.gridwidth = 2;
        jPanel1.add(panelLabelAudiences, cons);
        cons.gridx = 0;
        cons.gridy = 4;
        cons.gridheight = 3;
        jPanel1.add(audiences, cons);
        cons.gridx = 2;
        cons.gridy = 3;
        cons.gridheight = 1;
        jPanel1.add(panelLabelPrerequisites, cons);
        cons.gridy = 4;
        cons.gridheight = 3;
        jPanel1.add(prerequisites, cons);

        //fill
        cons.gridx = 0;
        cons.gridy = 7;
        cons.gridwidth = 5;
        cons.gridheight = 1;
        cons.weighty = 1.0;
        cons.insets = new Insets(0, 0, 0, 0);
        jPanel1.add(Box.createGlue(), cons);
        cons.gridx = 4;
        cons.gridy = 0;
        cons.gridwidth = 1;
        cons.weightx = 1.0;
        cons.weighty = 0.0;
        jPanel1.add(Box.createGlue(), cons);
    }

    public void getData(StandaloneTraining t) {
        if (!durationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setDuration(duration.getText());
        else {
            try {
                t.setDuration((String) ((TOMAComboBox) durationComponent).getSelectedItem());
            } catch (java.lang.ClassCastException exception) {
                t.setDuration(null);
            }
        }

        if (!priceComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPrice(price.getText());
        else {
            try {
                t.setPrice((String) ((TOMAComboBox) priceComponent).getSelectedItem());
            } catch (java.lang.ClassCastException exception) {
                t.setPrice(null);
            }
        }

        if (!priceCommentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPriceComment(priceComment.getText());
        else {
            try {
                t.setPriceComment((String) ((TOMAComboBox) priceCommentComponent).getSelectedItem());
            } catch (java.lang.ClassCastException exception) {
                t.setPriceComment(null);
            }
        }

        if (!paymentFacilitiesComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPaymentFacilities(paymentFacilities.getText());
        else {
            try {
                t.setPaymentFacilities((String) ((TOMAComboBox) paymentFacilitiesComponent).getSelectedItem());
            } catch (java.lang.ClassCastException exception) {
                t.setPaymentFacilities(null);
            }
        }

        if (!inscriptionConditionsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setInscriptionConditions(inscriptionConditions.getText());
        else {
            try {
                t.setInscriptionConditions((String) ((TOMAComboBox) inscriptionConditionsComponent).getSelectedItem());
            } catch (java.lang.ClassCastException exception) {
                t.setInscriptionConditions(null);
            }
        }

        //audiences
        Vector t_audiences = new Vector();
        JComponent[] audiences_elements = audiences.getElements();
        int size = audiences_elements.length;
        for (int i = 0; i < size; i++) {
            try {
                JTextField field = (JTextField) audiences_elements[i];
                if (!t_audiences.contains(field.getText()))
                    t_audiences.add(field.getText());
            } catch (java.lang.ClassCastException ex) {
                TOMAComboBox box = (TOMAComboBox) audiences_elements[i];
                String txt = (String) box.getSelectedItem();
                if (!t_audiences.contains(txt))
                    t_audiences.add(txt);
            }
        }
        t.setAudiences(t_audiences);

        //prerequisites
        Vector t_prerequisites = new Vector();
        JComponent[] prerequisites_elements = prerequisites.getElements();
        int prsize = prerequisites_elements.length;
        for (int i = 0; i < prsize; i++) {
            try {
                JTextField field = (JTextField) prerequisites_elements[i];
                if (!t_prerequisites.contains(field.getText()))
                    t_prerequisites.add(field.getText());
            } catch (java.lang.ClassCastException ex) {
                TOMAComboBox box = (TOMAComboBox) prerequisites_elements[i];
                String txt = (String) box.getSelectedItem();
                if (!t_prerequisites.contains(txt))
                    t_prerequisites.add(txt);
            }
        }
        t.setPrerequisites(t_prerequisites);
    }

    public void setData(StandaloneTraining t) {
        if (!durationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            duration.setText(t.getDuration());
        else
            TOMATemplateView.setTextCombo(t.getDuration(), (TOMAComboBox) durationComponent);

        if (!priceComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            price.setText(t.getPrice());
        else
            TOMATemplateView.setTextCombo(t.getPrice(), (TOMAComboBox) priceComponent);

        if (!priceCommentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            priceComment.setText(t.getPriceComment());
        else
            TOMATemplateView.setTextCombo(t.getPriceComment(), (TOMAComboBox) priceCommentComponent);

        if (!paymentFacilitiesComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            paymentFacilities.setText(t.getPaymentFacilities());
        else
            TOMATemplateView.setTextCombo(t.getPaymentFacilities(), (TOMAComboBox) paymentFacilitiesComponent);

        if (!inscriptionConditionsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            inscriptionConditions.setText(t.getInscriptionConditions());
        else
            TOMATemplateView.setTextCombo(t.getInscriptionConditions(), (TOMAComboBox) inscriptionConditionsComponent);

        //audiences
        Vector au = t.getAudiences();
        if (au != null) {
            Iterator iter = au.iterator();
            Vector audiences_elements = new Vector();
            while (iter.hasNext()) {
                String audience = (String) iter.next();
                if (audience != null) {
                    if (allowed_audiences == null || allowed_audiences.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(TrainingViewInscriptionDetails.multipleElementsLength));
                        field.setText(audience);
                        audiences_elements.add(field);
                    } else {
                        //combo boxes et pas text fields
                        Iterator iter2 = allowed_audiences.iterator();
                        String found = null;
                        while (iter2.hasNext() && found == null) {
                            try {
                                String aud = (String) iter2.next();
                                if (audience.equals(aud))
                                    found = aud;
                            } catch (java.lang.ClassCastException exception) {
                            }
                        }
                        if (found == null) {
                            allowed_audiences.add(audience);
                            found = audience;
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_audiences);
                        box.setSelectedItem(found);
                        audiences_elements.add(box);
                    }
                }
            }
            audiences.setElements(audiences_elements);
        }
        TOMATemplateResult audiencesResult = TOMATemplateView.getTemplateResult(type, "audience");
        if (audiencesResult.isForbidden())
            audiences.setEnabled(false);

        //prerequisites
        Vector pr = t.getPrerequisites();
        if (pr != null) {
            Iterator priter = pr.iterator();
            Vector prerequisites_elements = new Vector();
            while (priter.hasNext()) {
                String prerequisite = (String) priter.next();
                if (prerequisite != null) {
                    if (allowed_prerequisites == null || allowed_prerequisites.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(TrainingViewInscriptionDetails.multipleElementsLength));
                        field.setText(prerequisite);
                        prerequisites_elements.add(field);
                    } else {
                        //combo boxes et pas text fields
                        Iterator iter2 = allowed_prerequisites.iterator();
                        String found = null;
                        while (iter2.hasNext() && found == null) {
                            try {
                                String pre = (String) iter2.next();
                                if (prerequisite.equals(pre))
                                    found = pre;
                            } catch (java.lang.ClassCastException exception) {
                            }
                        }
                        if (found == null) {
                            allowed_prerequisites.add(prerequisite);
                            found = prerequisite;
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_prerequisites);
                        box.setSelectedItem(found);
                        prerequisites_elements.add(box);
                    }
                }
            }
            prerequisites.setElements(prerequisites_elements);
        }

        TOMATemplateResult prerequisitesResult = TOMATemplateView.getTemplateResult(type, "prerequisites");
        if (prerequisitesResult.isForbidden())
            prerequisites.setEnabled(false);

    }

    public String testTemplateElements(int type) {
        //formation pour les tests de template uniquement
        apostal.toma.data.TrainingCourse t = new apostal.toma.data.TrainingCourse();
        this.getData(t);

        String msg = "";

        String msg_duration = TOMATemplateView.testTemplateElement(type, "duration", t.getDuration(), labels.get("apostal.toma.trainingview.duration"));
        if (msg_duration != null)
            msg = msg + "\n" + msg_duration;

        String msg_price = TOMATemplateView.testTemplateElement(type, "price", t.getPrice(), labels.get("apostal.toma.trainingview.price"));
        if (msg_price != null)
            msg = msg + "\n" + msg_price;

        String msg_priceComment = TOMATemplateView.testTemplateElement(type, "priceComment", t.getPriceComment(), labels.get("apostal.toma.trainingview.priceComment"));
        if (msg_priceComment != null)
            msg = msg + "\n" + msg_priceComment;

        String msg_paymentF = TOMATemplateView.testTemplateElement(type, "paymentFacilities", t.getPaymentFacilities(), labels.get("apostal.toma.trainingview.paymentFacilities"));
        if (msg_paymentF != null)
            msg = msg + "\n" + msg_paymentF;

        String msg_insc = TOMATemplateView.testTemplateElement(type, "inscriptionConditions", t.getInscriptionConditions(), labels.get("apostal.toma.trainingview.inscriptionConditions"));
        if (msg_insc != null)
            msg = msg + "\n" + msg_insc;

        String msg_aud = TOMATemplateView.testTemplateElement(type, "audience", t.getAudiences(), labels.get("apostal.toma.trainingview.audiences"));
        if (msg_aud != null)
            msg = msg + "\n" + msg_aud;

        String msg_pre = TOMATemplateView.testTemplateElement(type, "prerequisites", t.getPrerequisites(), labels.get("apostal.toma.trainingview.prerequisites"));
        if (msg_pre != null)
            msg = msg + "\n" + msg_pre;

        if (msg.equals(""))
            return null;
        else
            return msg;
    }

}
