// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import apostal.toma.datacontrol.LocationsControl;
import apostal.toma.data.*;
import apostal.toma.TOMA;
import apostal.toma.database.LocationDB;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewLocations extends JScrollPane implements ActionListener, ListSelectionListener {
    private static ImageIcon addIcon;
    private static ImageIcon addPressedIcon;
    private static ImageIcon removeIcon;
    private static ImageIcon removePressedIcon;
    private static Vector locations;

    static {
        LocationsControl control = new LocationsControl();
        locations = control.loadLocations(false);

        addIcon = new ImageIcon(TOMAConstants.addIconPath);
        addPressedIcon = new ImageIcon(TOMAConstants.addPressedIconPath);
        removeIcon = new ImageIcon(TOMAConstants.removeIconPath);
        removePressedIcon = new ImageIcon(TOMAConstants.removePressedIconPath);
    }

    public static void refreshLists() {
        LocationsControl control = new LocationsControl();
        locations = control.loadLocations(false);
    }

    public void updateLocations() {
        //mettre  jour la liste des teachers existants
        existingLocations.setListData(locations);

        //mettre  jour les teachers chargs
        Training tc = new TrainingCourse();
        this.getData(tc);
        if (tc != null) {
            Vector tcLocations = tc.getLocations();
            Vector newLocations = new Vector();
            if (tcLocations != null) {
                Iterator it = tcLocations.iterator();
                while (it.hasNext()) {
                    Location l = (Location) it.next();
                    boolean found = false;
                    Iterator it2 = locations.iterator();
                    while (it2.hasNext() && !found) {
                        Location l2 = (Location) it2.next();
                        if (l2 != null && l != null && l2.getIdLocation() == l.getIdLocation()) {
                            newLocations.add(l2);
                            found = true;
                        }
                    }
                }
            }
            tc.setLocations(newLocations);
            this.setData(tc);
        }
    }

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMALabel label_existingLocations = new TOMALabel();
    JList existingLocations = new JList(locations);
    JScrollPane locationsPane = new JScrollPane();

    JButton addLocation = new JButton();
    TOMALabel label_locations = new TOMALabel();

    Vector trainingLocations = new Vector();
    JList trainingLocationsList = new JList(trainingLocations);
    JScrollPane trainingLocationsPane = new JScrollPane();

    JButton remove = new JButton();

    private TOMALabels labels;

    /*****************locationsData*****************/
    private JScrollPane locationsDataScrollPane;
    private JPanel locationsDataPane;
    private TOMALabel locationsDenomination;
    private TOMALabel locationsCompleteName;
    private TOMALabel locationsTel;
    private TOMALabel locationsFax;
    private TOMALabel locationsEmail;
    private TOMALabel locationsAddress;
    private TOMALabel locationsArea;
    private TOMALabel locationsAccessDescription;
    private TOMALabel locationsAccessComment;
    private TOMALabel locationsAccessFacilities;
    private TOMALabel locationsImages;

    public TrainingViewLocations(int type) {
        try {
            labels = new TOMALabels();
            jbInit(type);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit(int type) throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        label_existingLocations.setText(labels.get("apostal.toma.trainingview.locations.existingLocations"));
        existingLocations.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        existingLocations.setListData(locations);
        existingLocations.setVisibleRowCount(10);
        existingLocations.setFixedCellWidth(200);
        existingLocations.setBackground(TOMAColors.editingFieldColor);
        trainingLocationsList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        trainingLocationsList.setVisibleRowCount(10);
        trainingLocationsList.setFixedCellWidth(200);
        trainingLocationsList.setBackground(TOMAColors.editingFieldColor);
        trainingLocationsList.addListSelectionListener(this);

        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);
        Insets insets = new Insets(0, 0, 0, 0);

        addLocation.setIcon(addIcon);
        addLocation.setPressedIcon(addPressedIcon);
        addLocation.setBorder(border);
        addLocation.setMargin(insets);
        addLocation.setBackground(TOMAColors.trainingTabBackgroundColor);
        addLocation.setActionCommand("add");
        addLocation.addActionListener(this);
        label_locations.setText(labels.get("apostal.toma.trainingview.locations.trainingLocations"));

        remove.setIcon(removeIcon);
        remove.setPressedIcon(removePressedIcon);
        remove.setBorder(border);
        remove.setMargin(insets);
        remove.setBackground(TOMAColors.trainingTabBackgroundColor);
        remove.setActionCommand("remove");
        remove.addActionListener(this);

        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "location");
        if (result.isForbidden()) {
            addLocation.setEnabled(false);
            remove.setEnabled(false);
            trainingLocationsList.setEnabled(false);
        }

        locationsPane.getViewport().add(existingLocations);
        trainingLocationsPane.getViewport().add(trainingLocationsList);

        this.getViewport().add(jPanel1, null);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;

        jPanel1.add(label_existingLocations, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(locationsPane, new GridBagConstraints(0, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(addLocation, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0
                , anchor, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(remove, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0
                , anchor, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(label_locations, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(trainingLocationsPane, new GridBagConstraints(2, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));

        //fill
        jPanel1.add(Box.createGlue(), new GridBagConstraints(0, 3, 1, 1, 0.0, 1.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(Box.createGlue(), new GridBagConstraints(3, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));

        /*****************locationsData*****************/
        locationsDataScrollPane = new JScrollPane();
        locationsDataPane = new JPanel();
        locationsDataPane.setLayout(new BoxLayout(locationsDataPane, BoxLayout.Y_AXIS));
        locationsDataPane.setBackground(TOMAColors.auxBackgroundColor2);
        locationsDenomination = new TOMALabel();
        locationsDataPane.add(locationsDenomination);
        locationsCompleteName = new TOMALabel();
        locationsDataPane.add(locationsCompleteName);
        locationsTel = new TOMALabel();
        locationsDataPane.add(locationsTel);
        locationsFax = new TOMALabel();
        locationsDataPane.add(locationsFax);
        locationsEmail = new TOMALabel();
        locationsDataPane.add(locationsEmail);
        locationsAddress = new TOMALabel();
        locationsDataPane.add(locationsAddress);
        locationsArea = new TOMALabel();
        locationsDataPane.add(locationsArea);
        locationsAccessDescription = new TOMALabel();
        locationsDataPane.add(locationsAccessDescription);
        locationsAccessComment = new TOMALabel();
        locationsDataPane.add(locationsAccessComment);
        locationsAccessFacilities = new TOMALabel();
        locationsDataPane.add(locationsAccessFacilities);
        locationsImages = new TOMALabel();
        locationsDataPane.add(locationsImages);
        locationsDataScrollPane.setViewportView(locationsDataPane);
        locationsDataScrollPane.setPreferredSize(new Dimension(200, 200));
        jPanel1.add(locationsDataScrollPane, new GridBagConstraints(3, 0, 1, 3, 0.0, 0.0, anchor, fill, new Insets(5, 5, 5, 5), 0, 0));
    }

    public void setLocationsData(Location location) {
        String denomination = (location.getDenomination() == null) ? "" : location.getDenomination();
        locationsDenomination.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-weight: bold\">" + denomination + "</font>" + TOMAFonts.htmlEnd);

        String completeName = (location.getCompleteName() == null) ? "" : location.getCompleteName();
        locationsCompleteName.setTextWithLowerCase(labels.get("apostal.toma.location.completename") + ": " + completeName);

        String tel = (location.getTel() == null) ? "" : location.getTel();
        locationsTel.setTextWithLowerCase(labels.get("apostal.toma.location.telephone") + ": " + tel);

        String fax = (location.getFax() == null) ? "" : location.getFax();
        locationsFax.setTextWithLowerCase(labels.get("apostal.toma.location.fax") + ": " + fax);

        String email = (location.getEmail() == null) ? "" : location.getEmail();
        locationsEmail.setTextWithLowerCase(labels.get("apostal.toma.location.email") + ": " + email);

        if (location.getAddress() != null)
            locationsAddress.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-size: 10pt;\">" + labels.get("apostal.toma.location.address") + ": " + "<table><tr><td style=\"font-size: 10pt;\">" + location.getAddress().toHTMLString() + "</td></tr></table></font>" + TOMAFonts.htmlEnd);

        Area area = location.getArea();
        String a = labels.get("apostal.toma.location.area") + ": ";
        if (area != null) {
            LocationsControl control = new LocationsControl();
            Area[] areas = control.getFirstAndSecondArea(area);

            if (areas[0] != null)
                a = a + areas[0];
            if (areas[1] != null)
                a = a + " / " + areas[1];
        }
        locationsArea.setTextWithLowerCase(a);

        String accessDescription = (location.getAccessDescription() == null) ? "" : location.getAccessDescription();
        locationsAccessDescription.setTextWithLowerCase(labels.get("apostal.toma.location.access_description") + ": " + accessDescription);

        String accessComment = (location.getAccessComment() == null) ? "" : location.getAccessComment();
        locationsAccessComment.setTextWithLowerCase(labels.get("apostal.toma.location.acccess_comment") + ": " + accessComment);

        String accessFacilities = (location.getAccessFacilities() == null) ? "" : location.getAccessFacilities();
        locationsAccessFacilities.setTextWithLowerCase(labels.get("apostal.toma.location.access_facilities") + ": " + accessFacilities);

        String i = TOMAFonts.htmlBegin + "<font style=\"font-size: 10pt;\">" + labels.get("apostal.toma.location.images") + ":" + "<table style=\"font-size: 10pt;\"><tr><td>";
        if (location.getImages() != null) {
            Iterator it = location.getImages().iterator();
            while (it.hasNext()) {
                i = i + "<P>" + (String) it.next() + "</P>";
            }
        }
        i = i + "</td></tr></table></font>" + TOMAFonts.htmlEnd;
        locationsImages.setTextWithLowerCase(i);
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();

        if (cmd != null) {
            if (cmd.equals("add")) {
                //rcuprer le location slectionn
                Location t = (Location) existingLocations.getSelectedValue();
                if (t != null && !trainingLocations.contains(t)) {
                    trainingLocations.add(t);
                    trainingLocationsList.setListData(trainingLocations);
                }
            } else if (cmd.equals("remove")) {
                Location t = (Location) trainingLocationsList.getSelectedValue();
                if (t != null) {
                    trainingLocations.remove(t);
                    trainingLocationsList.setListData(trainingLocations);
                }
            }
        }
    }

    public void valueChanged(ListSelectionEvent e) {
        Location l = (Location) trainingLocationsList.getSelectedValue();
        if (l != null) {
            LocationsControl control = new LocationsControl();
            control.loadLocation(l, true);
            this.setLocationsData(l);
        }
    }

    public void getData(Training t) {
        t.setLocations(trainingLocations);
    }

    public void setData(Training t) {
        //training Locations
        Vector ts = t.getLocations();
        if (ts != null) {
            trainingLocations = new Vector();
            int size = ts.size();
            for (int i = 0; i < size; i++) {
                //retrouver le location dans "locations";
                Location l = (Location) ts.elementAt(i);
                if (l != null) {
                    int id = l.getIdLocation();
                    //Iterator iter = trainingLocations.iterator();
                    Iterator iter = locations.iterator();
                    boolean found = false;
                    while (iter.hasNext() && !found) {
                        Location l2 = (Location) iter.next();
                        if (l2 != null && l2.getIdLocation() == id) {
                            trainingLocations.add(l2);
                            found = true;
                        }
                    }
                }
            }
            trainingLocationsList.setListData(trainingLocations);
        }
    }

    public String testTemplateElements(int type) {
        String msg = null;
        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "location");
        if (result.isMandatory()) {
            TrainingCourse tc = new TrainingCourse();
            this.getData(tc);

            if (tc.getLocations() == null || tc.getLocations().isEmpty()) {
                msg = "\n" + labels.get("apostal.toma.trainingview.locations") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        return msg;
    }
}
