// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;
import java.util.Vector;
import java.util.Iterator;
import java.lang.Class;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.sql.Date;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.database.LanguageDB;
import apostal.toma.data.Language;
import apostal.toma.database.DomainDB;
import apostal.toma.data.Domain;
import apostal.toma.database.LevelDB;
import apostal.toma.data.Level;
import apostal.toma.database.SlotDB;
import apostal.toma.data.Slot;
import apostal.toma.database.ModeOfOrganizationDB;
import apostal.toma.data.ModeOfOrganization;
import apostal.toma.TOMA;
import apostal.toma.data.TOMAParameters;
import apostal.toma.viewcontrol.TrainingEventHandler;
import apostal.toma.view.TOMAMultipleElements;

import apostal.toma.data.Training;

import toolbox.swing.LimitedNumericDocument;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewMainPanel extends JPanel {
    private static Vector levels;
    private static Vector slots;
    private static Vector moos;

    static {
        TOMA toma = TOMA.getInstance();
        levels = toma.getLevels();
        slots = toma.getSlots();
        moos = toma.getMoos();
    }

    protected TOMALabels labels;

    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMALabel label_title = new TOMALabel();
    TOMATextField title = new TOMATextField();
    JComponent titleComponent;

    TOMALabel label_code = new TOMALabel();
    TOMATextField code = new TOMATextField();
    JComponent codeComponent;

    TOMALabel label_beginValiditDate = new TOMALabel();
    JPanel panel_beginValidityDates = new JPanel();
    FlowLayout flowLayout1 = new FlowLayout(FlowLayout.LEFT, 0, 0);
    TOMATextField beginValidityDate_day = new TOMATextField(2);
    TOMATextField beginValidityDate_month = new TOMATextField(2);
    TOMATextField beginValidityDate_year = new TOMATextField(4);
    TOMALabel label_endValidityDate = new TOMALabel();
    TOMATextField endValidityDate_year = new TOMATextField(4);
    FlowLayout flowLayout2 = new FlowLayout(FlowLayout.LEFT, 0, 0);
    TOMATextField endValidityDate_day = new TOMATextField(2);
    JPanel panel_endValidityDates = new JPanel();
    TOMATextField endValidityDate_month = new TOMATextField(2);

    TOMALabel label_level = new TOMALabel();
    TOMAComboBox levelCombo = new TOMAComboBox();

    TOMALabel label_modeOfOrganization = new TOMALabel();
    TOMAComboBox modeOfOrganizationCombo = new TOMAComboBox();

    TOMALabel label_slot = new TOMALabel();
    GridBagLayout gridBagLayout6 = new GridBagLayout();
    Vector slotsCheckBoxes = new Vector();
    JPanel panelSlots = new JPanel();

    TOMALabel label_validityDates1 = new TOMALabel();
    TOMALabel label_validityDates2 = new TOMALabel();

    public TrainingViewMainPanel(int type) {
        try {
            labels = new TOMALabels();
            jbInit(type);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit(int type) throws Exception {
        this.setLayout(gridBagLayout1);
        this.setBackground(TOMAColors.trainingMainBackgroundColor);

        //title
        label_title.setText(labels.get("apostal.toma.trainingview.title"));
        TOMATemplateResult titleResult = TOMATemplateView.getTemplateResult(type, "title");
        if (titleResult.getMaximum() > -1)
            label_title.setText(label_title.getText() + " (" + new Integer(titleResult.getMaximum()) + ")");
        if (titleResult.getValues() != null && !titleResult.getValues().isEmpty())
            titleComponent = new TOMAComboBox(titleResult.getValues());
        else
            titleComponent = title;

        //code
        label_code.setText(labels.get("apostal.toma.trainingview.code"));
        TOMATemplateResult codeResult = TOMATemplateView.getTemplateResult(type, "code");
        if (codeResult.getMaximum() > -1)
            label_code.setText(label_code.getText() + " (" + new Integer(codeResult.getMaximum()) + ")");
        if (codeResult.getValues() != null && !codeResult.getValues().isEmpty())
            codeComponent = new TOMAComboBox(codeResult.getValues());
        else
            codeComponent = code;

        //level
        label_level.setText(labels.get("apostal.toma.trainingview.level"));
        this.addLevels(type);

        //moo
        label_modeOfOrganization.setText(labels.get("apostal.toma.trainingview.modeOfOrganization"));
        this.addModeOfOrganizations(type);

        //slot
        label_slot.setText(labels.get("apostal.toma.trainingview.slots"));
        this.addSlots(type);
        TOMATemplateResult slotResult = TOMATemplateView.getTemplateResult(type, "slot");
        if (slotResult.isMandatory())
            label_slot.setText(label_slot.getText() + " (*)");

        panelSlots.setBackground(TOMAColors.trainingMainBackgroundColor);

        //panels dates
        label_validityDates1.setText(labels.get("apostal.toma.dateformat"));
        label_validityDates2.setText(labels.get("apostal.toma.dateformat"));
        label_beginValiditDate.setText(labels.get("apostal.toma.trainingview.beginValidityDate"));
        label_endValidityDate.setText(labels.get("apostal.toma.trainingview.endValidityDate"));
        beginValidityDate_day.setDocument(new LimitedNumericDocument(2));
        beginValidityDate_month.setDocument(new LimitedNumericDocument(2));
        beginValidityDate_year.setDocument(new LimitedNumericDocument(4));
        endValidityDate_day.setDocument(new LimitedNumericDocument(2));
        endValidityDate_month.setDocument(new LimitedNumericDocument(2));
        endValidityDate_year.setDocument(new LimitedNumericDocument(4));
        panel_beginValidityDates.setLayout(flowLayout1);
        panel_beginValidityDates.setBackground(TOMAColors.trainingMainBackgroundColor);
        panel_endValidityDates.setLayout(flowLayout2);
        panel_endValidityDates.setBackground(TOMAColors.trainingMainBackgroundColor);

        panel_beginValidityDates.add(beginValidityDate_day, null);
        panel_beginValidityDates.add(beginValidityDate_month, null);
        panel_beginValidityDates.add(beginValidityDate_year, null);
        panel_beginValidityDates.add(label_validityDates1, null);

        panel_endValidityDates.add(endValidityDate_day, null);
        panel_endValidityDates.add(endValidityDate_month, null);
        panel_endValidityDates.add(endValidityDate_year, null);
        panel_endValidityDates.add(label_validityDates2, null);

        //main
        int alignment = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.NONE;
        Insets insets = new Insets(3, 10, 0, 0);
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , alignment, fill, insets, 0, 0);
        //colonne de droite
        this.add(label_title, cons);
        cons.gridx = 1;
        this.add(titleComponent, cons);
        cons.gridx = 0;
        cons.gridy = 1;
        this.add(label_beginValiditDate, cons);
        cons.gridx = 1;
        this.add(panel_beginValidityDates, cons);
        cons.gridx = 0;
        cons.gridy = 2;
        this.add(label_endValidityDate, cons);
        cons.gridx = 1;
        this.add(panel_endValidityDates, cons);
        cons.gridy = 3;
        cons.gridwidth = 3;
        this.add(panelSlots, cons);
        cons.gridx = 0;
        cons.gridwidth = 1;
        this.add(label_slot, cons);

        //colonne de gauche
        insets = new Insets(3, 15, 0, 0);
        cons.gridx = 2;
        cons.gridy = 0;
        this.add(label_code, cons);
        cons.gridx = 3;
        this.add(codeComponent, cons);
        cons.gridx = 2;
        cons.gridy = 1;
        this.add(label_level, cons);
        cons.gridx = 3;
        this.add(levelCombo, cons);
        cons.gridx = 2;
        cons.gridy = 2;
        cons.gridwidth = 2;
        this.add(label_modeOfOrganization, cons);
        cons.gridx = 3;
        cons.gridy = 3;
        cons.insets = new Insets(0, 15, 0, 0);
        this.add(modeOfOrganizationCombo, cons);

        //fill
        cons.gridx = 0;
        cons.gridy = 4;
        cons.gridwidth = 1;
        cons.insets = new Insets(0, 0, 0, 0);
        cons.weighty = 1.0;
        this.add(Box.createGlue(), cons);
        cons.gridx = 5;
        cons.gridy = 0;
        cons.weightx = 1.0;
        cons.weighty = 0.0;
        this.add(Box.createGlue(), cons);

        /*
        //colonne de droite
        Insets insets=new Insets(3, 10, 0, 0);
        this.add(label_title,            new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(titleComponent,            new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));

        this.add(label_beginValiditDate,            new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(panel_beginValidityDates,          new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(label_endValidityDate,      new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(panel_endValidityDates,                  new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(panelSlots,     new GridBagConstraints(1, 3, 3, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(label_slot, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));

        //colonne de gauche
        insets=new Insets(3, 15, 0, 0);
        this.add(label_code,            new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(codeComponent,             new GridBagConstraints(3, 0, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(label_level,              new GridBagConstraints(2, 1, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(levelCombo,              new GridBagConstraints(3, 1, 1, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(label_modeOfOrganization,   new GridBagConstraints(2, 2, 2, 1, 0.0, 0.0
                ,alignment, fill, insets, 0, 0));
        this.add(modeOfOrganizationCombo, new GridBagConstraints(3, 3, 2, 1, 0.0, 0.0
                ,alignment, fill, new Insets(0, 15, 0, 0), 0, 0));

        //fill
        this.add(Box.createGlue(), new GridBagConstraints(0, 4, 1, 1, 0.0, 1.0
                ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
        this.add(Box.createGlue(), new GridBagConstraints(5, 0, 1, 1, 1.0, 0.0
                ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));

        */
    }

    public void addSlots(int type) {
        boolean enabled = true;
        Vector values = null;
        TOMATemplateResult slotResult = TOMATemplateView.getTemplateResult(type, "slot");
        if (slotResult.isForbidden())
            enabled = false;
        if (slotResult.getValues() != null && !slotResult.getValues().isEmpty())
            values = slotResult.getValues();

        slotsCheckBoxes = new Vector();
        GridBagLayout slotLayout = new GridBagLayout();
        panelSlots.setLayout(slotLayout);
        GridBagConstraints c = new GridBagConstraints();
        c.anchor = GridBagConstraints.WEST;
        c.fill = GridBagConstraints.NONE;
        c.gridx = 0;
        c.gridy = 0;
        c.gridheight = 1;
        c.gridwidth = 1;

        if (slots != null) {
            int nbSlots = slots.size();
            for (int i = 0; i < nbSlots; i++) {
                Slot s = (Slot) slots.elementAt(i);
                String sv = s.getValue();
                JCheckBox slot = new JCheckBox(s.getName());
                slot.setActionCommand(s.getValue());

                slot.setBackground(TOMAColors.trainingMainBackgroundColor);
                slot.setBorder(new LineBorder(TOMAColors.buttonsBorderColor, 1));
                slot.setForeground(TOMAColors.clickableTextColor);
                slot.setFont(TOMAFonts.listsFont);

                if (!enabled)
                    slot.setEnabled(false);
                if (values != null) {
                    Iterator iter = values.iterator();
                    boolean found = false;
                    while (iter.hasNext() && !found) {
                        String value = (String) iter.next();
                        if (value.equals(sv))
                            found = true;
                    }
                    if (found) {
                        slotsCheckBoxes.add(slot);
                        c.gridx = i;
                        panelSlots.add(slot, c);
                    }
                } else {
                    slotsCheckBoxes.add(slot);
                    c.gridx = i;
                    panelSlots.add(slot, c);
                }
            }
        }

        panelSlots.setBackground(TOMAColors.trainingMainBackgroundColor);
    }

    public void addLevels(int type) {
        Vector values = null;
        TOMATemplateResult levelResult = TOMATemplateView.getTemplateResult(type, "level");
        if (levelResult.getValues() != null && !levelResult.getValues().isEmpty())
            values = levelResult.getValues();

        levelCombo.removeAllItems();

        if (levels != null) {
            Iterator iter = levels.iterator();
            while (iter.hasNext()) {
                Level ln = (Level) iter.next();
                String v = ln.getValue();
                if (v != null && values != null && !values.isEmpty()) {
                    Iterator iter2 = values.iterator();
                    boolean found = false;
                    while (iter2.hasNext() && !found) {
                        String value = (String) iter2.next();
                        if (value != null && value.equals(v))
                            found = true;
                    }
                    if (found)
                        levelCombo.addItem(ln);
                } else
                    levelCombo.addItem(ln);
            }
        }
    }

    public void addModeOfOrganizations(int type) {
        modeOfOrganizationCombo.removeAllItems();
        Vector values = null;
        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "modeOfOrganization");
        if (result.getValues() != null && !result.getValues().isEmpty())
            values = result.getValues();

        if (moos != null) {
            Iterator iter = moos.iterator();
            while (iter.hasNext()) {
                ModeOfOrganization moo = (ModeOfOrganization) iter.next();
                String v = moo.getValue();
                if (v != null && values != null && !values.isEmpty()) {
                    Iterator iter2 = values.iterator();
                    boolean found = false;
                    while (iter2.hasNext() && !found) {
                        String value = (String) iter2.next();
                        if (value != null && value.equals(v))
                            found = true;
                    }
                    if (found)
                        modeOfOrganizationCombo.addItem(moo);
                } else
                    modeOfOrganizationCombo.addItem(moo);
            }
        }
    }

    public void getData(Training t) {
        if (!titleComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setTitle(title.getText());
        else {
            try {
                t.setTitle((String) ((TOMAComboBox) titleComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
            }
        }

        if (!codeComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setCode(code.getText());
        else {
            try {
                t.setCode((String) ((TOMAComboBox) codeComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
            }
        }

        //beginValidityDate
        String begin_day = beginValidityDate_day.getText();
        String begin_month = beginValidityDate_month.getText();
        String begin_year = beginValidityDate_year.getText();
        try {
            int day = Integer.parseInt(begin_day);
            int month = Integer.parseInt(begin_month);
            int year = Integer.parseInt(begin_year);

            GregorianCalendar cal = new GregorianCalendar();
            cal.set(Calendar.DAY_OF_MONTH, day);
            cal.set(Calendar.MONTH, month - 1);
            cal.set(Calendar.YEAR, year);
            Date beginValidityDate = new Date(cal.getTime().getTime());
            t.setBeginValidityDate(beginValidityDate);
        } catch (java.lang.NumberFormatException ex) {
            TOMA.log(TOMA.SEVERE, "beginValidityDate is not a number");
            t.setBeginValidityDate(null);
        }

        //endValidityDate
        String end_day = endValidityDate_day.getText();
        String end_month = endValidityDate_month.getText();
        String end_year = endValidityDate_year.getText();
        try {
            int day = Integer.parseInt(end_day);
            int month = Integer.parseInt(end_month);
            int year = Integer.parseInt(end_year);

            GregorianCalendar cal = new GregorianCalendar();
            cal.set(Calendar.DAY_OF_MONTH, day);
            cal.set(Calendar.MONTH, month - 1);
            cal.set(Calendar.YEAR, year);
            Date endValidityDate = new Date(cal.getTime().getTime());
            t.setEndValidityDate(endValidityDate);
        } catch (java.lang.NumberFormatException ex) {
            TOMA.log(TOMA.SEVERE, "endValidityDate is not a number");
            t.setEndValidityDate(null);
        }

        try {
            Level level = (Level) levelCombo.getSelectedItem();
            if (level != null)
                t.setLevel(level);
        } catch (java.lang.ClassCastException ex) {
            t.setLevel(null);
        }

        try {
            ModeOfOrganization moo = (ModeOfOrganization) modeOfOrganizationCombo.getSelectedItem();
            if (moo != null)
                t.setModeOfOrganization(moo);
        } catch (java.lang.ClassCastException ex) {
            t.setModeOfOrganization(null);
        }

        //slots
        Vector slotsSelected = new Vector();
        Iterator iter = slotsCheckBoxes.iterator();
        while (iter.hasNext()) {
            JCheckBox box = (JCheckBox) iter.next();

            if (box.isSelected()) {
                String value = box.getActionCommand();
                Slot s = new Slot(value);
                slotsSelected.add(s);
            }
        }
        t.setSlots(slotsSelected);
    }

    public void setData(Training t) {
        //title
        if (!titleComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            title.setText(t.getTitle());
        else {
            String title = t.getTitle();
            TOMATemplateView.setTextCombo(title, (TOMAComboBox) titleComponent);
        }

        //code
        if (!codeComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            code.setText(t.getCode());
        else {
            String code = t.getCode();
            TOMATemplateView.setTextCombo(code, (TOMAComboBox) codeComponent);
        }

        //level
        Level l = t.getLevel();
        if (l != null) {
            Iterator levels_iter = levels.iterator();
            //rcuprer le level correspondant dans levels
            Level selectedLevel = null;
            while (levels_iter.hasNext() && selectedLevel == null) {
                try {
                    Level level = (Level) levels_iter.next();
                    if (level != null && level.getValue().equals(l.getValue()))
                        selectedLevel = level;
                } catch (java.lang.ClassCastException ex) {
                }
            }

            if (selectedLevel != null) {
                //s'il n'est pas dans la liste de levelCombo, l'y rajouter
                String value = selectedLevel.getValue();
                int c = levelCombo.getItemCount();
                int i = 0;
                boolean found = false;
                while (i < c && !found) {
                    try {
                        Level level = (Level) levelCombo.getItemAt(i);
                        if (level != null && value.equals(level.getValue())) {
                            found = true;
                        }
                    } catch (java.lang.ClassCastException ex) {
                    }
                    i++;
                }
                if (!found) {
                    levelCombo.addItem(selectedLevel);
                }

                levelCombo.setSelectedItem(selectedLevel);
            }
        }

        //modeOfOrganiaztion
        ModeOfOrganization m = t.getModeOfOrganization();
        if (m != null) {
            Iterator moos_iter = moos.iterator();
            //rcuprer le moo correspondant dans levels
            ModeOfOrganization selectedModeOfOrganization = null;
            while (moos_iter.hasNext() && selectedModeOfOrganization == null) {
                try {
                    ModeOfOrganization moo = (ModeOfOrganization) moos_iter.next();
                    if (moo != null && moo.getValue().equals(m.getValue()))
                        selectedModeOfOrganization = moo;
                } catch (java.lang.ClassCastException ex) {
                }
            }
            if (selectedModeOfOrganization != null) {
                //s'il n'est pas dans la liste de mooCombo, l'y rajouter
                String value = selectedModeOfOrganization.getValue();
                int c = modeOfOrganizationCombo.getItemCount();
                int i = 0;
                boolean found = false;
                while (i < c && !found) {
                    try {
                        ModeOfOrganization moo = (ModeOfOrganization) modeOfOrganizationCombo.getItemAt(i);
                        if (moo != null && value.equals(moo.getValue())) {
                            found = true;
                        }
                    } catch (java.lang.ClassCastException ex) {
                    }
                    i++;
                }
                if (!found) {
                    modeOfOrganizationCombo.addItem(selectedModeOfOrganization);
                }

                modeOfOrganizationCombo.setSelectedItem(selectedModeOfOrganization);
            }
        }

        //slots
        Vector t_slots = t.getSlots();
        if (t_slots != null) {
            //parcourir les slots slectionns
            Iterator slots_iter = t_slots.iterator();
            while (slots_iter.hasNext()) {
                Slot slot = (Slot) slots_iter.next();
                if (slot != null) {
                    String value = slot.getValue();
                    //le retrouver dans les CheckBoxes
                    boolean found = false;
                    Iterator checkBoxes_iter = slotsCheckBoxes.iterator();
                    while (checkBoxes_iter.hasNext() && !found) {
                        JCheckBox box = (JCheckBox) checkBoxes_iter.next();
                        if (box.getActionCommand().equals(value)) {
                            found = true;
                            box.setSelected(true);
                        }
                    }
                }
            }
        }

        //beginValidityDate
        Date bvd = t.getBeginValidityDate();
        if (bvd != null) {
            GregorianCalendar beginCal = new GregorianCalendar();
            beginCal.setTime(bvd);
            int beginDay = beginCal.get(Calendar.DAY_OF_MONTH);
            int beginMonth = beginCal.get(Calendar.MONTH) + 1;
            int beginYear = beginCal.get(Calendar.YEAR);
            beginValidityDate_day.setText((new Integer(beginDay)).toString());
            beginValidityDate_month.setText((new Integer(beginMonth)).toString());
            beginValidityDate_year.setText((new Integer(beginYear)).toString());
        }

        //endValidityDate
        Date evd = t.getEndValidityDate();
        if (evd != null) {
            GregorianCalendar endCal = new GregorianCalendar();
            endCal.setTime(evd);
            int endDay = endCal.get(Calendar.DAY_OF_MONTH);
            int endMonth = endCal.get(Calendar.MONTH) + 1;
            int endYear = endCal.get(Calendar.YEAR);
            endValidityDate_day.setText((new Integer(endDay)).toString());
            endValidityDate_month.setText((new Integer(endMonth)).toString());
            endValidityDate_year.setText((new Integer(endYear)).toString());
        }
    }

    public String testTemplateElements(int type) {
        //formation pour les tests de template uniquement
        apostal.toma.data.TrainingCourse t = new apostal.toma.data.TrainingCourse();
        this.getData(t);

        String msg = "";

        String msg_title = TOMATemplateView.testTemplateElement(type, "title", t.getTitle(), labels.get("apostal.toma.trainingview.title"));
        if (msg_title != null)
            msg = msg + "\n" + msg_title;

        String msg_code = TOMATemplateView.testTemplateElement(type, "code", t.getCode(), labels.get("apostal.toma.trainingview.code"));
        if (msg_code != null)
            msg = msg + "\n" + msg_code;

        String msg_slot = TOMATemplateView.testTemplateElement(type, "slot", t.getSlots(), labels.get("apostal.toma.trainingview.slots"));
        if (msg_slot != null)
            msg = msg + "\n" + msg_slot;

        if (msg.equals(""))
            return null;
        else
            return msg;
    }

}
