// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import java.awt.*;
import java.lang.Class;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMALabels;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.data.Training;
import apostal.toma.view.PointDealtWithsComboBoxes;
import toolbox.text.ExtendedList;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewPoints extends JScrollPane {
    private static int introLength = 60;
    private static int introHeight = 4;
    private static int pointFrameLength = 600;
    private static int pointFrameHeight = 250;

    private int _type;

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMALabel label_introduction = new TOMALabel();
    TOMATextArea introduction = new TOMATextArea(TrainingViewPoints.introHeight, TrainingViewPoints.introLength);
    TOMALabel label_conclusion = new TOMALabel();
    TOMATextArea conclusion = new TOMATextArea(TrainingViewPoints.introHeight, TrainingViewPoints.introLength);

    TOMAMultipleElements points;

    private TOMALabels labels;
    private TOMATemplateResult result;

    public TrainingViewPoints(int type) {
        this._type = type;
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        //introduction
        label_introduction.setText(labels.get("apostal.toma.trainingview.pointsDealtWith.introduction"));
        TOMATemplateResult introResult = TOMATemplateView.getTemplateResult(_type, "pdwIntroduction");
        if (introResult.getMaximum() > -1)
            label_introduction.setText(label_introduction.getText() + " (" + new Integer(introResult.getMaximum()) + ")");
        if (introResult.isForbidden())
            introduction.setEnabled(false); 
        JScrollPane pane_introduction = new JScrollPane(introduction);

        //conclusion
        label_conclusion.setText(labels.get("apostal.toma.trainingview.pointsDealtWith.conclusion"));
        TOMATemplateResult cclResult = TOMATemplateView.getTemplateResult(_type, "pdwConclusion");
        if (cclResult.getMaximum() > -1)
            label_conclusion.setText(label_conclusion.getText() + " (" + new Integer(cclResult.getMaximum()) + ")");
        if (cclResult.isForbidden())
            conclusion.setEnabled(false);         
        JScrollPane pane_conclusion = new JScrollPane(conclusion);

        //points
        Class[] classes = new Class[1];
        classes[0] = Class.forName("java.lang.Integer");
        Object[] values = new Object[1];
        //values[0]=new Integer(30);
        values[0] = new Integer(_type);
        points = new TOMAMultipleElements("apostal.toma.view.PointDealtWithsComboBoxes", classes, values, 0, null, labels.get("apostal.toma.trainingview.pointsDealtWith.addPoint"), labels.get("apostal.toma.trainingview.pointsDealtWith.removePoint"), TOMAColors.multipleElementsColor, TrainingViewPoints.pointFrameLength, TrainingViewPoints.pointFrameHeight);
        TOMATemplateResult pointResult = TOMATemplateView.getTemplateResult(_type, "pointDealtWith");
        if(pointResult.isForbidden())
            points.setEnabled(false);
        
        //global
        result = TOMATemplateView.getTemplateResult(_type, "pointsDealtWith");        
        if (result.isForbidden()) {
            introduction.setEnabled(false);
            conclusion.setEnabled(false);
            points.setEnabled(false);
        }

        this.getViewport().add(jPanel1, null);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;

        jPanel1.add(label_introduction, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(pane_introduction, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 5, 0), 0, 0));

        jPanel1.add(points, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));

        jPanel1.add(label_conclusion, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(5, 10, 0, 0), 0, 0));
        jPanel1.add(pane_conclusion, new GridBagConstraints(0, 4, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));

        //fill
        jPanel1.add(Box.createGlue(), new GridBagConstraints(0, 5, 1, 1, 0.0, 1.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(Box.createGlue(), new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
    }

    public void getData(Training t) {
        ExtendedList ex = new ExtendedList();
        ex.setIntroduction(introduction.getText());
        //points
        JComponent[] elements = points.getElements();
        int size = elements.length;
        for (int i = 0; i < size; i++) {
            PointDealtWithsComboBoxes box = (PointDealtWithsComboBoxes) elements[i];
            ExtendedList ex2 = box.getData();
            ex.addElement(ex2);
        }
        ex.setConclusion(conclusion.getText());
        t.setPointsDealtWith(ex);
    }

    public void setData(Training t) {
        ExtendedList pdw = t.getPointsDealtWith();
        if (pdw != null) {
            introduction.setText(pdw.getIntroduction());

            Vector elements = new Vector();
            Vector l = pdw.getList();
            if (l != null) {
                Iterator iter = l.iterator();
                while (iter.hasNext()) {
                    ExtendedList ex2 = (ExtendedList) iter.next();
                    if (ex2 != null) {
                        PointDealtWithsComboBoxes box = new PointDealtWithsComboBoxes(new Integer(_type));
                        box.setData(ex2);
                        elements.add(box);
                    }
                }
                points.setElements(elements);
                if (result.isForbidden()
                || TOMATemplateView.getTemplateResult(_type, "pointDealtWith").isForbidden()
                )
                    points.setEnabled(false);
            }

            conclusion.setText(pdw.getConclusion());
        }
    }

    public String testTemplateElements(int type) {
        String msg = "";
        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "pointsDealtWith");
        if (result.isMandatory()) {
            TrainingCourse tc = new TrainingCourse();
            this.getData(tc);

            ExtendedList pdw = tc.getPointsDealtWith();

            if (
                    (pdw.getIntroduction() == null || pdw.getIntroduction().equals(""))
                    &&
                    (pdw.getConclusion() == null || pdw.getConclusion().equals(""))
                    &&
                    (pdw.getList() == null || pdw.getList().isEmpty())
            ) {
                msg = "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        //size of the elements
        //introduction
        String intro = introduction.getText();
        TOMATemplateResult introResult = TOMATemplateView.getTemplateResult(type, "pdwIntroduction");
        if (intro != null && introResult.getMaximum() > -1 && intro.length() > introResult.getMaximum()) {
            msg = msg + "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith.pdwIntroduction") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
        }
        //points
        JComponent[] elements = points.getElements();
        int nbPoints = elements.length;
        TOMATemplateResult subPwdIntroductionResult = TOMATemplateView.getTemplateResult(type, "subPwdIntroduction");
        TOMATemplateResult subPwdConclusionResult = TOMATemplateView.getTemplateResult(type, "subPwdConclusion");
        TOMATemplateResult subPwdPointResult = TOMATemplateView.getTemplateResult(type, "subPwdPoint");
        for (int j = 0; j < nbPoints; j++) {
            PointDealtWithsComboBoxes subPoint = (PointDealtWithsComboBoxes) elements[j];
            ExtendedList list = subPoint.getData();

            //introduction
            String subIntro = list.getIntroduction();
            TOMATemplateResult subIntroResult = TOMATemplateView.getTemplateResult(type, "subPdwIntroduction");
            if (subIntro != null && subPwdIntroductionResult.getMaximum() > -1 && subIntro.length() > subPwdIntroductionResult.getMaximum()) {
                msg = msg + "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith.point.subPdwIntroduction") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
            }

            Vector subPoints = list.getList();
            int nbSubPoints = subPoints.size();
            for (int k = 0; k < nbSubPoints; k++) {
                String sub = (String) subPoints.elementAt(k);

                if (sub != null && subPwdPointResult.getMaximum() > -1 && sub.length() > subPwdPointResult.getMaximum())
                    msg = msg + "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith.point.subPdwPoint") + " " + k + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
            }
            //conclusion
            String subCcl = list.getConclusion();
            TOMATemplateResult subCclResult = TOMATemplateView.getTemplateResult(type, "subPdwConclusion");
            if (subCcl != null && subPwdConclusionResult.getMaximum() > -1 && subCcl.length() > subPwdConclusionResult.getMaximum()) {
                msg = msg + "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith.point.subPdwConclusion") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
            }
        }

        //conclusion
        String ccl = conclusion.getText();
        TOMATemplateResult cclResult = TOMATemplateView.getTemplateResult(type, "pdwConclusion");
        if (ccl != null && cclResult.getMaximum() > -1 && ccl.length() > cclResult.getMaximum()) {
            msg = msg + "\n" + labels.get("apostal.toma.trainingview.pointsDealtWith.pdwConclusion") + " : " + labels.get("apostal.toma.trainingview.templateMaximumProblem");
        }

        if (msg.equals(""))
            msg = null;

        return msg;
    }
}