// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;
import java.util.Vector;
import java.util.Iterator;
import java.util.Hashtable;

import apostal.toma.data.*;
import apostal.toma.TOMA;
import apostal.toma.database.TeacherDB;
import apostal.toma.datacontrol.TeachersControl;

import toolbox.swing.LimitedRowsListCellRenderer;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class TrainingViewTeachers extends JScrollPane implements ActionListener, ListSelectionListener {
    private static Vector teachers;
    private static ImageIcon addIcon;
    private static ImageIcon addPressedIcon;
    private static ImageIcon removeIcon;
    private static ImageIcon removePressedIcon;

    static {
        TeachersControl control = new TeachersControl();
        teachers = control.loadTeachers(false);

        addIcon = new ImageIcon(TOMAConstants.addIconPath);
        addPressedIcon = new ImageIcon(TOMAConstants.addPressedIconPath);
        removeIcon = new ImageIcon(TOMAConstants.removeIconPath);
        removePressedIcon = new ImageIcon(TOMAConstants.removePressedIconPath);
    }

    public static void refreshLists() {
        //recharger la liste pour les prochains chargement
        TeachersControl control = new TeachersControl();
        teachers = control.loadTeachers(false);
    }

    public void updateTeachers() {
        //mettre  jour la liste des teachers existants
        existingTeachers.setListData(teachers);

        //mettre  jour les teachers chargs
        Training tc = new TrainingCourse();
        this.getData(tc);
        if (tc != null) {
            Vector tcteachers = tc.getTeachers();
            Vector newTeachers = new Vector();
            if (tcteachers != null) {
                Iterator it = tcteachers.iterator();
                while (it.hasNext()) {
                    Teacher t = (Teacher) it.next();
                    boolean found = false;
                    Iterator it2 = teachers.iterator();
                    while (it2.hasNext() && !found) {
                        Teacher t2 = (Teacher) it2.next();
                        if (t2 != null && t != null && t2.getIdTeacher() == t.getIdTeacher()) {
                            newTeachers.add(t2);
                            found = true;
                        }
                    }
                }
            }
            tc.setTeachers(newTeachers);
            this.setData(tc);
        }
    }

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMALabel label_existingTeachers = new TOMALabel();
    JList existingTeachers = new JList(teachers);
    JScrollPane existingTeachersPane = new JScrollPane();
    JButton addTeacher = new JButton();
    TOMALabel label_teachers = new TOMALabel();

    Hashtable trainingTeachersCompetence = new Hashtable();
    Vector trainingTeachers = new Vector();
    JList trainingTeachersList = new JList(trainingTeachers);
    JScrollPane trainingTeachersPane = new JScrollPane();

    JButton remove = new JButton();
    TOMALabel label_competence = new TOMALabel();
    Vector competences = new Vector();
    TOMAComboBox competence = new TOMAComboBox(competences);

    private TOMALabels labels;


    /*****************teachersData*****************/
    private JScrollPane teachersDataScrollPane;
    private JPanel teachersDataPane;
    private TOMALabel teachersName;
    private TOMALabel teachersFunction;
    private TOMALabel teachersCV;
    private TOMALabel teachersTel;
    private TOMALabel teachersFax;
    private TOMALabel teachersEmail;
    private TOMALabel teachersAddress;

    public TrainingViewTeachers(int type) {
        try {
            labels = new TOMALabels();
            jbInit(type);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit(int type) throws Exception {
        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        label_existingTeachers.setText(labels.get("apostal.toma.trainingview.teachers.existingTeachers"));
        existingTeachers.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        existingTeachers.setListData(teachers);
        existingTeachers.setVisibleRowCount(10);
        existingTeachers.setFixedCellWidth(200);
        existingTeachers.setBackground(TOMAColors.editingFieldColor);
        trainingTeachersList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        trainingTeachersList.addListSelectionListener(this);
        trainingTeachersList.setListData(new Vector());
        trainingTeachersList.setVisibleRowCount(10);
        trainingTeachersList.setFixedCellWidth(200);
        trainingTeachersList.setBackground(TOMAColors.editingFieldColor);
        competence.addActionListener(this);
        competence.setActionCommand("competence");
        competence.setRenderer(new LimitedRowsListCellRenderer(37));

        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);
        Insets insets = new Insets(0, 0, 0, 0);

        addTeacher.setIcon(addIcon);
        addTeacher.setPressedIcon(addPressedIcon);
        addTeacher.setBorder(border);
        addTeacher.setMargin(insets);
        addTeacher.setBackground(TOMAColors.trainingTabBackgroundColor);
        addTeacher.setActionCommand("add");
        addTeacher.addActionListener(this);
        label_teachers.setText(labels.get("apostal.toma.trainingview.teachers.trainingTeachers"));

        remove.setIcon(removeIcon);
        remove.setPressedIcon(removePressedIcon);
        remove.setBorder(border);
        remove.setMargin(insets);
        remove.setBackground(TOMAColors.trainingTabBackgroundColor);
        remove.setActionCommand("remove");
        remove.addActionListener(this);
        label_competence.setText(labels.get("apostal.toma.trainingview.teachers.competence"));
        this.getViewport().add(jPanel1, null);

        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "teacher");
        if (result.isForbidden()) {
            addTeacher.setEnabled(false);
            remove.setEnabled(false);
            trainingTeachersList.setEnabled(false);
            competence.setEnabled(false);
        }

        existingTeachersPane.getViewport().add(existingTeachers);
        trainingTeachersPane.getViewport().add(trainingTeachersList);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.BOTH;

        jPanel1.add(label_existingTeachers, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(existingTeachersPane, new GridBagConstraints(0, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 10, 0, 0), 0, 0));
        jPanel1.add(addTeacher, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0
                , anchor, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(remove, new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0
                , anchor, GridBagConstraints.NONE, new Insets(3, 3, 3, 3), 0, 0));
        jPanel1.add(label_teachers, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(trainingTeachersPane, new GridBagConstraints(2, 1, 1, 2, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(label_competence, new GridBagConstraints(2, 4, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(competence, new GridBagConstraints(2, 5, 2, 1, 0.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));

        //fill
        jPanel1.add(Box.createGlue(), new GridBagConstraints(0, 6, 1, 1, 0.0, 1.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));
        jPanel1.add(Box.createGlue(), new GridBagConstraints(4, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(0, 0, 0, 0), 0, 0));

        /*****************teachersData*****************/
        teachersDataScrollPane = new JScrollPane();
        teachersDataPane = new JPanel();
        teachersDataPane.setLayout(new BoxLayout(teachersDataPane, BoxLayout.Y_AXIS));
        teachersDataPane.setBackground(TOMAColors.auxBackgroundColor2);
        teachersName = new TOMALabel();
        teachersDataPane.add(teachersName);
        teachersFunction = new TOMALabel();
        teachersDataPane.add(teachersFunction);
        teachersTel = new TOMALabel();
        teachersDataPane.add(teachersTel);
        teachersFax = new TOMALabel();
        teachersDataPane.add(teachersFax);
        teachersEmail = new TOMALabel();
        teachersDataPane.add(teachersEmail);
        teachersAddress = new TOMALabel();
        teachersDataPane.add(teachersAddress);
        teachersCV = new TOMALabel();
        teachersDataPane.add(teachersCV);
        teachersDataScrollPane.setViewportView(teachersDataPane);
        teachersDataScrollPane.setPreferredSize(new Dimension(200, 200));
        jPanel1.add(teachersDataScrollPane, new GridBagConstraints(3, 0, 2, 4, 0.0, 0.0, anchor, fill, new Insets(5, 5, 5, 5), 0, 0));
    }

    public void setTeachersData(Teacher teacher) {
        String title = (teacher.getTitle() == null) ? "" : teacher.getTitle();
        String firstname = (teacher.getFirstname() == null) ? "" : teacher.getFirstname();
        String lastname = (teacher.getLastname() == null) ? "" : teacher.getLastname();
        teachersName.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-weight: bold\">" + title + " " + firstname + " " + lastname + "</font>" + TOMAFonts.htmlEnd);

        String function = (teacher.getFunction() == null) ? "" : teacher.getFunction();
        teachersFunction.setTextWithLowerCase(labels.get("apostal.toma.teacher.function") + ": " + function);

        String cv = (teacher.getCv() == null) ? "" : teacher.getCv();
        teachersCV.setTextWithLowerCase(labels.get("apostal.toma.teacher.cv") + ": " + cv);

        String tel = (teacher.getTel() == null) ? "" : teacher.getTel();
        teachersTel.setTextWithLowerCase(labels.get("apostal.toma.teacher.tel") + ": " + tel);

        String fax = (teacher.getFax() == null) ? "" : teacher.getFax();
        teachersFax.setTextWithLowerCase(labels.get("apostal.toma.teacher.fax") + ": " + fax);

        String email = (teacher.getEmail() == null) ? "" : teacher.getEmail();
        teachersEmail.setTextWithLowerCase(labels.get("apostal.toma.teacher.email") + ": " + email);

        if (teacher.getAddress() != null)
            teachersAddress.setTextWithLowerCase(TOMAFonts.htmlBegin + "<font style=\"font-size: 10pt;\">" + labels.get("apostal.toma.teacher.address") + ": " + "<table><tr><td style=\"font-size: 10pt;\">" + teacher.getAddress().toHTMLString() + "</td></tr></table></font>" + TOMAFonts.htmlEnd);
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();

        if (cmd != null) {
            if (cmd.equals("add")) {
                //rcuprer le teacher slectionn
                Teacher t = (Teacher) existingTeachers.getSelectedValue();
                if (t != null && !trainingTeachers.contains(t)) {
                    trainingTeachers.add(t);
                    trainingTeachersList.setListData(trainingTeachers);
                }
            } else if (cmd.equals("remove")) {
                Teacher t = (Teacher) trainingTeachersList.getSelectedValue();
                if (t != null) {
                    trainingTeachers.remove(t);
                    trainingTeachersList.setListData(trainingTeachers);
                }
            } else if (cmd.equals("competence"))
            //une comptence a t slectionne
            {
                Teacher t = (Teacher) trainingTeachersList.getSelectedValue();
                try {
                    String comp = (String) competence.getSelectedItem();
                    if (t != null && comp != null)
                        trainingTeachersCompetence.put(t, comp);
                } catch (ClassCastException ex) {
                    trainingTeachersCompetence.remove(t);
                }
            }
        }
    }

    /**
     *  mettre competences  jour
     */
    public void valueChanged(ListSelectionEvent e) {
        Teacher t = (Teacher) trainingTeachersList.getSelectedValue();
        competence.removeAllItems();
        if (t != null) {
            String comp_existante = (String) trainingTeachersCompetence.get(t);

            //rcuprer les comptences sauves
            competences = t.getCompetences();
            if (competences == null || competences.isEmpty()) {
                Language lng = TOMA.getInstance().getTomaParameters().getLanguage();
                TeacherDB tdb = new TeacherDB(t);
                tdb.loadById(lng, true);
                competences = t.getCompetences();
            }

            //mettre les nouveaux items
            competence.addItem(ElementNotSpecified.getInstance());
            competence.setSelectedItem(ElementNotSpecified.getInstance());
            trainingTeachersCompetence.remove(t);

            Iterator iter = competences.iterator();
            while (iter.hasNext()) {
                String comp = (String) iter.next();
                competence.addItem(comp);
                if (comp.equals(comp_existante)) {
                    competence.setSelectedItem(comp);
                    trainingTeachersCompetence.put(t, comp);
                }
            }

            this.setTeachersData(t);
        }
    }

    public void getData(Training t) {
        //teachers
        t.setTeachers(trainingTeachers);

        //competences
        Vector comps = new Vector();
        Iterator iter = trainingTeachers.iterator();
        while (iter.hasNext()) {
            Teacher te = (Teacher) iter.next();
            try {
                String comp = (String) trainingTeachersCompetence.get(te);
                comps.add(comp);

            } catch (java.lang.ClassCastException ex) {
                comps.add(null);
                TOMA.log(TOMA.INFO, "pour teacher=" + te.getLastname() + ", competence est null");
            }
        }
        t.setCompetences(comps);
    }

    public void setData(Training t) {
        Vector ts = t.getTeachers();
        Vector cs = t.getCompetences();
        trainingTeachersCompetence = new Hashtable();
        //trainingTeachers=ts;
        trainingTeachers = new Vector();

        if (ts != null) {
            int size = ts.size();
            for (int i = 0; i < size; i++) {
                //retrouver le teacher dans "teachers";
                Teacher te = (Teacher) ts.elementAt(i);
                if (te != null) {
                    int id = te.getIdTeacher();
                    Iterator iter = teachers.iterator();
                    Teacher t_found = null;
                    while (iter.hasNext() && t_found == null) {
                        Teacher t2 = (Teacher) iter.next();
                        if (t2.getIdTeacher() == id) {
                            trainingTeachers.add(t2);
                            t_found = t2;
                        }
                    }
                    String comp = (String) cs.elementAt(i);
                    if (comp != null && t_found != null)
                        trainingTeachersCompetence.put(t_found, comp);
                }
            }
            trainingTeachersList.setListData(trainingTeachers);
        }
    }

    public String testTemplateElements(int type) {
        String msg = null;
        TOMATemplateResult result = TOMATemplateView.getTemplateResult(type, "teacher");
        if (result.isMandatory()) {
            TrainingCourse tc = new TrainingCourse();
            this.getData(tc);

            if (tc.getTeachers() == null || tc.getTeachers().isEmpty()) {
                msg = "\n" + labels.get("apostal.toma.trainingview.teachers") + " : " + labels.get("apostal.toma.trainingview.templateMandatoryProblem");
            }
        }

        return msg;
    }
}
