// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;

import apostal.toma.data.TOMAConstants;
import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;
import apostal.toma.viewcontrol.UnitEventHandler;

public class UnitViewButtonsPanel extends TrainingViewButtonsPanel {
    private static Icon saveIcon;
    private static Icon savePressedIcon;
    private static Icon deleteIcon;
    private static Icon deletePressedIcon;
    private static Icon sessionsIcon;
    private static Icon sessionsPressedIcon;

    static {
        saveIcon = new ImageIcon(TOMAConstants.saveImagePath);
        savePressedIcon = new ImageIcon(TOMAConstants.savePressedImagePath);
        deleteIcon = new ImageIcon(TOMAConstants.deleteImagePath);
        deletePressedIcon = new ImageIcon(TOMAConstants.deletePressedImagePath);
        sessionsIcon = new ImageIcon(TOMAConstants.sessionsImagePath);
        sessionsPressedIcon = new ImageIcon(TOMAConstants.sessionsPressedImagePath);
    }

    private UnitView unitView;
    private TOMALabels labels;

    TOMAButton save = new TOMAButton(false);
    TOMAButton delete = new TOMAButton(false);
    TOMAButton sessions = new TOMAButton(false);
    JPanel panel_toolbar = new JPanel();
    GridBagLayout gridBagLayout = new GridBagLayout();

    public UnitViewButtonsPanel(UnitView unitView) {
        this.unitView = unitView;

        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        EmptyBorder border = new EmptyBorder(0, 0, 0, 0);
        Insets insets = new Insets(0, 0, 0, 0);

        save.setIcon(saveIcon);
        save.setPressedIcon(savePressedIcon);
        save.setBackground(TOMAColors.toolbarColor);
        save.setBorder(border);
        save.setMargin(insets);
        save.setToolTipText(labels.get("apostal.toma.trainingview.save"));
        save.setActionCommand("save");
        //save.addActionListener(new UnitEventHandler(unitView, unitView.getUnit()));

        delete.setIcon(deleteIcon);
        delete.setPressedIcon(deletePressedIcon);
        delete.setBackground(TOMAColors.toolbarColor);
        delete.setBorder(border);
        delete.setMargin(insets);
        delete.setToolTipText(labels.get("apostal.toma.trainingview.save"));
        delete.setActionCommand("delete");
        //delete.addActionListener(new UnitEventHandler(unitView, unitView.getUnit()));

        sessions.setIcon(sessionsIcon);
        sessions.setPressedIcon(sessionsPressedIcon);
        sessions.setBackground(TOMAColors.toolbarColor);
        sessions.setBorder(border);
        sessions.setMargin(insets);
        sessions.setToolTipText(labels.get("apostal.toma.trainingview.sessions"));
        sessions.setActionCommand("sessions");
        //sessions.addActionListener(new UnitEventHandler(unitView, unitView.getUnit()));

        this.setLayout(gridBagLayout);

        int anchor = GridBagConstraints.WEST;
        int fill = GridBagConstraints.HORIZONTAL;

        this.add(save, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(3, 3, 3, 3), 0, 0));
        /*this.add(delete,      new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
                ,anchor, fill, new Insets(3, 3, 3, 3), 0, 0));*/
        this.add(sessions, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(3, 3, 3, 3), 0, 0));

        //coller les boutons  gauche
        this.add(Box.createGlue(), new GridBagConstraints(2, 0, 1, 1, 1.0, 0.0
                , anchor, fill, new Insets(3, 0, 3, 0), 0, 0));

        this.add(delete, new GridBagConstraints(3, 0, 1, 1, 0.0, 0.0
                , anchor, fill, new Insets(3, 20, 3, 20), 0, 0));

        /*Border border=new LineBorder(Color.black, 1);
        this.setBorder(border);*/
        /*this.setBackground(TOMAColors.tomaBackgroundColor);
        this.setBorder(new LineBorder(TOMAColors.buttonsBorderColor, 1));*/
        this.setBackground(TOMAColors.toolbarColor);
    }


    public void setData(apostal.toma.data.Unit u) {
        save.addActionListener(new UnitEventHandler(unitView, u));
        delete.addActionListener(new UnitEventHandler(unitView, u));
        sessions.addActionListener(new UnitEventHandler(unitView, u));
    }
}
