// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import java.awt.*;

import apostal.toma.data.ElementNotSpecified;
import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMAParameters;
import apostal.toma.view.TOMAMultipleElements;
import apostal.toma.data.Unit;
import apostal.toma.view.TOMATextField;
import apostal.toma.database.LanguageDB;
import apostal.toma.data.Language;

import apostal.toma.TOMA;

import toolbox.swing.MultipleLinesLabel;

import java.lang.Class;
import java.lang.Integer;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class UnitViewDetails extends JScrollPane {
    private static int multipleElementsLength = 30;
    private static Vector languages;

    static {
        /*TOMAParameters params=TOMA.getInstance().getTomaParameters();
        Language ln=params.getLanguage();

        languages=LanguageDB.loadSomeLanguages(ln,true,false,false);*/

        languages = TOMA.getInstance().getLanguages();
    }

    private TOMALabels labels;

    private Vector allowed_prerequisites;
    private Vector allowed_keywords;
    private Vector allowed_languages;

    JPanel jPanel1 = new JPanel();
    GridBagLayout gridBagLayout1 = new GridBagLayout();
    TOMAMultipleLinesLabel label_partnership = new TOMAMultipleLinesLabel(10);
    TOMATextArea partnership = new TOMATextArea(3, 30);
    JComponent partnershipComponent;

    TOMAMultipleLinesLabel label_pedagogicalMethods = new TOMAMultipleLinesLabel(10);
    TOMATextArea pedagogicalMethods = new TOMATextArea(3, 30);
    JComponent pedagogicalMethodsComponent;

    TOMAMultipleLinesLabel label_courseMedia = new TOMAMultipleLinesLabel(10);
    TOMATextArea courseMedia = new TOMATextArea(3, 30);
    JComponent courseMediaComponent;

    TOMAMultipleLinesLabel label_evaluation = new TOMAMultipleLinesLabel(10);
    TOMATextArea evaluation = new TOMATextArea(3, 30);
    JComponent evaluationComponent;

    TOMAMultipleLinesLabel label_commentNotPublished = new TOMAMultipleLinesLabel(10);
    TOMATextArea commentNotPublished = new TOMATextArea(3, 30);
    TOMAMultipleLinesLabel label_comment = new TOMAMultipleLinesLabel(10);
    TOMATextArea comment = new TOMATextArea(3, 30);
    JComponent commentComponent;

    TOMAMultipleElements keywords;
    TOMALabel label_keywords = new TOMALabel();

    TOMAMultipleLinesLabel label_duration = new TOMAMultipleLinesLabel(10);
    TOMATextArea duration = new TOMATextArea(3, 30);
    JComponent durationComponent;

    TOMALabel label_prerequisites = new TOMALabel();
    TOMAMultipleElements prerequisites;

    TOMALabel label_languages = new TOMALabel();
    TOMAMultipleElements languagesCombo;

    public UnitViewDetails() {
        try {
            labels = new TOMALabels();
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        int type = TOMATemplateView.UNITVIEW;

        this.setBackground(TOMAColors.trainingTabBackgroundColor);

        jPanel1.setLayout(gridBagLayout1);
        jPanel1.setBackground(TOMAColors.trainingTabBackgroundColor);

        //language
        JPanel panelLabelLanguages = new JPanel();
        panelLabelLanguages.setLayout(new FlowLayout(FlowLayout.LEFT));
        panelLabelLanguages.setBackground(TOMAColors.listsLabelBackgroundColor);
        panelLabelLanguages.add(label_languages);
        label_languages.setText(labels.get("apostal.toma.trainingview.languages"));
        TOMATemplateResult languageResult = TOMATemplateView.getTemplateResult(type, "language");
        if (languageResult.isMandatory())
            label_languages.setText(label_languages.getText() + " (*)");
        Class[] classes_lng = new Class[1];
        classes_lng[0] = Class.forName("java.util.Vector");
        Object[] values_lng = new Object[1];
        values_lng[0] = this.languages;
        if (languageResult.getValues() != null && !languageResult.getValues().isEmpty()) {
            allowed_languages = new Vector();
            Iterator iter = languageResult.getValues().iterator();
            while (iter.hasNext()) {
                String ln_code = (String) iter.next();
                //trouver le language associ dans languages
                Iterator iter2 = languages.iterator();
                Language ln = null;
                while (iter2.hasNext() & ln == null) {
                    Language language = (Language) iter2.next();
                    if (language != null && language.getCode().equals(ln_code))
                        ln = language;
                }
                allowed_languages.add(ln);
            }
            values_lng[0] = allowed_languages;
        } else
            allowed_languages = languages;

        languagesCombo = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes_lng, values_lng, 0, null, labels.get("apostal.toma.trainingview.addLanguage"), labels.get("apostal.toma.trainingview.removeLanguage"), TOMAColors.multipleElementsColor, 265, 80);
        if (languageResult.isForbidden())
            languagesCombo.setEnabled(false);

        /*label_languages.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_languages.setForeground(TOMAColors.unclickableTextColor);*/

        //partnership
        label_partnership.setText(labels.get("apostal.toma.trainingview.partnership"));
        JScrollPane pane_partnership = new JScrollPane(partnership);
        TOMATemplateResult partnershipResult = TOMATemplateView.getTemplateResult(type, "partnership");
        if (partnershipResult.isForbidden())
            partnership.setEnabled(false);
        if (partnershipResult.isMandatory())
            label_partnership.setText(label_partnership.getText() + " (*)");
        if (partnershipResult.getMaximum() > -1)
            label_partnership.setText(label_partnership.getText() + " (" + new Integer(partnershipResult.getMaximum()) + ")");
        if (partnershipResult.getValues() != null && !partnershipResult.getValues().isEmpty()) {
            Vector v = partnershipResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox partnershipCombo = new TOMAComboBox(v);
            partnershipComponent = partnershipCombo;
        } else
            partnershipComponent = pane_partnership;

        //pedagogicalMethods
        label_pedagogicalMethods.setText(labels.get("apostal.toma.trainingview.pedagogicalMethods"));
        JScrollPane pane_pedagogicalMethods = new JScrollPane(pedagogicalMethods);
        TOMATemplateResult pedagogicalMethodsResult = TOMATemplateView.getTemplateResult(type, "pedagogicalMethods");
        if (pedagogicalMethodsResult.isForbidden())
            pedagogicalMethods.setEnabled(false);
        if (pedagogicalMethodsResult.isMandatory())
            label_pedagogicalMethods.setText(label_pedagogicalMethods.getText() + " (*)");
        if (pedagogicalMethodsResult.getMaximum() > -1)
            label_pedagogicalMethods.setText(label_pedagogicalMethods.getText() + " (" + new Integer(pedagogicalMethodsResult.getMaximum()) + ")");
        if (pedagogicalMethodsResult.getValues() != null && !pedagogicalMethodsResult.getValues().isEmpty()) {
            Vector v = pedagogicalMethodsResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox pedagogicalMethodsCombo = new TOMAComboBox(v);
            pedagogicalMethodsComponent = pedagogicalMethodsCombo;
        } else
            pedagogicalMethodsComponent = pane_pedagogicalMethods;

        //courseMedia
        label_courseMedia.setText(labels.get("apostal.toma.trainingview.courseMedia"));
        JScrollPane pane_courseMedia = new JScrollPane(courseMedia);
        TOMATemplateResult courseMediaResult = TOMATemplateView.getTemplateResult(type, "courseMedia");
        if (courseMediaResult.isForbidden())
            courseMedia.setEnabled(false);
        if (courseMediaResult.isMandatory())
            label_courseMedia.setText(label_courseMedia.getText() + " (*)");
        if (courseMediaResult.getMaximum() > -1)
            label_courseMedia.setText(label_courseMedia.getText() + " (" + new Integer(courseMediaResult.getMaximum()) + ")");
        if (courseMediaResult.getValues() != null && !courseMediaResult.getValues().isEmpty()) {
            Vector v = courseMediaResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox courseMediaCombo = new TOMAComboBox(v);
            courseMediaComponent = courseMediaCombo;
        } else
            courseMediaComponent = pane_courseMedia;

        //duration
        label_duration.setText(labels.get("apostal.toma.trainingview.duration"));
        JScrollPane pane_duration = new JScrollPane(duration);
        TOMATemplateResult durationResult = TOMATemplateView.getTemplateResult(type, "duration");
        if (durationResult.isForbidden())
            duration.setEnabled(false);
        if (durationResult.isMandatory())
            label_duration.setText(label_duration.getText() + " (*)");
        if (durationResult.getMaximum() > -1)
            label_duration.setText(label_duration.getText() + " (" + new Integer(durationResult.getMaximum()) + ")");
        if (durationResult.getValues() != null && !durationResult.getValues().isEmpty()) {
            Vector v = durationResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox durationCombo = new TOMAComboBox(v);
            durationComponent = durationCombo;
        } else
            durationComponent = pane_duration;

        //evaluation
        label_evaluation.setText(labels.get("apostal.toma.trainingview.evaluation"));
        JScrollPane pane_evaluation = new JScrollPane(evaluation);
        TOMATemplateResult evaluationResult = TOMATemplateView.getTemplateResult(type, "evaluation");
        if (evaluationResult.isForbidden())
            evaluation.setEnabled(false);
        if (evaluationResult.isMandatory())
            label_evaluation.setText(label_evaluation.getText() + " (*)");
        if (evaluationResult.getMaximum() > -1)
            label_evaluation.setText(label_evaluation.getText() + " (" + new Integer(evaluationResult.getMaximum()) + ")");
        if (evaluationResult.getValues() != null && !evaluationResult.getValues().isEmpty()) {
            Vector v = evaluationResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox evaluationCombo = new TOMAComboBox(v);
            evaluationComponent = evaluationCombo;
        } else
            evaluationComponent = pane_evaluation;

        //comment not published
        label_commentNotPublished.setText(labels.get("apostal.toma.trainingview.commentNotPublished"));
        JScrollPane pane_commentNotPublished = new JScrollPane(commentNotPublished);

        //comment
        label_comment.setText(labels.get("apostal.toma.trainingview.comment"));
        JScrollPane pane_comment = new JScrollPane(comment);
        TOMATemplateResult commentResult = TOMATemplateView.getTemplateResult(type, "comment");
        if (commentResult.isForbidden())
            comment.setEnabled(false);
        if (commentResult.isMandatory())
            label_comment.setText(label_comment.getText() + " (*)");
        if (commentResult.getMaximum() > -1)
            label_comment.setText(label_comment.getText() + " (" + new Integer(commentResult.getMaximum()) + ")");
        if (commentResult.getValues() != null && !commentResult.getValues().isEmpty()) {
            Vector v = commentResult.getValues();
            v.insertElementAt(ElementNotSpecified.getInstance(), 0);
            TOMAComboBox commentCombo = new TOMAComboBox(v);
            commentComponent = commentCombo;
        } else
            commentComponent = pane_comment;

        //prerequisites
        JPanel panelLabelPrerequisites = new JPanel();
        panelLabelPrerequisites.setLayout(new FlowLayout(FlowLayout.LEFT));
        panelLabelPrerequisites.setBackground(TOMAColors.listsLabelBackgroundColor);
        panelLabelPrerequisites.add(label_prerequisites);
        label_prerequisites.setText(labels.get("apostal.toma.trainingview.prerequisites"));
        TOMATemplateResult prerequisitesResult = TOMATemplateView.getTemplateResult(type, "prerequisites");
        if (prerequisitesResult.isMandatory())
            label_prerequisites.setText(label_prerequisites.getText() + " (*)");
        if (prerequisitesResult.getMaximum() > -1)
            label_prerequisites.setText(label_prerequisites.getText() + " (" + new Integer(prerequisitesResult.getMaximum()) + ")");
        if (prerequisitesResult.getValues() != null && !prerequisitesResult.getValues().isEmpty()) {
            allowed_prerequisites = prerequisitesResult.getValues();
            Class[] classes_pre = new Class[1];
            classes_pre[0] = Class.forName("java.util.Vector");
            Object[] values_pre = new Object[1];
            values_pre[0] = allowed_prerequisites;
            prerequisites = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes_pre, values_pre, 0, null, labels.get("apostal.toma.trainingview.addPrerequisite"), labels.get("apostal.toma.trainingview.removePrerequisite"), TOMAColors.multipleElementsColor, 360, 80);
        } else {
            Class[] classes_pre = new Class[1];
            classes_pre[0] = Class.forName("java.lang.Integer");
            Object[] values_pre = new Object[1];
            values_pre[0] = new Integer(UnitViewDetails.multipleElementsLength);
            prerequisites = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes_pre, values_pre, 0, null, labels.get("apostal.toma.trainingview.addPrerequisite"), labels.get("apostal.toma.trainingview.removePrerequisite"), TOMAColors.multipleElementsColor, 360, 80);
        }
        if (prerequisitesResult.isForbidden())
            prerequisites.setEnabled(false);

        /*label_prerequisites.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_prerequisites.setForeground(TOMAColors.unclickableTextColor);*/

        //keywords
        JPanel panelLabelKeywords = new JPanel();
        panelLabelKeywords.setLayout(new FlowLayout(FlowLayout.LEFT));
        panelLabelKeywords.setBackground(TOMAColors.listsLabelBackgroundColor);
        panelLabelKeywords.add(label_keywords);
        label_keywords.setText(labels.get("apostal.toma.trainingview.keywords"));
        TOMATemplateResult keywordsResult = TOMATemplateView.getTemplateResult(type, "keyword");
        if (keywordsResult.isMandatory())
            label_keywords.setText(label_keywords.getText() + " (*)");
        if (keywordsResult.getMaximum() > -1)
            label_keywords.setText(label_keywords.getText() + " (" + new Integer(keywordsResult.getMaximum()) + ")");
        if (keywordsResult.getValues() != null && !keywordsResult.getValues().isEmpty()) {
            allowed_keywords = keywordsResult.getValues();
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.util.Vector");
            Object[] values = new Object[1];
            values[0] = allowed_keywords;
            keywords = new TOMAMultipleElements("apostal.toma.view.TOMAComboBox", classes, values, 0, null, labels.get("apostal.toma.trainingview.addKeyword"), labels.get("apostal.toma.trainingview.removeKeyword"), TOMAColors.multipleElementsColor, 360, 80);
        } else {
            Class[] classes = new Class[1];
            classes[0] = Class.forName("java.lang.Integer");
            Object[] values = new Object[1];
            values[0] = new Integer(UnitViewDetails.multipleElementsLength);
            keywords = new TOMAMultipleElements("apostal.toma.view.TOMATextField", classes, values, 0, null, labels.get("apostal.toma.trainingview.addKeyword"), labels.get("apostal.toma.trainingview.removeKeyword"), TOMAColors.multipleElementsColor, 360, 80);
        }
        if (keywordsResult.isForbidden())
            keywords.setEnabled(false);

        /*label_keywords.setBackground(TOMAColors.trainingTabBackgroundColor);
        label_keywords.setForeground(TOMAColors.unclickableTextColor);*/

        this.getViewport().add(jPanel1);

        int anchor = GridBagConstraints.NORTHWEST;
        int fill = GridBagConstraints.NONE;
        Insets insets = new Insets(0, 10, 3, 0);

        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
                , anchor, fill, insets, 0, 0);

        jPanel1.add(label_partnership, cons);
        cons.gridx = 1;
        jPanel1.add(partnershipComponent, cons);
        cons.gridx = 0;
        cons.gridy = 1;
        jPanel1.add(label_pedagogicalMethods, cons);
        cons.gridx = 1;
        jPanel1.add(pedagogicalMethodsComponent, cons);
        cons.gridx = 0;
        cons.gridy = 2;
        jPanel1.add(label_courseMedia, cons);
        cons.gridx = 1;
        jPanel1.add(courseMediaComponent, cons);
        cons.gridx = 0;
        cons.gridy = 3;
        cons.gridwidth = 2;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(panelLabelKeywords, cons);
        cons.gridx = 0;
        cons.gridy = 4;
        cons.gridheight = 2;
        cons.fill = fill;
        jPanel1.add(keywords, cons);
        cons.gridy = 6;
        cons.gridheight = 1;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(panelLabelPrerequisites, cons);
        cons.gridy = 7;
        cons.gridheight = 2;
        cons.fill = fill;
        jPanel1.add(prerequisites, cons);

        //2eme colonne
        insets = new Insets(0, 15, 3, 0);
        cons.gridx = 2;
        cons.gridy = 3;
        cons.gridwidth = 1;
        jPanel1.add(label_commentNotPublished, cons);
        cons.gridx = 3;
        jPanel1.add(pane_commentNotPublished, cons);
        cons.gridx = 2;
        cons.gridy = 2;
        cons.gridheight = 1;
        jPanel1.add(label_comment, cons);
        cons.gridx = 3;
        jPanel1.add(commentComponent, cons);
        cons.gridx = 2;
        cons.gridy = 1;
        jPanel1.add(label_duration, cons);
        cons.gridx = 3;
        jPanel1.add(durationComponent, cons);
        cons.gridx = 2;
        cons.gridy = 0;
        jPanel1.add(label_evaluation, cons);
        cons.gridx = 3;
        jPanel1.add(evaluationComponent, cons);
        cons.gridx = 2;
        cons.gridy = 6;
        cons.gridwidth = 2;
        cons.fill = GridBagConstraints.HORIZONTAL;
        jPanel1.add(panelLabelLanguages, cons);
        cons.gridy = 7;
        cons.gridheight = 2;
        cons.fill = fill;
        jPanel1.add(languagesCombo, cons);

        //fill
        cons.gridx = 0;
        cons.gridy = 9;
        cons.gridwidth = 1;
        cons.gridheight = 1;
        cons.weighty = 1.0;
        cons.insets = new Insets(0, 0, 0, 0);
        jPanel1.add(Box.createGlue(), cons);
        cons.gridx = 4;
        cons.gridy = 0;
        cons.weightx = 1.0;
        cons.weighty = 0.0;
        jPanel1.add(Box.createGlue(), cons);
    }

    /**
     * agit directement sur le tc pass en paramtre
     */
    public void getData(Unit t) {
        if (!durationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setDuration(duration.getText());
        else {
            try {
                t.setDuration((String) ((TOMAComboBox) durationComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setDuration(null);
            }
        }

        if (!partnershipComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPartnership(partnership.getText());
        else {
            try {
                t.setPartnership((String) ((TOMAComboBox) partnershipComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setPartnership(null);
            }
        }

        if (!pedagogicalMethodsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setPedagogicalMethods(pedagogicalMethods.getText());
        else {
            try {
                t.setPedagogicalMethods((String) ((TOMAComboBox) pedagogicalMethodsComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setPedagogicalMethods(null);
            }
        }

        if (!courseMediaComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setCourseMedia(courseMedia.getText());
        else {
            try {
                t.setCourseMedia((String) ((TOMAComboBox) courseMediaComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setCourseMedia(null);
            }
        }

        if (!evaluationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setEvaluation(evaluation.getText());
        else {
            try {
                t.setEvaluation((String) ((TOMAComboBox) evaluationComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setEvaluation(null);
            }
        }

        if (!commentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            t.setComment(comment.getText());
        else {
            try {
                t.setComment((String) ((TOMAComboBox) commentComponent).getSelectedItem());
            } catch (java.lang.ClassCastException ex) {
                t.setComment(null);
            }
        }

        t.setCommentNotPublished(commentNotPublished.getText());

        //keywords
        Vector words = new Vector();
        JComponent[] kws = keywords.getElements();
        int size = kws.length;
        for (int i = 0; i < size; i++) {
            try {
                JTextField field = (JTextField) kws[i];
                if (!words.contains(field.getText()))
                    words.add(field.getText());
            } catch (java.lang.ClassCastException ex) {
                TOMAComboBox box = (TOMAComboBox) kws[i];
                String txt = (String) box.getSelectedItem();
                if (!words.contains(txt))
                    words.add(txt);
            }
        }
        t.setKeywords(words);

        //prerequisites
        Vector t_prerequisites = new Vector();
        JComponent[] prerequisites_elements = prerequisites.getElements();
        int prsize = prerequisites_elements.length;
        for (int i = 0; i < prsize; i++) {
            try {
                JTextField field = (JTextField) prerequisites_elements[i];
                if (!t_prerequisites.contains(field.getText()))
                    t_prerequisites.add(field.getText());
            } catch (java.lang.ClassCastException ex) {
                TOMAComboBox box = (TOMAComboBox) prerequisites_elements[i];
                String txt = (String) box.getSelectedItem();
                if (!t_prerequisites.contains(txt))
                    t_prerequisites.add(txt);
            }
        }
        t.setPrerequisites(t_prerequisites);

        //languages
        Vector lngs = new Vector();
        JComponent[] languagesComponents = languagesCombo.getElements();
        int components_size = languagesComponents.length;
        for (int i = 0; i < components_size; i++) {
            TOMAComboBox combo = (TOMAComboBox) languagesComponents[i];
            Language l = (Language) combo.getSelectedItem();
            if (!lngs.contains(l))
                lngs.add(l);
        }
        t.setLanguages(lngs);

    }

    public void setData(Unit t) {
        if (!durationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            duration.setText(t.getDuration());
        else
            TOMATemplateView.setTextCombo(t.getDuration(), (TOMAComboBox) durationComponent);

        if (!partnershipComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            partnership.setText(t.getPartnership());
        else
            TOMATemplateView.setTextCombo(t.getPartnership(), (TOMAComboBox) partnershipComponent);

        if (!pedagogicalMethodsComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            pedagogicalMethods.setText(t.getPedagogicalMethods());
        else
            TOMATemplateView.setTextCombo(t.getPedagogicalMethods(), (TOMAComboBox) pedagogicalMethodsComponent);

        if (!courseMediaComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            courseMedia.setText(t.getCourseMedia());
        else
            TOMATemplateView.setTextCombo(t.getCourseMedia(), (TOMAComboBox) courseMediaComponent);

        if (!evaluationComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            evaluation.setText(t.getEvaluation());
        else
            TOMATemplateView.setTextCombo(t.getEvaluation(), (TOMAComboBox) evaluationComponent);

        if (!commentComponent.getClass().getName().equals("apostal.toma.view.TOMAComboBox"))
            comment.setText(t.getComment());
        else
            TOMATemplateView.setTextCombo(t.getComment(), (TOMAComboBox) commentComponent);

        commentNotPublished.setText(t.getCommentNotPublished());

        //keywords
        Vector k = t.getKeywords();
        if (k != null) {
            Vector words = new Vector();

            Iterator iter = k.iterator();
            while (iter.hasNext()) {
                String keyword = (String) iter.next();
                if (keyword != null) {
                    if (allowed_keywords == null || allowed_keywords.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(UnitViewDetails.multipleElementsLength));
                        field.setText(keyword);
                        words.add(field);
                    } else {
                        //combo boxes et pas text fields
                        Iterator iter2 = allowed_keywords.iterator();
                        String found = null;
                        while (iter2.hasNext() && found == null) {
                            String kw = (String) iter2.next();
                            if (keyword.equals(kw))
                                found = kw;
                        }
                        if (found == null) {
                            allowed_keywords.add(keyword);
                            found = keyword;
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_keywords);
                        box.setSelectedItem(found);
                        words.add(box);
                    }
                }
            }
            keywords.setElements(words);
        }

        //prerequisites
        Vector pr = t.getPrerequisites();
        if (pr != null) {
            Iterator priter = pr.iterator();
            Vector prerequisites_elements = new Vector();
            while (priter.hasNext()) {
                String prerequisite = (String) priter.next();
                if (prerequisite != null) {
                    if (allowed_prerequisites == null || allowed_prerequisites.isEmpty()) {
                        TOMATextField field = new TOMATextField(new Integer(UnitViewDetails.multipleElementsLength));
                        field.setText(prerequisite);
                        prerequisites_elements.add(field);
                    } else {
                        //combo boxes et pas text fields
                        Iterator iter2 = allowed_prerequisites.iterator();
                        String found = null;
                        while (iter2.hasNext() && found == null) {
                            String pre = (String) iter2.next();
                            if (prerequisite.equals(pre))
                                found = pre;
                        }
                        if (found == null) {
                            allowed_prerequisites.add(prerequisite);
                            found = prerequisite;
                        }
                        TOMAComboBox box = new TOMAComboBox(allowed_prerequisites);
                        box.setSelectedItem(found);
                        prerequisites_elements.add(box);
                    }
                }
            }
            prerequisites.setElements(prerequisites_elements);
        }

        //languages
        Vector lng_combo = new Vector();
        Vector t_languages = t.getLanguages();
        if (t_languages != null) {
            Iterator t_languages_iter = t_languages.iterator();
            while (t_languages_iter.hasNext()) {
                Language lng = (Language) t_languages_iter.next();
                if (lng != null) {
                    String code = lng.getCode();

                    //trouver le language  slectionner dans languages
                    Language selectedLanguage = null;
                    Iterator languages_iter = languages.iterator();
                    while (languages_iter.hasNext() && selectedLanguage == null) {
                        Language l_found = (Language) languages_iter.next();
                        if (l_found != null && l_found.getCode().equals(code))
                            selectedLanguage = l_found;
                    }

                    if (selectedLanguage != null) {
                        TOMAComboBox combo = new TOMAComboBox(allowed_languages);
                        combo.setSelectedItem(selectedLanguage);
                        lng_combo.add(combo);
                    } else
                        TOMA.log(TOMA.SEVERE, "language " + code + " not found in the list");
                }
            }
            languagesCombo.setElements(lng_combo);
        }
    }

    public String testTemplateElements() {
        //formation pour les tests de template uniquement
        apostal.toma.data.Unit u = new apostal.toma.data.Unit();
        this.getData(u);

        int type = TOMATemplateView.UNITVIEW;
        String msg = "";

        String msg_partnership = TOMATemplateView.testTemplateElement(type, "partnership", u.getPartnership(), labels.get("apostal.toma.trainingview.partnership"));
        if (msg_partnership != null)
            msg = msg + "\n" + msg_partnership;

        String msg_ped = TOMATemplateView.testTemplateElement(type, "pedagogicalMethods", u.getPedagogicalMethods(), labels.get("apostal.toma.trainingview.pedagogicalMethods"));
        if (msg_ped != null)
            msg = msg + "\n" + msg_ped;

        String msg_courseMedia = TOMATemplateView.testTemplateElement(type, "courseMedia", u.getCourseMedia(), labels.get("apostal.toma.trainingview.courseMedia"));
        if (msg_courseMedia != null)
            msg = msg + "\n" + msg_courseMedia;

        String msg_eval = TOMATemplateView.testTemplateElement(type, "evaluation", u.getEvaluation(), labels.get("apostal.toma.trainingview.evaluation"));
        if (msg_eval != null)
            msg = msg + "\n" + msg_eval;

        String msg_comment = TOMATemplateView.testTemplateElement(type, "comment", u.getComment(), labels.get("apostal.toma.trainingview.comment"));
        if (msg_comment != null)
            msg = msg + "\n" + msg_comment;

        String msg_kw = TOMATemplateView.testTemplateElement(type, "keyword", u.getKeywords(), labels.get("apostal.toma.trainingview.keywords"));
        if (msg_kw != null)
            msg = msg + "\n" + msg_kw;

        String msg_duration = TOMATemplateView.testTemplateElement(type, "duration", u.getDuration(), labels.get("apostal.toma.trainingview.duration"));
        if (msg_duration != null)
            msg = msg + "\n" + msg_duration;

        String msg_pre = TOMATemplateView.testTemplateElement(type, "prerequisites", u.getPrerequisites(), labels.get("apostal.toma.trainingview.prerequisites"));
        if (msg_pre != null)
            msg = msg + "\n" + msg_pre;

        String msg_lng = TOMATemplateView.testTemplateElement(type, "language", u.getLanguages(), labels.get("apostal.toma.trainingview.languages"));
        if (msg_lng != null)
            msg = msg + "\n" + msg_lng;

        if (msg.equals(""))
            return null;
        else
            return msg;
    }
}
