// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;
import java.util.Vector;
import java.util.Iterator;
import java.lang.Class;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.sql.Date;

import apostal.toma.data.TOMATemplateResult;
import apostal.toma.data.Unit;
import apostal.toma.view.*;
import apostal.toma.TOMA;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class UnitViewTabsPanel extends TrainingViewTabsPanel {
    UnitViewDetails details = new UnitViewDetails();
    UnitViewContacts contacts = new UnitViewContacts();
    TrainingViewContent content = new TrainingViewContent(TOMATemplateView.UNITVIEW);
    TrainingViewLocations locations = new TrainingViewLocations(TOMATemplateView.UNITVIEW);
    TrainingViewObjectives objectives = new TrainingViewObjectives(TOMATemplateView.UNITVIEW);
    TrainingViewPoints points = new TrainingViewPoints(TOMATemplateView.UNITVIEW);
    TrainingViewTeachers teachers = new TrainingViewTeachers(TOMATemplateView.UNITVIEW);

    public void updateTeachers() {
        if (teachers != null)
            teachers.updateTeachers();
    }

    public void updateContacts() {
        if (contacts != null)
            contacts.updateContacts();
    }

    public void updateLocations() {
        if (locations != null)
            locations.updateLocations();
    }

    public UnitViewTabsPanel() {
        super();

        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void jbInit() throws Exception {
        this.setFont(TOMAFonts.buttonsFont);

        int type = TOMATemplateView.UNITVIEW;

        this.addTOMATab(labels.get("apostal.toma.trainingview.details"), details);
        this.setSelectedComponent(details);

        String label_objectives = labels.get("apostal.toma.trainingview.objectives");
        TOMATemplateResult objectivesResult = TOMATemplateView.getTemplateResult(type, "objectives");
        if (objectivesResult.isMandatory())
            label_objectives = label_objectives + " (*)";
        //if(objectivesResult.getMaximum()>-1)
        //label_objectives=label_objectives+" ("+new Integer(objectivesResult.getMaximum())+")";
        this.addTOMATab(label_objectives, objectives);

        String label_points = labels.get("apostal.toma.trainingview.pointsDealtWith");
        TOMATemplateResult pointsResult = TOMATemplateView.getTemplateResult(type, "pointsDealtWith");
        if (pointsResult.isMandatory())
            label_points = label_points + " (*)";
        //if(pointsResult.getMaximum()>-1)
        //label_points=label_points+" ("+new Integer(pointsResult.getMaximum())+")";
        this.addTOMATab(label_points, points);

        String label_content = labels.get("apostal.toma.trainingview.content");
        TOMATemplateResult contentResult = TOMATemplateView.getTemplateResult(type, "contentDescription");
        if (contentResult.isMandatory())
            label_content = label_content + " (*)";
        //if(contentResult.getMaximum()>-1)
        //label_content=label_content+" ("+new Integer(contentResult.getMaximum())+")";
        this.addTOMATab(label_content, content);

        String label_locations = labels.get("apostal.toma.trainingview.locations");
        TOMATemplateResult locationsResult = TOMATemplateView.getTemplateResult(type, "location");
        if (locationsResult.isMandatory())
            label_locations = label_locations + " (*)";
        this.addTOMATab(label_locations, locations);

        String label_contacts = labels.get("apostal.toma.trainingview.contacts");
        TOMATemplateResult contactsResult = TOMATemplateView.getTemplateResult(type, "trainingContact");
        if (contactsResult.isMandatory())
            label_contacts = label_contacts + " (*)";
        this.addTOMATab(label_contacts, contacts);

        String label_teachers = labels.get("apostal.toma.trainingview.teachers");
        TOMATemplateResult teachersResult = TOMATemplateView.getTemplateResult(type, "teacher");
        if (teachersResult.isMandatory())
            label_teachers = label_teachers + " (*)";
        this.addTOMATab(label_teachers, teachers);
    }

    public void getData(Unit t) {
        details.getData(t);
        objectives.getData(t);
        points.getData(t);
        content.getData(t);
        locations.getData(t);
        contacts.getData(t);
        teachers.getData(t);
    }

    public void setData(Unit t) {
        details.setData(t);
        objectives.setData(t);
        points.setData(t);
        content.setData(t);
        locations.setData(t);
        contacts.setData(t);
        teachers.setData(t);
    }

    public String testTemplateElements() {
        int type = TOMATemplateView.UNITVIEW;
        String msg = "";

        String msg_details = details.testTemplateElements();
        if (msg_details != null)
            msg = msg_details;

        String msg_obj = objectives.testTemplateElements(type);
        if (msg_obj != null)
            msg = msg + msg_obj;

        String msg_pdw = points.testTemplateElements(type);
        if (msg_pdw != null)
            msg = msg + msg_pdw;

        String msg_content = content.testTemplateElements(type);
        if (msg_content != null)
            msg = msg + msg_content;

        String msg_locations = locations.testTemplateElements(type);
        if (msg_locations != null)
            msg = msg + msg_locations;

        String msg_contacts = contacts.testTemplateElements();
        if (msg_contacts != null)
            msg = msg + msg_contacts;

        String msg_teachers = teachers.testTemplateElements(type);
        if (msg_teachers != null)
            msg = msg + msg_teachers;

        if (msg.equals(""))
            return null;
        else
            return msg;
    }


    private void addTOMATab(String s, Component c) {
        String maj = s.toUpperCase();
        this.addTab(maj, c);

        int i = this.getTabCount();
        //this.setForegroundAt(i-1, TOMAColors.clickableTextColor);
        this.setForegroundAt(i - 1, TOMAColors.trainingTabTitleForegroundColor);
        //this.setBackgroundAt(i-1, TOMAColors.trainingTabBackgroundColor);
        this.setBackgroundAt(i - 1, TOMAColors.trainingTabTitleBackgroundColor);
    }
}