// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import apostal.toma.data.TOMALabels;

import java.util.Vector;
import java.util.Iterator;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class ViewTrainingAux extends JPanel {
    private TOMALabels labels;

    public ViewTrainingAux(Training t) {
        labels = new TOMALabels();

        this.setLayout(new GridBagLayout());
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(2, 2, 2, 2), 0, 0);

        /*String title=labels.get("apostal.toma.viewtraining.whowhere");
        this.setBorder(new TitledBorder(new LineBorder(java.awt.Color.black), title, TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.DEFAULT_POSITION, ViewTraining.titleFont, ViewTraining.titleColor));*/

        //locations
        TOMALabel label_loc = new TOMALabel(labels.get("apostal.toma.trainingview.locations"));
        cons.gridx = 0;
        cons.gridy = 0;
        this.add(label_loc, cons);
        TOMATextArea loc = new TOMATextArea(1, 20);
        loc.setEditable(false);
        if (t.getLocations() != null) {
            String txt = "";
            Iterator iter = t.getLocations().iterator();
            while (iter.hasNext()) {
                Location location = (Location) iter.next();
                txt = txt + location.toString() + "\n";
            }

            txt = txt.trim();
            loc.setText(txt);
        }
        cons.gridx = 1;
        cons.gridwidth = 3;
        this.add(loc, cons);

        //training contacts
        TOMALabel label_tc = new TOMALabel(labels.get("apostal.toma.trainingview.contacts.trainingContacts"));
        cons.gridx = 0;
        cons.gridy = 1;
        cons.gridwidth = 1;
        this.add(label_tc, cons);
        TOMATextArea tc = new TOMATextArea(1, 20);
        tc.setEditable(false);
        if (t.getTrainingContacts() != null) {
            String txt = "";
            Iterator iter = t.getTrainingContacts().iterator();
            while (iter.hasNext()) {
                Contact c = (Contact) iter.next();
                txt = txt + c.toString() + "\n";
            }
            txt = txt.trim();
            tc.setText(txt);
        }
        cons.gridx = 1;
        this.add(tc, cons);

        //inscription contacts
        try {
            StandaloneTraining st = (StandaloneTraining) t;

            TOMALabel label_ic = new TOMALabel(labels.get("apostal.toma.trainingview.contacts.inscriptionContacts"));
            cons.gridx = 2;
            this.add(label_ic, cons);
            TOMATextArea ic = new TOMATextArea(1, 20);
            ic.setEditable(false);
            if (st.getInscriptionContacts() != null) {
                String txt = "";
                Iterator iter = st.getInscriptionContacts().iterator();
                while (iter.hasNext()) {
                    Contact c = (Contact) iter.next();
                    txt = txt + c.toString() + "\n";
                }
                txt = txt.trim();
                ic.setText(txt);
            }
            cons.gridx = 3;
            this.add(ic, cons);

        } catch (java.lang.ClassCastException ex) {
        }

        //teachers
        TOMALabel label_tea = new TOMALabel(labels.get("apostal.toma.trainingview.teachers"));
        cons.gridx = 0;
        cons.gridy = 2;
        this.add(label_tea, cons);
        TOMATextArea tea = new TOMATextArea(1, 60);
        tea.setEditable(false);
        if (t.getTeachers() != null) {
            String txt = "";
            Iterator iter = t.getTeachers().iterator();
            int cpt = 0;
            while (iter.hasNext()) {
                Teacher teacher = (Teacher) iter.next();
                txt = txt + teacher.toString() + "\n";

                try {
                    String comp = (String) t.getCompetences().elementAt(cpt);
                    txt = txt + "  (" + labels.get("apostal.toma.trainingview.teachers.competenceName") + ": " + comp + ")\n";

                } catch (java.lang.Exception ex) {
                }

                cpt++;
            }
            txt = txt.trim();
            tea.setText(txt);
        }
        cons.gridx = 1;
        cons.gridwidth = 3;
        this.add(tea, cons);

        this.setBackground(TOMAColors.auxBackgroundColor2);
    }

}
