// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import apostal.toma.data.TOMALabels;
import apostal.toma.database.DomainDB;

import java.util.Vector;
import java.util.Iterator;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class ViewTrainingDetails extends JPanel {
    private TOMALabels labels;

    public ViewTrainingDetails(StandaloneTraining t) {
        labels = new TOMALabels();

        this.setLayout(new GridBagLayout());
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(2, 2, 2, 2), 0, 0);

        /*String title=labels.get("apostal.toma.trainingview.details");
        this.setBorder(new TitledBorder(new LineBorder(java.awt.Color.black), title, TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.DEFAULT_POSITION, ViewTraining.titleFont, ViewTraining.titleColor));*/

        //partnership
        TOMALabel label_par = new TOMALabel(labels.get("apostal.toma.trainingview.partnership"));
        this.add(label_par, cons);
        TOMATextArea par = new TOMATextArea(1, 20);
        par.setEditable(false);
        par.setText(t.getPartnership());
        cons.gridx = 1;
        this.add(par, cons);

        //evaluation
        TOMALabel label_eval = new TOMALabel(labels.get("apostal.toma.trainingview.evaluation"));
        cons.gridx = 2;
        this.add(label_eval, cons);
        TOMATextArea eval = new TOMATextArea(1, 20);
        eval.setEditable(false);
        eval.setText(t.getEvaluation());
        cons.gridx = 3;
        this.add(eval, cons);

        //ped
        TOMALabel label_ped = new TOMALabel(labels.get("apostal.toma.trainingview.pedagogicalMethods"));
        cons.gridy = 1;
        cons.gridx = 0;
        this.add(label_ped, cons);
        TOMATextArea ped = new TOMATextArea(1, 20);
        ped.setEditable(false);
        ped.setText(t.getPedagogicalMethods());
        cons.gridx = 1;
        this.add(ped, cons);

        //cert
        TOMALabel label_cert = new TOMALabel(labels.get("apostal.toma.trainingview.certificatesOrDiplomas"));
        cons.gridx = 2;
        this.add(label_cert, cons);
        TOMATextArea cert = new TOMATextArea(1, 20);
        cert.setEditable(false);
        cert.setText(t.getCertificatesOrDiplomas());
        cons.gridx = 3;
        this.add(cert, cons);

        //courseMedia
        TOMALabel label_course = new TOMALabel(labels.get("apostal.toma.trainingview.courseMedia"));
        cons.gridy = 2;
        cons.gridx = 0;
        this.add(label_course, cons);
        TOMATextArea course = new TOMATextArea(1, 20);
        course.setEditable(false);
        course.setText(t.getCourseMedia());
        cons.gridx = 1;
        this.add(course, cons);

        //comment
        TOMALabel label_com = new TOMALabel(labels.get("apostal.toma.trainingview.comment"));
        cons.gridx = 2;
        this.add(label_com, cons);
        TOMATextArea com = new TOMATextArea(1, 20);
        com.setEditable(false);
        com.setText(t.getComment());
        cons.gridx = 3;
        this.add(com, cons);

        //commentNotPublished
        TOMALabel label_comnp = new TOMALabel(labels.get("apostal.toma.trainingview.commentNotPublished"));
        cons.gridy = 3;
        cons.gridx = 0;
        this.add(label_comnp, cons);
        TOMATextArea comnp = new TOMATextArea(1, 20);
        comnp.setEditable(false);
        comnp.setText(t.getCommentNotPublished());
        cons.gridx = 1;
        this.add(comnp, cons);

        //keywords
        TOMALabel label_kw = new TOMALabel(labels.get("apostal.toma.trainingview.keywords"));
        cons.gridx = 2;
        this.add(label_kw, cons);
        TOMATextArea kw = new TOMATextArea(1, 20);
        kw.setEditable(false);
        if (t.getKeywords() != null) {
            String kwtext = "";
            Iterator iter = t.getKeywords().iterator();
            while (iter.hasNext()) {
                String k = (String) iter.next();
                kwtext = kwtext + k + "\n";
            }
            kwtext = kwtext.trim();
            kw.setText(kwtext);
        }
        cons.gridx = 3;
        this.add(kw, cons);

        //languages
        TOMALabel label_lng = new TOMALabel(labels.get("apostal.toma.trainingview.languages"));
        cons.gridy = 4;
        cons.gridx = 0;
        this.add(label_lng, cons);
        TOMATextArea lng = new TOMATextArea(1, 20);
        lng.setEditable(false);
        if (t.getLanguages() != null) {
            String lngText = "";
            Iterator iter = t.getLanguages().iterator();
            while (iter.hasNext()) {
                Language l = (Language) iter.next();
                lngText = lngText + l.getName() + "\n";
            }
            lngText = lngText.trim();
            lng.setText(lngText);
        }
        cons.gridx = 1;
        this.add(lng, cons);

        //domains
        Language tomaLng = TOMA.getInstance().getTomaParameters().getLanguage();
        TOMALabel label_dom = new TOMALabel(labels.get("apostal.toma.trainingview.domains"));
        cons.gridy = 5;
        cons.gridx = 0;
        this.add(label_dom, cons);
        TOMATextArea dom = new TOMATextArea(1, 50);
        dom.setEditable(false);
        if (t.getDomains() != null) {
            String domText = "";
            Vector doms = t.getDomains();
            Vector fils = DomainDB.reduceToLastLevelsDomains(tomaLng, doms);

            Iterator iter = fils.iterator();
            while (iter.hasNext()) {
                Domain d = (Domain) iter.next();
                String text = d.getName();
                DomainDB ddb = new DomainDB(d);
                d = ddb.getSuperDomain(tomaLng);

                while (d != null) {
                    text = d.getName() + " / " + text;
                    ddb = new DomainDB(d);
                    d = ddb.getSuperDomain(tomaLng);
                }

                domText = domText + text + "\n";
            }
            domText = domText.trim();
            dom.setText(domText);
        }
        cons.gridx = 1;
        cons.gridwidth = 3;
        this.add(dom, cons);

        this.setBackground(TOMAColors.auxBackgroundColor2);
    }
}