// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;


import apostal.toma.data.*;

import apostal.toma.data.TOMALabels;

import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Vector;
import java.util.Iterator;
import java.sql.Date;
import javax.swing.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class ViewTrainingMain extends JPanel {
    private TOMALabels labels;

    public ViewTrainingMain(Training t) {
        labels = new TOMALabels();

        this.setLayout(new GridBagLayout());
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(2, 2, 2, 2), 0, 0);

        //title
        TOMALabel label_title = new TOMALabel(labels.get("apostal.toma.trainingview.title"));
        this.add(label_title, cons);
        TOMATextArea title = new TOMATextArea(1, 20);
        title.setEditable(false);
        title.setText(t.getTitle());
        cons.gridx = 1;
        this.add(title, cons);

        //code
        TOMALabel label_code = new TOMALabel(labels.get("apostal.toma.trainingview.code"));
        cons.gridx = 2;
        this.add(label_code, cons);
        TOMATextArea code = new TOMATextArea(1, 20);
        code.setEditable(false);
        code.setText(t.getCode());
        cons.gridx = 3;
        this.add(code, cons);

        //bvd
        TOMALabel label_bvd = new TOMALabel(labels.get("apostal.toma.trainingview.beginValidityDate"));
        cons.gridy = 1;
        cons.gridx = 0;
        this.add(label_bvd, cons);
        TOMATextArea bvd = new TOMATextArea(1, 20);
        bvd.setEditable(false);
        Date tbvd = t.getBeginValidityDate();
        if (tbvd != null) {
            GregorianCalendar cal = new GregorianCalendar();
            cal.setTime(tbvd);
            bvd.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
        }
        cons.gridx = 1;
        this.add(bvd, cons);

        //level
        TOMALabel label_level = new TOMALabel(labels.get("apostal.toma.trainingview.level"));
        cons.gridx = 2;
        this.add(label_level, cons);
        TOMATextArea level = new TOMATextArea(1, 20);
        level.setEditable(false);
        Level tlevel = t.getLevel();
        if (tlevel != null)
            level.setText(tlevel.getName());
        cons.gridx = 3;
        this.add(level, cons);

        //evd
        TOMALabel label_evd = new TOMALabel(labels.get("apostal.toma.trainingview.endValidityDate"));
        cons.gridx = 0;
        cons.gridy = 2;
        this.add(label_evd, cons);
        TOMATextArea evd = new TOMATextArea(1, 20);
        evd.setEditable(false);
        Date tevd = t.getEndValidityDate();
        if (tevd != null) {
            GregorianCalendar cal = new GregorianCalendar();
            cal.setTime(tevd);
            evd.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
        }
        cons.gridx = 1;
        this.add(evd, cons);

        //moo
        TOMALabel label_moo = new TOMALabel(labels.get("apostal.toma.trainingview.modeOfOrganization"));
        cons.gridx = 2;
        this.add(label_moo, cons);
        TOMATextArea moo = new TOMATextArea(1, 20);
        moo.setEditable(false);
        ModeOfOrganization tmoo = t.getModeOfOrganization();
        if (tmoo != null)
            moo.setText(tmoo.getName());
        cons.gridx = 3;
        this.add(moo, cons);

        //slots
        TOMALabel label_slots = new TOMALabel(labels.get("apostal.toma.trainingview.slots"));
        cons.gridx = 0;
        cons.gridy = 3;
        this.add(label_slots, cons);
        TOMATextArea slots = new TOMATextArea(1, 20);
        slots.setEditable(false);
        String txtSlots = "";
        if (t.getSlots() != null) {
            Iterator iter = t.getSlots().iterator();
            while (iter.hasNext()) {
                Slot s = (Slot) iter.next();
                txtSlots = txtSlots + s.getName() + "\n";
            }
            txtSlots = txtSlots.trim();
        }
        slots.setText(txtSlots);
        cons.gridx = 1;
        this.add(slots, cons);

        this.setBackground(TOMAColors.auxBackgroundColor);
    }
}