// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import apostal.toma.data.TOMALabels;

import toolbox.text.ExtendedList;

import java.util.Vector;
import java.util.Iterator;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class ViewTrainingPoints extends JPanel {
    private TOMALabels labels;

    public ViewTrainingPoints(Training t) {
        labels = new TOMALabels();

        this.setLayout(new GridBagLayout());
        GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(2, 2, 2, 2), 0, 0);

        /*String title=labels.get("apostal.toma.viewtraining.points");
        this.setBorder(new TitledBorder(new LineBorder(java.awt.Color.black), title, TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.DEFAULT_POSITION, ViewTraining.titleFont, ViewTraining.titleColor));*/

        //obj
        TOMALabel label_obj = new TOMALabel(labels.get("apostal.toma.trainingview.objectives"));
        this.add(label_obj, cons);
        TOMATextArea obj = new TOMATextArea(1, 60);
        obj.setEditable(false);

        String objText = "";
        if (t.getObjectivesIntroduction() != null)
            objText = t.getObjectivesIntroduction() + "\n";
        if (t.getObjectives() != null) {
            Iterator iter = t.getObjectives().iterator();
            while (iter.hasNext()) {
                String o = (String) iter.next();
                objText = objText + "- " + o + "\n";
            }
        }
        if (t.getObjectivesConclusion() != null)
            objText = objText + t.getObjectivesConclusion();

        objText = objText.trim();
        obj.setText(objText);

        cons.gridx = 1;
        this.add(obj, cons);

        //points
        TOMALabel label_pt = new TOMALabel(labels.get("apostal.toma.trainingview.pointsDealtWith"));
        cons.gridy = 1;
        cons.gridx = 0;
        this.add(label_pt, cons);
        TOMATextArea pt = new TOMATextArea(1, 60);
        pt.setEditable(false);

        if (t.getPointsDealtWith() != null) {
            ExtendedList ex = t.getPointsDealtWith();
            String ptText = "";

            if (ex.getIntroduction() != null)
                ptText = ex.getIntroduction() + "\n";

            if (ex.getList() != null) {
                Iterator iter = ex.getList().iterator();
                while (iter.hasNext()) {
                    ExtendedList ex2 = (ExtendedList) iter.next();
                    String subpt = "- ";
                    if (ex2.getIntroduction() != null)
                        subpt = subpt + ex2.getIntroduction() + "\n";
                    if (ex2.getList() != null) {
                        Iterator iter2 = ex2.getList().iterator();
                        while (iter2.hasNext()) {
                            String sp = (String) iter2.next();
                            subpt = subpt + "   -" + sp + "\n";
                        }
                    }
                    if (ex2.getConclusion() != null)
                        subpt = subpt + ex2.getConclusion() + "\n";

                    ptText = ptText + subpt;
                }
            }
            if (ex.getConclusion() != null)
                ptText = ptText + ex.getConclusion();

            ptText = ptText.trim();
            pt.setText(ptText);
        }

        cons.gridx = 1;
        this.add(pt, cons);


        //cont
        TOMALabel label_cont = new TOMALabel(labels.get("apostal.toma.trainingview.content"));
        cons.gridx = 0;
        cons.gridy = 2;
        this.add(label_cont, cons);
        TOMATextArea cont = new TOMATextArea(1, 60);
        cont.setEditable(false);

        String contText = "";
        if (t.getContentDescriptionIntroduction() != null)
            contText = t.getContentDescriptionIntroduction() + "\n";
        if (t.getContentDescription() != null) {
            Iterator iter = t.getContentDescription().iterator();
            while (iter.hasNext()) {
                String c = (String) iter.next();
                contText = contText + "- " + c + "\n";
            }
        }
        if (t.getContentDescriptionConclusion() != null)
            contText = contText + t.getContentDescriptionConclusion();

        contText = contText.trim();
        cont.setText(contText);

        cons.gridx = 1;
        this.add(cont, cons);

        this.setBackground(TOMAColors.auxBackgroundColor2);
    }

}