// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.view;

import java.awt.*;
import java.awt.print.*;
import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.border.EmptyBorder;
import java.util.Iterator;
import java.util.Vector;
import java.lang.Integer;

import apostal.toma.TOMA;
import apostal.toma.data.TrainingProgramme;
import apostal.toma.data.Unit;
import apostal.toma.data.TOMALabels;

public class ViewTrainingProgramme extends ViewTraining implements ActionListener {

    //panel du training programme
    private TOMAPrintablePanel panel;
    //panels des units
    private Vector unitPanels = new Vector();

    public ViewTrainingProgramme(TrainingProgramme t) {
        super(t);

        this.setTitle(labels.get("apostal.toma.viewtrainingprogramme.title") + " \"" + t.toString() + "\"");

        JTabbedPane tabbedPane = new JTabbedPane();

        /*********** training programme ****************/
        panel = new TOMAPrintablePanel();
        panel.setLayout(new GridBagLayout());

        GridBagConstraints c = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 0, 5, 0), 0, 0);

        ViewTrainingMain main = new ViewTrainingMain(t);
        panel.add(main, c);

        //details
        TOMALabel titleDetails = new TOMALabel(labels.get("apostal.toma.trainingview.details"));
        c.gridy = 1;
        panel.add(titleDetails, c);
        ViewTrainingDetails details = new ViewTrainingDetails(t);
        c.gridy = 2;
        panel.add(details, c);

        //inscription details
        TOMALabel titleInscriptionDetails = new TOMALabel(labels.get("apostal.toma.trainingview.inscriptionDetails"));
        c.gridy = 3;
        panel.add(titleInscriptionDetails, c);
        ViewTrainingInscriptionDetails inscriptionDetails = new ViewTrainingInscriptionDetails(t);
        c.gridy = 4;
        panel.add(inscriptionDetails, c);

        //points
        TOMALabel titlePoints = new TOMALabel(labels.get("apostal.toma.viewtraining.points"));
        c.gridy = 5;
        panel.add(titlePoints, c);
        ViewTrainingPoints points = new ViewTrainingPoints(t);
        c.gridy = 6;
        panel.add(points, c);

        //aux
        TOMALabel titleAux = new TOMALabel(labels.get("apostal.toma.viewtraining.whowhere"));
        c.gridy = 7;
        panel.add(titleAux, c);
        ViewTrainingAux aux = new ViewTrainingAux(t);
        c.gridy = 8;
        panel.add(aux, c);

        //sessions
        ViewProgrammeSession sess = new ViewProgrammeSession(t);
        c.gridy = 9;
        panel.add(sess, c);

        panel.setBackground(TOMAColors.auxBackgroundColor);

        //print
        JPanel panelPrint = new JPanel();
        panelPrint.setBackground(TOMAColors.auxBackgroundColor);
        panelPrint.setBorder(new EmptyBorder(0, 0, 0, 0));
        panelPrint.setLayout(new GridBagLayout());
        TOMAButton print = new TOMAButton(labels.get("apostal.toma.print.button"));
        print.addActionListener(this);
        print.setActionCommand("programme");
        c = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0);
        panelPrint.add(print, c);
        //coller le bouton  gauche
        panelPrint.add(Box.createGlue(), new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0
                , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));

        //mise panel
        JPanel mainPanel = new JPanel();
        mainPanel.setLayout(new BoxLayout(mainPanel, BoxLayout.Y_AXIS));
        mainPanel.add(panelPrint);
        mainPanel.add(panel);
        JScrollPane scrollPane = new JScrollPane();
        scrollPane.setViewportView(mainPanel);

        tabbedPane.add(scrollPane, labels.get("apostal.toma.trainingprogramme"));

        /****************** Units *******************/
        if (t.getUnits() != null) {
            Vector units = t.getUnits();
            int nbUnits = units.size();
            for (int i = 0; i < nbUnits; i++) {
                Unit u = (Unit) units.elementAt(i);

                TOMAPrintablePanel panel2 = new TOMAPrintablePanel();
                panel2.setLayout(new GridBagLayout());
                unitPanels.add(panel2);

                GridBagConstraints c2 = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(5, 0, 5, 0), 0, 0);

                ViewTrainingMain main2 = new ViewTrainingMain(u);
                panel2.add(main2, c2);

                //details
                TOMALabel titleDetails2 = new TOMALabel(labels.get("apostal.toma.trainingview.details"));
                c2.gridy = 1;
                panel2.add(titleDetails2, c2);
                ViewUnitDetails details2 = new ViewUnitDetails(u);
                c2.gridy = 2;
                panel2.add(details2, c2);

                //points
                TOMALabel titlePoints2 = new TOMALabel(labels.get("apostal.toma.viewtraining.points"));
                c2.gridy = 3;
                panel2.add(titlePoints2, c2);
                ViewTrainingPoints points2 = new ViewTrainingPoints(u);
                c2.gridy = 4;
                panel2.add(points2, c2);

                //aux
                TOMALabel titleAux2 = new TOMALabel(labels.get("apostal.toma.viewtraining.whowhere"));
                c2.gridy = 5;
                panel2.add(titleAux2, c2);
                ViewTrainingAux aux2 = new ViewTrainingAux(u);
                c2.gridy = 6;
                panel2.add(aux2, c2);

                //session
                ViewUnitSession sess2 = new ViewUnitSession(u);
                c2.gridy = 7;
                panel2.add(sess2, c2);

                panel2.setBackground(TOMAColors.auxBackgroundColor);

                //print
                JPanel panelPrint2 = new JPanel();
                panelPrint2.setBackground(TOMAColors.auxBackgroundColor);
                panelPrint2.setBorder(new EmptyBorder(0, 0, 0, 0));
                panelPrint2.setLayout(new GridBagLayout());
                TOMAButton print2 = new TOMAButton(labels.get("apostal.toma.print.button"));
                print2.addActionListener(this);
                print2.setActionCommand(String.valueOf(i));
                c = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0);
                panelPrint2.add(print2, c);
                //coller le bouton  gauche
                panelPrint2.add(Box.createGlue(), new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0
                        , GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));

                //mise panel
                JPanel mainPanel2 = new JPanel();
                mainPanel2.setLayout(new BoxLayout(mainPanel2, BoxLayout.Y_AXIS));
                mainPanel2.add(panelPrint2);
                mainPanel2.add(panel2);
                JScrollPane scrollPane2 = new JScrollPane();
                scrollPane2.setViewportView(mainPanel2);

                tabbedPane.add(scrollPane2, u.getTitle());
            }
        }

        tabbedPane.setBackground(TOMAColors.auxBackgroundColor);
        int size = tabbedPane.getTabCount();
        for (int i = 0; i < size; i++) {
            tabbedPane.setBackgroundAt(i, TOMAColors.auxBackgroundColor);
        }

        tabbedPane.setBorder(new EmptyBorder(10, 10, 10, 10));

        this.setBackground(TOMAColors.auxBackgroundColor);
        this.getContentPane().add(tabbedPane);

        this.pack();
    }

    public void actionPerformed(ActionEvent e) {
        if (e != null) {
            String cmd = e.getActionCommand();

            //PrinterJob
            PrinterJob job = PrinterJob.getPrinterJob();
            job.setCopies(1);
            job.setJobName("TOMA Print");

            TOMAPrintablePanel printablePanel = null;

            if (cmd.equals("programme"))
                printablePanel = panel;
            else {
                try {
                    int i = Integer.parseInt(cmd);
                    printablePanel = (TOMAPrintablePanel) unitPanels.elementAt(i);
                } catch (Exception ex) {
                }
            }

            if (printablePanel != null) {
                job.setPrintable(printablePanel);

                if (job.printDialog()) {
                    try {
                        TOMA.log(TOMA.INFO, "printing");
                        job.print();
                    } catch (java.awt.print.PrinterException ex) {
                        TOMAError error = new TOMAError(labels.get("apostal.toma.print.error.message"), labels.get("apostal.toma.print.error.title"));
                    }
                }
            }
        }
    }
}
