// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.view;

import apostal.toma.TOMA;
import apostal.toma.data.*;

import apostal.toma.data.TOMALabels;
import apostal.toma.database.DomainDB;

import java.sql.Date;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Vector;
import java.util.Iterator;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class ViewUnitSession extends JPanel {
    private TOMALabels labels;

    public ViewUnitSession(Unit t) {
        labels = new TOMALabels();

        this.setLayout(new GridBagLayout());

        if (t.getUnitSessions() != null) {
            int cpt = 0;
            Iterator iter = t.getUnitSessions().iterator();
            while (iter.hasNext()) {
                UnitSession s = (UnitSession) iter.next();

                GridBagConstraints cons = new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 0, 0);

                TOMALabel title = new TOMALabel(labels.get("apostal.toma.sessionview.session") + " \"" + s.getSessionName() + "\"");
                cons.gridx = 0;
                cons.gridy = cpt * 2;
                cons.gridwidth = 5;
                this.add(title, cons);

                JPanel panel = new JPanel();
                panel.setLayout(new GridBagLayout());

                /*String title=labels.get("apostal.toma.sessionview.session")+" \""+s.getSessionName()+"\"";
                panel.setBorder(new TitledBorder(new LineBorder(java.awt.Color.black), title, TitledBorder.DEFAULT_JUSTIFICATION, TitledBorder.DEFAULT_POSITION, ViewTraining.titleFont, ViewTraining.titleColor));*/

                //name
                TOMALabel label_name = new TOMALabel(labels.get("apostal.toma.sessionview.name"));
                cons.gridx = 0;
                cons.gridy = 0;
                cons.gridwidth = 1;
                panel.add(label_name, cons);
                TOMATextArea name = new TOMATextArea(1, 20);
                name.setEditable(false);
                name.setText(s.getSessionName());
                cons.gridx = 1;
                panel.add(name, cons);

                //textual calendar
                TOMALabel label_tc = new TOMALabel(labels.get("apostal.toma.sessionview.textualCalendar"));
                cons.gridx = 0;
                cons.gridy = 1;
                cons.gridheight = 2;
                panel.add(label_tc, cons);
                TOMATextArea tc = new TOMATextArea(1, 20);
                tc.setEditable(false);
                tc.setText(s.getTextualCalendar());
                cons.gridx = 1;
                panel.add(tc, cons);

                //bvd
                TOMALabel label_bvd = new TOMALabel(labels.get("apostal.toma.sessionview.beginValidityDate"));
                cons.gridx = 2;
                cons.gridheight = 1;
                panel.add(label_bvd, cons);
                TOMATextArea bvd = new TOMATextArea(1, 20);
                bvd.setEditable(false);
                Date sbvd = s.getBeginValidityDate();
                if (sbvd != null) {
                    GregorianCalendar cal = new GregorianCalendar();
                    cal.setTime(sbvd);
                    bvd.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
                }
                cons.gridx = 3;
                panel.add(bvd, cons);

                //evd
                TOMALabel label_evd = new TOMALabel(labels.get("apostal.toma.sessionview.endValidityDate"));
                cons.gridx = 2;
                cons.gridy = 2;
                panel.add(label_evd, cons);
                TOMATextArea evd = new TOMATextArea(1, 20);
                evd.setEditable(false);
                Date sevd = s.getEndValidityDate();
                if (sevd != null) {
                    GregorianCalendar cal = new GregorianCalendar();
                    cal.setTime(sevd);
                    evd.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
                }
                cons.gridx = 3;
                panel.add(evd, cons);

                //price
                TOMALabel label_price = new TOMALabel(labels.get("apostal.toma.sessionview.price"));
                cons.gridx = 0;
                cons.gridy = 3;
                cons.gridheight = 2;
                panel.add(label_price, cons);
                TOMATextArea price = new TOMATextArea(1, 20);
                price.setEditable(false);
                price.setText(s.getPrice());
                cons.gridx = 1;
                panel.add(price, cons);

                //bd
                TOMALabel label_bd = new TOMALabel(labels.get("apostal.toma.sessionview.dateBegin"));
                cons.gridx = 2;
                cons.gridheight = 1;
                panel.add(label_bd, cons);
                TOMATextArea bd = new TOMATextArea(1, 20);
                bd.setEditable(false);
                Date sbd = s.getBeginDate();
                if (sbd != null) {
                    GregorianCalendar cal = new GregorianCalendar();
                    cal.setTime(sbd);
                    bd.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
                }
                cons.gridx = 3;
                panel.add(bd, cons);

                //ed
                TOMALabel label_ed = new TOMALabel(labels.get("apostal.toma.sessionview.dateEnd"));
                cons.gridx = 2;
                cons.gridy = 4;
                panel.add(label_ed, cons);
                TOMATextArea ed = new TOMATextArea(1, 20);
                ed.setEditable(false);
                Date sed = s.getEndDate();
                if (sed != null) {
                    GregorianCalendar cal = new GregorianCalendar();
                    cal.setTime(sed);
                    ed.setText(new Integer(cal.get(Calendar.DAY_OF_MONTH)) + "/" + new Integer(cal.get(Calendar.MONTH) + 1) + "/" + new Integer(cal.get(Calendar.YEAR)));
                }
                cons.gridx = 3;
                panel.add(ed, cons);

                //price c
                TOMALabel label_pricec = new TOMALabel(labels.get("apostal.toma.sessionview.priceComment"));
                cons.gridx = 0;
                cons.gridy = 5;
                cons.gridheight = 2;
                panel.add(label_pricec, cons);
                TOMATextArea pricec = new TOMATextArea(1, 20);
                pricec.setEditable(false);
                pricec.setText(s.getPriceComment());
                cons.gridx = 1;
                panel.add(pricec, cons);

                //lng
                TOMALabel label_lng = new TOMALabel(labels.get("apostal.toma.sessionview.language"));
                cons.gridx = 2;
                cons.gridheight = 1;
                panel.add(label_lng, cons);
                TOMATextArea lng = new TOMATextArea(1, 20);
                lng.setEditable(false);
                Language slng = s.getLanguage();
                if (slng != null)
                    lng.setText(slng.getName());
                cons.gridx = 3;
                panel.add(lng, cons);

                //loc
                TOMALabel label_loc = new TOMALabel(labels.get("apostal.toma.sessionview.location"));
                cons.gridx = 2;
                cons.gridy = 6;
                panel.add(label_loc, cons);
                TOMATextArea loc = new TOMATextArea(1, 20);
                loc.setEditable(false);
                Location sloc = s.getLocation();
                if (sloc != null)
                    loc.setText(sloc.getDenomination());
                cons.gridx = 3;
                panel.add(loc, cons);

                //com
                TOMALabel label_com = new TOMALabel(labels.get("apostal.toma.sessionview.comment"));
                cons.gridx = 0;
                cons.gridy = 7;
                panel.add(label_com, cons);
                TOMATextArea com = new TOMATextArea(1, 20);
                com.setEditable(false);
                com.setText(s.getComment());
                cons.gridx = 1;
                panel.add(com, cons);

                //slot
                TOMALabel label_slot = new TOMALabel(labels.get("apostal.toma.sessionview.slot"));
                cons.gridx = 2;
                panel.add(label_slot, cons);
                TOMATextArea slot = new TOMATextArea(1, 20);
                slot.setEditable(false);
                Slot sslot = s.getSlot();
                if (sslot != null)
                    slot.setText(sslot.getName());
                cons.gridx = 3;
                panel.add(slot, cons);

                //teachers
                TOMALabel label_tea = new TOMALabel(labels.get("apostal.toma.sessionview.teachers"));
                cons.gridx = 0;
                cons.gridy = 8;
                panel.add(label_tea, cons);
                TOMATextArea tea = new TOMATextArea(1, 20);
                tea.setEditable(false);
                if (s.getTeachers() != null) {
                    String txt = "";
                    Iterator iter2 = s.getTeachers().iterator();
                    while (iter2.hasNext()) {
                        Teacher teacher = (Teacher) iter2.next();
                        txt = txt + teacher.toString() + "\n";
                    }
                    txt = txt.trim();
                    tea.setText(txt);
                }
                cons.gridwidth = 2;
                cons.gridx = 1;
                panel.add(tea, cons);

                //seances
                TOMALabel label_se = new TOMALabel(labels.get("apostal.toma.sessionview.seances"));
                cons.gridx = 0;
                cons.gridy = 9;
                cons.gridwidth = 1;
                panel.add(label_se, cons);
                TOMATextArea se = new TOMATextArea(1, 20);
                se.setEditable(false);
                if (s.getSeances() != null) {
                    String txt = "";
                    Iterator iter2 = s.getSeances().iterator();
                    while (iter2.hasNext()) {
                        Seance seance = (Seance) iter2.next();
                        txt = txt + seance.toString() + "\n";
                    }
                    txt = txt.trim();
                    se.setText(txt);
                }
                cons.gridwidth = 2;
                cons.gridx = 1;
                panel.add(se, cons);

                //programme session
                int id = s.getIdProgrammeSession();
                if (id != -1) {
                    TOMALabel label_ps = new TOMALabel(labels.get("apostal.toma.sessionview.programmeSession"));
                    cons.gridx = 0;
                    cons.gridy = 10;
                    cons.gridwidth = 1;
                    panel.add(label_ps, cons);
                    TOMATextArea ps = new TOMATextArea(1, 20);
                    ps.setEditable(false);

                    apostal.toma.datacontrol.ProgrammeSessionControl control = new apostal.toma.datacontrol.ProgrammeSessionControl();
                    ProgrammeSession psession = new ProgrammeSession(id);
                    control.loadSession(psession);
                    ps.setText(psession.getSessionName());

                    cons.gridx = 1;
                    panel.add(ps, cons);
                }

                panel.setBackground(TOMAColors.auxBackgroundColor2);

                cons.gridx = 0;
                cons.gridy = cpt * 2 + 1;
                this.add(panel, cons);

                cpt++;
            }
        }

        this.setBackground(TOMAColors.auxBackgroundColor);
    }
}