// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

import apostal.toma.data.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.*;
import apostal.toma.datacontrol.CatalogueControl;
import apostal.toma.datacontrol.TrainingControl;
import apostal.toma.datacontrol.TrainingCourseControl;
import apostal.toma.datacontrol.TrainingProgrammeControl;
import apostal.toma.view.*;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TrainingProgramme;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import java.util.*;
import java.awt.*;
import javax.swing.*;
import javax.swing.JTree;
import javax.swing.tree.*;


import apostal.toma.TOMA;

public class CatalogueEventHandler extends WindowAdapter implements ActionListener {
    private CatalogueView catalogueView;
    protected TOMALabels labels = new TOMALabels();
    private CatalogueControl control = new CatalogueControl();
    private TrainingProgrammeControl trpcontrol = new TrainingProgrammeControl();
    private TrainingCourseControl trccontrol = new TrainingCourseControl();
    private CreateCatalogue create;
    private CreateTrainingProgramme createProgramme;
    private CreateTrainingCourse createCourse;
    private RemoveTrainingView removeTraining;
    //private Catalogue rootcatalogue;
    private Catalogue catalogue;
    private TOMATreeControl treecontrol;
    private TrainingInCatalogueChooser chooseViewTraining;
    private int createdif = 0;

    public CatalogueEventHandler(CatalogueView catalogueView) {
        treecontrol = new TOMATreeControl();
        this.catalogueView = catalogueView;
        //rootcatalogue = control.loadCatalogue(false);
    }

    /*    public CatalogueEventHandler(CatalogueView catalogueView, boolean load)
	  {
	  treecontrol=new TOMATreeControl();
	  this.catalogueView = catalogueView;
	  if(load)
	  rootcatalogue = control.loadCatalogue(false);
	  }*/
    public CatalogueEventHandler() {
        treecontrol = new TOMATreeControl();
        //rootcatalogue = control.loadCatalogue(false);
    }

    /*public CatalogueEventHandler(boolean load)
      {
      treecontrol=new TOMATreeControl();
      if(load)
      rootcatalogue = control.loadCatalogue(false);
      }*/
    public void actionPerformed(ActionEvent e) {
        String actioncommand = e.getActionCommand();
        String action = getAction(actioncommand);
        if (action.compareTo("new") == 0) {

            createdif = 0;
            create = new CreateCatalogue(this, TOMA.getInstance().getTomaView());
            create.pack();
            create.center();
            create.show();
            //create();
        } else if (action.compareTo("delete") == 0) {
            delete();
        } else if (action.compareTo("save") == 0) {
            save();
        } else if (action.compareTo("course") == 0) {
            createdif = 1;
            createCourse = new CreateTrainingCourse(this, TOMA.getInstance().getTomaView());
            createCourse.pack();
            createCourse.center();
            createCourse.show();
        } else if (action.compareTo("prog") == 0) {
            createdif = 2;
            createProgramme = new CreateTrainingProgramme(this, TOMA.getInstance().getTomaView());
            createProgramme.pack();
            createProgramme.center();
            createProgramme.show();
        } else if (action.compareTo("add") == 0) {
            chooseViewTraining = new TrainingInCatalogueChooser(labels.get("apostal.toma.catalogue.add.message"), labels.get("apostal.toma.catalogue.add.title"), labels.get("apostal.toma.catalogue.add.ok"), labels.get("apostal.toma.catalogue.add.cancel"), true, true, true, true, this);
            chooseViewTraining.pack();
            chooseViewTraining.setVisible(true);
        } else if (action.compareTo("remove") == 0) {
            createdif = 3;
            Vector vtrainings = catalogueView.getData().getTrainings();
            removeTraining = new RemoveTrainingView(this, vtrainings, TOMA.getInstance().getTomaView());
            removeTraining.pack();
            removeTraining.show();
        } else if (action.compareTo("choose_ok") == 0) {
            addTraining();
        } else if (action.compareTo("create_ok") == 0) {
            //Create new
            if (createdif == 0) {
                create();
            } else if (createdif == 1) {
                createCourse();
            } else if (createdif == 2) {
                createProgramme();
            } else if (createdif == 3) {
                removeTraining();
            }

        }
    }


    public void create() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.catalogue.error.create.empty");
        String message2 = labels.get("apostal.toma.catalogue.error.create.exists");
        String title = labels.get("apostal.toma.catalogue.error.create.title");
        /*String cattitle = (String)create.getData();
        String catdescription = (String)create.getDescription();
        Catalogue c = new Catalogue();
        c.setTitle(cattitle);
        c.setDescription(catdescription);*/
        Catalogue c = (Catalogue) create.getData();
        String cattitle = c.getTitle();
        //String catdescription = c.getDescription();

        int idsubcat = catalogueView.getId();
        String titlesubcat = catalogueView.getData().getTitle();
        c.setIdSuperCatalogue(idsubcat);
        //Test title pas vide
        if (cattitle.compareTo("") == 0) {
            error = new TOMAError(message1, title);
        }
        //test si le title n'esiste pas encore
        else if (!control.testCreate(c)) {
            error = new TOMAError(message2, title);
        }
        // creation
        else {
            control.createCatalogue(c);
            create.hide();
            //unlock catalogue
            control.unlock(c);
            //update Tree
            TreePath path = TOMA.getInstance().getTomaView().getTree().getTree().getSelectionPath();

            CatalogueTreeNode catalogueTreeNode = new CatalogueTreeNode(c.getIdCatalogue(), c.getTitle(), new Vector(), 0, true, true);
            CatalogueTreeNode cat = (CatalogueTreeNode) TOMA.getInstance().getTomaView().getTree().getTree().getSelectionPath().getLastPathComponent();
            cat.addCatalogueTreeNode(catalogueTreeNode);
            catalogueTreeNode.setParent(cat);
            TOMA.getInstance().getTomaView().getTree().getTree().setSelectionPath(path);
        }
    }

    //Create Training programme
    public void createProgramme() {
        //Crer training course
        TrainingProgramme tp = (TrainingProgramme) createProgramme.getData();
        String code = tp.getCode();
        String title = tp.getTitle();

        //Date de cration
        Calendar calendar = new GregorianCalendar();
        Date trialtime = new Date();
        calendar.setTime(trialtime);
        java.sql.Date date = new java.sql.Date(calendar.getTime().getTime());
        tp.setDateCreation(date);
        //Test code title pas vide
        if ((title.compareTo("") == 0) || (code.compareTo("") == 0)) {
            createProblemempty();
        }
        //test si le title n'esiste pas encore
        else if (!trpcontrol.testCreate(tp)) {
            createProblemexist();
        }
        // creation
        else {
            //save Training
            trpcontrol.create(tp);
            //Introduire training course dans catalogue actuel
            Catalogue c = catalogueView.getData();
            Vector vtrainings = c.getTrainings();
            vtrainings.addElement(tp);
            c.setTrainings(vtrainings);
            control.saveCatalogue(c);
            createProgramme.hide();
            //update Tree
            TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
            TreePath path = tree.getSelectionPath();
            CatalogueTreeNode cat = (CatalogueTreeNode) tree.getSelectionPath().getLastPathComponent();
            TrainingTreeNode trainingTreeNode = new TrainingTreeNode(tp.getIdTraining(), tp.getTitle(), tp.getCode(), cat.getIdCatalogue(), TrainingTreeNode.TRAININGPROGRAMME);
            cat.addTrainingTreeNode(trainingTreeNode);
            tree.setSelectionPath(path);
            //treecontrol.updateTree(path);
        }
    }

    // Create Training Course
    public void createCourse() {
        TrainingCourse tc = (TrainingCourse) createCourse.getData();
        String code = tc.getCode();
        String title = tc.getTitle();
        //Date de cration
        Calendar calendar = new GregorianCalendar();
        Date trialtime = new Date();
        calendar.setTime(trialtime);
        java.sql.Date date = new java.sql.Date(calendar.getTime().getTime());
        tc.setDateCreation(date);
        //Test code title pas vide
        if ((title.compareTo("") == 0) || (code.compareTo("") == 0)) {
            createProblemempty();
        }
        //test si le title n'esiste pas encore
        else if (!trccontrol.testCreate(tc)) {
            createProblemexist();
        }
        // creation
        else {
            //save Training
            trccontrol.create(tc);
            //Introduire training course dans catalogue actuel
            Catalogue c = catalogueView.getData();
            Vector vtrainings = c.getTrainings();
            vtrainings.addElement(tc);
            c.setTrainings(vtrainings);
            control.saveCatalogue(c);
            //fermer fentre
            createCourse.hide();
            //update Tree
            TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
            TreePath path = tree.getSelectionPath();
            CatalogueTreeNode cat = (CatalogueTreeNode) tree.getSelectionPath().getLastPathComponent();
            TrainingTreeNode trainingTreeNode = new TrainingTreeNode(tc.getIdTraining(), tc.getTitle(), tc.getCode(), cat.getIdCatalogue(), TrainingTreeNode.TRAININGCOURSE);
            cat.addTrainingTreeNode(trainingTreeNode);
            tree.setSelectionPath(path);
        }

    }

    public void createProblemexist() {
        TOMAError error;
        String message = labels.get("apostal.toma.catalogue.training.exists");
        String title = labels.get("apostal.toma.catalogue.training.title");
        error = new TOMAError(message, title);
    }

    public void createProblemempty() {
        TOMAError error;
        String message = labels.get("apostal.toma.catalogue.training.empty");
        String title = labels.get("apostal.toma.catalogue.training.title");
        error = new TOMAError(message, title);
    }

    public CatalogueView openCatalogue(Catalogue c) {
        this.catalogue = c;

        if (catalogueView == null) {
            catalogueView = new CatalogueView(this);
        }

        try {
            catalogueView.setData(c);
        } catch (NullPointerException np) {
        }

        TOMAFrame tomaFrame = new TOMAFrame();
        try {
            tomaFrame.getContentPane().add(catalogueView);
        } catch (NullPointerException np) {
        }
        return catalogueView;
    }

    public void save() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.catalogue.error.save.empty");
        String message2 = labels.get("apostal.toma.catalogue.error.save.exists");
        String title = labels.get("apostal.toma.catalogue.error.save.title");
        Catalogue data = catalogueView.getData();
        String cattitle = data.getTitle();
        //Test denomination pas vide
        if (cattitle.compareTo("") == 0) {
            error = new TOMAError(message1, title);
        }
        //test si le title n'existe pas encore
        else if (!control.testUpdate(data)) {
            error = new TOMAError(message2, title);
        }
        // creation
        else {
            control.saveCatalogue(data);
            //update Tree
            TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
            TreePath path = tree.getSelectionPath();
            treecontrol.updateTree(path);

        }
    }

    public TreePath selectCatalogues(TOMATree tree, CatalogueTreeNode node, CatalogueTreeNode newNode) {
        TreePath path = null;
        DefaultTreeModel model = (DefaultTreeModel) tree.getTree().getModel();
        CatalogueTreeNode root = tree.getRoot();
        Enumeration e = root.depthFirstEnumeration();
        while (e.hasMoreElements()) {
            Object o = e.nextElement();
            String className = o.getClass().getName();
            if (className.equals("apostal.toma.view.CatalogueTreeNode")) {
                CatalogueTreeNode nodeTest = (CatalogueTreeNode) o;
                if (nodeTest.getIdCatalogue() == newNode.getIdCatalogue()) {
                    path = new TreePath(model.getPathToRoot(nodeTest));
                }
            }
        }
        return path;
    }

    public void delete() {
        TOMAQuestion question;
        int result = 0;
        int sure = 0;
        String question1 = labels.get("apostal.toma.catalogue.error.delete.desktop");
        String question2 = labels.get("apostal.toma.catalogue.error.delete.desktop2");
        String title = labels.get("apostal.toma.catalogue.error.delete.title");
        String confirm = labels.get("apostal.toma.catalogue.error.delete.confirm");
        String training = "";
        Catalogue data = catalogueView.getData();
        boolean used = testused(data);
        String denomination = data.getTitle();

        //test si dekstop
        CatalogueDB catdb = new CatalogueDB(data);
        if (!catdb.isRootCatalogue()) {
            // Sure de supprimer le catalogue?
            question = new TOMAQuestion(confirm, title, JOptionPane.OK_CANCEL_OPTION);
            sure = question.getResult();
            //Test lieu utilis
            if (sure == 0) {
                if (used) {
                    Vector vtraining = data.getTrainings();
                    /*training = training + "\n - " +vtraining.toString();
                    training = question1 +"\n" +training;*/
                    training = TOMAFonts.htmlBegin + "<P>" + question1 + "</P><UL>";
                    if (vtraining != null) {
                        Iterator it = vtraining.iterator();
                        while (it.hasNext()) {
                            Training t = (Training) it.next();
                            training = training + "<LI>" + t.toString() + "</LI>";
                        }
                        training = training + "</UL><P>" + question2 + "</P></HTML>";
                    }
                    training = training + TOMAFonts.htmlEnd;
                    question = new TOMAQuestion(training, title, JOptionPane.OK_CANCEL_OPTION);
                    result = question.getResult();
                }
                //delete du catalogue
                if (result == 0) {
                    control.putDesktop(data);
                    control.deleteCatalogue(data);
                    TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
                    TreePath path = tree.getSelectionPath();
                    treecontrol.updateTree(path);
                    catalogueView.empty();
                }
            }
        } else {
            TOMAError tomaerror = new TOMAError(labels.get("apostal.toma.catalogue.error.delete.desktopCannotBeDeleted"), labels.get("apostal.toma.catalogue.error.delete.title"));
        }
    }

    public boolean testused(Catalogue c) {
        boolean used = false;
        if (c.getTrainings().size() != 0) {
            used = true;
        }
        return used;
    }

    //Ligne prcise dans le String
    public int getIndex(String action) {
        int index = 0;
        int point = action.indexOf(".");
        String substring = action.substring(0, point);
        try {
            index = Integer.parseInt(substring);
        } catch (NumberFormatException np) {
        }
        return index;
    }

    //Action prcise dans le String
    public String getAction(String action) {
        int point = action.indexOf(".");
        return action.substring(point + 1);
    }


    public void addTraining() {
        int Test = chooseViewTraining.getIdTraining();
        int type = chooseViewTraining.getTypeTraining();
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
        CatalogueTreeNode cat = (CatalogueTreeNode) tree.getSelectionPath().getLastPathComponent();
        int nbrChild = cat.getChildCount();
        int i = 0;
        boolean exist = false;
        while (i < nbrChild && !exist) {
            Object o = cat.getChildAt(i);
            String className = o.getClass().getName();
            if (className.equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode node = (TrainingTreeNode) o;
                if (node.getIdTraining() == Test) {
                    exist = true;
                }
            }
            i++;
        }
        if (!exist) {
            Training t = trccontrol.loadTraining(Test);
            control.addTraining(catalogueView.getData(), t);
            chooseViewTraining.hide();
            //update Tree
            TreePath path = tree.getSelectionPath();
            TrainingTreeNode trainingTreeNode = new TrainingTreeNode(t.getIdTraining(), t.getTitle(), t.getCode(), cat.getIdCatalogue(), type);
            cat.addTrainingTreeNode(trainingTreeNode);
            tree.setSelectionPath(path);
        }
        //treecontrol.updateTree(path);
    }


    public void removeTraining() {
        TOMAError error;
        Vector vtraining = (Vector) removeTraining.getData();
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
        TreePath path = tree.getSelectionPath();
        CatalogueTreeNode node = (CatalogueTreeNode)path.getLastPathComponent();
        for (int i = 0; i < vtraining.size(); i++) {
            //Training a supprimer
            StandaloneTraining tr = (StandaloneTraining) vtraining.elementAt(i);
            int idtr = tr.getIdTraining();
            tr = trccontrol.loadTraining(idtr);

            //Cataloge duquel il faut supprimer
            Catalogue cat = catalogueView.getData();

            //Test si dans desktop
            //if((cat.getIdCatalogue()==0) && (tr.getCatalogues().size()==1))
            CatalogueDB catdb = new CatalogueDB(cat);
            if (catdb.isRootCatalogue() && (tr.getCatalogues().size() == 1)) {
                //pas possible de faire remove
                String message = labels.get("apostal.toma.catalogue.training.remove.not");
                String title = labels.get("apostal.toma.catalogue.training.remove.title2");
                error = new TOMAError(message, title);
            }
            //Test si seulement dans ca catalogue
            else if (tr.getCatalogues().size() == 1) {
                String message1 = labels.get("apostal.toma.catalogue.training.remove.desktop");
                String title1 = labels.get("apostal.toma.catalogue.training.remove.title2");
                error = new TOMAError(message1, title1);
                control.moveDesktop(cat, tr);
            } else {
                control.deleteTraining(cat, tr);
            }
            TrainingTreeNode trainingTreeNode = new TrainingTreeNode(cat.getIdCatalogue(),tr.getIdTraining());
        }
        removeTraining.hide();
        tree.setSelectionPath(path);

        //node.removeNode();
        /*  CatalogueTreeNode cat = (CatalogueTreeNode)tree.getSelectionPath().getLastPathComponent();
          tree.setSelectionPath(path); */
        treecontrol.updateTree(path);
    }
}

