// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.viewcontrol;

import apostal.toma.TOMA;
import apostal.toma.view.ContactsView;
import apostal.toma.data.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.*;
import apostal.toma.datacontrol.ContactsControl;
import apostal.toma.view.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import apostal.toma.TOMA;
import java.util.*;

public class ContactsEventHandler extends WindowAdapter implements ActionListener {
    private ContactsView contactsView;
    protected TOMALabels labels = new TOMALabels();
    private ContactsControl control = new ContactsControl();
    private CreateContact create;
    private Vector contacts;
    public ContactsEventHandler(ContactsView contactsView)
    {
      this.contactsView = contactsView;
      contacts = control.loadContacts(false);
    }

	public void refreshContactsOtherLists()
	{
		TrainingView.refreshContacts();
	}

    public void actionPerformed(ActionEvent e)
    {
      String denomination;
      String actioncommand = e.getActionCommand();
      String action = getAction(actioncommand);
      if (action.compareTo("new")==0)
      {
        int result = 0;
        if (TOMA.getInstance().getTomaParameters().getOpenWarningWindow() && contactsView.contactSelected()){
                TOMAQuestion tq = new TOMAQuestion(TOMAFonts.htmlBegin+labels.get("apostal.toma.changeSelection.contact.confirm")+TOMAFonts.htmlEnd,labels.get("apostal.toma.changeSelection.contact.confirm.title"));
                result = tq.getResult();
        }
        if (result==0){

          create = new CreateContact(this,this.contactsView);
        create.pack();
        create.center();
        create.show();
        this.refreshContactsOtherLists();
        }
      }
      else if (action.compareTo("delete")==0)
      {

          deleteContact();
        this.refreshContactsOtherLists();

      }
      else if (action.compareTo("save")==0)
      {
        //Sauvegarde des donnes du formulaire dans un object
        Contact c = contactsView.save();
        saveContact();
        this.refreshContactsOtherLists();
      }
      else if (action.compareTo("create_ok")==0)
      {
        //Create new
        createContact();
        this.refreshContactsOtherLists();
      }
    }

    public void windowClosing(WindowEvent e) 
    {
        TOMAEventHandler tomaHandler=TOMA.getInstance().getHandler();
        tomaHandler.closeContactsView();
        
       //unlock
        Contact c=contactsView.getData();
        if(c!=null) //pas un cran "lock"
        {
            control.unlockContact(c);
        }        
    }
    
    public void openContacts() {
    }

    public void refreshContacts() {

    }

    public void createContact() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.contact.error.creation.empty");
        String message2 = labels.get("apostal.toma.contact.error.creation.exist");
        String title = labels.get("apostal.toma.contact.error.creation.title");
        String firstname = create.getFirstname();
        String lastname = create.getLastname();
        String tel = create.getTel();
        String email = create.getEmail();
        // Try to unlock locked data
        try
        {
          Contact data = contactsView.getData();
          control.unlockContact(data);
        }
        catch(NullPointerException np){}

        //Test denomination pas vide
        if (firstname.compareTo("")==0)
        {
          error = new TOMAError(message1, title);
        }
        //test si le nom n'existe pas encore
        else if (contactexists(firstname, lastname, tel, email))
        {
          error = new TOMAError(message2, title);
        }
        // creation
        else
        {
          Contact c = new Contact();
          c.setFirstname(firstname);
          c.setLastname(lastname);
          c.setTel(tel);
          c.setEmail(email);
          control.createContact(c);
          create.hide();

          contactsView.show();
          contactsView.refresh();
          
          contactsView.selectContact(c.getIdContact());
        }
    }

    public void saveContact() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.contact.error.save.empty");
        String message2 = labels.get("apostal.toma.contact.error.save.exist");
        String title = labels.get("apostal.toma.contact.error.save.title");
        Contact data = contactsView.getData();
        if (data!=null){
        
        String lastname = data.getLastname();
        int id = data.getIdContact();
        //Test denomination pas vide
        ContactDB cdb=new ContactDB(data);
        
        boolean update=cdb.testUpdate();
        if (lastname.compareTo("")==0
            ||!update
        )
        {
            if(update)
                error = new TOMAError(message1, title);
            else
                error = new TOMAError(message2, title);
          
            //recharger l'id sec
            control.loadContact(data, false);            
            contactsView.setData(data);
            contactsView.repaint();              
        }
        /*else
        {
          control.saveContact(data);
          
        }*/
        boolean ok=true;

        String template=this.testTemplate();
            if(template!=null)
            {
                //ouvrir la fenetre de demande de confirmation
                String qTitle=labels.get("apostal.toma.contact.templateProblemTitle");
                TOMAQuestion question=new TOMAQuestion(template,qTitle);
                if(question.getResult()!=0)
                    ok=false;
            }
       if(ok)
        control.saveContact(data);
        
    	}
    }

    /**
     * tests the template:
     * @return: the error message to display if it is incorrect. Otherwise null.
     */
    public String testTemplate()
    {
      //effectuer tous les tests
      String s=contactsView.testTemplateElements();
      if(s!=null && !s.equals(""))
      {
	String msg=labels.get("apostal.toma.contact.templateProblem");
        msg=msg+"\n"+s;
        msg=msg+"\n\n"+labels.get("apostal.toma.contact.templateProblemSave");
        
	return msg;
      }
      else
	return null;
    }     
    
    public void deleteContact() {
        TOMAQuestion question;
        int result = 0;
        String question1 = labels.get("apostal.toma.contact.error.delete.used");
        String question2 = labels.get("apostal.toma.contact.error.delete.question");
        String title = labels.get("apostal.toma.contact.error.save.title");
        Contact data = contactsView.getData();
        int id = data.getIdContact();
        //Test lieu utilis
        if (control.isUsedInTraining(id))
        {
          question = new TOMAQuestion(question1 + " " +question2,title);
          result = question.getResult();
        }
        //delete du lieu
        if (result==0)
        {
            control.deleteContact(data);
            contactsView.refresh();          
        }
    }


    public boolean contactexists(String firstname, String lastname, String tel, String email)
    {
      /*boolean test = false;
      for (int i=0;i<contacts.size();i++)
      {
        String firstnamedata = ((Contact)contacts.elementAt(i)).getFirstname();
        String lastnamedata = ((Contact)contacts.elementAt(i)).getLastname();
        String teldata = ((Contact)contacts.elementAt(i)).getTel();
        String emaildata = ((Contact)contacts.elementAt(i)).getEmail();
        if (firstnamedata.compareTo(firstname)==0 && lastnamedata.compareTo(lastname)==0 && teldata.compareTo(tel)==0 && emaildata.compareTo(email)==0 )
        {
          test = true;
        }
      }
      return test;*/
        
          Contact c = new Contact();
          c.setFirstname(firstname);
          c.setLastname(lastname);
          c.setTel(tel);
          c.setEmail(email);
          ContactDB cdb=new ContactDB(c);
          return !cdb.testCreate();
    }

        //Ligne prcise dans le String
    public int getIndex(String action)
    {
       int index = 0;
       int point = action.indexOf(".");
       String substring = action.substring(0,point);
       try
       {
           index = Integer.parseInt(substring);
       }
       catch(NumberFormatException np)
       {
       }
       return index;
    }

    //Action prcise dans le String
    public String getAction (String action)
    {
      int point = action.indexOf(".");
      return action.substring(point+1);
    }
}
