// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import java.awt.event.WindowEvent;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.CourseSession;

import apostal.toma.database.CourseSessionDB;
import apostal.toma.database.TrainingCourseDB;

import apostal.toma.datacontrol.CourseSessionControl;

import apostal.toma.view.CourseSessionView;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.CreateSession;
import apostal.toma.view.CreateConsecSessionsView;

public class CourseSessionEventHandler extends SessionEventHandler
{
  private CourseSessionControl control;
  private CreateConsecSessionsView ccSesssionView;
  private static boolean sessionsOpened;

  public void windowClosing(WindowEvent e)
  {
      sessionsOpened=false;
  }

  public CourseSessionEventHandler()
  {
    control=new CourseSessionControl();
  }

  public void save()
  {
      CourseSession cs=((CourseSessionView) view).getData();

      if(control.testSave(cs))
      {
	boolean ok=true;

        String template=this.testTemplate();
	if(template!=null)
	{
	   //ouvrir la fenetre de demande de confirmation
	   String title=labels.get("apostal.toma.sessionview.templateProblemTitle");

	   TOMAQuestion question=new TOMAQuestion(template,title);
	   if(question.getResult()!=0)
	    ok=false;
	}

	if(ok)
	  control.saveSession(cs);
      }
      else
      {
        TOMAError error=new TOMAError(labels.get("apostal.toma.sessionview.saveproblem"), labels.get("apostal.toma.sessionview.saveproblemtitle"));
      }
  }

  public void openSessions(TrainingCourse tc)
  {
    if(!sessionsOpened)
    {
      sessionsOpened=true;
      CourseSessionView session=new CourseSessionView(this);
      if(tc!=null)
      {
	//charger tout
	Iterator iter = tc.getCourseSessions().iterator();
	while (iter.hasNext())
	{
	  CourseSession cs = (CourseSession) iter.next();
	  control.loadSession(cs);
	}

        session.setData(tc);

	//garder le idTraining
	this.idTraining=tc.getIdTraining();
      }
      else
	TOMA.log(TOMA.SEVERE, "trainingCourse was null when opening sessions");

      session.pack();
      session.setVisible(true);
      SessionEventHandler.view=session;
    }
  }

  public void delete()
  {
    TOMAQuestion question=new TOMAQuestion(labels.get("apostal.toma.sessionview.delete.message"), labels.get("apostal.toma.sessionview.delete.title"));
    if(question.getResult()==0)
    {
      CourseSession s=((CourseSessionView) view).getData();

      //delete BD
      control.deleteSession(s);

      //maj liste + changer la session slectionne
      ((CourseSessionView) view).deleteSession(s);
    }
  }

  public void create()
  {
    create=new CreateSession(this,this.view);
    create.pack();
    create.center();
    create.show();
  }

	public void addSeancesConsec(){
		ccSesssionView = new CreateConsecSessionsView(this,this.view);
		ccSesssionView.pack();
		ccSesssionView.center();
		ccSesssionView.show();
		
	}
	public void doAddSeancesConsec(){
		((CourseSessionView)view).addSeancesConsec(ccSesssionView.getData());
		ccSesssionView.dispose();
		view.show();
		
	}

  public void doCreate()
  {
    String name=(String) create.getData();

    CourseSession session=new CourseSession();
    session.setSessionName(name);
    session.setIdTraining(idTraining);

    if(control.testCreate(session))
    {
      control.create(session);
      ((CourseSessionView) view).createSession(session);
      create.dispose();
      view.show();
    }
    else
    {
      TOMAError error=new TOMAError(labels.get("apostal.toma.sessionview.create.nameproblem"), labels.get("apostal.toma.sessionview.create.nameproblemtitle"));
    }
  }
}