// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import apostal.toma.TOMA;
import apostal.toma.view.TOMATree;
import apostal.toma.view.ImportTrainingView;
import apostal.toma.view.TrainingView;
import apostal.toma.datacontrol.ImportTEDControl;
import java.util.*;
import apostal.toma.external.XMLImport;
import javax.swing.*;
import apostal.ted.*;
import apostal.toma.database.TrainingDB;
import javax.swing.JTree;
import javax.swing.tree.*;
import apostal.toma.data.Catalogue;
import apostal.toma.data.TOMAConstants;

public class ImportTEDEventHandler extends WindowAdapter implements ActionListener {
    private TOMATreeControl treecontrol = new TOMATreeControl();
    private ImportTrainingView importView;
   // private TrainingView trview = new TrainingView();
    private ImportTEDControl control = new ImportTEDControl();
    private XMLImport imp = new XMLImport();

    public ImportTEDEventHandler(ImportTrainingView importView)
    {
      this.importView = importView;
    }

    public void actionPerformed(ActionEvent e)
    {
      boolean testcreate = true;
      boolean testreplace = false;
      String denomination;
      String actioncommand = e.getActionCommand();
      String action = getAction(actioncommand);
      if (action.compareTo("cancel")==0)
      {
        //quitter
        importView.dispose();
      }
      else if (action.compareTo("import")==0)
      {
        importView.saveChoiceLocation();
        importView.saveChoiceContact();
        importView.saveChoiceTeacher();
        importView.saveUnit();
        //Sauvegarder toutes les donnes dans un object
        TrainingXML t = importView.saveObjectTedXML();

        Vector vcat = importView.gestCatalogues();
        //test sur l'importation des locations
        boolean test = control.testLocations(t);
        //test sur l'importation des teachers
        test = test && control.testTeachers(t);
        //test sur l'importation des training contacts
        test = test && control.testContacts(t);
        //test sur l'importations des units
        test = test && control.testUnits(t);
        TOMA.log(TOMA.WARNING, "Test des units: " +test);
        //test si le domain est reconnu pas TOMA, pas de stop mais seulement message d'erreur
        control.testDomains(t);
        //test si le nom de l'organisme est celui de la BD
        control.testOrganism(t);
        // Si teacher, contact et locations  et domains sont ok
        if (test)
        {
            //test si la formation existe dj false = existe dj
            testcreate = control.testTraining(t);
            //Test si ecrase la foration existante, true = ecraser
            if(!testcreate)
            {
              testreplace = control.replaceTraining(t);
              // si true delete de l'ancienne formation
              if(testreplace)
              {
                //delete de la formation avec code = code de t
                control.deleteTraining(t);
              }
              //nouvelle testcreate
              testcreate = control.testTraining(t);
            }
            //si possible de creer
            if (testcreate){
              //debuggage
              TedXML ted=new TedXML();
              if(t instanceof apostal.ted.TrainingCourseXML)
                ted.addTrainingCourse((TrainingCourseXML) t);
              else
                ted.addTrainingProgramme((TrainingProgrammeXML) t);
              SaveXML save=new SaveXML(TOMAConstants.temporaryXMLFile);
              save.save(ted);

              //Importer les donnes
              imp.importTraining(t,vcat);
              //update Tree
              TOMATree tree=TOMA.getInstance().getTomaView().getTree();
              tree.getTree().treeDidChange();
              treecontrol.updateTree(tree.getTree().getClosestPathForLocation(0,0));
              //update Locations
              TrainingView.refreshLocations();
              //update Teachers
              TrainingView.refreshTeachers();
              //update Contacts
              TrainingView.refreshContacts();
              //quitter
              importView.dispose();
            }
         }
      }
      else if (action.compareTo("contact")==0)
      {
        importView.saveChoiceContact();
        importView.showContact();
      }
      else if (action.compareTo("location")==0)
      {
        importView.saveChoiceLocation();
        importView.showLocation();
      }
      else if (action.compareTo("teacher")==0)
      {
        importView.saveChoiceTeacher();
        importView.showTeacher();
      }
      else if (action.compareTo("unit")==0)
      {
        importView.saveUnit();
        importView.showUnit();
      }
      else if (action.compareTo("timport")==0)
      {
        importView.selecttimport();
      }
      else if (action.compareTo("limport")==0)
      {
        importView.selectlimport();
      }
      else if (action.compareTo("cimport")==0)
      {
        importView.selectcimport();
      }

    }

    //Action prcise dans le String
    public String getAction (String action)
    {
      int point = action.indexOf(".");
      return action.substring(point+1);
    }

    public void windowClosing(WindowEvent e) {
    }

    public void importTED() {
    }

    public void openFileChooser() {
    }

    public void openImportTraining() {
    }

    public void importTraining() {
    }

    public void importTEDFile() {

    }
}
