// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

import apostal.toma.TOMA;

import apostal.toma.view.LocationsView;
import apostal.toma.data.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.*;
import apostal.toma.datacontrol.LocationsControl;
import apostal.toma.view.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import apostal.toma.view.TeachersView;
import java.util.*;

public class LocationsEventHandler extends WindowAdapter implements ActionListener {
    private LocationsView locationsView;
    protected TOMALabels labels = new TOMALabels();
    private LocationsControl control = new LocationsControl();
    private CreateLocation create;
    private Vector locations;
    public boolean newLocation;
    public LocationsEventHandler(LocationsView locationsView)
    {
      this.locationsView = locationsView;
      locations = control.loadLocations(false);
    }

	public void refreshLocationsOtherLists()
	{
		TrainingView.refreshLocations();
	}


    public void actionPerformed(ActionEvent e)
    {
      String denomination;
      String actioncommand = e.getActionCommand();
      String action = getAction(actioncommand);
      if (action.compareTo("new")==0)
      {
        int result = 0;
        if (TOMA.getInstance().getTomaParameters().getOpenWarningWindow() && locationsView.locationSelected()){
                TOMAQuestion tq = new TOMAQuestion(TOMAFonts.htmlBegin+labels.get("apostal.toma.changeSelection.location.confirm")+TOMAFonts.htmlEnd,labels.get("apostal.toma.changeSelection.location.confirm.title"));
                result = tq.getResult();
            }
          if (result ==0){
                this.newLocation = true;
                create = new CreateLocation(this,this.locationsView);
                create.pack();
                create.center();
                create.show();
                //boolean possible = locationsView.createNew(denomination);
                // Create new Location in database
                //createLocation(denomination);
                // locationsView.alreadyWarned = true;
                this.refreshLocationsOtherLists();
          }
      }
      else if (action.compareTo("delete")==0)
      {
          deleteLocation();
          locationsView.oldLocation = null;
        this.refreshLocationsOtherLists();

      }
      else if (action.compareTo("save")==0)
      {
        //Sauvegarde des donnes du formulaire dans un object
        Location l = locationsView.save();
        saveLocation();
        this.refreshLocationsOtherLists();
      }
      else if (action.compareTo("create_ok")==0)
      {
        //Create new
          createLocation();
          locationsView.counterToZero();
        this.refreshLocationsOtherLists();
      //  this.newLocation = false;
      }
    }

    public void windowClosing(WindowEvent e) 
    {
        TOMAEventHandler tomaHandler=TOMA.getInstance().getHandler();
        tomaHandler.closeLocationsView();
        
        //unlock
        Location l=locationsView.getData();
        if(l!=null) //pas un cran "lock"
        {
            control.unlockLocation(l);
        }
    }

    public void openLocations() {
    }

    public void refreshLocations() {

    }

    public void openLocation() {

    }

    public void createLocation() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.location.error.creation.empty");
        String message2 = labels.get("apostal.toma.location.error.creation.exist");
        String title = labels.get("apostal.toma.location.error.creation.title");
        String denomination = (String)create.getData();
        // Try to unlock locked data
        try
        {
          Location data = locationsView.getData();
          control.unlockLocation(data);
        }
        catch(NullPointerException np){}

        //Test denomination pas vide
        if (denomination.compareTo("")==0)
        {
          error = new TOMAError(message1, title);
        }
        //test si le nom n'esiste pas encore
        else if (locationexists(denomination))
        {
          error = new TOMAError(message2, title);
        }
        // creation
        else
        {
          Location l = new Location();
          l.setDenomination(denomination);                    
          control.createLocation(l);
          create.hide();
          
          locationsView.show();
          locationsView.refresh();
          locationsView.selectLocation(l.getIdLocation());
        }
    }

    public void saveLocation() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.location.error.save.empty");
        String message2 = labels.get("apostal.toma.location.error.save.exist");
        String title = labels.get("apostal.toma.location.error.save.title");
        Location data = locationsView.getData();
        String denomination = data.getDenomination();
        
        LocationDB ldb=new LocationDB(data);
        //Test denomination pas vide
        boolean update=ldb.testUpdate();
        if (denomination.compareTo("")==0
            || !update
        )
        {
            if(update)
                error = new TOMAError(message1, title);
            else
                error = new TOMAError(message2, title);
            
            //recharger la denomination
            control.loadLocation(data, false);            
            locationsView.setData(data);
            locationsView.repaint();            
        }                
        /*else
        {
          control.saveLocation(data);
        }*/
        
        boolean ok=true;

        String template=this.testTemplate();
            if(template!=null)
            {
                //ouvrir la fenetre de demande de confirmation
                String qTitle=labels.get("apostal.toma.location.templateProblemTitle");
                TOMAQuestion question=new TOMAQuestion(template,qTitle);
                if(question.getResult()!=0)
                    ok=false;
            }
       if(ok)
        control.saveLocation(data);
    }
    
    /**
     * tests the template:
     * @return: the error message to display if it is incorrect. Otherwise null.
     */
    public String testTemplate()
    {
      //effectuer tous les tests
      String s=locationsView.testTemplateElements();
      if(s!=null && !s.equals(""))
      {
	String msg=labels.get("apostal.toma.location.templateProblem");
        msg=msg+"\n"+s;
        msg=msg+"\n\n"+labels.get("apostal.toma.location.templateProblemSave");
        
	return msg;
      }
      else
	return null;
    }      

    public void deleteLocation() {
        TOMAQuestion question;
        int result = 0;
        String question1 = labels.get("apostal.toma.location.error.delete.used");
        String question2 = labels.get("apostal.toma.location.error.delete.question");
        String title = labels.get("apostal.toma.location.error.save.title");
        Location data = locationsView.getData();
        String denomination = data.getDenomination();
        int id = data.getIdLocation();
        //Test lieu utilis
        if (control.isUsedInTraining(id))
        {
          question = new TOMAQuestion(question1 + " " +question2,title);
          result = question.getResult();
        }
        //delete du lieu
        if (result==0)
        {
          control.deleteLocation(data);
          locationsView.refresh();
          
          
        }
    }


    public boolean locationexists(String denomination)
    {
      /*boolean test = false;
      for (int i=0;i<locations.size();i++)
      {
        if (locations.elementAt(i).toString().compareTo(denomination)==0)
        {
          test = true;
        }
      }
      return test;*/
        Location l=new Location();
        l.setDenomination(denomination);
        LocationDB ldb=new LocationDB(l);
        return !ldb.testCreate();
    }

        //Ligne prcise dans le String
    public int getIndex(String action)
    {
       int index = 0;
       int point = action.indexOf(".");
       String substring = action.substring(0,point);
       try
       {
           index = Integer.parseInt(substring);
       }
       catch(NumberFormatException np)
       {
       }
       return index;
    }

    //Action prcise dans le String
    public String getAction (String action)
    {
      int point = action.indexOf(".");
      return action.substring(point+1);
    }
}
