// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */
import java.util.Vector;
import java.util.Iterator;
import java.lang.Thread;

import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;
import apostal.toma.external.SOAPPublication;
//import apostal.toma.external.SyrecosPublicationThread;

import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAWait;
import apostal.toma.view.TOMAOk;
import apostal.toma.view.TOMAFonts;


public class SOAPPublicationEventHandler
{
  private TOMALabels labels;
  private SOAPPublication soapPublication;

  public SOAPPublicationEventHandler(SOAPPublication soapPublication)
  {
    labels=new TOMALabels();
    this.soapPublication=soapPublication;
  }

  public boolean publish(boolean addFirstCat)
  {
    Vector trainings=soapPublication.getTrainings();
    boolean publish=true;
    boolean publishOk = false;
    
      String title=labels.get("apostal.toma.external.syrecos.title");
      String message=TOMAFonts.htmlBegin;
      Vector[] messages=soapPublication.getWarnings(soapPublication.getTrainings());
      Vector domains_warnings=messages[0];
      if(!domains_warnings.isEmpty())
      {
      message=message+"<p>"+labels.get("apostal.toma.external.syrecos.warning.domain")+"</p>";
      message=message+"<p>"+labels.get("apostal.toma.external.syrecos.warning.domain.trainings")+"</p><ul>";
      Iterator iter = domains_warnings.iterator();
      while (iter.hasNext())
      {
      Object item = iter.next();
      message=message+"<li>"+item.toString();
      }
      message=message+"</ul>";
      }
      Vector languages_warnings=messages[1];
      if(!languages_warnings.isEmpty())
      {
      message=message+"<br><p>"+labels.get("apostal.toma.external.syrecos.warning.language")+"</p>";
      message=message+"<p>"+labels.get("apostal.toma.external.syrecos.warning.language.sessions")+"</p><ul>";
      Iterator iter = languages_warnings.iterator();
      while (iter.hasNext())
      {
      Object item = iter.next();
      message=message+"<li>"+item.toString();
      }
      message=message+"</ul>";
      }

      message=message+"<br><p>"+labels.get("apostal.toma.external.syrecos.warning.continue")+TOMAFonts.htmlEnd;

      if(!domains_warnings.isEmpty() || !languages_warnings.isEmpty())
      {
        //TOMAQuestion q=new TOMAQuestion(message, title, javax.swing.JOptionPane.OK_CANCEL_OPTION);
        TOMAQuestion q=new TOMAQuestion(message, title, javax.swing.JOptionPane.OK_CANCEL_OPTION, true, 800, 400);
        int result=q.getResult();

        if(result==javax.swing.JOptionPane.OK_OPTION)
            publish=true;
        else
            publish=false;
      }    

    //faire la publication
    if(publish)
    {
        //ouvrir la fentre d'attente
	
    TOMAWaitThread waitCheck=new TOMAWaitThread(labels.get("apostal.toma.publication.publish.checkCompliance.message"), labels.get("apostal.toma.publication.publish.checkCompliance.title"));
    waitCheck.start();
    	try{waitCheck.join();}catch(Exception ex){}
    
    //preparer la transfo: lecture paramtres
    soapPublication.preparePublication();	
    	
	//faire la transfo XML
	soapPublication.publishXML(addFirstCat);
	waitCheck.close();    
	//warnings XML
	XMLPublicationEventHandler xmlpub=new XMLPublicationEventHandler();
	publish=xmlpub.interpretInternalXMLPublication(soapPublication.getXMLWarnings());

	//si on veut toujours continuer
	if(publish)
	{
	  TOMAWaitThread wait=new TOMAWaitThread(labels.get("apostal.toma.publication.publish.message"), labels.get("apostal.toma.publication.publish.title"));
		wait.start();
        try{wait.join();}catch(Exception ex){}
	  TOMA.log(TOMA.WARNING, "SOAP publishing");

	  soapPublication.publish();
	  //apostal.toma.external.SOAPClient client=new apostal.toma.external.SOAPClient("http://localhost:8080/axis/services/Portail", "urn:Portail", "echoFile");
	  //client.echoFile("TOMATemporaryFile.xml");	  
	  	  
	  //fermer le wait
	  wait.close();

	 String msg=soapPublication.getMessages();
	if(soapPublication.getResult())
	{

		publishOk=true;
        TOMAOk info = new TOMAOk(msg, labels.get("apostal.toma.publication.publish.ok.title"),true,800,400);
	//	TOMAOk info=new TOMAOk(msg, labels.get("apostal.toma.publication.publish.ok.title"));
	}

	else
	{
	//	TOMAError error=new TOMAError(msg, labels.get("apostal.toma.external.soap.error.title"));
        TOMAError error=new TOMAError(msg, labels.get("apostal.toma.external.soap.error.title"),true,800,400);
	}
			  
	}
	}
	return publishOk;
  }
}
