// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.viewcontrol;

import apostal.toma.TOMA;


import apostal.toma.view.*;

import apostal.toma.datacontrol.TOMAParametersControl;
import apostal.toma.datacontrol.CatalogueControl;
import apostal.toma.datacontrol.TrainingCourseControl;
import apostal.toma.datacontrol.TrainingProgrammeControl;
import apostal.toma.datacontrol.TrainingControl;
import apostal.toma.datacontrol.ImportTEDControl;
import apostal.toma.viewcontrol.TOMATreeControl;

import apostal.toma.data.TOMAConstants;
import apostal.toma.data.TOMAParameters;
import apostal.toma.data.TOMATemplate;
import apostal.toma.data.TOMALabels;
import apostal.toma.data.Training;
import apostal.toma.data.TOMAParameters;
import apostal.toma.data.Catalogue;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.TrainingProgramme;
import apostal.toma.data.Unit;

import apostal.toma.database.DatabaseFacilities;

import toolbox.util.BrowserControl;


import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import javax.swing.event.TreeSelectionListener;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.tree.TreePath;
import javax.swing.JComponent;
import javax.swing.JTree;
import javax.swing.JOptionPane;
import java.util.Iterator;
import java.util.Vector;
import java.util.Hashtable;
import java.io.File;

/**
 * event handler for:
 * - the toolbar buttons
 * - the menu
 * - the global frame
 * - the main tree
 */
public class TOMAEventHandler extends WindowAdapter implements ActionListener, TreeSelectionListener {

    private TOMATreeControl control;
    private TOMAView view;

    private TrainingCourse selectedTrainingCourse;
    private TrainingProgramme selectedTrainingProgramme;
    private Catalogue selectedCatalogue;

    private TrainingInCatalogueChooser chooseViewTraining;

    private TOMALabels labels;

    private ImportTEDControl importTedControl = new ImportTEDControl();
    private TreePath selectedPath;
    private boolean alreadyWarned;
    //crans aux
    LocationsView locationsView;
    TeachersView teachersView;
    ContactsView contactsView;
    OrganismView organismView;
    PublicationUnitsView publicationUnitsView;
    AboutView aboutView;

    public void closeAboutView() {
        aboutView = null;
    }

    public void closeLocationsView() {
        locationsView = null;
    }

    public void closeTeachersView() {
        teachersView = null;
    }

    public void closeContactsView() {
        contactsView = null;
    }

    public void closeOrganismView() {
        organismView = null;
    }

    public void closePublicationUnitsView() {
        publicationUnitsView = null;
    }

    public TOMAEventHandler() {
        control = new TOMATreeControl();
        labels = new TOMALabels();
    }

    public TOMAView openTOMAView() {
        view = new TOMAView(this, this);
        this.openRootTree();
        return view;
    }

    public void openRootTree() {
        TOMATree tree = control.createRootTree(true, true, true, true, true, TOMA.getInstance().getTomaParameters().getLanguage());
        tree.addTreeSelectionListener(this);
        view.setTree(tree);
    }

    public void valueChanged(TreeSelectionEvent e) {
        if (!alreadyWarned) {
            int result = 0;
            if (selectedPath != null && TOMA.getInstance().getTomaParameters().getOpenWarningWindow()) {
                TOMAQuestion testOpenWarning = new TOMAQuestion(TOMAFonts.htmlBegin + labels.get("apostal.toma.changeSelection.confirm") + TOMAFonts.htmlEnd, labels.get("apostal.toma.changeSelection.confirm.title"));
                result = testOpenWarning.getResult();
            }
            if (result == 0) {
                TreePath path = e.getPath();
                selectedPath = path;
                Object o = control.getSelection(path);
                if (o != null) {
                    this.unlock();
                    String className = o.getClass().getName();
                    TOMA.log(TOMA.WARNING, "------------" + className);
                    if (className.equals("apostal.toma.data.Catalogue")) {
                        // debug
                        //Catalogue c = (Catalogue)o;
                        //TOMA.log(TOMA.WARNING, c.getTitle() +"********");
                        this.openCatalogue((Catalogue) o);
                    } else if (className.equals("apostal.toma.data.TrainingCourse")) {
                        this.openTrainingCourse((TrainingCourse) o);
                    } else if (className.equals("apostal.toma.data.TrainingProgramme")) {
                        this.openTrainingProgramme((TrainingProgramme) o);
                    }
                }
                alreadyWarned = false;
            } else {
                alreadyWarned = true;
                view.getTree().getTree().setSelectionPath(selectedPath);
            }
        } else {
            alreadyWarned = false;
        }
    }

    public void unlock() {
        //dlocker les lments ouverts
        //(si ils sont vraiment ouverts et pas ouverts avec un message "lock")
        if (selectedCatalogue != null)
            (new CatalogueControl()).unlock(selectedCatalogue);
        if (selectedTrainingCourse != null)
            (new TrainingCourseControl()).unlock(selectedTrainingCourse);
        if (selectedTrainingProgramme != null)
            (new TrainingProgrammeControl()).unlock(selectedTrainingProgramme);

        //dsassigner
        this.selectedCatalogue = null;
        this.selectedTrainingCourse = null;
        this.selectedTrainingProgramme = null;

        //dlocker seulement si standalone
        TOMAParameters params = TOMA.getInstance().getTomaParameters();
        if (!params.isClientServer()) {

            DatabaseFacilities.unlockAll();
        }
    }

    public void openCatalogue(Catalogue c) {
        TOMA.log(TOMA.WARNING, "TOMAEventHandler.openCatalogue: id=" + new Integer(c.getIdCatalogue()));

        CatalogueControl control = new CatalogueControl();
        boolean locked = control.isLocked(c);
        TOMA.log(TOMA.WARNING, "locked? " + new Boolean(locked));
        if (!locked) {
            //control.loadCatalogue(c);
            //c=control.loadCatalogue(c.getIdCatalogue());
            //c=control.loadCatalogue(c.getIdCatalogue(), true, false);
            control.loadCatalogue(c, true, true);
            control.lock(c);

            CatalogueEventHandler handler = new CatalogueEventHandler();
            CatalogueView view = handler.openCatalogue(c);
            this.setContextualView(view);
            this.selectedCatalogue = c;
        } else {
            this.setContextualView(new TOMALocked(c));
        }
    }

    public void openTrainingCourse(TrainingCourse t) {
        TrainingCourseControl control = new TrainingCourseControl();
        if (!control.isLocked(t)) {

            control.loadTraining(t);
            control.lock(t);

            TrainingCourseEventHandler handler = new TrainingCourseEventHandler();
            TrainingCourseView view = handler.openTraining(t);
            this.setContextualView(view);

            this.selectedTrainingCourse = t;
        } else {
            this.setContextualView(new TOMALocked(t));
        }
    }

    public void openTrainingProgramme(TrainingProgramme t) {
        TrainingProgrammeControl control = new TrainingProgrammeControl();
        if (!control.isLocked(t)) {
            control.loadTraining(t);
            control.lock(t);

            TrainingProgrammeEventHandler handler = new TrainingProgrammeEventHandler();
            TrainingProgrammeAndUnitsView view = handler.openTraining(t);

            this.setContextualView(view);

            this.selectedTrainingProgramme = t;
        } else {
            this.setContextualView(new TOMALocked(t));
        }
    }

    public void setContextualView(JComponent component) {
        view.setContextualView(component);
    }

    public void openViewTraining() {
        chooseViewTraining = new TrainingInCatalogueChooser(labels.get("apostal.toma.viewtraining.chooseTraining"), labels.get("apostal.toma.viewtraining.chooseTraining.title"), labels.get("apostal.toma.viewtraining.chooseTraining.ok"), labels.get("apostal.toma.viewtraining.chooseTraining.cancel"), true, true, true, true, this);
        chooseViewTraining.changeActionCommand("view_ok");
        chooseViewTraining.pack();
        chooseViewTraining.setVisible(true);
    }

    public void doOpenViewTraining() {
        int id = chooseViewTraining.getIdTraining();
        chooseViewTraining.dispose();

        Training t = TrainingControl.getInstance(true, id);

        if (t != null) {
            String name = t.getClass().getName();
            if (name.equals("apostal.toma.data.TrainingCourse")) {
                TrainingCourse tc = (TrainingCourse) t;
                TrainingCourseControl control = new TrainingCourseControl();
                control.loadTrainingWithSessions(tc);
                ViewTrainingCourse viewtc = new ViewTrainingCourse(tc);
                viewtc.setVisible(true);
            } else if (name.equals("apostal.toma.data.TrainingProgramme")) {
                TrainingProgramme tp = (TrainingProgramme) t;
                TrainingProgrammeControl control = new TrainingProgrammeControl();
                control.loadTrainingWithSessions(tp);
                ViewTrainingProgramme viewtp = new ViewTrainingProgramme(tp);
                viewtp.setVisible(true);
            }
        }
    }

    public void actionPerformed(ActionEvent e) {
        String cmd = e.getActionCommand();
        if (cmd.equals("view")) {
            this.openViewTraining();
        } else if (cmd.equals("view_ok")) {
            this.doOpenViewTraining();
        } else if (cmd.equals("import")) {
            importTedControl.openFile();
            //ImportTrainingView importView = new ImportTrainingView();
        } else if (cmd.equals("parameters")) {
            TOMAParametersEventHandler handler = new TOMAParametersEventHandler();
            handler.openTOMAParameters();
        } else if (cmd.equals("quit")) {
            this.quit();
        } else if (cmd.equals("locations")) {
            //LocationsView locations=new LocationsView();
            if (locationsView == null) {
                locationsView = new LocationsView();
                locationsView.pack();
            } else
                locationsView.show();
        } else if (cmd.equals("contacts")) {
            //ContactsView contacts=new ContactsView();
            if (contactsView == null) {
                contactsView = new ContactsView();
                contactsView.pack();
            } else
                contactsView.show();
        } else if (cmd.equals("teachers")) {
            //TeachersView teachers=new TeachersView();
            if (teachersView == null) {
                teachersView = new TeachersView();
                teachersView.pack();
            } else
                teachersView.show();
        } else if (cmd.equals("organism")) {
            //OrganismView organism=new OrganismView();
            if (organismView == null) {
                organismView = new OrganismView();
                organismView.pack();
            } else
                organismView.show();
        } else if (cmd.equals("publicationUnits")) {
            //PublicationUnitsView publicationUnits=new PublicationUnitsView();
            if (publicationUnitsView == null) {
                publicationUnitsView = new PublicationUnitsView();
                publicationUnitsView.pack();
            } else
                publicationUnitsView.show();
        } else if (cmd.equals("help")) {
            File fileTemp = new File(TOMAConstants.helpPath);
            String path = fileTemp.getAbsolutePath();
            TOMAParameters param = TOMA.getInstance().getTomaParameters();
            String browser = param.getBrowser();
            if (browser != null) {
                if (!(browser.compareTo("") == 0)) {
                    BrowserControl.displayURL(path, browser);
                } else {
                    BrowserControl.displayURL("file://" + path, null);
                }
            } else {
                BrowserControl.displayURL("file://" + path, browser);
            }
        } else if (cmd.equals("about")) {

            if (aboutView == null) {
                aboutView = new AboutView(labels.get("apostal.toma.aboutview.title"));
                aboutView.pack();
                aboutView.center();
                aboutView.show();
            } else
                aboutView.show();
        }
    }

    public void quit() {
        //todo: cran de confirmation
        TOMAQuestion question = new TOMAQuestion(TOMAFonts.htmlBegin + labels.get("apostal.toma.quit.confirm") + TOMAFonts.htmlEnd, labels.get("apostal.toma.quit.confirm.title"));
        if (question.getResult() == JOptionPane.YES_OPTION) {
            this.unlock();

            //fermer la connection
            apostal.toma.database.TOMADatabase.close();

            System.exit(0);
        }
    }

    public void windowClosing(WindowEvent e) {
        this.quit();
    }

    public TOMATemplate openTemplate() {
        TOMATemplate template = new TOMATemplate();
        String title = labels.get("apostal.toma.template.problem.title");

        TOMA.log(TOMA.WARNING, "TOMAEventHandler.openTemplate");

        boolean ok = template.aTemplateFileIsGiven();
        if (ok) {
            ok = template.openTemplateDocument();
            if (!ok) {
                //message d'erreur: erreur de lecture (fichier introuvable ou corrompu ou IOEXception)
                String message = TOMAFonts.htmlBegin + labels.get("apostal.toma.template.documentProblem") + TOMAFonts.htmlEnd;
                TOMAError error = new TOMAError(message, title);
            } else {
                ok = template.isTemplateValid();
                if (!ok) {
                    //message d'erreur: template non valide + erreurs
                    String message = TOMAFonts.htmlBegin + labels.get("apostal.toma.template.validityProblem");

                    //ajouter les messages d'erreur
                    Vector messages = template.getValidationMessages();
                    Iterator it = messages.iterator();
                    while (it.hasNext()) {
                        String msg = (String) it.next();
                        message = message + "<P>" + msg + "</P>";
                    }
                    message = message + "<BR/>" + TOMAFonts.htmlEnd;

                    TOMAError error = new TOMAError(message, title, true, 700, 300);
                } else {
                    ok = template.load();
                    if (!ok) {
                        //message d'erreur: load error
                        String message = labels.get("apostal.toma.template.loadProblem");
                        TOMAError error = new TOMAError(message, title);
                    }
                }
            }
        }
        return template;
    }

    public void updateTree() {
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
        TreePath path = tree.getSelectionPath();
        control.updateTree(path);
    }
}
