// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/*
* TOMAFirstRunEventHandler.java
*
* Created on February 25, 2002, 4:32 PM
*/

package apostal.toma.viewcontrol;

import apostal.toma.data.TOMAConstants;
import apostal.toma.data.Language;
import apostal.toma.data.Organism;
import apostal.toma.database.LanguageDB;
import apostal.toma.database.OrganismDB;
import apostal.toma.database.TOMADatabase;
import apostal.toma.view.TOMAFirstRun;
import apostal.toma.view.TOMAFirstRunServerProblem;
import apostal.toma.view.TOMAFirstRunSyrecosProblem;
import apostal.toma.view.TOMAFirstRunSOAPProblem;

import apostal.toma.external.SyrecosExtractionClient;
import apostal.toma.external.XMLImport;
import apostal.toma.external.SOAPExtraction;

import apostal.toma.TOMA;
import apostal.toma.TOMAServer;
import apostal.toma.view.TOMAView;

import apostal.ted.LoadXML;

import java.util.Properties;
import java.util.Vector;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.File;

import java.awt.event.*;

/**
*
* @author  ramel
*/
public class TOMAFirstRunEventHandler implements ActionListener{
	
	private static String syrecosWaitMessage="Please wait while your data is being extracted from Syrecos";
	private static String syrecosWaitTitle="Syrecos data extraction";
	private static String soapWaitMessage="Please wait while your data is being extracted from a SOAP server";
	private static String soapWaitTitle="SOAP data extraction";
	
	/** Creates a new instance of TOMAFirstRunEventHandler */
	private TOMAFirstRun run;
	
	private int type;
	
	private TOMAFirstRunServerProblem server_pb;
	private TOMAFirstRunSyrecosProblem syrecos_pb;
	private TOMAFirstRunSOAPProblem soap_pb;    
	
	//donnes  mettre dans le fichier de proprits
	private String languageCode=null;
	private String exportationLanguageCode=null;    
	private String server=null;    
	
	public TOMAFirstRunEventHandler(TOMAFirstRun run) {
		this.run=run;
	}
	
	public void actionPerformed(ActionEvent e)
	{
		String cmd=e.getActionCommand();
		if(cmd!=null)
		{
			/*if(cmd.equals("syrecos"))
			{
				run.showSyrecosLoginPanel();
			}
			else */
				if(cmd.equals("soap"))
			{
				run.showSOAPLoginPanel();
			}            
			else if(cmd.equals("no"))
			{
				run.showOrganismPanel();
			}            
			else if(cmd.equals("ok"))
			{
				this.ok();
			}            
			else if(cmd.equals("ok_server"))
			{                
				if(server_pb!=null)
				{
					server_pb.dispose();
					server=server_pb.getServer();
					this.tryServer();
				}
			}                
			else if(cmd.equals("ok_syrecos"))
			{
				if(syrecos_pb!=null)
				{
					syrecos_pb.dispose();
					String login=syrecos_pb.getLogin();
					String pwd=new String(syrecos_pb.getPassword());
					this.trySyrecos(login, pwd);
				}
			}                            
			else if(cmd.equals("cancel_syrecos"))
			{
				this.continueTOMA();
			}        
			else if(cmd.equals("ok_soap"))
			{
				if(soap_pb!=null)
				{
					soap_pb.dispose();
					String login=soap_pb.getLogin();
					String pwd=new String(soap_pb.getPassword());
					this.trySOAP(login, pwd);
				}
			}                            
			else if(cmd.equals("cancel_soap"))
			{
				this.continueTOMA();
			}                                               
		}
	}
	
	public void ok()
	{
		boolean quitter=true;
		
		run.dispose();
		
		type=run.getType();
		
		if(type==TOMAFirstRun.CLIENT || type==TOMAFirstRun.SINGLESTATION)
		{            
			//rcuprer la langue + langue d'exportation
			Language lng=(Language) run.getLanguageSelected();
			if(lng!=null)
			{
				languageCode=lng.getCode();
				exportationLanguageCode=lng.getCode();
			}
		}
		
		if(type==TOMAFirstRun.CLIENT)
		{           
			//noter le chemin du serveur
			server=run.getServer();
		}        
		
		//sauver le props dans le fichier si client ou singlestation
		if(type!=TOMAFirstRun.SERVER)
		{
			this.writeProperties();
		}
		else
		{
			try{
				File f=new File(TOMAConstants.parametersFile);
				f.delete();
			}catch(Exception ex)
			{ //si on ne peut pas le dtruire
				
				Properties props=new Properties();
				try{
					FileOutputStream fout=new FileOutputStream(TOMAConstants.parametersFile);
					if(fout!=null)
					{
						props.store(fout, "");
						fout.flush();
						fout.close();
					}
					
				}catch(Exception ex2)
				{}                
			}
		}
		
		// partir d'ici, la base doit tre accessible!                
		if(type==TOMAFirstRun.CLIENT)        
		{
			//faire un test
			boolean pb=false;           
			if(!TOMADatabase.tryConnection())
			{
				//resauver l'ancien fichier
				this.writePropertyFirstRunType(TOMAFirstRun.CLIENT);
				
				//redemander le chemin du server
				server_pb=new TOMAFirstRunServerProblem(this, server);
				
				quitter=false;
			}
		}
		
		if(type==TOMAFirstRun.SERVER || type==TOMAFirstRun.SINGLESTATION)
		{
			Language lng=new Language("eng");
			
			//faire l'extraction Syrecos si demande
			/*if(run.isSyrecosSelected())
			{
				//effacer temporaryXMLFile
				try{
					File f=new File(TOMAConstants.temporaryXMLFile);
					f.delete();
				}catch(Exception ex)
				{}
				
				TOMAWaitThread wait=new TOMAWaitThread(TOMAFirstRunEventHandler.syrecosWaitMessage, TOMAFirstRunEventHandler.syrecosWaitTitle);
				wait.start();
				try{wait.join();}catch(Exception ex){}
				
				//extraire les donnes
				SyrecosExtractionClient ex=new SyrecosExtractionClient();
				char[] pwd=run.getSyrecosPassword();                    
				String password=new String(pwd);
				String login=run.getSyrecosLogin();
				ex.extract(login, password, TOMAConstants.temporaryXMLFile);
				
				//tester le fichier dans TOMAConstants.temporaryXMLFile
				LoadXML l=new LoadXML(TOMAConstants.temporaryXMLFile);
				File f=new File(TOMAConstants.temporaryXMLFile);
				boolean exists=f.exists();
				if(exists)
					l.setDifferentTedFilename(TOMAConstants.temporaryXMLFile, TOMAConstants.tedFilename);
				if(exists && l.validate())
				{
					//faire le first import
					XMLImport importer=new XMLImport();
					importer.doFirstImport(TOMAConstants.temporaryXMLFile);                                                
					
					wait.close();
				}
				else
				{
					wait.close();
					
					//redemander le login/password + warnings
					syrecos_pb=new TOMAFirstRunSyrecosProblem(this, login, password);
					quitter=false;
				}
			}  
			else */if(run.isSOAPSelected())
			{

				
				TOMAWaitThread wait=new TOMAWaitThread(TOMAFirstRunEventHandler.soapWaitMessage, TOMAFirstRunEventHandler.soapWaitTitle);
				wait.start();
				try{wait.join();}catch(Exception ex){}
				
				//fichier de donnes: fichier temporaire ! (sinon, parfois pb sous Windows)
				String filename=this.getTargetFile();
				
				//extraire les donnes
				String login=run.getSOAPLogin();
				String pwd=new String(run.getSOAPPassword());
				SOAPExtraction extraction=new SOAPExtraction(login, pwd, filename);
				boolean ok=extraction.extract();
				
				if(ok)
				{
					//tester le fichier dans TOMAConstants.temporaryXMLFile
					LoadXML l=new LoadXML(filename);
					boolean exists=(new File(filename)).exists();
					if(exists)
						l.setDifferentTedFilename(filename, TOMAConstants.tedFilename);
					if(exists && l.validate())
					{
						//faire le first import
						XMLImport importer=new XMLImport();
						importer.doFirstImport(filename);                                                
						
						wait.close();
					}
					else
					{
						wait.close();
						//redemander le login/password + warnings
						syrecos_pb=new TOMAFirstRunSyrecosProblem(this, login, pwd);
						quitter=false;
					}            
				}
				else
				{
					wait.close();
					//redemander le login/password + warnings
					soap_pb=new TOMAFirstRunSOAPProblem(this, login, pwd);
					quitter=false;
				}
			}
			//sinon, organisme
			else
			{   
				String denom=run.getOrganismDenomination();
				
				Organism o=OrganismDB.getOrganism(lng, true);
				if(o==null)
				{
					o=new Organism();                
					o.setDenomination(denom);
					OrganismDB odb=new OrganismDB(o);
					if(odb.testCreate())
						odb.create();
				}
				else
				{
					o.setDenomination(denom);
					OrganismDB odb=new OrganismDB(o);
					if(odb.testUpdate())
						odb.update();                
				}
			}
		}
		
		//quitter
		if(quitter)
			this.continueTOMA();
	}    
	
	public void continueTOMA()
	{
		TOMADatabase.close();       
		//System.exit(0);    
		
		if(type==TOMAFirstRun.SERVER)
		{
			TOMAServer.runServer();
		}
		else
		{
			TOMA toma=TOMA.getInstance();
			TOMAView view=toma.openTomaView();             
		}
	}
	
	public void tryServer()
	{
		//crit le nouveau chemin du serveur, les langues, ...
		this.writeProperties();
		
		// partir d'ici, la base doit tre accessible!                
		//faire un test
		boolean pb=false;           
		if(!TOMADatabase.tryConnection())
		{
			//resauver l'ancien fichier
			this.writePropertyFirstRunType(TOMAFirstRun.CLIENT);
			
			//redemander le chemin du server
			server_pb=new TOMAFirstRunServerProblem(this, server);                
		}
		else
			this.continueTOMA();
	}
	
	public void trySyrecos(String login, String password)
	{
		Language lng=new Language("eng");
		
		TOMAWaitThread wait=new TOMAWaitThread(TOMAFirstRunEventHandler.syrecosWaitMessage, TOMAFirstRunEventHandler.syrecosWaitTitle);
		wait.start();    
		try{wait.join();}catch(Exception ex){}
		
		//fichier de donnes: fichier temporaire ! (sinon, parfois pb sous Windows)
		String filename=this.getTargetFile();
		
		//extraire les donnes
		SyrecosExtractionClient ex=new SyrecosExtractionClient();
		ex.extract(login, password, filename);
                
		//tester le fichier dans TOMAConstants.temporaryXMLFile
		LoadXML l=new LoadXML(filename);
		boolean exists=(new File(filename)).exists();
		if(exists)
			l.setDifferentTedFilename(filename, TOMAConstants.tedFilename);
		if(exists && l.validate())	    
                {
			//faire le first import
			XMLImport importer=new XMLImport();
			importer.doFirstImport(filename);                                                
			
			wait.close();
			
			this.continueTOMA();
                }
		else
                {
			wait.close();
			
			//redemander le login/password + warnings
			syrecos_pb=new TOMAFirstRunSyrecosProblem(this, login, password);
                }    
	}
	public void trySOAP(String login, String password)
	{
		Language lng=new Language("eng");            
		
		TOMAWaitThread wait=new TOMAWaitThread(TOMAFirstRunEventHandler.soapWaitMessage, TOMAFirstRunEventHandler.soapWaitTitle);
		wait.start();    
		try{wait.join();}catch(Exception ex){}
		
		//fichier de donnes: fichier temporaire ! (sinon, parfois pb sous Windows)
		String filename=this.getTargetFile();				
		
		//extraire les donnes
		SOAPExtraction extraction=new SOAPExtraction(login, password, filename);
		boolean ok=extraction.extract();
		
		if(ok)
		{
			//tester le fichier dans TOMAConstants.temporaryXMLFile
			LoadXML l=new LoadXML(filename);
			boolean exists=(new File(filename)).exists();
	    		if(exists)
				l.setDifferentTedFilename(filename, TOMAConstants.tedFilename);
			if(exists && l.validate())	    
			{
				//faire le first import
				XMLImport importer=new XMLImport();
				importer.doFirstImport(filename);                                                
				
				wait.close();
				
				this.continueTOMA();
			}
			else
			{
				wait.close();
				
				//redemander le login/password + warnings
				soap_pb=new TOMAFirstRunSOAPProblem(this, login, password);
			}    
		}
		
	}    
	
	/**
	* @return target filename in which the result willm be written
	**/
	private String getTargetFile(){
		String path=null;
		try{
			File tempFile=File.createTempFile("toma-temp", ".xml", new File(""));
			tempFile.deleteOnExit();
			path=tempFile.getAbsolutePath();
		}catch(java.io.IOException ex){
			System.out.println("IOException while trying to create temp file: "+ex.getMessage());
			path=TOMAConstants.temporaryXMLFile;
		}
		return path;
	}
	
	public void writePropertyFirstRunType(int type)
	{
		Properties props=new Properties();
		
		if(type==TOMAFirstRun.CLIENT)
			props.put("firstRunType", "client");
		else if(type==TOMAFirstRun.SERVER)
			props.put("firstRunType", "server");
		else if(type==TOMAFirstRun.SINGLESTATION)
			props.put("firstRunType", "singlestation");          
		
		//sauver le props dans le fichier        
		try{
			FileOutputStream fout=new FileOutputStream(TOMAConstants.parametersFile);
			if(fout!=null)
			{
				props.store(fout, "TOMA Parameters. Only edit if you know what you are doing...");
				fout.flush();
				fout.close();
			}
		}catch(Exception ex)
		{}                    
	}
	
	public void writeProperties()
	{
		Properties props=new Properties();
		
		// tester
		props.setProperty("tomaPath", ".");
		
		props.put("languageCode", languageCode);
		props.put("exportationLanguageCode", exportationLanguageCode);        
		props.put("openWarningWindow",new String("true"));
		if(server!=null && !server.equals(""))
			props.put("server", server);
		
		try{
			FileOutputStream fout=new FileOutputStream(TOMAConstants.parametersFile);
			if(fout!=null)
			{
				props.store(fout, "TOMA Parameters. Only edit if you know what you are doing...");
				fout.flush();
				fout.close();
			}
		}catch(Exception ex)
		{}
	}
}
