// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/*
 * (c) Copyright 2001 MyCorporation.
 * All Rights Reserved.
 */
package apostal.toma.viewcontrol;

import apostal.toma.database.DatabaseFacilities;
import apostal.toma.database.TOMADatabase;
import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.TOMAFonts;
import apostal.toma.view.TOMAServerView;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JOptionPane;
import java.lang.Thread;

/**
 * @version 	1.0
 * @author
 */
public class TOMAServerEventHandler implements ActionListener
{
	private TOMAServerView view;
	private ServerThread serverThread;
	
	public TOMAServerEventHandler()
	{
		serverThread=new ServerThread();	
		serverThread.start();
		
		view=new TOMAServerView(this);
	}
	
	
	public void actionPerformed(ActionEvent e)
	{
		if(e!=null)
		{
			String cmd=e.getActionCommand();
			if(cmd.equals("quit"))
			{
				this.quit();
			}
			else if(cmd.equals("unlock"))
			{
				this.unlock();
			}
		}
	}
	
	public void quit()
	{
		String msg=TOMAFonts.htmlBegin+"<P>Are you sure you want to stop the TOMA server?</P><P>Please check that nobody is using TOMA before continuing.</P>"+TOMAFonts.htmlEnd;
		TOMAQuestion question=new TOMAQuestion(msg, "Stop TOMA Server");
		if(question.getResult()==JOptionPane.OK_OPTION)
		{
			view.dispose();
			TOMADatabase db=TOMADatabase.getInstance(true);
			db.shutdown(true);
			System.exit(0);
		}
	}
	
	public void unlock()
	{
		String msg=TOMAFonts.htmlBegin+"<P>Are you sure you want to unlock TOMA's data?</P><P>Please check that nobody is using TOMA before continuing.</P>"+TOMAFonts.htmlEnd;	
		TOMAQuestion question=new TOMAQuestion(msg, "Unlock TOMA Data");
		if(question.getResult()==JOptionPane.OK_OPTION)
		{
			DatabaseFacilities.unlockAll(true);
		}	
	}	
}

class ServerThread extends Thread
{
	public ServerThread()
	{
		
	}
	
	public void run()
	{
         String[] options={"-database", "toma"};
         org.hsqldb.Server.main(options);  		
	}
}