// TOMA, v1.0 - 07/2002
//
// TOMA (Training Offer Management Application) is a Java application
// to manage training offers and all the related data
// (organism data, locations, animators, contacts, ...).
// It also allows to publish the data in different formats:
// 	- XML (in the "TED" format, "Training Exchange Definition",
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
//
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Contact Information:
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;


import apostal.toma.TOMA;
import apostal.toma.view.*;
import apostal.toma.data.*;
import apostal.toma.database.*;

import apostal.toma.datacontrol.CatalogueControl;
import apostal.toma.datacontrol.TrainingControl;

import java.util.Vector;
import java.util.Iterator;

import javax.swing.tree.*;

import java.lang.Class;

public class TOMATreeControl {
    public CatalogueTreeNode createTreeNode(Catalogue catalogue, CatalogueTreeNode parent, boolean seeCourses, boolean seeProgrammes) {
        CatalogueTreeNode node = null;
        if (parent != null)
            node = new CatalogueTreeNode(parent, catalogue.getIdCatalogue(), catalogue.getTitle(), seeCourses, seeProgrammes);
        else
            node = new CatalogueTreeNode(catalogue.getIdCatalogue(), catalogue.getTitle(), seeCourses, seeProgrammes);
        Vector data = new Vector();
        //catalogues
        Vector cats = catalogue.getCatalogues();
        int nbCatalogues = 0;
        if (cats != null) {
            nbCatalogues = cats.size();
            Iterator it = cats.iterator();
            while (it.hasNext()) {
                Catalogue c = (Catalogue) it.next();
                CatalogueTreeNode subnode = this.createTreeNode(c, node, seeCourses, seeProgrammes);
                data.add(subnode);
            }
        }
        //trainings
        if (seeCourses || seeProgrammes) {
            Vector trainings = catalogue.getTrainings();
            if (trainings != null) {
                Iterator it = trainings.iterator();
                while (it.hasNext()) {
                    Training t = (Training) it.next();
                    Class cl_course = null;
                    Class cl_programme = null;
                    try {
                        cl_course = Class.forName("apostal.toma.data.TrainingCourse");
                        cl_programme = Class.forName("apostal.toma.data.TrainingProgramme");
                    } catch (java.lang.ClassNotFoundException ex) {
                        //jamais atteind
                    }
                    if ((cl_course.isInstance(t) && seeCourses)) {
                        TrainingTreeNode tr = new TrainingTreeNode(node, t.getIdTraining(), t.getTitle(), t.getCode(), catalogue.getIdCatalogue(), TrainingTreeNode.TRAININGCOURSE);
                        data.add(tr);
                    } else if (cl_programme.isInstance(t) && seeProgrammes) {
                        TrainingTreeNode tr = new TrainingTreeNode(node, t.getIdTraining(), t.getTitle(), t.getCode(), catalogue.getIdCatalogue(), TrainingTreeNode.TRAININGPROGRAMME);
                        data.add(tr);
                    }
                }
            }
        }
        node.setData(data, nbCatalogues);
        return node;
    }

    public TOMATree createTree(boolean seeCourses, boolean seeProgrammes, boolean selectCatalogues, boolean selectCourses, boolean selectProgrammes, Catalogue catalogue) {
        CatalogueTreeNode node = this.createTreeNode(catalogue, null, seeCourses, seeProgrammes);
        TOMATree tree = new TOMATree(selectCatalogues, selectCourses, selectProgrammes, node);
        return tree;
    }

    public TOMATree createRootTree(boolean seeCourses, boolean seeProgrammes, boolean selectCatalogues, boolean selectCourses, boolean selectProgrammes, Language language) {
        Catalogue catalogue = CatalogueDB.getRootCatalogue(language, true);

        CatalogueTreeNode node = this.createTreeNode(catalogue, null, seeCourses, seeProgrammes);

        TOMATree tree = new TOMATree(selectCatalogues, selectCourses, selectProgrammes, node);

        return tree;
    }

    public Object getSelection(TreePath path) {
        TOMA.log(TOMA.WARNING, "TOMAEventHandler.getSelection");
        Object value = null;
        Object o = path.getLastPathComponent();
        if (o != null) {
            String className = o.getClass().getName();
            if (className.equals("apostal.toma.view.CatalogueTreeNode")) {
                CatalogueTreeNode node = (CatalogueTreeNode) o;
                CatalogueControl control = new CatalogueControl();
                //value=control.loadCatalogue(node.getIdCatalogue());
                value = control.loadCatalogue(node.getIdCatalogue(), false, false);
                //Catalogue c=new Catalogue(node.getIdCatalogue());
                //value = new Catalogue(node.getIdCatalogue());
            } else if (className.equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode node = (TrainingTreeNode) o;
                value = TrainingControl.getInstance(false, node.getIdTraining());
            } else
                TOMA.log(TOMA.SEVERE, "TOMATreeControl.getSelection, className=" + className);
        }
        return value;
    }

    /**
     * methods to be used by EventHandlers
     */

    public void updateTrainingNodeView(Training t) {
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
        Object o = tree.getLastSelectedPathComponent();
        if (o != null && t != null) {
            String title = t.getTitle();
            String code = t.getCode();

            String name = o.getClass().getName();
            if (name.equals("apostal.toma.view.TrainingTreeNode")) {
                TrainingTreeNode node = (TrainingTreeNode) o;
                node.setTitle(title);
                node.setCode(code);
            }
            tree.repaint();
        } else
            TOMA.log(TOMA.SEVERE, "updateTrainingNodeView, o=" + o + ", t=" + t);
    }

    public void updateCatalogueNodeView(Catalogue c) {
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();
        Object o = tree.getLastSelectedPathComponent();
        if (o != null && c != null) {
            String title = c.getTitle();

            String name = o.getClass().getName();
            if (name.equals("apostal.toma.view.CatalogueTreeNode")) {
                CatalogueTreeNode node = (CatalogueTreeNode) o;
                node.setTitle(title);
            }
            tree.repaint();
        } else
            TOMA.log(TOMA.SEVERE, "updateCatalogueNodeView, o=" + o + ", c=" + c);
    }

    public void deleteNode() {
        TOMATree tomaTree = TOMA.getInstance().getTomaView().getTree();
        TOMAJTree tree = tomaTree.getTree();
        TreePath path = tree.getSelectionPath();
        if (path != null) {
            Object deleted = path.getLastPathComponent();
            TreePath parent = path.getParentPath();
            Object o = parent.getLastPathComponent();
            if (o != null) {
                String name = o.getClass().getName();
                if (name.equals("apostal.toma.view.CatalogueTreeNode")) {
                    CatalogueTreeNode node = (CatalogueTreeNode) o;
                    node.removeNode(deleted);

                    TOMA.getInstance().getTomaView().setTree(tomaTree);

                    tomaTree.getTree().setSelectionRow(0);
                } else
                    TOMA.log(TOMA.SEVERE, "deleteNode, name=" + name);
            } else
                TOMA.log(TOMA.SEVERE, "deleteNode, lastPathComponent=null");
        } else
            TOMA.log(TOMA.SEVERE, "deleteNode, path=null");
    }

    public void addTrainingNodeToDesktop(Training t) {

        if (t != null) {
            TOMATree tree = TOMA.getInstance().getTomaView().getTree();
            TreePath selection = tree.getTree().getSelectionPath();
            CatalogueTreeNode root = tree.getRoot();

            if (root != null) {
                int type = TrainingTreeNode.TRAININGCOURSE;
                if (t.getClass().getName().equals("apostal.toma.data.TrainingProgramme")) {
                    type = TrainingTreeNode.TRAININGPROGRAMME;
                } else if (t.getClass().getName().equals("apostal.toma.data.Unit"))
                    type = TrainingTreeNode.UNIT;

                TrainingTreeNode node = new TrainingTreeNode(root, t.getIdTraining(), t.getTitle(), t.getCode(), root.getIdCatalogue(), type);
                root.addTrainingTreeNode(node);
                DefaultTreeModel model = new DefaultTreeModel(root);
                tree.getTree().setModel(model);
                TOMA.getInstance().getTomaView().setTree(tree);

                tree.getTree().setSelectionPath(selection);
            } else
                TOMA.log(TOMA.SEVERE, "addTrainingNodeToDesktop: root node=null !");
        } else
            TOMA.log(TOMA.SEVERE, "addTrainingNodeToDesktop, t=" + t);

    }

    /**
     * gets the selected path and if it is a catalogue, adds the training
     */
    public void addTrainingNode(Training t) {
        if (t != null) {
            TOMATree tomaTree = TOMA.getInstance().getTomaView().getTree();
            TOMAJTree tree = tomaTree.getTree();
            TreePath path = tree.getSelectionPath();
            Object o = path.getLastPathComponent();
            if (o != null) {
                try {
                    CatalogueTreeNode c = (CatalogueTreeNode) o;

                    int type = TrainingTreeNode.TRAININGCOURSE;
                    if (t.getClass().getName().equals("apostal.toma.data.TrainingProgramme"))
                        type = TrainingTreeNode.TRAININGPROGRAMME;
                    else if (t.getClass().getName().equals("apostal.toma.data.Unit"))
                        type = TrainingTreeNode.UNIT;

                    TrainingTreeNode node = new TrainingTreeNode(c, t.getIdTraining(), t.getTitle(), t.getCode(), c.getIdCatalogue(), type);
                    c.addTrainingTreeNode(node);
                    TOMA.getInstance().getTomaView().setTree(tomaTree);
                    tomaTree.getTree().setSelectionPath(path);
                } catch (java.lang.ClassCastException ex) {
                    TOMA.log(TOMA.SEVERE, "addTrainingNode: the last path component wasn't a CatalogueTreeNode:" + ex.getMessage());
                }
            } else
                TOMA.log(TOMA.SEVERE, "addTrainingNode, o=null");
        }
    }


    public void updateTree(TreePath selection) {
        TOMA toma = TOMA.getInstance();
        toma.getHandler().openRootTree();

        //maj slection
        TreePath path = this.getNewPath(selection);

        TOMATree tomaTree = toma.getTomaView().getTree();
        TOMAJTree tree = tomaTree.getTree();
        if (path != null) {
            tree.expandPath(path);
            TOMA.log(TOMA.WARNING, "path " + path + " has been expanded: " + new Boolean(tree.hasBeenExpanded(path)));
            TOMA.log(TOMA.WARNING, "path " + path + " is expanded: " + new Boolean(tree.isExpanded(path)));

            tree.setSelectionPath(path);
            TOMA.log(TOMA.WARNING, "path " + path + " is selected: " + new Boolean(tree.isPathSelected(path)));
        } else {
            tree.setSelectionRow(0);
        }
    }

    /**
     * returns the path in the tree corresponding to the old path in the old tree
     */
    public TreePath getNewPath(TreePath old) {
        TreePath newPath = null;
        boolean found = false;
        TOMAJTree tree = TOMA.getInstance().getTomaView().getTree().getTree();

        Object o = old.getLastPathComponent();
        String name = o.getClass().getName();

        if (!name.equals("apostal.toma.view.TrainingTreeNode") && !name.equals("apostal.toma.view.CatalogueTreeNode")) {
            TOMA.log(TOMA.SEVERE, "getNewPath.className=" + name);
        } else {
            TOMA.log(TOMA.WARNING, "getNewPath, classe=CatalogueTreeNode ou TrainingTreeNode");

            //chercher tous les fils
            int cpt = tree.getRowCount();
            int i = 0;
            while (i < cpt && !found) {
                newPath = tree.getPathForRow(i);
                TOMA.log(TOMA.WARNING, "getNewPath, parcours des path: newPath=" + newPath);

                Object o2 = newPath.getLastPathComponent();
                String name2 = o2.getClass().getName();
                if (name2.equals(name)) {
                    TOMA.log(TOMA.WARNING, "getNewPath, parcours des path, classe identique=" + name2);
                    if (o.equals(o2)) {
                        found = true;
                        TOMA.log(TOMA.WARNING, "getNewPath, parcours des path, objet gaux: " + o2);
                    }
                }
                i++;
            }
        }

        if (found)
            return newPath;
        else
            return null;
    }

}
