// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

import apostal.toma.view.TeachersView;
import apostal.toma.data.*;
import apostal.toma.data.TOMALabels;
import apostal.toma.database.*;
import apostal.toma.datacontrol.TeachersControl;
import apostal.toma.view.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import apostal.toma.view.TeachersView;
import apostal.toma.TOMA;
import java.util.*;

public class TeachersEventHandler extends WindowAdapter implements ActionListener {
    private TeachersView teachersView;
    protected TOMALabels labels = new TOMALabels();
    private TeachersControl control = new TeachersControl();
    private CreateTeacher create;
    private Vector teachers;

    public TeachersEventHandler(TeachersView teachersView)
    {
      this.teachersView = teachersView;
      teachers = control.loadTeachers(false);
    }

	public void refreshTeachersOtherLists()
	{
		TrainingView.refreshTeachers();		
	}

    public void actionPerformed(ActionEvent e)
    {
      String actioncommand = e.getActionCommand();
      String action = getAction(actioncommand);
      if (action.compareTo("new")==0)
      {
        int result = 0;
        if (TOMA.getInstance().getTomaParameters().getOpenWarningWindow() && teachersView.teacherSelected()){
            TOMAQuestion tq = new TOMAQuestion(TOMAFonts.htmlBegin+labels.get("apostal.toma.changeSelection.teacher.confirm")+TOMAFonts.htmlEnd,labels.get("apostal.toma.changeSelection.teacher.confirm.title"));
            result = tq.getResult();
        }
        if (result==0){
            create = new CreateTeacher(this,this.teachersView);
            create.pack();
            create.center();
            create.show();
            //boolean possible = teachersView.createNew(denomination);
            // Create new Teacher in database
            //createTeacher(denomination);
            this.refreshTeachersOtherLists();
        }
      }
      else if (action.compareTo("delete")==0)
      {
        deleteTeacher();
	this.refreshTeachersOtherLists();        
      }
      else if (action.compareTo("save")==0)
      {
        //Sauvegarde des donnes du formulaire dans un object
        Teacher t = teachersView.save();
        saveTeacher();
	this.refreshTeachersOtherLists();
      }
      else if (action.compareTo("create_ok")==0)
      {
        //Create new
        createTeacher();
	this.refreshTeachersOtherLists();
      }
    }

    public void windowClosing(WindowEvent e) 
    {
        TOMAEventHandler tomaHandler=TOMA.getInstance().getHandler();
        tomaHandler.closeTeachersView();
        
       //unlock
        Teacher t=teachersView.getData();
        if(t!=null) //pas un cran "lock"
        {
            control.unlockTeacher(t);
        }           
    }    

    public void openTeachers() {
    }

    public void refreshTeachers() {

    }

    public void openTeacher() {

    }

    public void createTeacher() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.teacher.error.save.empty");
        String message2 = labels.get("apostal.toma.teacher.error.save.exist");
        String title = labels.get("apostal.toma.teacher.error.creation.title");
        String firstname = create.getFirstname();
        String lastname = create.getLastname();
        String function = create.getFunction();
        // Try to unlock locked data
        try
        {
          Teacher data = teachersView.getData();
          control.unlockTeacher(data);
        }
        catch(NullPointerException np){}
        //Test denomination pas vide
        if (firstname.compareTo("")==0)
        {
          error = new TOMAError(message1, title);
        }
        //test si le nom n'esiste pas encore
        else if (teacherexists(firstname, lastname, function))
        {
          error = new TOMAError(message2, title);
        }
        // creation
        else
        {
          Teacher t = new Teacher();
          t.setFirstname(create.getFirstname());
          t.setLastname(create.getLastname());
          t.setFunction(create.getFunction());
          control.createTeacher(t);
          create.hide();
          
          teachersView.show();
          teachersView.refresh();
          teachersView.selectTeacher(t.getIdTeacher());
        }
    }

    public void saveTeacher() {
        TOMAError error;
        String message1 = labels.get("apostal.toma.teacher.error.save.empty");
        String message2 = labels.get("apostal.toma.teacher.error.save.exist");
        String title = labels.get("apostal.toma.teacher.error.save.title");
        Teacher data = teachersView.getData();
        String lastname = data.getLastname();
        int id = data.getIdTeacher();
        TeacherDB tdb=new TeacherDB(data);
        
        boolean update=tdb.testUpdate();
        //Test denomination pas vide
        if (lastname.compareTo("")==0
            && !update
        )
        {
            if(update)
                error = new TOMAError(message1, title);
            else
                error = new TOMAError(message2, title);
          
            //recharger l'id sec
            control.loadTeacher(data, false);            
            teachersView.setData(data);
            teachersView.repaint();              
        }
        /*// creation
        else
        {
          control.saveTeacher(data);
          //teachersView.refresh();
        }*/
        boolean ok=true;
        String template=this.testTemplate();
            if(template!=null)
            {
                //ouvrir la fenetre de demande de confirmation
                String qTitle=labels.get("apostal.toma.teacher.templateProblemTitle");
                TOMAQuestion question=new TOMAQuestion(template,qTitle);
                if(question.getResult()!=0)
                    ok=false;
            }
       if(ok)
        control.saveTeacher(data);      
    }

    /**
     * tests the template:
     * @return: the error message to display if it is incorrect. Otherwise null.
     */
    public String testTemplate()
    {
      //effectuer tous les tests
      String s=teachersView.testTemplateElements();
      if(s!=null && !s.equals(""))
      {
	String msg=labels.get("apostal.toma.teacher.templateProblem");
        msg=msg+"\n"+s;
        msg=msg+"\n\n"+labels.get("apostal.toma.teacher.templateProblemSave");
        
	return msg;
      }
      else
	return null;
    }     
    
    public void deleteTeacher() {
        TOMAQuestion question;
        int result = 0;
        String question1 = labels.get("apostal.toma.teacher.error.delete.used");
        String question2 = labels.get("apostal.toma.teacher.error.delete.question");
        String title = labels.get("apostal.toma.teacher.error.save.title");
        Teacher data = teachersView.getData();
        int id = data.getIdTeacher();
        //Test lieu utilis
        if (control.isUsedInTraining(id))
        {
          question = new TOMAQuestion(question1 + " " +question2,title);
          result = question.getResult();
        }
        //delete du lieu
        if (result==0)
        {
          control.deleteTeacher(data);
          
          //maj de la liste
          teachersView.refresh();
        }
    }


    public boolean teacherexists(String firstname, String lastname, String function)
    {
      /*
      boolean test = false;
      for (int i=0;i<teachers.size();i++)
      {
        if (teachers.elementAt(i).toString().compareTo(firstname)==0)
        {
          test = true;
        }
      }
      return test;*/
        
          Teacher t = new Teacher();
          t.setFirstname(create.getFirstname());
          t.setLastname(create.getLastname());
          t.setFunction(create.getFunction());
          
          TeacherDB tdb=new TeacherDB(t);
          return !tdb.testCreate();
    }

        //Ligne prcise dans le String
    public int getIndex(String action)
    {
       int index = 0;
       int point = action.indexOf(".");
       String substring = action.substring(0,point);
       try
       {
           index = Integer.parseInt(substring);
       }
       catch(NumberFormatException np)
       {
       }
       return index;
    }

    //Action prcise dans le String
    public String getAction (String action)
    {
      int point = action.indexOf(".");
      return action.substring(point+1);
    }
}
