// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;

import java.lang.String;
import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;
import apostal.toma.view.CatalogueTreeNode;
import apostal.toma.view.TrainingTreeNode;
import apostal.toma.view.TrainingCourseDuplication;
import apostal.toma.view.TrainingView;
import apostal.toma.view.TrainingCourseView;
import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.TOMAError;
import apostal.toma.view.CourseSessionView;
import apostal.toma.view.TOMAFileChooser;
import apostal.toma.view.TOMAFileFilter;

import apostal.toma.datacontrol.PublicationsControl;
import apostal.toma.viewcontrol.TOMATreeControl;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.TrainingCourse;
import apostal.toma.data.Catalogue;
import apostal.toma.data.CourseSession;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.TOMATemplateResult;

import apostal.toma.datacontrol.TrainingCourseControl;
import apostal.toma.datacontrol.PublicationsControl;

public class TrainingCourseEventHandler extends TrainingEventHandler
{
  private TrainingCourseControl control;

  private TrainingView trainingView;
  private TrainingCourseDuplication duplication;

  public TrainingCourseEventHandler(TrainingCourseView trainingCourseView)
    {
      this.trainingView=trainingCourseView;
      control=new TrainingCourseControl();
    }

  public TrainingCourseEventHandler()
  {
    control=new TrainingCourseControl();
  }

  public TrainingView getView()
  {
    return trainingView;
  }

    public void actionPerformed(ActionEvent e) {
    String cmd=e.getActionCommand();
    if(cmd!=null)
    {
      if(cmd.equals("save"))
      {
	this.save();
      }
      else if(cmd.equals("delete"))
      {
	this.delete();
      }
      else if(cmd.equals("duplicate"))
      {
	this.duplicate();
      }
      else if(cmd.equals("duplicate_ok"))
      {
	this.doDuplication();
      }
      else if(cmd.equals("export"))
      {
	this.export();
      }
      else if(cmd.equals("sessions"))
      {
	this.openSessions();
      }
    }
    }

    public void windowClosing(WindowEvent e) {
    }


/************* Actions ***********************/

    public TrainingCourseView openTraining(int idTraining)
    {
      //charger la formation
      TrainingCourse tc=control.loadTraining(idTraining);

      return this.openTraining(tc);
    }

    public TrainingCourseView openTraining(TrainingCourse tc)
    {
      //la mettre ds l'attribut
      this.training=tc;

      //mettre les donnes
      //TOMA.printTime("opening tc view");
      trainingView=new TrainingCourseView();
      //TOMA.printTime("tc view opened, setting data");
      ((TrainingCourseView) trainingView).setData(tc);
      //TOMA.printTime("tc view, data set");

      return ((TrainingCourseView) trainingView);
    }


    /*public void export()
    {
      TOMAFileChooser chooser=new TOMAFileChooser(TOMA.getInstance().getTomaView(), labels.get("apostal.toma.trainingview.export.title"), labels.get("apostal.toma.trainingview.export.ok"), labels.get("apostal.toma.trainingview.export.cancel"));
      TOMAFileFilter filter=new TOMAFileFilter(TOMAFileFilter.xml);
      chooser.addTOMAFileFilter(filter);
      int ret=chooser.showSaveDialog();
      if (ret == TOMAFileChooser.APPROVE)
	 {
	    PublicationsControl pubControl=new PublicationsControl();
	    Vector errors=pubControl.export(training, chooser.getSelectedFile());
	    if(errors!=null && !errors.isEmpty())
	    {
	      String message=labels.get("apostal.toma.export.errors.message");
	      Iterator iter = errors.iterator();
	      while (iter.hasNext())
	      {
		String error= (String) iter.next();
		message=message+error+"\n";
	      }
	      TOMAError error=new TOMAError(message, labels.get("apostal.toma.export.errors.title"));
	    }
	 }
    }*/

    public void duplicate() {
      duplication=new TrainingCourseDuplication(this, (TrainingCourse) training,TOMA.getInstance().getTomaView());
      duplication.pack();
      duplication.show();
    }

    public void doDuplication()
    {
        Vector v = new Vector();
        v = (Vector)duplication.getData();
        TrainingCourse  t=(TrainingCourse) v.elementAt(0);
        boolean withSession = ((Boolean)v.elementAt(1)).booleanValue();
        boolean ok=control.duplicate(t,withSession);
      if(!ok)
	{
	  //message d'erreur
	  TOMAError error=new TOMAError(labels.get("apostal.toma.trainingview.duplicate.codeproblem"), labels.get("apostal.toma.trainingview.duplicate.codeproblemtitle"));
	}
      else
      {
	duplication.dispose();

	//maj arbre
	TOMATreeControl control=new TOMATreeControl();
	control.addTrainingNodeToDesktop(t);
      }
    }

    public void openSessions()
    {
      TrainingCourse tc=(TrainingCourse) this.training;
      //recharger les sessions?
      //pour les sessions -> oui
      //pour les autres donnes -> ne pas perdre les info rentres. Prendre en compte les dernires valeurs
      TrainingCourse tc2=control.loadTraining(tc.getIdTraining());

      CourseSessionEventHandler handler=new CourseSessionEventHandler();
      handler.openSessions(tc2);
    }

    public void delete() {
	//cran de confirmation
	TOMALabels labels=new TOMALabels();
	TOMAQuestion question=new TOMAQuestion(labels.get("apostal.toma.trainingcourseview.delete"), labels.get("apostal.toma.trainingcourseview.delete.title"));
	int result=question.getResult();

	//delete
	if(result==0)
	{
	  TrainingCourse tc=(TrainingCourse) this.training;
	  ((TrainingCourseView) trainingView).getData(tc);
	  control.delete(tc);

	  //todo: changer l'cran en cours
	  trainingView.setVisible(false);

	  //maj arbre
	  /*TOMATreeControl control=new TOMATreeControl();	 
	  control.deleteNode();*/
          TOMA.getInstance().getHandler().updateTree();
	}
    }

    public void save() {
      //rcuprer les donnes
      TrainingCourse tc=(TrainingCourse) this.training;
      ((TrainingCourseView) trainingView).getData(tc);

      boolean ok=control.testSave(tc);
      if(!ok)
      {
        TOMAError tomaerror=new TOMAError(labels.get("apostal.toma.trainingview.saveproblem"), labels.get("apostal.toma.trainingview.saveproblemTitle"));
      }
      else
      {
        //vrifier le template avant & mettre le warning si ncessaire
	String template=this.testTemplate();
	if(template!=null)
	{
	   //ouvrir la fenetre de demande de confirmation
	   String title=labels.get("apostal.toma.trainingview.templateProblemTitle");

	   TOMAQuestion question=new TOMAQuestion(template,title);
	   if(question.getResult()!=0)
	   {
	      ok=false;
	    }
        }

      //sauvegarde
      if(ok)
      {
	  control.save(tc);
	  //maj arbre
	  TOMATreeControl control=new TOMATreeControl();	
	  control.updateTrainingNodeView(tc);
      }
      }
    }


    /*public void refreshTeachers() {
    }

    public void refreshContacts() {
    }

    public void refreshLocations() {
    }*/


    /**
     * tests the template:
     * @return: the error message to display if it is incorrect. Otherwise null.
     */
    public String testTemplate()
    {
      //effectuer tous les tests
      String s=trainingView.testTemplateElements();
      if(s!=null && !s.equals(""))
      {
	String msg=labels.get("apostal.toma.trainingview.templateProblem");

        msg=msg+"\n"+s;

        msg=msg+"\n\n"+labels.get("apostal.toma.trainingview.templateProblemSave");

	return msg;
      }
      else
	return null;
    }

}
