// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

/* Generated by Together */

package apostal.toma.viewcontrol;

import apostal.toma.TOMA;

import apostal.toma.view.UnitView;
import apostal.toma.view.TrainingProgrammeAndUnitsView;
import apostal.toma.view.TOMAError;
import apostal.toma.view.TOMAQuestion;

import apostal.toma.viewcontrol.TrainingEventHandler;
import apostal.toma.viewcontrol.TrainingProgrammeEventHandler;

import apostal.toma.data.TOMALabels;
import apostal.toma.data.Unit;
import apostal.toma.data.TrainingProgramme;

import apostal.toma.datacontrol.UnitControl;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.Vector;

public class UnitEventHandler extends TrainingEventHandler implements ActionListener {

    private UnitControl control;
    private Unit unit;
    private UnitView view;

    public UnitEventHandler(UnitView view, Unit unit)
    {
      this.view=view;
      this.unit=unit;

      control=new UnitControl();
    }

    public void actionPerformed(ActionEvent e)
    {
      String cmd=e.getActionCommand();
      if(cmd!=null)
      {
        if(cmd.equals("save"))
        {
	  this.save();
        }
        else if(cmd.equals("delete"))
        {
	  this.delete();
        }
        else if(cmd.equals("sessions"))
        {
	  this.openSessions();
        }
      }
    }

    public void delete()
    {
	//cran de confirmation
	TOMALabels labels=new TOMALabels();
	TOMAQuestion question=new TOMAQuestion(labels.get("apostal.toma.unitview.delete"), labels.get("apostal.toma.unitview.delete.title"));
	int result=question.getResult();

	//delete
	if(result==0)
	{
          view.getData(unit);
	  control.delete((TrainingProgramme) TrainingEventHandler.getTraining(), unit);

	  //pas besoin de changer l'cran en cours: le JTabbedPane s'en charge
	  TrainingProgrammeAndUnitsView tpView=view.getTpView();
	  tpView.removeUnit(view);
	}
    }

    public void save() {
      //rcuprer les donnes
      view.getData(unit);

      boolean ok=control.testSave(unit);

      //vrifier le template avant & mettre le warning si ncessaire
      if(!ok)
      {
	TOMAError tomaerror=new TOMAError(labels.get("apostal.toma.trainingview.saveproblem"), labels.get("apostal.toma.trainingview.saveproblemTitle"));
      }
      else
      {
	String template=this.testTemplate();
	if(template!=null)
	{
	   //ouvrir la fenetre de demande de confirmation
	   String title=labels.get("apostal.toma.trainingview.templateProblemTitle");

	   TOMAQuestion question=new TOMAQuestion(template,title);
	   if(question.getResult()!=0)
	   {
	      ok=false;
	    }
	}
      }

      //sauvegarde
      if(ok)
      {
	  control.save(unit);
	  //pas besoin de maj de l'arbre
      }
    }

    public void openSessions()
    {
      //recharger les sessions?
      //pour les sessions -> oui
      //pour les autres donnes -> ne pas perdre les info rentres. Prendre en compte les dernires valeurs
      Unit u2=control.loadUnit(unit.getIdTraining());

      UnitSessionEventHandler handler=new UnitSessionEventHandler();
      handler.openSessions(u2);
    }

    /**
     * tests the template:
     * @return: the error message to display if it is incorrect. Otherwise null.
     */
    public String testTemplate()
    {
      //effectuer tous les tests
      String s=view.testTemplateElements();
      if(s!=null && !s.equals(""))
      {
	String msg=labels.get("apostal.toma.trainingview.templateProblem");

        msg=msg+"\n"+s;

        msg=msg+"\n\n"+labels.get("apostal.toma.trainingview.templateProblemSave");

	return msg;
      }
      else
	return null;
    }
}
