// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

import java.awt.event.WindowEvent;

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;
import apostal.toma.data.Unit;
import apostal.toma.data.UnitSession;
import apostal.toma.data.TrainingProgramme;

import apostal.toma.database.UnitDB;
import apostal.toma.database.UnitSessionDB;

import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.TOMAError;
import apostal.toma.view.UnitSessionView;
import apostal.toma.view.CreateSession;
import apostal.toma.view.CreateConsecSessionsView;

import apostal.toma.datacontrol.UnitSessionControl;
import apostal.toma.datacontrol.UnitControl;

public class UnitSessionEventHandler extends SessionEventHandler
{

  private UnitSessionControl control;
  private CreateConsecSessionsView ccSesssionView;

  private static boolean sessionsOpened;

  public void windowClosing(WindowEvent e)
  {
      sessionsOpened=false;
  }

  public UnitSessionEventHandler()
  {
    control=new UnitSessionControl();
  }

  public void openSessions(Unit u)
  {
    if(!sessionsOpened)
    {

      sessionsOpened=true;
      UnitSessionView session=new UnitSessionView(this);
      if(u!=null)
      {
	//charger tout
	Iterator iter = u.getUnitSessions().iterator();
	while (iter.hasNext())
	{
	  UnitSession s = (UnitSession) iter.next();
	  control.loadSession(s);
	}

	UnitControl ucontrol=new UnitControl();
  	TrainingProgramme tp=ucontrol.getTrainingProgramme(u);
        session.setData(tp, u);
	this.idTraining=u.getIdTraining();
      }
      else
	TOMA.log(TOMA.SEVERE, "unit was null when opening sessions");

      session.pack();
      session.setVisible(true);
      SessionEventHandler.view=session;
    }
  }

  public void save()
  {
      UnitSession s=((UnitSessionView) view).getData();

      if(control.testSave(s))
      {
	boolean ok=true;

        String template=this.testTemplate();
	if(template!=null)
	{
	   //ouvrir la fenetre de demande de confirmation
	   String title=labels.get("apostal.toma.sessionview.templateProblemTitle");

	   TOMAQuestion question=new TOMAQuestion(template,title);
	   if(question.getResult()!=0)
	    ok=false;
	}

	if(ok)
	  control.saveSession(s);
      }
      else
      {
        TOMAError error=new TOMAError(labels.get("apostal.toma.sessionview.saveproblem"), labels.get("apostal.toma.sessionview.saveproblemtitle"));
      }
  }

  public void delete()
  {
    TOMAQuestion question=new TOMAQuestion(labels.get("apostal.toma.sessionview.delete.message"), labels.get("apostal.toma.sessionview.delete.title"));
    if(question.getResult()==0)
    {
      UnitSession s=((UnitSessionView) view).getData();

      //delete BD
      control.deleteSession(s);

      //maj liste + changer la session slectionne
      ((UnitSessionView) view).deleteSession(s);
    }
  }

  public void create()
  {
    create=new CreateSession(this,this.view);
    create.pack();
    create.center();
    create.show();
  }

  public void addSeancesConsec(){
  	ccSesssionView = new CreateConsecSessionsView(this,this.view);
	ccSesssionView.pack();
	ccSesssionView.center();
	ccSesssionView.show();
  }
  public void doAddSeancesConsec(){
		/*ccSesssionView = new CreateConsecSessionsView(this,this.view);
		ccSesssionView.pack();
		ccSesssionView.center();
		ccSesssionView.show();*/
		((UnitSessionView)view).addSeancesConsec(ccSesssionView.getData());
		ccSesssionView.dispose();
		view.show();
		
	}
  
  public void doCreate()
  {
    String name=(String) create.getData();

    UnitSession session=new UnitSession();
    session.setSessionName(name);
    session.setIdTraining(idTraining);

    if(control.testCreate(session))
    {
      control.create(session);
      ((UnitSessionView) view).createSession(session);
      create.dispose();
      view.show();
    }
    else
    {
      TOMAError error=new TOMAError(labels.get("apostal.toma.sessionview.create.nameproblem"), labels.get("apostal.toma.sessionview.create.nameproblemtitle"));
    }
  }
}