// TOMA, v1.0 - 07/2002
// 
// TOMA (Training Offer Management Application) is a Java application 
// to manage training offers and all the related data 
// (organism data, locations, animators, contacts, ...). 
// It also allows to publish the data in different formats: 
// 	- XML (in the "TED" format, "Training Exchange Definition", 
// 			http://binux.tudor.lu:8080/XML/ted.xsd)
// 	- PDF
// 	- RTF
// 	- HTML
// 
// Copyright (C) 2002 CRP Henri Tudor, Luxembourg
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program (file gpl.txt); if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Contact Information: 
// 	Address:    CRP Henri Tudor
// 			6 rue Coudenhove-Kalergi
// 			L - 1359 Luxembourg
// 	Email: 		toma@tudor.lu

package apostal.toma.viewcontrol;

import java.util.Vector;
import java.util.Iterator;

import apostal.toma.TOMA;
import apostal.toma.data.TOMALabels;

import apostal.toma.view.TOMAQuestion;
import apostal.toma.view.TOMAFonts;

/**
 * Title:        TOMA
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      CRP Henri Tudor
 * @author
 * @version 1.0
 */

public class XMLPublicationEventHandler
{
  private TOMALabels labels;

  public XMLPublicationEventHandler()
  {
    labels=new TOMALabels();
  }

  /**
   * interprets the XML publication warnings for internal transformations,
   * such as save on Syrecos or to HTML, PDF or RTF files.
   * @returns true if the publication must be continued despite eventual warnings
   */
  public boolean interpretInternalXMLPublication(Vector warnings)
  {
    boolean continuePub=true;
	if(warnings!=null && !warnings.isEmpty())
	{
	  TOMA.log(TOMA.WARNING, "There were warnings during XML Publication");
	  String message=TOMAFonts.htmlBegin+labels.get("apostal.toma.tomatoted.warning")+"</p><ul>";
	  Iterator iter = warnings.iterator();
	  while (iter.hasNext())
	  {
	    String warning = (String) iter.next();
	    message=message+"<li>"+warning+"</li>";
	  }
	  message=message+"</ul><p>"+labels.get("apostal.toma.tomatoted.warning.continue")+TOMAFonts.htmlEnd;
	  String title=labels.get("apostal.toma.tomatoted.warning.title");
	  
          TOMAQuestion question=new TOMAQuestion(message, title, javax.swing.JOptionPane.OK_CANCEL_OPTION, true, 800, 400);
	  int result=question.getResult();

	  if(result==javax.swing.JOptionPane.OK_OPTION)
	    continuePub=true;
	  else
	    continuePub=false;
	}
	else
	  TOMA.log(TOMA.WARNING, "The XML Publication worked: no warnings");

    return continuePub;
  }
}